(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16327,        604]*)
(*NotebookOutlinePosition[     16958,        626]*)
(*  CellTagsIndexPosition[     16914,        622]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        RowBox[{\(c14 : \ Limit\ cycle\ of\ the\ Van\ der\ Pol\ equation\), 
          ",", " ", \((2.   .6  .61)\), ",", " ", 
          RowBox[{
          "page", " ", "78", " ", "in", "\[IndentingNewLine]", "the", " ", 
            "book", " ", "Mathematical", " ", "Methods", " ", "in", " ", 
            "Physics", " ", "and", " ", "Engineering", " ", "with", " ", 
            StyleBox["Mathematica",
              FontSlant->"Italic"]}], 
          StyleBox[",",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], \(CRC\ Press\), ",", 
          StyleBox[" ",
            FontSlant->"Italic"], \(ISBN\ 1584884029\)}], " ", "*)"}], 
      " ", \(Clear[mu, n]\)}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(mu = 1. ; n = 2. ;\), "\[IndentingNewLine]", 
    \(\(Sol = 
        NDSolve[{\(x1'\)[t] \[Equal] 
              x2[t], \(x2'\)[t] \[Equal] \(-x1[t]\) + 
                mu*\((1 - \((x1[t])\)^2)\)*x2[t], x1[0] \[Equal] n, 
            x2[0] \[Equal] 0}, \[IndentingNewLine]{x1, x2}, {t, 0, 
            8. *Pi}];\)\), "\[IndentingNewLine]", 
    \(ParametricPlot[
      Evaluate[{x1[t], x2[t]} /. Sol], {t, 0, 4. *Pi}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499997 0.237076 0.309016 0.109879 [
[.02584 .29652 -6 -9 ]
[.02584 .29652 6 0 ]
[.26292 .29652 -6 -9 ]
[.26292 .29652 6 0 ]
[.73707 .29652 -3 -9 ]
[.73707 .29652 3 0 ]
[.97415 .29652 -3 -9 ]
[.97415 .29652 3 0 ]
[.4875 .08926 -12 -4.5 ]
[.4875 .08926 0 4.5 ]
[.4875 .19914 -12 -4.5 ]
[.4875 .19914 0 4.5 ]
[.4875 .41889 -6 -4.5 ]
[.4875 .41889 0 4.5 ]
[.4875 .52877 -6 -4.5 ]
[.4875 .52877 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02584 .30902 m
.02584 .31527 L
s
[(-2)] .02584 .29652 0 1 Mshowa
.26292 .30902 m
.26292 .31527 L
s
[(-1)] .26292 .29652 0 1 Mshowa
.73707 .30902 m
.73707 .31527 L
s
[(1)] .73707 .29652 0 1 Mshowa
.97415 .30902 m
.97415 .31527 L
s
[(2)] .97415 .29652 0 1 Mshowa
.125 Mabswid
.07326 .30902 m
.07326 .31277 L
s
.12067 .30902 m
.12067 .31277 L
s
.16809 .30902 m
.16809 .31277 L
s
.21551 .30902 m
.21551 .31277 L
s
.31034 .30902 m
.31034 .31277 L
s
.35775 .30902 m
.35775 .31277 L
s
.40517 .30902 m
.40517 .31277 L
s
.45258 .30902 m
.45258 .31277 L
s
.54741 .30902 m
.54741 .31277 L
s
.59483 .30902 m
.59483 .31277 L
s
.64224 .30902 m
.64224 .31277 L
s
.68966 .30902 m
.68966 .31277 L
s
.78449 .30902 m
.78449 .31277 L
s
.8319 .30902 m
.8319 .31277 L
s
.87932 .30902 m
.87932 .31277 L
s
.92673 .30902 m
.92673 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .08926 m
.50625 .08926 L
s
[(-2)] .4875 .08926 1 0 Mshowa
.5 .19914 m
.50625 .19914 L
s
[(-1)] .4875 .19914 1 0 Mshowa
.5 .41889 m
.50625 .41889 L
s
[(1)] .4875 .41889 1 0 Mshowa
.5 .52877 m
.50625 .52877 L
s
[(2)] .4875 .52877 1 0 Mshowa
.125 Mabswid
.5 .11123 m
.50375 .11123 L
s
.5 .13321 m
.50375 .13321 L
s
.5 .15519 m
.50375 .15519 L
s
.5 .17716 m
.50375 .17716 L
s
.5 .22111 m
.50375 .22111 L
s
.5 .24309 m
.50375 .24309 L
s
.5 .26506 m
.50375 .26506 L
s
.5 .28704 m
.50375 .28704 L
s
.5 .33099 m
.50375 .33099 L
s
.5 .35297 m
.50375 .35297 L
s
.5 .37494 m
.50375 .37494 L
s
.5 .39692 m
.50375 .39692 L
s
.5 .44087 m
.50375 .44087 L
s
.5 .46285 m
.50375 .46285 L
s
.5 .48482 m
.50375 .48482 L
s
.5 .5068 m
.50375 .5068 L
s
.5 .06728 m
.50375 .06728 L
s
.5 .04531 m
.50375 .04531 L
s
.5 .02333 m
.50375 .02333 L
s
.5 .00136 m
.50375 .00136 L
s
.5 .55075 m
.50375 .55075 L
s
.5 .57273 m
.50375 .57273 L
s
.5 .5947 m
.50375 .5947 L
s
.5 .61668 m
.50375 .61668 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97415 .30902 m
.97409 .30569 L
.97395 .30279 L
.97367 .29959 L
.97331 .29671 L
.97289 .29417 L
.97244 .29191 L
.97119 .28713 L
.96963 .28272 L
.96759 .27829 L
.96512 .27404 L
.96259 .2705 L
.95672 .26414 L
.9495 .25833 L
.93443 .24968 L
.91582 .24193 L
.89304 .23421 L
.84511 .21947 L
.71835 .17399 L
.52184 .08068 L
.45026 .04871 L
.40596 .03266 L
.38401 .02626 L
.3631 .02132 L
.3445 .018 L
.33399 .01662 L
.32437 .01568 L
.31381 .01503 L
.30784 .01485 L
.30231 .01481 L
.29218 .01505 L
.28142 .01577 L
.27124 .01693 L
.26031 .01869 L
.25006 .02087 L
.24074 .02331 L
.21946 .03061 L
.19775 .04073 L
.16117 .06461 L
.13125 .09148 L
.10133 .12628 L
.07797 .16033 L
.04798 .21731 L
.03701 .24507 L
.03015 .26728 L
.02766 .27759 L
.02592 .28659 L
.0252 .29123 L
.0246 .29604 L
.02421 .3002 L
Mistroke
.02399 .30387 L
.02387 .30749 L
.02388 .31074 L
.02397 .31353 L
.02415 .31643 L
.02445 .31946 L
.02488 .3225 L
.02533 .32498 L
.0259 .32757 L
.02755 .33311 L
.02939 .33767 L
.0319 .34242 L
.03462 .34647 L
.04015 .35278 L
.04705 .3586 L
.06156 .36725 L
.07997 .37509 L
.12379 .38934 L
.23453 .42555 L
.39781 .49785 L
.51965 .55667 L
.55895 .57305 L
.58157 .58133 L
.6035 .58836 L
.62445 .594 L
.63563 .59654 L
.64756 .59883 L
.65767 .60044 L
.66306 .60115 L
.66884 .60182 L
.67904 .6027 L
.68859 .60318 L
.69934 .60331 L
.70477 .60319 L
.71076 .60293 L
.72132 .60209 L
.73121 .60085 L
.74274 .59884 L
.75324 .59644 L
.77653 .58908 L
.79498 .5811 L
.81451 .57041 L
.85114 .54333 L
.88079 .5137 L
.90784 .47931 L
.94402 .41807 L
.95808 .38631 L
.96705 .36075 L
.97063 .34794 L
.97311 .33703 L
Mistroke
.97487 .3267 L
.97549 .32165 L
.97575 .31893 L
.97593 .31652 L
.97613 .31263 L
.97619 .30869 L
.97612 .30517 L
.97594 .30212 L
.97579 .30031 L
.97562 .2987 L
.97512 .2952 L
.97457 .29228 L
.97387 .28936 L
.97234 .28446 L
.97063 .2803 L
.96845 .27613 L
.96581 .27207 L
.9597 .26505 L
.95318 .25957 L
.94522 .25438 L
.93595 .24955 L
.89767 .2353 L
.80373 .206 L
.65606 .1462 L
.55845 .0985 L
.49089 .0661 L
.45443 .05031 L
.41939 .03703 L
.40063 .03091 L
.37987 .0251 L
.3616 .02092 L
.35181 .01909 L
.34124 .01744 L
.33537 .01668 L
.32998 .01609 L
.31941 .01523 L
.31372 .01493 L
.30751 .01475 L
.30164 .01472 L
.29621 .01481 L
.28564 .01533 L
.27609 .01622 L
.26512 .01775 L
.25486 .01969 L
.23385 .02531 L
.22345 .02895 L
.21222 .03357 L
.17547 .05408 L
.15613 .06853 L
.13677 .08586 L
Mistroke
.10575 .12045 L
.0611 .18982 L
.04451 .22527 L
.03404 .25376 L
.02817 .27502 L
.02601 .28565 L
.0253 .29007 L
.02469 .29469 L
.02443 .29706 L
.02423 .29922 L
.02395 .30331 L
.02382 .30685 L
.02381 .31045 L
.02386 .31241 L
.02395 .31447 L
.02408 .31636 L
.02424 .31805 L
.02461 .32114 L
.02512 .32424 L
.0257 .32697 L
.02643 .3298 L
.02802 .33457 L
.02987 .3388 L
.03183 .34239 L
.03702 .34954 L
.04354 .3559 L
.04985 .3606 L
.05628 .36451 L
.07257 .37222 L
.11289 .38603 L
.15688 .39938 L
.28088 .44383 L
.36036 .47961 L
.47035 .53367 L
.53572 .56363 L
.57079 .57751 L
.60468 .58871 L
.63657 .59673 L
.65295 .59973 L
.66233 .60107 L
.67115 .60205 L
.68065 .60281 L
.6897 .60322 L
.69782 .60332 L
.70668 .60313 L
.71627 .60255 L
.72646 .6015 L
.73603 .60009 L
.74465 .59844 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooohoG0P2?e`00SmL00`3Ge`2>e`00SmL00`3G
e`2>e`00SmL00`3Ge`2>e`00CMLD02kG00<0emL0S]L004SG1P0Ce`D0:ML00`3Ge`2>e`00A=L501cG
1P0Te`80SmL0047G100Ue`H07mL00`3Ge`2>e`00?]L402kG1@0Je`030=OG08kG000le`<0==L401SG
00<0emL0S]L003[G0`0ie`@05ML00`3Ge`2>e`00>=L303gG100Ce`030=OG08kG000fe`<0@]L4013G
00<0emL0S]L003GG0P17e`<03]L208oG000ce`80BmL400_G00<0emL0S]L003;G0P1?e`<02ML00`3G
e`2>e`00<ML00`3Ge`1Ae`@01]L00`3Ge`2>e`00;mL205KG1004e`030=OG08kG000^e`030=OG05SG
1002e`030=OG08kG000]e`030=OG05_G1P2?e`00;=L00`3Ge`1Oe`<0SmL002_G00<0emL0HML408gG
000Ye`80I=L00`3Ge`0308_G000Xe`030=OG05_G1005e`030=OG00;G0`29e`009mL00`3Ge`1Le`03
0=OG00KG00<0emL01ML208OG000Ve`030=OG05kG00<0emL01ML300OG0P25e`009ML00`3Ge`1He`@0
1=L00`3Ge`04e`030=OG00WG0P23e`009=L00`3Ge`1Re`030=OG00?G00<0emL02mL2087G000Se`03
0=OG063G00@0emL01ML00`3Ge`0=e`<0O]L002;G0P1Se`801]L00`3Ge`0@e`80O=L002;G00<0emL0
J]L00`3Ge`0Be`80N]L0027G00<0emL0JmL201GG0P1he`008=L00`3Ge`1/e`030=OG01KG0P1fe`00
7mL00`3Ge`1]e`030=OG01SG0`1ce`007]L206oG00<0emL06]L3077G000Me`80L=L00`3Ge`0Le`<0
KmL001gG00<0emL0KmL00`3Ge`0Oe`80KML001cG00<0emL0L=L00`3Ge`0Qe`80JmL001_G00<0emL0
LML202CG0P1Ye`006mL00`3Ge`1ae`030=OG02GG0`1Ve`006]L00`3Ge`1be`030=OG02OG0`1Te`00
6ML00`3Ge`1ce`030=OG02WG0`1Re`006=L207GG00<0emL0;=L2063G000He`030=OG07CG00<0emL0
;]L205kG000Ge`030=OG07GG0P0ae`<0FmL001KG0P1ge`030=OG03?G0P1Ie`005]L00`3Ge`1fe`03
0=OG03GG0P1Ge`005ML207SG00<0emL0=mL305CG000Ee`030=OG07OG00<0emL0>ML305;G000De`03
0=OG07SG00<0emL0>mL3053G000De`030=OG07SG0P0oe`<0CML001?G00<0emL0NML00`3Ge`11e`80
BmL001;G0P1ke`030=OG04?G0`18e`004]L00`3Ge`1je`030=OG04GG1015e`004ML207cG00<0emL0
B=L404;G000Ae`030=OG07;G1005e`030=OG04[G1010e`004=L207KG00<0emL01=L00`3Ge`1<e`D0
?ML0013G00<0emL0MML00`3Ge`04e`<0CmL503[G000?e`80KmL400CG00<0emL01=L00`3Ge`1Ae`80
00CG0000=mL000oG00<0emL0M]L00`3Ge`04e`030=OG05?G0`001=L0000de`003mL00`3Ge`1de`<0
1]L00`3Ge`1Fe`H0<]L000kG00<0emL0MmL00`3Ge`04e`030=OG05[G1@0_e`003]L00`3Ge`1ne`03
0=OG05gG1@0/e`003ML00`3Ge`1oe`80HML502WG000=e`030=OG07oG00<0emL0I=L302OG000<e`80
PML00`3Ge`1We`<09=L000cG00<0emL0P=L00`3Ge`1Ze`@08=L000_G0P22e`030=OG06gG100Me`00
2mL00`3Ge`21e`030=OG073G100Je`002]L208?G0P1de`<06=L000[G0P23e`030=OG07KG0`0Ee`00
2]L00`3Ge`22e`030=OG07SG0`0Ce`002ML208CG00<0emL0N]L3017G0009e`80Q=L00`3Ge`1le`<0
3mL000WG00<0emL0PmL00`3Ge`1ne`803]L000SG0P25e`80P=L300cG0008e`80QML00`3Ge`20e`80
3=L000SG1010e`@0?mL00`3Ge`0oe`@0?]L600OG0008e`030=OG04?G00<0emL0?]L00`3Ge`11e`03
0=OG03kG0P0:e`002=L204CG00<0emL0?]L00`3Ge`11e`030=OG03oG0P09e`000]L40005e`00e`00
>mL400CG00<0emL0?]L00`3Ge`11e`030=OG03oG0`08e`001mL01@3GemL004;G00<0emL0?]L00`3G
e`11e`030=OG03oG0P000mL0e`06e`001mL200;G00<0emL0?]L3043G0P10e`<0@ML400OG0007e`04
0=L004?G00<0emL0?]L00`3Ge`11e`030=OG043G0P08e`001mL00`3Ge`25e`030=OG08CG0P08e`00
1mL00`3Ge`25e`030=OG08GG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`030=OG00KG0007e`03
0=OG08GG00<0emL0QML00`3Ge`06e`00o`0P007G0007e`030=OG00_G00<0emL02]L00`3Ge`0;e`03
0=OG00_G00<0emL02]L00`3Ge`0;e`030=OG00[G00<0emL02mL00`3Ge`0:e`030=OG00_G00<0emL0
2mL00`3Ge`0:e`030=OG00_G00<0emL02]L00`3Ge`0;e`030=OG00[G00<0emL02mL00`3Ge`0;e`03
0=OG00[G00<0emL02mL00`3Ge`06e`001mL00`3Ge`11e`030=OG047G00<0emL0@ML00`3Ge`11e`03
0=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL0
1]L000OG00<0emL0QML00`3Ge`25e`030=OG00KG0007e`030=OG08GG0P26e`030=OG00KG0008e`03
0=OG08CG00<0emL0Q=L00`3Ge`07e`002=L00`3Ge`24e`030=OG08CG00<0emL01mL000SG00<0emL0
Q=L00`3Ge`24e`030=OG00OG0009e`030=OG08?G00<0emL0Q=L00`3Ge`07e`002ML208CG00<0emL0
Q=L00`3Ge`07e`002]L00`3Ge`22e`030=OG08CG00<0emL01mL000_G0P22e`80Q=L00`3Ge`08e`00
3=L2087G00<0emL0PmL00`3Ge`08e`003]L00`3Ge`1ne`030=OG08?G00<0emL02=L000oG0`1me`03
0=OG08?G00<0emL02=L0017G0`1ke`030=OG08;G00<0emL02ML001?G101he`030=OG08;G00<0emL0
2ML001KG101ee`80P]L00`3Ge`0:e`006ML307?G00<0emL0PML00`3Ge`0:e`007=L3073G00<0emL0
P=L00`3Ge`0;e`007mL306gG00<0emL0P=L00`3Ge`0;e`008]L306[G00<0emL0P=L00`3Ge`0;e`00
9ML406KG00<0emL0OmL00`3Ge`0<e`00:=L406?G0P20e`030=OG00cG000[e`@0H=L00`3Ge`1ne`03
0=OG00gG000_e`<0GML00`3Ge`1ne`030=OG00gG000be`<0F]L00`3Ge`1me`030=OG00kG000de`@0
C]L400GG00<0emL0OML00`3Ge`0>e`00=mL404gG00<0emL01=L00`3Ge`1le`030=OG00oG000je`D0
BML00`3Ge`04e`<0O=L00`3Ge`0?e`00?=L604KG00<0emL01=L00`3Ge`1ke`030=OG013G000oe`H0
@mL00`3Ge`04e`030=OG07_G00<0emL04=L004;G0P000mL0000oe`<01]L00`3Ge`1je`030=OG017G
0014e`D0?mL00`3Ge`04e`030=OG07[G00<0emL04ML004OG1014e`030=OG07WG00<0emL04]L004[G
1011e`030=OG07WG00<0emL04]L004cG100oe`80NML00`3Ge`0Ce`00CmL303gG00<0emL0N=L00`3G
e`0Ce`00D]L203_G00<0emL0MmL00`3Ge`0De`00E=L303SG00<0emL0M]L00`3Ge`0Ee`00E]L303KG
00<0emL0M]L00`3Ge`0Ee`00FML203CG00<0emL0MML00`3Ge`0Fe`00FmL203;G0P1fe`030=OG01KG
001Me`80<=L00`3Ge`1de`030=OG01OG001Oe`<0;ML00`3Ge`1de`030=OG01OG001Re`80:mL00`3G
e`1ce`030=OG01SG001Te`80:ML00`3Ge`1ce`030=OG01SG001Ve`<09]L00`3Ge`1be`030=OG01WG
001Xe`<09=L207;G00<0emL06]L006_G0P0Re`030=OG073G00<0emL06mL006gG0P0Pe`030=OG073G
00<0emL06mL006oG0P0Ne`030=OG06oG00<0emL07=L0077G0`0Ke`030=OG06kG00<0emL07ML007?G
0`0Ie`030=OG06gG00<0emL07]L007GG0`0Ge`030=OG06cG00<0emL07mL007OG0`0Ee`80KML00`3G
e`0Oe`00N]L201?G00<0emL0JmL00`3Ge`0Pe`00O=L2017G00<0emL0J]L00`3Ge`0Qe`00O]L200oG
00<0emL0JML00`3Ge`0Re`00P=L200CG1005e`030=OG06SG00<0emL08mL008;G0P02e`030=OG00KG
00<0emL0ImL00`3Ge`0Te`00Q=L20003e`3G00KG0`1Ve`030=OG02GG0026e`<01]L00`3Ge`1Ue`03
0=OG02KG0028e`801ML00`3Ge`1Te`030=OG02OG0026e`030=OG00<00mL00`3Ge`1Se`030=OG02SG
0027e`800mL20003e`3G06?G00<0emL0:ML008kG0P1Re`80;=L008oG0`1Oe`030=OG02cG002?e`03
0=OG0080G=L00`3Ge`0]e`00SmL00`3Ge`02e`<0EmL2033G002?e`030=OG00CG0`1De`030=OG033G
002?e`030=OG00KG0`1Ae`030=OG037G002?e`030=OG00WG0P1=e`80==L008oG00<0emL02mL304WG
00<0emL0==L008oG0P0>e`<0AML203OG002?e`030=OG013G0`10e`80>ML008oG00<0emL04mL303[G
0`0ke`00SmL00`3Ge`0Fe`@0==L203kG002?e`030=OG01[G100]e`<0@=L008oG00<0emL07ML502KG
0`13e`00SmL2027G1`0Ne`<0A]L008oG00<0emL09]L501GG1@19e`00SmL00`3Ge`0ZeaL0CML008oG
00<0emL0S]L008oG00<0emL0S]L008oG00<0emL0S]L008oG0P2?e`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.11425, -2.81236, \
0.0147335, 0.0317892}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1072, 599},
WindowMargins->{{97, Automatic}, {Automatic, 28}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 774, 17, 101, "Input"],

Cell[CellGroupData[{
Cell[2504, 71, 453, 9, 124, "Input"],
Cell[2960, 82, 13218, 514, 186, 6035, 421, "GraphicsData", "PostScript", \
"Graphics"],
Cell[16181, 598, 130, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

