(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37221,       1322]*)
(*NotebookOutlinePosition[     63439,       2272]*)
(*  CellTagsIndexPosition[     63395,       2268]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
(* c41: Colmeigv.: Eigenvalue problem for a 
circular membrane.Calculation in cartesian coordinates.
1.step :give n collocation points and separation 
constants b *)
n=4; dth=N[Pi/(2*n),6];
Table[x[l]=Cos[l*dth],{l,1,n}];
Table[y[l]=Sin[l*dth],{l,1,n}];
Table[{x[l],y[l]},{l,1,n}];
(* Are the collocation points on the circle? *)
Table[x[l]^2+y[l]^2,{l,1,n}]
firsteigenv=2.000000000000; delta=firsteigenv/n;
b[1]=firsteigenv-0.0000001;
Table[b[l+1]=b[l]
-delta,{l,1,n-1}];
Table[b[l],{l,1,n}];
(* 2.step: calculate the eigenvalue from 
homogeneous boundary conditions *)
Clear[eigenvalue];
f[eigenvalue_]=Det[Table[Cos[b[mi]*y[ipi]]*
Cos[Sqrt[eigenvalue^2-b[mi]^2]*x[ipi]],
{ipi,1,n},{mi,1,n}]];
(* 3. step: make a plot to find an other guess 
for the first eigenvalue.Try 2 methods for 
finding roots of the determinant *)
Plot[f[eigenvalue],{eigenvalue,0.,3.}]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \({1.`, 1.`, 1.`, 1.`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0681575 233.405 [
[.18254 .05566 -9 -9 ]
[.18254 .05566 9 0 ]
[.34127 .05566 -3 -9 ]
[.34127 .05566 3 0 ]
[.5 .05566 -9 -9 ]
[.5 .05566 9 0 ]
[.65873 .05566 -3 -9 ]
[.65873 .05566 3 0 ]
[.81746 .05566 -9 -9 ]
[.81746 .05566 9 0 ]
[.97619 .05566 -3 -9 ]
[.97619 .05566 3 0 ]
[.01131 .18486 -36 -4.5 ]
[.01131 .18486 0 4.5 ]
[.01131 .30156 -30 -4.5 ]
[.01131 .30156 0 4.5 ]
[.01131 .41827 -36 -4.5 ]
[.01131 .41827 0 4.5 ]
[.01131 .53497 -30 -4.5 ]
[.01131 .53497 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .06816 m
.18254 .07441 L
s
[(0.5)] .18254 .05566 0 1 Mshowa
.34127 .06816 m
.34127 .07441 L
s
[(1)] .34127 .05566 0 1 Mshowa
.5 .06816 m
.5 .07441 L
s
[(1.5)] .5 .05566 0 1 Mshowa
.65873 .06816 m
.65873 .07441 L
s
[(2)] .65873 .05566 0 1 Mshowa
.81746 .06816 m
.81746 .07441 L
s
[(2.5)] .81746 .05566 0 1 Mshowa
.97619 .06816 m
.97619 .07441 L
s
[(3)] .97619 .05566 0 1 Mshowa
.125 Mabswid
.05556 .06816 m
.05556 .07191 L
s
.0873 .06816 m
.0873 .07191 L
s
.11905 .06816 m
.11905 .07191 L
s
.15079 .06816 m
.15079 .07191 L
s
.21429 .06816 m
.21429 .07191 L
s
.24603 .06816 m
.24603 .07191 L
s
.27778 .06816 m
.27778 .07191 L
s
.30952 .06816 m
.30952 .07191 L
s
.37302 .06816 m
.37302 .07191 L
s
.40476 .06816 m
.40476 .07191 L
s
.43651 .06816 m
.43651 .07191 L
s
.46825 .06816 m
.46825 .07191 L
s
.53175 .06816 m
.53175 .07191 L
s
.56349 .06816 m
.56349 .07191 L
s
.59524 .06816 m
.59524 .07191 L
s
.62698 .06816 m
.62698 .07191 L
s
.69048 .06816 m
.69048 .07191 L
s
.72222 .06816 m
.72222 .07191 L
s
.75397 .06816 m
.75397 .07191 L
s
.78571 .06816 m
.78571 .07191 L
s
.84921 .06816 m
.84921 .07191 L
s
.88095 .06816 m
.88095 .07191 L
s
.9127 .06816 m
.9127 .07191 L
s
.94444 .06816 m
.94444 .07191 L
s
.25 Mabswid
0 .06816 m
1 .06816 L
s
.02381 .18486 m
.03006 .18486 L
s
[(0.0005)] .01131 .18486 1 0 Mshowa
.02381 .30156 m
.03006 .30156 L
s
[(0.001)] .01131 .30156 1 0 Mshowa
.02381 .41827 m
.03006 .41827 L
s
[(0.0015)] .01131 .41827 1 0 Mshowa
.02381 .53497 m
.03006 .53497 L
s
[(0.002)] .01131 .53497 1 0 Mshowa
.125 Mabswid
.02381 .0915 m
.02756 .0915 L
s
.02381 .11484 m
.02756 .11484 L
s
.02381 .13818 m
.02756 .13818 L
s
.02381 .16152 m
.02756 .16152 L
s
.02381 .2082 m
.02756 .2082 L
s
.02381 .23154 m
.02756 .23154 L
s
.02381 .25488 m
.02756 .25488 L
s
.02381 .27822 m
.02756 .27822 L
s
.02381 .3249 m
.02756 .3249 L
s
.02381 .34824 m
.02756 .34824 L
s
.02381 .37158 m
.02756 .37158 L
s
.02381 .39492 m
.02756 .39492 L
s
.02381 .44161 m
.02756 .44161 L
s
.02381 .46495 m
.02756 .46495 L
s
.02381 .48829 m
.02756 .48829 L
s
.02381 .51163 m
.02756 .51163 L
s
.02381 .04482 m
.02756 .04482 L
s
.02381 .02148 m
.02756 .02148 L
s
.02381 .55831 m
.02756 .55831 L
s
.02381 .58165 m
.02756 .58165 L
s
.02381 .60499 m
.02756 .60499 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60328 L
.03053 .60324 L
.03279 .60317 L
.03527 .60308 L
.0379 .60295 L
.04262 .60267 L
.04749 .60228 L
.05205 .60185 L
.06244 .60057 L
.07305 .59886 L
.08274 .59694 L
.10458 .59138 L
.14429 .57702 L
.18248 .5583 L
.22313 .53357 L
.26226 .5056 L
.30384 .47212 L
.34391 .43693 L
.38246 .4011 L
.42346 .36165 L
.46295 .32315 L
.50092 .28634 L
.54134 .24808 L
.58025 .21279 L
.62161 .17752 L
.66146 .14623 L
.69979 .11896 L
.74057 .09328 L
.77984 .07197 L
.81759 .05469 L
.85779 .03973 L
.89648 .02856 L
.91612 .02405 L
.93762 .01997 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 174.25},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[PP10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG6mL00?oG6mL00?oG6mL00?oG6mL00?oG
6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL002OG00<0emL0l=L002OG00<0emL0l=L002OG
00<0emL0l=L002OG00<0emL0l=L002OG00<0emL0iML500KG000We`030=OG0=gG200;e`009mL20=WG
1@0Ce`009mL00`3Ge`0Me`801=L00`3Ge`02e`<07]L401kG1003e`030=OG00;G0`0Ne`@07ML400?G
00<0emL00]L300cG100@e`801]L002OG00<0emL07=L0103Ge`0;e`030=OG01gG00<0emL07mL00`3G
e`0:e`030=OG01_G00<0emL07]L00`3Ge`0<e`030=OG00KG0`0Ce`040=OG00GG000We`030=OG01cG
00@0emL02mL00`3Ge`0Me`030=OG01oG00<0emL02]L00`3Ge`0Le`030=OG01kG00<0emL02mL00`3G
e`02e`@06ML00`3Ge`03e`009mL00`3Ge`0Le`040=OG00SG0`0Pe`030=OG01oG00<0emL01mL3023G
00<0emL07]L00`3Ge`07e`<00]L301_G0P06e`009mL201gG00@0emL02=L00`3Ge`0Pe`030=OG01oG
00<0emL01mL00`3Ge`0Qe`030=OG01kG00<0emL01]L00`3Ge`02023G00<0emL00mL002OG00<0emL0
7=L0103Ge`08e`030=OG01kG0`0Oe`<02ML00`3Ge`0Ne`040=OG01gG00@0emL02=L301oG00@0emL0
1ML002OG00<0emL07ML200WG100Oe`030=OG01oG00<0emL01mL401kG0P0Oe`801mL601oG0P06e`00
9mL00`3Ge`30e`<0;ML002OG00<0emL0_]L2033G000We`030=OG0;cG0P0be`008MOi00009mL00`3G
e`04e`030=OG00GG00<0emL01ML00`3Ge`05e`030=OG00GG00<0emL01ML00`3Ge`05e`030=OG00GG
00<0emL01=L00`3Ge`05e`030=OG00GG00<0emL01ML00`3Ge`05e`030=OG00GG00<0emL01ML00`3G
e`04e`030=OG00GG00<0emL01ML00`3Ge`05e`030=OG00GG00<0emL01ML00`3Ge`05e`030=OG00GG
00<0emL00mL200OG00<0emL01ML00`3Ge`05e`030=OG00GG00<0emL01ML00`3Ge`05e`030=OG00CG
000We`030=OG02CG00<0emL09=L00`3Ge`0Ue`030=OG02CG00<0emL06ML200WG00<0emL09ML00`3G
e`04e`009mL00`3Ge`2de`80>]L002OG00<0emL0/]L203cG000We`030=OG0;3G0P0ne`009mL20:oG
0P10e`009mL00`3Ge`2/e`80@]L002OG00<0emL0ZmL00`3Ge`12e`009mL00`3Ge`2Ze`030=OG04?G
000We`030=OG0:SG0P16e`009mL00`3Ge`2We`030=OG04KG000We`80Y]L204WG000We`030=OG0:CG
00<0emL0BML002OG00<0emL0XmL00`3Ge`1:e`009mL00`3Ge`2Qe`80CML002OG00<0emL0X=L00`3G
e`1=e`009mL00`3Ge`2Oe`030=OG04kG000We`80W]L2057G000We`030=OG09cG00<0emL0DML002OG
00<0emL0VmL00`3Ge`1Be`009mL00`3Ge`2Ie`80EML002OG00<0emL0V=L00`3Ge`1Ee`009mL209SG
00<0emL0E]L002OG00<0emL0UML205WG000We`030=OG09CG00<0emL0FML002OG00<0emL0T]L205cG
0002e`801=L00`3Ge`03e`801=L200CG0P03e`<01ML00`3Ge`2Ae`030=OG05cG00001ML0emL000SG
00@0emL00]L0103Ge`02e`040=OG00GG00<0emL00]L00`3Ge`2@e`030=OG05gG00001ML0emL000SG
00@0emL00]L0103Ge`02e`040=OG00GG00<0emL00]L208oG0P1Pe`0000GG0=OG0008e`040=OG00;G
00@0emL00]L0103Ge`02e`<01ML00`3Ge`2=e`030=OG063G00001ML0emL000SG00@0emL00]L0103G
e`02e`040=OG00;G00<0emL01ML00`3Ge`2<e`030=OG067G00001ML0emL000SG00@0emL00]L0103G
e`02e`040=OG00;G00<0emL01ML00`3Ge`2;e`030=OG06;G0002e`802]L200CG0P04e`800mL400CG
00<0emL0R]L00`3Ge`1Se`009mL00`3Ge`28e`80I]L002OG0P28e`030=OG06KG000We`030=OG08KG
00<0emL0ImL002OG00<0emL0QML00`3Ge`1Xe`009mL00`3Ge`24e`030=OG06WG000We`030=OG08?G
00<0emL0J]L002OG00<0emL0P]L00`3Ge`1[e`009mL208;G00<0emL0K=L002OG00<0emL0P=L00`3G
e`1]e`009mL00`3Ge`1oe`030=OG06kG000We`030=OG07kG00<0emL0KmL002OG00<0emL0OML00`3G
e`1`e`009mL207gG00<0emL0LML002OG00<0emL0NmL00`3Ge`1be`009mL00`3Ge`1je`030=OG07?G
000We`030=OG07WG00<0emL0M=L002OG00<0emL0MmL207OG000We`030=OG07KG00<0emL0MmL002OG
0P1fe`030=OG07SG000We`030=OG07CG00<0emL0NML002OG00<0emL0LmL00`3Ge`1je`009mL00`3G
e`1be`030=OG07_G0008e`801=L00`3Ge`03e`801=L200?G1004e`030=OG077G00<0emL0O=L000OG
00@0emL02=L0103Ge`02e`040=OG00CG00<0emL00mL00`3Ge`1`e`030=OG07gG0007e`040=OG00SG
00@0emL00]L0103Ge`04e`030=OG00?G0P1`e`030=OG07kG0007e`040=OG00SG00@0emL00]L0103G
e`04e`030=OG00?G00<0emL0KML2087G0007e`040=OG00SG00@0emL00]L0103Ge`04e`030=OG00?G
00<0emL0K=L00`3Ge`21e`001mL0103Ge`08e`040=OG00;G00@0emL00]L300GG00<0emL0JmL00`3G
e`22e`002=L200[G0P04e`801ML00`3Ge`03e`030=OG06[G00<0emL0PmL002OG00<0emL0JML00`3G
e`24e`009mL206WG00<0emL0QML002OG00<0emL0ImL00`3Ge`26e`009mL00`3Ge`1Ve`030=OG08OG
000We`030=OG06GG00<0emL0R=L002OG00<0emL0I=L00`3Ge`29e`009mL00`3Ge`1Te`030=OG08WG
000We`80I=L00`3Ge`2:e`009mL00`3Ge`1Re`030=OG08_G000We`030=OG067G00<0emL0S=L002OG
00<0emL0H=L00`3Ge`2=e`009mL00`3Ge`1Oe`030=OG08kG000We`80GmL00`3Ge`2?e`009mL00`3G
e`1Me`030=OG093G000We`030=OG05cG00<0emL0TML002OG00<0emL0F]L209CG000We`030=OG05WG
00<0emL0U=L002OG00<0emL0F=L00`3Ge`2Ee`009mL205SG00<0emL0U]L002OG00<0emL0E]L00`3G
e`2Ge`009mL00`3Ge`1Ee`030=OG09SG000We`030=OG05CG00<0emL0VML000;G0P04e`030=OG00?G
0P04e`800mL400;G0`05e`030=OG05?G00<0emL0V]L00005e`3Ge`002=L0103Ge`02e`040=OG00CG
00<0emL01=L00`3Ge`02e`030=OG05;G00<0emL0VmL00005e`3Ge`002=L0103Ge`02e`040=OG00CG
00<0emL01=L00`3Ge`02e`80D]L00`3Ge`2Le`0000GG0=OG0008e`040=OG00;G00@0emL01=L0103G
emL300GG00<0emL0D=L00`3Ge`2Me`0000GG0=OG0008e`040=OG00;G00@0emL01=L01@3GemL000OG
00<0emL0CmL00`3Ge`2Ne`0000GG0=OG0008e`040=OG00;G00@0emL00]L300?G00<0emL01ML00`3G
e`1>e`030=OG09oG0002e`802]L200CG0P05e`040=OGe`@01=L00`3Ge`1=e`030=OG0:3G000We`03
0=OG04cG00<0emL0XML002OG0P1<e`030=OG0:;G000We`030=OG04WG0P2Ue`009mL00`3Ge`18e`03
0=OG0:GG000We`030=OG04OG00<0emL0Y]L002OG00<0emL0A]L00`3Ge`2We`009mL00`3Ge`14e`80
Z]L002OG0P14e`030=OG0:[G000We`030=OG04;G00<0emL0ZmL002OG00<0emL0@ML00`3Ge`2/e`00
9mL00`3Ge`10e`030=OG0:gG000We`030=OG03oG00<0emL0[]L002OG0P0oe`030=OG0:oG000We`03
0=OG03cG0P2be`009mL00`3Ge`0ke`030=OG0;;G000We`030=OG03[G00<0emL0/mL002OG00<0emL0
>ML00`3Ge`2de`009mL00`3Ge`0he`030=OG0;GG000We`80=mL20;SG000We`030=OG03GG00<0emL0
^=L002OG00<0emL0==L00`3Ge`2ie`009mL00`3Ge`0be`80_=L000SG0P04e`030=OG00?G0P04e`80
0mL400CG00<0emL0<ML00`3Ge`2le`001mL0103Ge`08e`040=OG00;G00@0emL00]L00`3Ge`05e`03
0=OG02oG0P2oe`001mL0103Ge`08e`040=OG00;G00@0emL00mL00`3Ge`04e`80;mL00`3Ge`2oe`00
1mL0103Ge`08e`040=OG00;G00@0emL01=L00`3Ge`03e`030=OG02cG0P32e`001mL0103Ge`08e`04
0=OG00;G00@0emL01ML00`3Ge`02e`030=OG02[G0P34e`001mL0103Ge`08e`040=OG00;G00@0emL0
0]L0103Ge`04e`030=OG02WG00<0emL0a=L000SG0P0:e`801=L200CG0P05e`030=OG02OG0P37e`00
9mL00`3Ge`0Ue`80bML002OG0P0Te`80bmL002OG00<0emL08ML20<gG000We`030=OG01kG0`3?e`00
9mL00`3Ge`0Le`80d]L002OG00<0emL06ML30=CG000We`806=L20=OG000We`030=OG01GG0P3Ie`00
9mL00`3Ge`0Ce`80fmL002OG00<0emL03mL40=gG000We`030=OG00_G103Qe`009mL00`3Ge`04e`L0
iML002OG1`3/e`009mL00`3Ge`3`e`009mL00`3Ge`3`e`009mL00`3Ge`3`e`00omLKe`00omLKe`00
omLKe`00omLKe`00omLKe`00omLKe`00omLKe`00omLKe`00omLKe`00omLKe`00\
\>"],
  ImageRangeCache->{{{0, 281}, {173.25, 0}} -> {-0.497016, -0.000465794, \
0.0127119, 1.72897*^-5}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindRoot[f[eigenvalue]==0,
{eigenvalue,2.0}] //Timing\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \({0.3700000000000001`\ Second, {eigenvalue \[Rule] 
          2.405926450226068`}}\)], "Output"]
}, Open  ]],

Cell["\<\
(* 4.step: define the matrix M *) eigenvalue=2.40593;
Clear[m];m=Table[j*k,{j,1,n},{k,1,n}];
Table[m[[ipi,mi]]=Cos[b[mi]*y[ipi]]*
Cos[Sqrt[eigenvalue^2-b[mi]^2]*x[ipi]],{ipi,1,n},{mi,1,n}];
nf=n-1;\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[CellGroupData[{

Cell["Det[m]", "Input",
  FontSize->18],

Cell[BoxData[
    \(3.0360959354609804`*^-9\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(* 5.step: solve the homogeneous linear equations *)
bbf=Table[-m[[ifit,n]],{ifit,1,nf}];
rdutn=Table[m[[ifit,klfit]],
{ifit,1,nf},{klfit,1,nf}];
B=LinearSolve[rdutn,bbf];
An={1.};
A=Table[B[[lk]],{lk,1,nf}];
(*6.step: check satisfaction of the homogeneous
boundary condition.*)
Amp=Join[A,An];
boundary = m . Amp\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \({0.`, \(-6.938893903907228`*^-17\), 
      0.`, \(-0.00011477519396052571`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
fxy[x_,y_]:=Sum[Amp[[mi]]*Cos[b[mi]*y]*
Cos[Sqrt[eigenvalue^2-b[mi]^2]*x],{mi,1,n}]
Do[Print[fxy[x[l],y[l]]],{l,n}]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \(0.`\)], "Print"],

Cell[BoxData[
    \(\(-9.71445146547012`*^-17\)\)], "Print"],

Cell[BoxData[
    \(\(-2.220446049250313`*^-16\)\)], "Print"],

Cell[BoxData[
    \(\(-0.00011477519396052571`\)\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
plot1=ContourPlot[fxy[x,y],{x,-1.05,1.05},{y,-1.05,1.05},
ContourShading->False,ContourSmoothing-> 2,
PlotPoints->60,Contours->{0},DisplayFunction->Identity];
plot2=ListPlot[Table[{x[i],y[i]},{i,1,n}],
Frame->True, AspectRatio->1.,
PlotRange->{{-1.,1.},{-1.,1.}},
PlotStyle->PointSize[1/60],DisplayFunction->Identity];
Show[plot1,plot2,DisplayFunction->$DisplayFunction]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.478019 0.499976 0.476215 [
[.02198 -0.0125 -6 -9 ]
[.02198 -0.0125 6 0 ]
[.26099 -0.0125 -12 -9 ]
[.26099 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.73901 -0.0125 -9 -9 ]
[.73901 -0.0125 9 0 ]
[.97802 -0.0125 -3 -9 ]
[.97802 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02376 -12 -4.5 ]
[-0.0125 .02376 0 4.5 ]
[-0.0125 .26187 -24 -4.5 ]
[-0.0125 .26187 0 4.5 ]
[-0.0125 .49998 -6 -4.5 ]
[-0.0125 .49998 0 4.5 ]
[-0.0125 .73808 -18 -4.5 ]
[-0.0125 .73808 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02198 0 m
.02198 .00625 L
s
[(-1)] .02198 -0.0125 0 1 Mshowa
.26099 0 m
.26099 .00625 L
s
[(-0.5)] .26099 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73901 0 m
.73901 .00625 L
s
[(0.5)] .73901 -0.0125 0 1 Mshowa
.97802 0 m
.97802 .00625 L
s
[(1)] .97802 -0.0125 0 1 Mshowa
.125 Mabswid
.06978 0 m
.06978 .00375 L
s
.11758 0 m
.11758 .00375 L
s
.16539 0 m
.16539 .00375 L
s
.21319 0 m
.21319 .00375 L
s
.30879 0 m
.30879 .00375 L
s
.35659 0 m
.35659 .00375 L
s
.4044 0 m
.4044 .00375 L
s
.4522 0 m
.4522 .00375 L
s
.5478 0 m
.5478 .00375 L
s
.5956 0 m
.5956 .00375 L
s
.64341 0 m
.64341 .00375 L
s
.69121 0 m
.69121 .00375 L
s
.78681 0 m
.78681 .00375 L
s
.83461 0 m
.83461 .00375 L
s
.88242 0 m
.88242 .00375 L
s
.93022 0 m
.93022 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02376 m
.00625 .02376 L
s
[(-1)] -0.0125 .02376 1 0 Mshowa
0 .26187 m
.00625 .26187 L
s
[(-0.5)] -0.0125 .26187 1 0 Mshowa
0 .49998 m
.00625 .49998 L
s
[(0)] -0.0125 .49998 1 0 Mshowa
0 .73808 m
.00625 .73808 L
s
[(0.5)] -0.0125 .73808 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(1)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .07138 m
.00375 .07138 L
s
0 .119 m
.00375 .119 L
s
0 .16663 m
.00375 .16663 L
s
0 .21425 m
.00375 .21425 L
s
0 .30949 m
.00375 .30949 L
s
0 .35711 m
.00375 .35711 L
s
0 .40473 m
.00375 .40473 L
s
0 .45235 m
.00375 .45235 L
s
0 .5476 m
.00375 .5476 L
s
0 .59522 m
.00375 .59522 L
s
0 .64284 m
.00375 .64284 L
s
0 .69046 m
.00375 .69046 L
s
0 .7857 m
.00375 .7857 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02198 .99375 m
.02198 1 L
s
.26099 .99375 m
.26099 1 L
s
.5 .99375 m
.5 1 L
s
.73901 .99375 m
.73901 1 L
s
.97802 .99375 m
.97802 1 L
s
.125 Mabswid
.06978 .99625 m
.06978 1 L
s
.11758 .99625 m
.11758 1 L
s
.16539 .99625 m
.16539 1 L
s
.21319 .99625 m
.21319 1 L
s
.30879 .99625 m
.30879 1 L
s
.35659 .99625 m
.35659 1 L
s
.4044 .99625 m
.4044 1 L
s
.4522 .99625 m
.4522 1 L
s
.5478 .99625 m
.5478 1 L
s
.5956 .99625 m
.5956 1 L
s
.64341 .99625 m
.64341 1 L
s
.69121 .99625 m
.69121 1 L
s
.78681 .99625 m
.78681 1 L
s
.83461 .99625 m
.83461 1 L
s
.88242 .99625 m
.88242 1 L
s
.93022 .99625 m
.93022 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02376 m
1 .02376 L
s
.99375 .26187 m
1 .26187 L
s
.99375 .49998 m
1 .49998 L
s
.99375 .73808 m
1 .73808 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07138 m
1 .07138 L
s
.99625 .119 m
1 .119 L
s
.99625 .16663 m
1 .16663 L
s
.99625 .21425 m
1 .21425 L
s
.99625 .30949 m
1 .30949 L
s
.99625 .35711 m
1 .35711 L
s
.99625 .40473 m
1 .40473 L
s
.99625 .45235 m
1 .45235 L
s
.99625 .5476 m
1 .5476 L
s
.99625 .59522 m
1 .59522 L
s
.99625 .64284 m
1 .64284 L
s
.99625 .69046 m
1 .69046 L
s
.99625 .7857 m
1 .7857 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.40642 .03291 m
.42344 .02985 L
.44045 .02742 L
.45746 .02561 L
.47448 .02441 L
.49149 .02381 L
.50851 .02381 L
.52552 .02441 L
.54254 .02561 L
.55955 .02742 L
.57656 .02985 L
.59358 .03291 L
.59822 .03385 L
.61059 .03661 L
.62761 .04098 L
.64462 .04602 L
.6589 .0508 L
.66164 .05177 L
.67865 .05826 L
.69566 .06551 L
.70058 .06775 L
.71268 .07356 L
.72969 .08246 L
.73374 .0847 L
.74671 .09224 L
.7617 .10165 L
.76372 .10298 L
.78073 .11474 L
.786 .1186 L
.79775 .12761 L
.80752 .13555 L
.81476 .14171 L
.82679 .1525 L
.83178 .15719 L
.84418 .16945 L
.84879 .17424 L
.85994 .1864 L
.86581 .19315 L
.87426 .20335 L
.88282 .21432 L
.88727 .2203 L
.89911 .23725 L
.89983 .23835 L
.90985 .2542 L
.91685 .26621 L
.91958 .27115 L
.92837 .2881 L
.93386 .29969 L
.93627 .30505 L
.94333 .322 L
Mistroke
.94961 .33895 L
.95088 .34262 L
.95515 .3559 L
.95998 .37285 L
.96413 .3898 L
.96764 .40675 L
.96789 .4081 L
.97052 .4237 L
.97281 .44065 L
.9745 .4576 L
.97563 .47455 L
.97619 .4915 L
.97619 .50845 L
.97563 .5254 L
.9745 .54235 L
.97281 .5593 L
.97052 .57625 L
.96789 .59185 L
.96764 .5932 L
.96413 .61015 L
.95998 .6271 L
.95515 .64405 L
.95088 .65733 L
.94961 .661 L
.94333 .67795 L
.93627 .6949 L
.93386 .70026 L
.92837 .71185 L
.91958 .7288 L
.91685 .73374 L
.90985 .74575 L
.89983 .76161 L
.89911 .7627 L
.88727 .77965 L
.88282 .78563 L
.87426 .7966 L
.86581 .8068 L
.85994 .81355 L
.84879 .82571 L
.84418 .8305 L
.83178 .84276 L
.82679 .84745 L
.81476 .85824 L
.80752 .8644 L
.79775 .87234 L
.786 .88135 L
.78073 .88521 L
.76372 .89697 L
.7617 .8983 L
.74671 .90771 L
Mistroke
.73374 .91525 L
.72969 .91749 L
.71268 .92639 L
.70058 .9322 L
.69566 .93444 L
.67865 .94169 L
.66164 .94818 L
.6589 .94915 L
.64462 .95393 L
.62761 .95898 L
.61059 .96334 L
.59822 .9661 L
.59358 .96704 L
.57656 .9701 L
.55955 .97253 L
.54254 .97434 L
.52552 .97554 L
.50851 .97614 L
.49149 .97614 L
.47448 .97554 L
.45746 .97434 L
.44045 .97253 L
.42344 .9701 L
.40642 .96704 L
.40178 .9661 L
.38941 .96334 L
.37239 .95898 L
.35538 .95393 L
.3411 .94915 L
.33836 .94818 L
.32135 .94169 L
.30434 .93444 L
.29942 .9322 L
.28732 .92639 L
.27031 .91749 L
.26626 .91525 L
.25329 .90771 L
.2383 .8983 L
.23628 .89697 L
.21927 .88521 L
.214 .88135 L
.20225 .87234 L
.19248 .8644 L
.18524 .85824 L
.17321 .84745 L
.16822 .84276 L
.15582 .8305 L
.15121 .82571 L
.14006 .81355 L
.13419 .8068 L
Mistroke
.12574 .7966 L
.11718 .78563 L
.11273 .77965 L
.10089 .7627 L
.10017 .76161 L
.09015 .74575 L
.08315 .73374 L
.08042 .7288 L
.07163 .71185 L
.06614 .70026 L
.06373 .6949 L
.05667 .67795 L
.05039 .661 L
.04912 .65733 L
.04485 .64405 L
.04002 .6271 L
.03587 .61015 L
.03236 .5932 L
.03211 .59185 L
.02948 .57625 L
.02719 .5593 L
.0255 .54235 L
.02437 .5254 L
.02381 .50845 L
.02381 .4915 L
.02437 .47455 L
.0255 .4576 L
.02719 .44065 L
.02948 .4237 L
.03211 .4081 L
.03236 .40675 L
.03587 .3898 L
.04002 .37285 L
.04485 .3559 L
.04912 .34262 L
.05039 .33895 L
.05667 .322 L
.06373 .30505 L
.06614 .29969 L
.07163 .2881 L
.08042 .27115 L
.08315 .26621 L
.09015 .2542 L
.10017 .23835 L
.10089 .23725 L
.11273 .2203 L
.11718 .21432 L
.12574 .20335 L
.13419 .19315 L
.14006 .1864 L
Mistroke
.15121 .17424 L
.15582 .16945 L
.16822 .15719 L
.17321 .1525 L
.18524 .14171 L
.19248 .13555 L
.20225 .12761 L
.214 .1186 L
.21927 .11474 L
.23628 .10298 L
.2383 .10165 L
.25329 .09224 L
.26626 .0847 L
.27031 .08246 L
.28732 .07356 L
.29942 .06775 L
.30434 .06551 L
.32135 .05826 L
.33836 .05177 L
.3411 .0508 L
.35538 .04602 L
.37239 .04098 L
.38941 .03661 L
.40178 .03385 L
.40642 .03291 L
Mfstroke
.01667 w
.94163 .68222 Mdot
.83801 .83671 Mdot
.68293 .93994 Mdot
.5 .97619 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016PP10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG6mL00?oG6mL00?oG6mL00?oG6mL00?oG
6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL0027G100de`801=L00`3Ge`02e`<0<]L203CG
0P04e`030=OG00;G0`0de`@01ML002?G00<0emL0<]L0103Ge`0;e`030=OG02kG00@0emL0<]L0103G
e`0;e`030=OG03?G00<0emL01=L002?G00<0emL0<]L0103Ge`0;e`030=OG02kG00@0emL0<]L0103G
e`0;e`030=OG03?G00<0emL01=L001_G1004e`030=OG02cG1002e`040=OG00SG0`0ae`040=OG03;G
00@0emL02=L303KG00<0emL01=L002?G00<0emL0<]L0103Ge`08e`030=OG037G00@0emL0<]L0103G
e`08e`030=OG03KG00<0emL01=L0027G0`0de`040=OG00SG00<0emL0<ML0103Ge`0be`040=OG00SG
00<0emL0==L300KG000Se`030=OG03?G0P09e`@0<ML203CG0P09e`@0=ML00`3Ge`04e`00omLKe`00
omLKe`00omLKe`006mOn007G000Ke`030=OG00;G00<0emL02ML00`3Ge`0:e`030=OG00WG00<0emL0
2ML00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL02]L00`3Ge`09e`03
0=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00[G00<0emL0
2ML00`3Ge`09e`030=OG00;G0@01e`006mL00`3Ge`02e`030=OG03[G00<0emL0>]L00`3Ge`0ie`03
0=OG03[G00<0emL00]L1007G000Ke`030=OG0?[G0@01e`004mL400CG00<0emL0n]L1007G000Ee`03
0=OG00?G00<0emL0n]L1007G000Ee`030=OG00?G0P1eea00MML2007G000=e`@01=L00`3Ge`03e`03
0=OG06_G2@0@e`T0KML1007G000Ee`030=OG00?G00<0emL0ImL402;G101Ye`400ML001?G0`05e`03
0=OG06;G1@0Ze`D0I=L1007G000Ee`030=OG00?G00<0emL0G]L403CG101Pe`400ML001_G00<0emL0
F]L403cG101Le`400ML001_G00<0emL0E]L404CG101He`400ML001_G00<0emL0D]L404cG101De`40
0ML001_G00<0emL0D=L205CG0P1Be`400ML001_G00<0emL0C]L205SG0P1@e`400ML001_G00<0emL0
C=L205cG0P1>e`400ML001_G00<0emL0BML3063G0`1;e`400ML001_G0P18e`80I]L204SG0P01e`00
6mL00`3Ge`15e`80J]L204OG0@01e`006mL00`3Ge`13e`80K]L204GG0@01e`006mL00`3Ge`11e`80
L]L204?G0@01e`006mL00`3Ge`10e`030=OG07CG00<0emL0@=L1007G000Ke`030=OG03kG0P1he`80
@=L1007G000Ke`030=OG03gG00<0emL0N]L00`3Ge`0me`400ML001_G00<0emL0>mL207kG0P0me`40
0ML001_G00<0emL0>ML208;G0P0ke`400ML001_G00<0emL0=mL208KG0P0ie`400ML001_G00<0emL0
=ML208[G0P0ge`400ML001_G00<0emL0==L00`3Ge`2<e`030=OG03CG0@01e`006mL203CG00<0emL0
S]L00`3Ge`0be`800ML001_G00<0emL0<]L00`3Ge`2@e`030=OG03;G0@01e`006mL00`3Ge`0ae`03
0=OG09;G00<0emL0<ML1007G000Ke`030=OG033G00<0emL0U=L00`3Ge`0`e`400ML001_G00<0emL0
;mL00`3Ge`2Fe`80<=L1007G000Ke`030=OG02kG00<0emL0VML00`3Ge`0]e`400ML001_G00<0emL0
;=L209gG00<0emL0;=L1007G000Ke`030=OG02_G00<0emL0W]L00`3Ge`0[e`400ML001_G00<0emL0
:]L00`3Ge`2Pe`030=OG02[G0@01e`006mL00`3Ge`0Ye`030=OG0:;G00<0emL0:ML1007G000Ke`03
0=OG02OG0P2Ve`80:ML1007G000Ke`030=OG02KG00<0emL0Z=L00`3Ge`0Ve`400ML001_G00<0emL0
9ML00`3Ge`2Ze`030=OG02GG0@01e`006mL202GG00<0emL0[=L00`3Ge`0Se`800ML001_G00<0emL0
8mL00`3Ge`2^e`030=OG02?G0@01e`006mL00`3Ge`0Re`030=OG0;3G00<0emL08]L1007G000Ke`03
0=OG027G00<0emL0/ML00`3Ge`0Re`400ML001_G00<0emL08ML00`3Ge`2be`030=OG027G0@01e`00
6mL00`3Ge`0Pe`030=OG0;CG00<0emL08=L1007G000Ke`030=OG01oG00<0emL0]]L00`3Ge`0Oe`40
0ML001_G00<0emL07]L00`3Ge`2he`030=OG01kG0@01e`006mL00`3Ge`0Ne`030=OG0;SG00<0emL0
7]L1007G000Ke`030=OG01gG00<0emL0^]L00`3Ge`0Me`400ML001_G00<0emL07=L00`3Ge`2le`03
0=OG01cG0@01e`006mL00`3Ge`0Ke`030=OG0;kG00<0emL06mL1007G000Ke`806mL00`3Ge`30e`03
0=OG01WG0P01e`006mL00`3Ge`0Ie`030=OG0<;G00<0emL06ML1007G000Ke`030=OG01SG00<0emL0
a=L00`3Ge`0He`400ML001_G00<0emL05mL00`3Ge`35e`030=OG01SG0@01e`006mL00`3Ge`0Ge`03
0=OG0<KG00<0emL05mL1007G000Ke`030=OG01KG00<0emL0b=L00`3Ge`0Fe`400ML001_G00<0emL0
5]L00`3Ge`38e`030=OG01KG0@01e`006mL00`3Ge`0Ee`030=OG0<[G00<0emL05ML1007G000Ke`03
0=OG01GG00<0emL0b]L00`3Ge`0Ee`400ML001_G00<0emL05=L00`3Ge`3<e`030=OG01CG0@01e`00
2=L200CG00<0emL00]L300GG00<0emL05=L00`3Ge`3=e`030=OG01?G0@01e`001mL0103Ge`0;e`03
0=OG00;G00<0emL04mL00`3Ge`3>e`030=OG01?G0@01e`001mL0103Ge`0;e`030=OG00;G0P0De`03
0=OG0<oG00<0emL04ML2007G00000mL0000200;G00@0emL02=L300GG00<0emL04]L00`3Ge`3@e`03
0=OG01;G0@01e`001mL0103Ge`08e`030=OG00GG00<0emL04ML00`3Ge`3Be`030=OG017G0@01e`00
1mL0103Ge`08e`030=OG00GG00<0emL04=L00`3Ge`3Ce`030=OG017G0@01e`002=L200WG1004e`03
0=OG013G00<0emL0e=L00`3Ge`0@e`400ML001_G00<0emL03mL00`3Ge`3Ee`030=OG013G0@01e`00
6mL00`3Ge`0?e`030=OG0=KG00<0emL03mL1007G000Ke`030=OG00kG00<0emL0f=L00`3Ge`0>e`40
0ML001_G00<0emL03]L00`3Ge`3He`030=OG00kG0@01e`006mL00`3Ge`0=e`030=OG0=[G00<0emL0
3ML1007G000Ke`030=OG00gG00<0emL0f]L00`3Ge`0=e`400ML001_G00<0emL03ML00`3Ge`3Je`03
0=OG00gG0@01e`006mL200gG00<0emL0fmL00`3Ge`0<e`800ML001_G00<0emL03=L00`3Ge`3Le`03
0=OG00cG0@01e`006mL00`3Ge`0;e`030=OG0=gG00<0emL03=L1007G000Ke`030=OG00_G00<0emL0
g]L00`3Ge`0;e`400ML001_G00<0emL02]L00`3Ge`3Oe`030=OG00_G0@01e`006mL00`3Ge`0:e`03
0=OG0>3G00<0emL02]L1007G000Ke`030=OG00WG00<0emL0hML00`3Ge`0:e`400ML001_G00<0emL0
2ML00`3Ge`3Re`030=OG00WG0@01e`006mL00`3Ge`09e`030=OG0>;G00<0emL02ML1007G000Ke`03
0=OG00WG00<0emL0h]L00`3Ge`09e`400ML001_G00<0emL02=L00`3Ge`3Se`030=OG00WG0@01e`00
6mL00`3Ge`08e`030=OG0>CG00<0emL02=L1007G000Ke`802ML00`3Ge`3Te`030=OG00OG0P01e`00
6mL00`3Ge`08e`030=OG0>CG00<0emL02=L1007G000Ke`030=OG00OG00<0emL0iML00`3Ge`08e`40
0ML001_G00<0emL01mL00`3Ge`3Ve`030=OG00OG0@01e`006mL00`3Ge`07e`030=OG0>KG00<0emL0
1mL1007G000Ke`030=OG00OG00<0emL0i]L00`3Ge`07e`400ML001_G00<0emL01]L00`3Ge`3We`03
0=OG00OG0@01e`006mL00`3Ge`06e`030=OG0>SG00<0emL01]L1007G000Ke`030=OG00KG00<0emL0
j=L00`3Ge`06e`400ML001_G00<0emL01]L00`3Ge`3Xe`030=OG00KG0@01e`006mL00`3Ge`05e`03
0=OG0>WG00<0emL01]L1007G000Ke`030=OG00GG00<0emL0j]L00`3Ge`05e`400ML001_G0P06e`03
0=OG0>[G00<0emL01=L2007G000Ke`030=OG00GG00<0emL0j]L00`3Ge`05e`400ML001_G00<0emL0
1ML00`3Ge`3Ze`030=OG00GG0@01e`006mL00`3Ge`04e`030=OG0>_G00<0emL01ML1007G000Ke`03
0=OG00CG00<0emL0k=L00`3Ge`04e`400ML001_G00<0emL01=L00`3Ge`3/e`030=OG00CG0@01e`00
6mL00`3Ge`04e`030=OG0>cG00<0emL01=L1007G000Ke`030=OG00CG00<0emL0k=L00`3Ge`04e`40
0ML001_G00<0emL01=L00`3Ge`3/e`030=OG00CG0@01e`006mL00`3Ge`04e`030=OG0>cG00<0emL0
1=L1007G000Ke`030=OG00CG00<0emL0k=L00`3Ge`04e`400ML001_G00<0emL00mL00`3Ge`3]e`03
0=OG00CG0@01e`006mL200CG00<0emL0k]L00`3Ge`02e`800ML001_G00<0emL00mL00`3Ge`3^e`03
0=OG00?G0@01e`006mL00`3Ge`03e`030=OG0>kG00<0emL00mL1007G000Ke`030=OG00?G00<0emL0
k]L00`3Ge`03e`400ML001_G00<0emL00mL00`3Ge`3^e`030=OG00?G0@01e`006mL00`3Ge`03e`03
0=OG0>kG00<0emL00mL1007G000Ke`030=OG00?G00<0emL0k]L00`3Ge`03e`400ML001_G00<0emL0
0mL00`3Ge`3^e`030=OG00?G0@01e`006mL00`3Ge`03e`030=OG0>kG00<0emL00mL1007G000Ke`03
0=OG00?G00<0emL0k]L00`3Ge`03e`400ML001CG0P05e`030=OG00?G00<0emL0k]L00`3Ge`03e`40
0ML001?G00@0emL01=L00`3Ge`03e`030=OG0>kG00<0emL00mL1007G000Ce`040=OG00CG0P04e`03
0=OG0>kG00<0emL00]L2007G000Ce`040=OG00CG00<0emL00mL00`3Ge`3^e`030=OG00?G0@01e`00
4mL0103Ge`04e`030=OG00?G00<0emL0k]L00`3Ge`03e`400ML001?G00@0emL01=L00`3Ge`03e`03
0=OG0>kG00<0emL00mL1007G000De`801ML00`3Ge`03e`030=OG0>kG00<0emL00mL1007G000Ke`03
0=OG00?G00<0emL0k]L00`3Ge`03e`400ML001_G00<0emL00mL00`3Ge`3^e`030=OG00?G0@01e`00
6mL00`3Ge`03e`030=OG0>kG00<0emL00mL1007G000Ke`030=OG00?G00<0emL0k]L00`3Ge`03e`40
0ML001_G00<0emL00mL00`3Ge`3^e`030=OG00?G0@01e`006mL00`3Ge`03e`030=OG0>kG00<0emL0
0mL1007G000Ke`030=OG00?G00<0emL0k]L00`3Ge`03e`400ML001_G0P04e`030=OG0>kG00<0emL0
0]L2007G000Ke`030=OG00?G00<0emL0kML00`3Ge`04e`400ML001_G00<0emL01=L00`3Ge`3/e`03
0=OG00CG0@01e`006mL00`3Ge`04e`030=OG0>cG00<0emL01=L1007G000Ke`030=OG00CG00<0emL0
k=L00`3Ge`04e`400ML001_G00<0emL01=L00`3Ge`3/e`030=OG00CG0@01e`006mL00`3Ge`04e`03
0=OG0>cG00<0emL01=L1007G000Ke`030=OG00CG00<0emL0k=L00`3Ge`04e`400ML001_G00<0emL0
1=L00`3Ge`3/e`030=OG00CG0@01e`006mL00`3Ge`04e`030=OG0>_G00<0emL01ML1007G000Ke`03
0=OG00GG00<0emL0j]L00`3Ge`05e`400ML001_G00<0emL01ML00`3Ge`3Ze`030=OG00GG0@01e`00
6mL200KG00<0emL0j]L00`3Ge`04e`800ML001_G00<0emL01ML00`3Ge`3Ze`030=OG00GG0@01e`00
6mL00`3Ge`05e`030=OG0>WG00<0emL01]L1007G000Ke`030=OG00KG00<0emL0j=L00`3Ge`06e`40
0ML001_G00<0emL01]L00`3Ge`3Xe`030=OG00KG0@01e`006mL00`3Ge`06e`030=OG0>SG00<0emL0
1]L1007G000Ke`030=OG00KG00<0emL0imL00`3Ge`07e`400ML001_G00<0emL01mL00`3Ge`3Ve`03
0=OG00OG0@01e`006mL00`3Ge`07e`030=OG0>KG00<0emL01mL1007G000Ke`030=OG00OG00<0emL0
i]L00`3Ge`07e`400ML001_G00<0emL01mL00`3Ge`3Ve`030=OG00OG0@01e`006mL00`3Ge`08e`03
0=OG0>CG00<0emL02=L1007G000Ke`802ML00`3Ge`3Te`030=OG00OG0P01e`006mL00`3Ge`08e`03
0=OG0>CG00<0emL02=L1007G000Ke`030=OG00SG00<0emL0i=L00`3Ge`08e`400ML001_G00<0emL0
2ML00`3Ge`3Re`030=OG00WG0@01e`006mL00`3Ge`09e`030=OG0>;G00<0emL02ML1007G000Ke`03
0=OG00WG00<0emL0h]L00`3Ge`09e`400ML001_G00<0emL02ML00`3Ge`3Qe`030=OG00[G0@01e`00
6mL00`3Ge`0:e`030=OG0>3G00<0emL02]L1007G000Ke`030=OG00[G00<0emL0gmL00`3Ge`0;e`40
0ML001_G00<0emL02mL00`3Ge`3Me`<03=L1007G000Ke`030=OG00_G00<0emL0g=L400cG0@01e`00
6mL00`3Ge`0<e`030=OG0=cG0`0<e`400ML001_G0P0=e`030=OG0=cG0P0<e`800ML001_G00<0emL0
3ML00`3Ge`3Je`030=OG00gG0@01e`006mL00`3Ge`0=e`030=OG0=[G00<0emL03ML1007G000Ke`03
0=OG00gG00<0emL0f]L00`3Ge`0=e`400ML001_G00<0emL03]L00`3Ge`3He`030=OG00kG0@01e`00
6mL00`3Ge`0>e`030=OG0=SG00<0emL03]L1007G000Ke`030=OG00oG00<0emL0e]L00`3Ge`0?e`40
0ML001_G00<0emL03mL00`3Ge`3Ee`030=OG013G0@01e`006mL00`3Ge`0@e`030=OG0=CG00<0emL0
4=L1007G000Ke`030=OG013G00<0emL0dmL00`3Ge`0Ae`400ML000SG0P04e`030=OG00;G0`05e`03
0=OG017G00<0emL0d]L00`3Ge`0Ae`400ML000OG00@0emL02mL00`3Ge`02e`030=OG01;G00<0emL0
d=L00`3Ge`0Be`400ML000OG00@0emL02mL00`3Ge`02e`805=L00`3Ge`3?e`030=OG017G0P01e`00
1mL0103Ge`08e`<01ML00`3Ge`0Ce`030=OG0<kG00<0emL04mL1007G0007e`040=OG00SG00<0emL0
1ML00`3Ge`0De`030=OG0<gG00<0emL04mL1007G0007e`040=OG00SG00<0emL01ML00`3Ge`0De`03
0=OG0<cG00<0emL05=L1007G0008e`802ML400CG00<0emL05ML00`3Ge`3:e`030=OG01GG0@01e`00
6mL00`3Ge`0Ee`030=OG0<[G00<0emL05ML1007G000Ke`030=OG01KG00<0emL0b=L00`3Ge`0Fe`40
0ML001_G00<0emL05]L00`3Ge`38e`030=OG01KG0@01e`006mL00`3Ge`0Ge`030=OG0<KG00<0emL0
5mL1007G000Ke`030=OG01OG00<0emL0aML00`3Ge`0He`400ML001_G00<0emL06=L00`3Ge`34e`03
0=OG01SG0@01e`006mL00`3Ge`0Ie`030=OG0<;G00<0emL06ML1007G000Ke`030=OG01WG00<0emL0
`ML00`3Ge`0Je`400ML001_G0P0Ke`030=OG0<3G00<0emL06ML2007G000Ke`030=OG01_G0P2ne`80
7ML1007G000Ke`030=OG01gG00<0emL0^]L00`3Ge`0Me`400ML001_G00<0emL07]L00`3Ge`2he`03
0=OG01kG0@01e`006mL00`3Ge`0Ne`030=OG0;SG00<0emL07]L1007G000Ke`030=OG01oG00<0emL0
]]L00`3Ge`0Oe`400ML001_G00<0emL07mL00`3Ge`2ee`030=OG023G0@01e`006mL00`3Ge`0Pe`03
0=OG0;CG00<0emL08=L1007G000Ke`030=OG027G00<0emL0/]L00`3Ge`0Qe`400ML001_G00<0emL0
8]L00`3Ge`2`e`030=OG02;G0@01e`006mL00`3Ge`0Se`030=OG0:kG00<0emL08mL1007G000Ke`03
0=OG02CG00<0emL0Z]L302KG0@01e`006mL202KG00<0emL0Z=L402GG0P01e`006mL00`3Ge`0Ve`03
0=OG0:SG0`0Ve`400ML001_G00<0emL09mL00`3Ge`2Ve`030=L002OG0@01e`006mL00`3Ge`0Xe`80
Y=L202[G0@01e`006mL00`3Ge`0Ze`030=OG0:3G00<0emL0:]L1007G000Ke`030=OG02_G00<0emL0
W]L00`3Ge`0[e`400ML001_G00<0emL0;=L00`3Ge`2Le`030=OG02cG0@01e`006mL00`3Ge`0]e`03
0=OG09[G00<0emL0;ML1007G000Ke`030=OG02kG00<0emL0VML00`3Ge`0]e`400ML001_G00<0emL0
;mL00`3Ge`2Fe`80<=L1007G000Ke`030=OG033G00<0emL0U=L00`3Ge`0`e`400ML001_G00<0emL0
<ML209;G0P0ce`400ML001_G0P0de`030=OG08kG00<0emL0<]L2007G000Ke`030=OG03CG00<0emL0
S=L00`3Ge`0de`400ML001_G00<0emL0=ML208[G0P0ge`400ML001_G00<0emL0=mL208KG0P0ie`40
0ML001_G00<0emL0>ML00`3Ge`22e`030=OG03WG0@01e`006mL00`3Ge`0je`030=OG083G00<0emL0
>]L1007G000Ke`030=OG03_G0P1ne`80?ML1007G000Ke`030=OG03gG0P1je`80?mL1007G000Ke`03
0=OG03oG0P1fe`80@ML1007G000Ke`030=OG047G0P1be`80@mL1007G000Ke`030=OG04?G0P1^e`80
AML1007G000Ke`030=OG04GG0P1Ze`80AmL1007G000Ke`80B=L206KG0P18e`800ML001_G00<0emL0
BML205kG0`000mL0001;e`400ML001_G00<0emL0BmL205_G1@1=e`400ML001_G00<0emL0CML305WG
0`1>e`400ML001_G00<0emL0D=L205GG0P000mL0e`1>e`400ML001_G00<0emL0D]L304kG101Ce`40
0ML001_G00<0emL0EML304SG0`1Ge`400ML001_G00<0emL0F=L204CG0P1Je`400ML001_G00<0emL0
F]L303kG0`1Le`400ML001_G00<0emL0GML7033G1`1Oe`400ML001?G1004e`030=OG06CG1P0Ae`<0
4=L606KG0@01e`005ML00`3Ge`03e`030=OG06[G2@07e`@01mL906cG0@01e`005ML00`3Ge`03e`80
M=LB07CG0P01e`005ML00`3Ge`03e`030=OG07cG00<0emL0NmL1007G000Ee`030=OG00?G00<0emL0
n]L1007G000Ce`<01ML00`3Ge`3je`400ML001GG00<0emL00mL00`3Ge`02e`030=OG03[G00<0emL0
>]L00`3Ge`0ie`030=OG03[G00<0emL00]L1007G000Ke`030=OG00;G00<0emL02ML00`3Ge`0:e`03
0=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL0
2]L00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`03
0=OG00[G00<0emL02ML00`3Ge`09e`030=OG00;G0@01e`006mOn007G003oea_G003oea_G003oea_G
003oea_G003oea_G003oea_G003oea_G0000\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-1.27004, -1.21324, 0.00824579, \
0.00827703}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1041, 764},
WindowMargins->{{85, Automatic}, {Automatic, 56}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "c70533"}, \
"Colmeigv.nb.ps", CharacterEncoding -> "ASCII"],
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{7, Inherited}, {8, 40}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 0},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{7, Inherited}, {6, 15}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 10},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{7, Inherited}, {6, 20}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 20},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 30},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{19, Inherited}, {8, 15}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 40},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[EmptySquare]",
    CellMargins->{{18, Inherited}, {8, 12}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 50},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{7, 10}, {7, 7}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{7, 10}, {6, 6}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    AspectRatioFixed->True,
    FontFamily->"New York",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    PageWidth->Infinity,
    CellMargins->{{42, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    PageWidth->Infinity,
    CellMargins->{{42, 10}, {7, 5}},
    CellEditDuplicate->True,
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    PageWidth->Infinity,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    PageWidth->Infinity,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    PageWidth->Infinity,
    CellMargins->{{7, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    AspectRatioFixed->True,
    ImageSize->{282, 287},
    ImageMargins->{{34, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{7, 0}, {4, 1}},
    Evaluatable->False,
    PageBreakWithin->Automatic,
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"New York",
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{7, 0}, {0, 4}},
    Evaluatable->False,
    PageBreakWithin->Automatic,
    TextAlignment->Center,
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"New York",
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Open  ]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 929, 28, 462, "Input"],
Cell[2659, 82, 54, 1, 27, "Output"],
Cell[2716, 85, 11272, 379, 183, 3995, 285, "GraphicsData", "PostScript", \
"Graphics"],
Cell[13991, 466, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14158, 474, 120, 5, 48, "Input"],
Cell[14281, 481, 115, 2, 27, "Output"]
}, Open  ]],
Cell[14411, 486, 264, 8, 102, "Input"],

Cell[CellGroupData[{
Cell[14700, 498, 39, 1, 30, "Input"],
Cell[14742, 501, 57, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14836, 507, 380, 14, 210, "Input"],
Cell[15219, 523, 111, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15367, 530, 182, 6, 66, "Input"],
Cell[15552, 538, 36, 1, 23, "Print"],
Cell[15591, 541, 60, 1, 26, "Print"],
Cell[15654, 544, 61, 1, 26, "Print"],
Cell[15718, 547, 61, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15816, 553, 437, 11, 156, "Input"],
Cell[16256, 566, 20816, 748, 290, 7665, 581, "GraphicsData", "PostScript", \
"Graphics"],
Cell[37075, 1316, 130, 3, 27, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

