(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    196135,       7093]*)
(*NotebookOutlinePosition[    196766,       7115]*)
(*  CellTagsIndexPosition[    196722,       7111]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
(* c42: Cassmem.nb Clamped  Cassini membrane in Cartesian \
Coordinates. Eigenvalue problem of the homogeneous Helmholtz equation.Check \
the solution *)
Clear[u,x,y,A,b,n,k];
u[x,y]=A[n]*Cos[Sqrt[k^2-b[n]^2]*x]*Cos[b[n]*y];
Simplify[D[u[x,y],{x,2}]+D[u[x,y],{y,2}]+k^2*u[x,y]]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ Step : \(1 : \ Define\ the\ Cassini\ boundary\), \ 
      the\ 4\ vertex\ points\ and\ n\ collocation\ points\ *) \)\(\n\)\(Clear[
      F, b, xmin, xmax, ymax, ymin, Fy, Fx, x, y, n, a, c]; n = 8; a = 1.0; 
    c = 0.85; 
    F[x_, y_] := \((x^2 + y^2)\)^2 - 2*c^2*\((x^2 - y^2)\) - a^4 + c^4; 
    Fy[x_] = InputForm[Solve[F[x, y] \[Equal] 0, y]]; 
    ymax = Sqrt[Sqrt[a^4] - c^2]; 
    Fx[y] = InputForm[Solve[F[x, y] \[Equal] 0, x]]; 
    Fx[y_] := Sqrt[c^2 - y^2 + Sqrt[a^4 - 4*c^2*y^2]]\)\)\)], "Input"],

Cell[BoxData[
    \(xmax = Fx[0]; xmin = \(-xmax\); ymin = \(-ymax\); 
    dx = xmax/\((n - 1)\); x[1] = xmin; 
    Table[x[l] = xmin + \((l - 1)\)*dx, {l, 1, n}]; dth = N[Pi/\((2*n)\)]; 
    r[phi_] := Sqrt[
        c^2*Cos[2*phi] + Sqrt[a^4 - c^4*\((Sin[2*phi])\)^2]]\)], "Input"],

Cell[BoxData[
    \(Table[x[l] = r[l*dth]*Cos[l*dth], {l, 1, n}]; 
    Table[y[l] = r[l*dth]*Sin[l*dth], {l, 1, n}]; 
    TXY = Table[{x[l], y[l]}, {l, 1, n}]; << 
      Graphics`ImplicitPlot`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Packages\)], "Input"],

Cell[BoxData[
    \({"Utilities`FilterOptions`", "Graphics`ImplicitPlot`", "Global`", 
      "System`"}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(Clear[pl1, pl2, pl3]; Off[General::spell]\), "\n", 
    \(\(pl1 = 
        ImplicitPlot[F[x, y] \[Equal] 0, {x, xmin, xmax}, 
          AspectRatio \[Rule] 1, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(pl2 = ListPlot[TXY, DisplayFunction \[Rule] Identity]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl3 = 
      Show[pl1, pl2, DisplayFunction \[Rule] $DisplayFunction, 
        Prolog \[Rule] AbsolutePointSize[6]]; Off[General::spell]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.362828 0.5 0.809599 [
[.13717 .4875 -6 -9 ]
[.13717 .4875 6 0 ]
[.31859 .4875 -12 -9 ]
[.31859 .4875 12 0 ]
[.68141 .4875 -9 -9 ]
[.68141 .4875 9 0 ]
[.86283 .4875 -3 -9 ]
[.86283 .4875 3 0 ]
[.4875 .01424 -24 -4.5 ]
[.4875 .01424 0 4.5 ]
[.4875 .17616 -24 -4.5 ]
[.4875 .17616 0 4.5 ]
[.4875 .33808 -24 -4.5 ]
[.4875 .33808 0 4.5 ]
[.4875 .66192 -18 -4.5 ]
[.4875 .66192 0 4.5 ]
[.4875 .82384 -18 -4.5 ]
[.4875 .82384 0 4.5 ]
[.4875 .98576 -18 -4.5 ]
[.4875 .98576 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13717 .5 m
.13717 .50625 L
s
[(-1)] .13717 .4875 0 1 Mshowa
.31859 .5 m
.31859 .50625 L
s
[(-0.5)] .31859 .4875 0 1 Mshowa
.68141 .5 m
.68141 .50625 L
s
[(0.5)] .68141 .4875 0 1 Mshowa
.86283 .5 m
.86283 .50625 L
s
[(1)] .86283 .4875 0 1 Mshowa
.125 Mabswid
.17345 .5 m
.17345 .50375 L
s
.20974 .5 m
.20974 .50375 L
s
.24602 .5 m
.24602 .50375 L
s
.2823 .5 m
.2823 .50375 L
s
.35487 .5 m
.35487 .50375 L
s
.39115 .5 m
.39115 .50375 L
s
.42743 .5 m
.42743 .50375 L
s
.46372 .5 m
.46372 .50375 L
s
.53628 .5 m
.53628 .50375 L
s
.57257 .5 m
.57257 .50375 L
s
.60885 .5 m
.60885 .50375 L
s
.64513 .5 m
.64513 .50375 L
s
.7177 .5 m
.7177 .50375 L
s
.75398 .5 m
.75398 .50375 L
s
.79026 .5 m
.79026 .50375 L
s
.82655 .5 m
.82655 .50375 L
s
.10089 .5 m
.10089 .50375 L
s
.06461 .5 m
.06461 .50375 L
s
.02832 .5 m
.02832 .50375 L
s
.89911 .5 m
.89911 .50375 L
s
.93539 .5 m
.93539 .50375 L
s
.97168 .5 m
.97168 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .01424 m
.50625 .01424 L
s
[(-0.6)] .4875 .01424 1 0 Mshowa
.5 .17616 m
.50625 .17616 L
s
[(-0.4)] .4875 .17616 1 0 Mshowa
.5 .33808 m
.50625 .33808 L
s
[(-0.2)] .4875 .33808 1 0 Mshowa
.5 .66192 m
.50625 .66192 L
s
[(0.2)] .4875 .66192 1 0 Mshowa
.5 .82384 m
.50625 .82384 L
s
[(0.4)] .4875 .82384 1 0 Mshowa
.5 .98576 m
.50625 .98576 L
s
[(0.6)] .4875 .98576 1 0 Mshowa
.125 Mabswid
.5 .05472 m
.50375 .05472 L
s
.5 .0952 m
.50375 .0952 L
s
.5 .13568 m
.50375 .13568 L
s
.5 .21664 m
.50375 .21664 L
s
.5 .25712 m
.50375 .25712 L
s
.5 .2976 m
.50375 .2976 L
s
.5 .37856 m
.50375 .37856 L
s
.5 .41904 m
.50375 .41904 L
s
.5 .45952 m
.50375 .45952 L
s
.5 .54048 m
.50375 .54048 L
s
.5 .58096 m
.50375 .58096 L
s
.5 .62144 m
.50375 .62144 L
s
.5 .7024 m
.50375 .7024 L
s
.5 .74288 m
.50375 .74288 L
s
.5 .78336 m
.50375 .78336 L
s
.5 .86432 m
.50375 .86432 L
s
.5 .9048 m
.50375 .9048 L
s
.5 .94528 m
.50375 .94528 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .49986 m
.02544 .44394 L
.0303 .38861 L
.03838 .33474 L
.04961 .28305 L
.06392 .23424 L
.0812 .18902 L
.10135 .14805 L
.12422 .112 L
.14966 .08147 L
.17748 .057 L
.20752 .03907 L
.23955 .02798 L
.27336 .02381 L
.30872 .02626 L
.34538 .0344 L
.3831 .04643 L
.42162 .05943 L
.46068 .06963 L
.5 .07352 L
.53932 .06963 L
.57838 .05943 L
.6169 .04643 L
.65462 .0344 L
.69128 .02626 L
.72664 .02381 L
.76045 .02798 L
.79248 .03907 L
.82252 .057 L
.85034 .08147 L
.87578 .112 L
.89865 .14805 L
.9188 .18902 L
.93608 .23424 L
.95039 .28305 L
.96162 .33474 L
.9697 .38861 L
.97456 .44394 L
.97619 .49986 L
s
.02381 .50014 m
.02544 .55606 L
.0303 .61139 L
.03838 .66526 L
.04961 .71695 L
.06392 .76576 L
.0812 .81098 L
.10135 .85195 L
.12422 .888 L
.14966 .91853 L
.17748 .943 L
.20752 .96093 L
.23955 .97202 L
.27336 .97619 L
.30872 .97374 L
.34538 .9656 L
.3831 .95357 L
.42162 .94057 L
.46068 .93037 L
.5 .92648 L
.53932 .93037 L
.57838 .94057 L
.6169 .95357 L
.65462 .9656 L
.69128 .97374 L
.72664 .97619 L
.76045 .97202 L
.79248 .96093 L
.82252 .943 L
.85034 .91853 L
.87578 .888 L
.89865 .85195 L
.9188 .81098 L
.93608 .76576 L
.95039 .71695 L
.96162 .66526 L
.9697 .61139 L
.97456 .55606 L
.97619 .50014 L
s
6 Mabswid
.95412 .70156 Mdot
.89243 .86271 Mdot
.80485 .95451 Mdot
.71332 .976 Mdot
.63792 .96057 Mdot
.582 .94172 Mdot
.53835 .93019 Mdot
.5 .92648 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML008oG00<0emL0S]L008oG00<0emL0
S]L007_G0P04e`030=OG00?G0P06e`030=OG08kG001je`040=OG00SG00@0emL01ML00`3Ge`2>e`00
N]L0103Ge`08e`040=OG00GG0`2>e`00M=L400;G00@0emL02=L300KG00<0emL0S]L007[G00@0emL0
2=L00`3Ge`06e`030=OG08kG001:ea008=L0103Ge`08e`030=OG00KG00<0emL0<mL@04_G0013e`L0
4=L401gG0P0:e`<01ML00`3Ge`0_e`@04=L704CG0010e`<06mL402gG00<0emL0:mL401_G0`11e`00
?ML302;G0`0Ze`030=OG02SG0`0Re`<0?]L003_G0P0Xe`@09]L00`3Ge`0Te`@0:=L203cG000ie`80
;]L402;G00<0emL08=L402kG0P0je`00>=L00`3Ge`0be`<07mL00`3Ge`0Me`<0==L00`3Ge`0ge`00
=]L203SG0`0Le`030=OG01[G0`0he`80=mL003CG0P0me`806]L00`3Ge`0He`80?ML203GG000ce`03
0=OG03oG0`0Ge`805]L3047G00<0emL0<]L003;G00<0emL0@mL301CG00<0emL04]L304GG00<0emL0
<ML0037G00<0emL0AmL4013G00<0emL03]L404WG00<0emL0<=L0033G00<0emL0C=L400cG00<0emL0
2]L404kG00<0emL0;mL002kG0P1Ce`L01ML00`3Ge`03e`L0DmL202oG000]e`030=OG05[G2`1Le`03
0=OG02cG000/e`030=OG063G00<0emL0H=L00`3Ge`0[e`00:mL00`3Ge`1Qe`030=OG067G00<0emL0
:]L002[G00<0emL0H]L00`3Ge`1Re`030=OG02WG000Ye`030=OG06?G00<0emL0HmL00`3Ge`0Xe`00
:=L00`3Ge`1Te`030=OG06CG00<0emL09mL002OG00<0emL0IML206KG00<0emL09]L002OG00<0emL0
IML00`3Ge`1Ue`030=OG02KG000Ve`030=OG06KG00<0emL0I]L00`3Ge`0Ue`009ML00`3Ge`1We`03
0=OG06OG00<0emL09=L002CG00<0emL0J=L00`3Ge`1Xe`030=OG02?G000Se`030=OG06WG00<0emL0
JML00`3Ge`0Re`008]L00`3Ge`1Ze`030=OG06[G00<0emL08ML002;G00<0emL0J]L00`3Ge`1Ze`03
0=OG027G000Qe`030=OG06_G00<0emL0JmL00`3Ge`0Pe`008ML00`3Ge`1[e`030=OG06_G00<0emL0
8=L0023G00<0emL0K=L00`3Ge`1/e`030=OG01oG000Oe`030=OG06gG00<0emL0KML00`3Ge`0Ne`00
7mL00`3Ge`1]e`80K]L00`3Ge`0Ne`007]L00`3Ge`1^e`030=OG06kG00<0emL07ML001kG00<0emL0
K]L00`3Ge`1^e`030=OG01gG000Me`030=OG06oG00<0emL0KmL00`3Ge`0Le`007=L00`3Ge`1`e`03
0=OG06oG00<0emL07=L001cG00<0emL0L=L00`3Ge`1`e`030=OG01_G000Ke`030=OG077G00<0emL0
L=L00`3Ge`0Ke`006mL00`3Ge`1ae`030=OG077G00<0emL06]L001[G00<0emL0L]L00`3Ge`1ae`03
0=OG01[G000Je`030=OG05kG0P04e`030=OG00CG00<0emL01=L00`3Ge`1be`030=OG01WG000Ie`03
0=OG05kG00@0emL02]L00`3Ge`04e`030=OG07;G00<0emL06ML001WG00<0emL0G]L0103Ge`07e`D0
1ML307?G00<0emL06=L001SG00<0emL0FML400;G00@0emL01mL0103Ge`06e`030=OG07?G00<0emL0
6=L001SG00<0emL0GmL0103Ge`08e`030=L000KG00<0emL0M=L00`3Ge`0Ge`005mL00`3Ge`1Pe`04
0=OG00WG0P06e`030=OG07CG00<0emL05mL001OG00<0emL0HML200_G00<0emL01=L00`3Ge`1ee`03
0=OG01KG000Ge`030=OG07GG00<0emL0MML00`3Ge`0Fe`005]L00`3Ge`1fe`030=OG07KG00<0emL0
5ML001KG00<0emL0M]L00`3Ge`1fe`030=OG01GG000Ee`030=OG07OG00<0emL0MmL00`3Ge`0De`00
5ML00`3Ge`1ge`030=OG07OG00<0emL05=L001GG00<0emL0MmL00`3Ge`1ge`030=OG01CG000De`03
0=OG07SG00<0emL0N=L00`3Ge`0Ce`005=L00`3Ge`1he`80NML00`3Ge`0Ce`005=L00`3Ge`1he`03
0=OG07SG00<0emL04mL001?G00<0emL0NML00`3Ge`1ie`030=OG01;G000Ce`030=OG07WG00<0emL0
NML00`3Ge`0Be`004]L00`3Ge`1je`030=OG07[G00<0emL04ML001;G00<0emL0N]L00`3Ge`1je`03
0=OG017G000Be`030=OG07[G00<0emL0N]L00`3Ge`0Ae`004ML00`3Ge`1ke`030=OG07_G00<0emL0
4=L0017G00<0emL0NmL00`3Ge`1ke`030=OG013G000Ae`030=OG07_G00<0emL0NmL00`3Ge`0@e`00
4ML00`3Ge`1ke`030=OG07_G00<0emL04=L0013G00<0emL0O=L207gG00<0emL03mL0013G00<0emL0
O=L00`3Ge`1le`030=OG00oG000@e`030=OG07cG00<0emL0O=L00`3Ge`0?e`003mL00`3Ge`1me`03
0=OG07gG00<0emL03]L000oG00<0emL0OML00`3Ge`1me`030=OG00kG000?e`030=OG07gG00<0emL0
OML00`3Ge`0>e`003mL00`3Ge`1me`030=OG07gG00<0emL03]L000kG00<0emL0O]L00`3Ge`1ne`03
0=OG00gG000>e`030=OG07kG00<0emL0O]L00`3Ge`0=e`003]L00`3Ge`1ne`030=OG07kG00<0emL0
3ML000kG00<0emL0O]L00`3Ge`1ne`030=OG00gG000=e`030=OG07oG00<0emL0OmL00`3Ge`0<e`00
3ML00`3Ge`1oe`80P=L00`3Ge`0<e`003ML00`3Ge`1oe`030=OG07oG00<0emL03=L000gG00<0emL0
OmL00`3Ge`1oe`030=OG00cG000=e`030=OG07oG00<0emL0OmL00`3Ge`0<e`003=L00`3Ge`20e`03
0=OG083G00<0emL02mL000cG00<0emL0P=L00`3Ge`20e`030=OG00_G000<e`030=OG083G00<0emL0
P=L00`3Ge`0;e`003=L00`3Ge`20e`030=OG083G00<0emL02mL000cG00<0emL0P=L00`3Ge`20e`03
0=OG00_G000;e`030=OG087G00<0emL0PML00`3Ge`0:e`002mL00`3Ge`1]e`801=L00`3Ge`02e`@0
1ML00`3Ge`21e`030=OG00[G000;e`030=OG06cG00@0emL02=L00`3Ge`06e`030=OG087G00<0emL0
2]L000_G00<0emL0K=L0103Ge`09e`030=OG00GG0`21e`030=OG00[G000;e`030=OG06KG1002e`04
0=OG00[G00<0emL01=L00`3Ge`21e`030=OG00[G000;e`030=OG06cG00@0emL02mL00`3Ge`03e`03
0=OG087G00<0emL02]L000[G00<0emL0KML0103Ge`08e`040=OG00GG00<0emL0P]L00`3Ge`09e`00
2]L00`3Ge`1^e`802]L200KG00<0emL0P]L00`3Ge`09e`002]L00`3Ge`22e`030=OG08;G00<0emL0
2ML000[G00<0emL0P]L00`3Ge`22e`030=OG00WG000:e`030=OG08;G00<0emL0P]L00`3Ge`09e`00
2]L00`3Ge`22e`030=OG08;G00<0emL02ML000[G00<0emL0P]L00`3Ge`22e`030=OG00WG000:e`03
0=OG08;G00<0emL0P]L00`3Ge`09e`002ML00`3Ge`23e`80Q=L00`3Ge`08e`002ML00`3Ge`23e`03
0=OG08?G00<0emL02=L000WG00<0emL0PmL00`3Ge`23e`030=OG00SG0009e`030=OG08?G00<0emL0
PmL00`3Ge`08e`002ML00`3Ge`23e`030=OG08?G00<0emL02=L000WG00<0emL0PmL00`3Ge`23e`03
0=OG00SG0009e`030=OG08?G00<0emL0PmL00`3Ge`08e`002=L00`3Ge`24e`030=OG08?G00<0emL0
2=L000SG00<0emL0Q=L00`3Ge`24e`030=OG00OG0008e`030=OG08CG00<0emL0Q=L00`3Ge`07e`00
2=L00`3Ge`24e`030=OG08CG00<0emL01mL000SG00<0emL0Q=L00`3Ge`24e`030=OG00OG0008e`03
0=OG08CG0P25e`030=OG00OG0008e`030=OG08CG00<0emL0Q=L00`3Ge`07e`002=L00`3Ge`24e`03
0=OG08CG00<0emL01mL000OG00<0emL0QML00`3Ge`24e`030=OG00OG0007e`030=OG08GG00<0emL0
QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`03
0=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL0
1]L000OG00<0emL0QML00`3Ge`25e`030=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`00
1mL00`3Ge`25e`80Q]L00`3Ge`06e`001mL00`3Ge`0Ne`@0:mL200CG00<0emL00]L302[G00<0emL0
:]L200CG00<0emL00]L302_G100Ne`030=OG00KG0007e`030=OG023G00<0emL0:ML0103Ge`0;e`03
0=OG02OG00<0emL0:ML0103Ge`0;e`030=OG02[G00<0emL07ML00`3Ge`06e`001mL00`3Ge`0Pe`03
0=OG02WG00@0emL02mL00`3Ge`0We`030=OG02WG00@0emL02mL00`3Ge`0Ze`030=OG01gG00<0emL0
1]L000OG00<0emL06=L400CG00<0emL08mL400;G00@0emL02=L302[G00<0emL0:ML0103Ge`08e`<0
;ML00`3Ge`0Me`030=OG00KG0007e`030=OG023G00<0emL0:ML0103Ge`08e`030=OG02[G00<0emL0
:ML0103Ge`08e`030=OG02gG00<0emL07ML00`3Ge`06e`001mL00`3Ge`0Ne`<0:mL0103Ge`08e`03
0=OG02[G00<0emL0:ML0103Ge`08e`030=OG02_G0`0Oe`030=OG00KG0007e`030=OG023G00<0emL0
:]L200WG100Ye`030=OG02[G0P09e`@0;=L00`3Ge`0Me`030=OG00KG0007e`030=OG08GG00<0emL0
QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`03
0=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`00o`0P007G0007e`802ML00`3Ge`08e`03
0=OG00OG00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL0
2=L00`3Ge`07e`030=OG00SG00<0emL01mL00`3Ge`07e`030=OG00SG00<0emL01mL00`3Ge`08e`03
0=OG00OG00<0emL01mL00`3Ge`08e`030=OG00OG00<0emL01mL00`3Ge`08e`030=OG00OG00<0emL0
2=L00`3Ge`07e`802=L000OG00<0emL07ML00`3Ge`0ae`030=OG037G00<0emL0<ML00`3Ge`0ae`03
0=OG01gG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`030=OG00KG0007e`030=OG08GG00<0emL0
QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`03
0=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL0
1]L000OG00<0emL0QML00`3Ge`25e`030=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`00
1mL00`3Ge`25e`030=OG08GG00<0emL01]L000OG00<0emL0QML208KG00<0emL01]L000OG00<0emL0
QML00`3Ge`25e`030=OG00KG0007e`030=OG08GG00<0emL0QML00`3Ge`06e`001mL00`3Ge`25e`03
0=OG08GG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`030=OG00KG0007e`030=OG08GG00<0emL0
QML00`3Ge`06e`001mL00`3Ge`25e`030=OG08GG00<0emL01]L000OG00<0emL0QML00`3Ge`25e`03
0=OG00KG0007e`030=OG08GG00<0emL0Q=L00`3Ge`07e`002=L00`3Ge`24e`030=OG08CG00<0emL0
1mL000SG00<0emL0Q=L00`3Ge`24e`030=OG00OG0008e`030=OG08CG0P25e`030=OG00OG0008e`03
0=OG08CG00<0emL0Q=L00`3Ge`07e`002=L00`3Ge`24e`030=OG08CG00<0emL01mL000SG00<0emL0
Q=L00`3Ge`24e`030=OG00OG0008e`030=OG08CG00<0emL0Q=L00`3Ge`07e`002=L00`3Ge`24e`03
0=OG08?G00<0emL02=L000WG00<0emL0PmL00`3Ge`23e`030=OG00SG0009e`030=OG08?G00<0emL0
PmL00`3Ge`08e`002ML00`3Ge`23e`030=OG08?G00<0emL02=L000WG00<0emL0PmL00`3Ge`23e`03
0=OG00SG0009e`030=OG08?G00<0emL0PmL00`3Ge`08e`002ML00`3Ge`23e`030=OG08?G00<0emL0
2=L000WG00<0emL0PmL208CG00<0emL02=L000[G00<0emL0P]L00`3Ge`22e`030=OG00WG000:e`03
0=OG08;G00<0emL0P]L00`3Ge`09e`002]L00`3Ge`22e`030=OG08;G00<0emL02ML000[G00<0emL0
P]L00`3Ge`22e`030=OG00WG000:e`030=OG08;G00<0emL0P]L00`3Ge`09e`002]L00`3Ge`22e`03
0=OG08;G00<0emL02ML000[G00<0emL0P]L00`3Ge`22e`030=OG00WG000:e`030=OG08;G00<0emL0
P]L00`3Ge`09e`002mL00`3Ge`1]e`801=L00`3Ge`02e`@01ML00`3Ge`21e`030=OG00[G000;e`03
0=OG06cG00@0emL02=L00`3Ge`06e`030=OG087G00<0emL02]L000_G00<0emL0K=L0103Ge`09e`03
0=OG00GG0`21e`030=OG00[G000;e`030=OG06cG00@0emL02]L00`3Ge`04e`030=OG087G00<0emL0
2]L000_G00<0emL0K=L0103Ge`0;e`030=OG00?G00<0emL0PML00`3Ge`0:e`002mL00`3Ge`1/e`04
0=OG00SG00@0emL01ML00`3Ge`21e`030=OG00[G000<e`030=OG06cG0P0:e`801]L00`3Ge`20e`03
0=OG00_G000<e`030=OG083G00<0emL0P=L00`3Ge`0;e`003=L00`3Ge`20e`030=OG083G00<0emL0
2mL000cG00<0emL0P=L00`3Ge`20e`030=OG00_G000<e`030=OG083G00<0emL0P=L00`3Ge`0;e`00
3ML00`3Ge`1oe`030=OG07gG1@0<e`003ML00`3Ge`1oe`030=OG07gG1@0<e`003ML00`3Ge`1oe`03
0=OG07cG1P0<e`003ML00`3Ge`1oe`80O]L500cG000=e`030=OG07oG00<0emL0OML500cG000>e`03
0=OG07kG00<0emL0O]L200kG000>e`030=OG07kG00<0emL0O]L00`3Ge`0=e`003]L00`3Ge`1ne`03
0=OG07kG00<0emL03ML000kG00<0emL0O]L00`3Ge`1ne`030=OG00gG000?e`030=OG07gG00<0emL0
OML00`3Ge`0>e`003mL00`3Ge`1me`030=OG07gG00<0emL03]L000oG00<0emL0OML00`3Ge`1me`03
0=OG00kG000?e`030=OG07gG00<0emL0OML00`3Ge`0>e`004=L00`3Ge`1le`030=OG07cG00<0emL0
3mL0013G00<0emL0O=L207gG00<0emL03mL0013G00<0emL0O=L00`3Ge`1le`030=OG00oG000Ae`03
0=OG07_G00<0emL0NmL00`3Ge`0@e`004ML00`3Ge`1ke`030=OG07_G00<0emL04=L0017G00<0emL0
NmL00`3Ge`1ke`030=OG013G000Ae`030=OG07_G00<0emL0NmL00`3Ge`0@e`004]L00`3Ge`1je`03
0=OG07[G00<0emL04ML001;G00<0emL0N]L00`3Ge`1je`030=OG017G000Be`030=OG07[G00<0emL0
N]L00`3Ge`0Ae`004mL00`3Ge`1ie`030=OG07WG00<0emL04]L001?G00<0emL0NML00`3Ge`1ie`03
0=OG01;G000De`030=OG07SG00<0emL0N=L00`3Ge`0Ce`005=L00`3Ge`1he`80NML00`3Ge`0Ce`00
5=L00`3Ge`1he`030=OG07SG00<0emL04mL001GG00<0emL0MmL00`3Ge`1ge`030=OG01CG000Ee`03
0=OG07OG00<0emL0MmL00`3Ge`0De`005ML00`3Ge`1ge`030=OG07OG00<0emL05=L001KG00<0emL0
M]L00`3Ge`1fe`030=OG01GG000Fe`030=OG07KG00<0emL0M]L00`3Ge`0Ee`005mL00`3Ge`1ee`03
0=OG07GG00<0emL05]L001OG00<0emL0MML00`3Ge`1ee`030=OG01KG000Ge`030=OG07GG00<0emL0
M=L00`3Ge`0Ge`006=L00`3Ge`1Pe`801=L00`3Ge`04e`030=OG00CG00<0emL0M=L00`3Ge`0Ge`00
6=L00`3Ge`1Oe`040=OG00[G00<0emL01=L00`3Ge`1ce`030=OG01SG000Ie`030=OG05kG00@0emL0
1mL500GG0`1ce`030=OG01SG000Ie`030=OG05kG00@0emL01mL0103Ge`06e`030=OG07;G00<0emL0
6ML001[G00<0emL0GML0103Ge`08e`030=L000KG00<0emL0L]L00`3Ge`0Ie`006]L00`3Ge`1Me`04
0=OG00WG0P06e`030=OG077G00<0emL06]L001_G00<0emL0GML200_G00<0emL01=L00`3Ge`1ae`03
0=OG01[G000Ke`030=OG077G00<0emL0L=L00`3Ge`0Ke`007=L00`3Ge`1`e`030=OG073G00<0emL0
6mL001cG00<0emL0L=L00`3Ge`1_e`030=OG01cG000Me`030=OG06oG00<0emL0K=L501gG000Ne`03
0=OG06kG00<0emL0K=L501gG000Ne`030=OG06kG00<0emL0JmL601gG000Oe`030=OG06gG0P1]e`D0
7ML001oG00<0emL0KML00`3Ge`1/e`D07ML0023G00<0emL0K=L00`3Ge`1/e`030=L001oG000Qe`03
0=OG06_G00<0emL0JmL00`3Ge`0Pe`008ML00`3Ge`1[e`030=OG06_G00<0emL08=L002;G00<0emL0
J]L00`3Ge`1Ze`030=OG027G000Re`030=OG06[G00<0emL0J]L00`3Ge`0Qe`008mL00`3Ge`1Ye`03
0=OG06WG00<0emL08]L002CG00<0emL0J=L00`3Ge`1Xe`030=OG02?G000Ue`030=OG06OG00<0emL0
ImL00`3Ge`0Te`009]L00`3Ge`1Ve`030=OG06KG00<0emL09ML002OG00<0emL0IML00`3Ge`1Ue`03
0=OG02KG000We`030=OG06GG0P1Ve`030=OG02KG000Xe`030=OG06CG00<0emL0I=L00`3Ge`0We`00
:ML00`3Ge`1Se`030=OG06?G00<0emL0:=L002[G00<0emL0H]L00`3Ge`1Re`030=OG02WG000[e`03
0=OG063G1@1Pe`030=OG02[G000/e`030=OG05oG1@05e`D0EML00`3Ge`0[e`00;ML00`3Ge`1Je`/0
0mL505CG00<0emL0;=L002kG00<0emL0D]L700CG1@02e`P0DmL00`3Ge`0]e`00;mL204kG100;e`D0
1ML800GG1@14e`80<=L0037G00<0emL0AmL4013G0P07e`D00mL40003e`0000<0@mL00`3Ge`0`e`00
<]L00`3Ge`13e`<05=L00`3Ge`08e`030=OG00OG1P12e`030=OG037G000ce`030=OG03oG0`0Ge`80
5=L5047G00<0emL0<]L003CG0P0me`806]L00`3Ge`0Ce`L0>ML603GG000fe`030=OG03OG0`0Le`03
0=OG01GG00<0emL00]L300KG1@0[e`D0=]L003OG0P0de`<07mL00`3Ge`0Me`<00mL502[G1P0fe`00
>ML202kG100Re`030=OG023G200Ze`H0=]L003_G0P0Xe`@09]L00`3Ge`0Se`D0:=L20003e`0000<0
=]L003gG0`0Re`<0:]L00`3Ge`0Se`P08]L300GG00<0emL0=]L0043G0`0Ke`@0;ML00`3Ge`0Ue`03
0=OG00?G100:e`D03=L3047G0013e`H04ML4037G00<0emL0;mL400KG1@06e`H0A=L004WG4@0ee`03
0=OG03?G4@1:e`00NmL200CG00<0emL00mL200KG00<0emL0>ML5053G001je`040=OG00SG00@0emL0
1ML00`3Ge`0ie`D0D=L007[G00@0emL02=L0103Ge`05e`<0>mL00`3Ge`1@e`00N]L0103Ge`08e`<0
1]L00`3Ge`2>e`00N]L0103Ge`08e`030=OG00KG00<0emL0S]L007[G00@0emL02=L00`3Ge`06e`03
0=OG08kG001ke`802]L300GG00<0emL0S]L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.38217, -0.619431, 0.00963187, \
0.0043166}}]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      Step\ 2 : 
        Calculate\ the\ separation\ constants\ \(\(b\)\(.\)\)\ *) \)\(\n\
\)\(Clear[fst, delta, b, tb]; fst = 2.3; delta = fst/n; b[1] = fst - 0.0001; 
    Table[b[k + 1] = b[k] - delta, {k, 1, n}]; 
    tb = Table[b[k], {k, 1, n}];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Step\ 3 : \ 
        Fill\ matrix\ MM\ for\ the\ boundary\ condition\ *) \)\(\n\)\(Clear[
      M, MM, k, W]; M = Table[ip*li, {li, 1, n}, {ip, 1, n}]; 
    MM = Table[
        M[\([li, ip]\)] = 
          Cos[Sqrt[k^2 - b[ip]^2]*x[li]]*Cos[b[ip]*y[li]], {li, 1, n}, {ip, 
          1, n}]; \(W[k_] = Det[MM];\) // Timing\)\)\)], "Input"],

Cell[BoxData[
    \({167.12`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Step\ 4 : \ 
        Find\ the\ eigenvalue\ k . \ 
            Do\ not\ forget\ to\ define\ the\ result\ as\ k\ *) \)\(\n\
\)\(Clear[k]; 
    FindRoot[W[k] \[Equal] 0, {k, {fst, 3.0}}] // Timing\)\)\)], "Input"],

Cell[BoxData[
    \({41.359999999999985`\ Second, {k \[Rule] 
          2.995715143901334`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(k = 2.99572\)], "Input"],

Cell[BoxData[
    \(2.99572`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Step\ 5 : \ 
        Calculate\ the\ partial\ amplitudes\ A[n]\ *) \)\(\n\)\(nf = n - 1; 
    bbf = Table[\(-MM[\([\)\(\ \)\(ifit, n\)\(]\)]\), {ifit, 1, nf}];\n
    rdutn = 
      Table[MM[\([\)\(ifit, klfit\)\(]\)], {ifit, 1, nf}, {klfit, 1, nf}]; 
    B = LinearSolve[rdutn, bbf]; An = {1}; 
    A = Table[B[\([\)\(lk\)\(]\)], {lk, 1, nf}]\)\)\)], "Input"],

Cell[BoxData[
    \({\(-0.005150479823585538`\), 
      0.06431960953182037`, \(-0.3604468058394886`\), 
      1.185088155603926`, \(-2.4945228353605313`\), 
      3.3992474637253967`, \(-2.7885351124680806`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Step\ 6 : \ 
        Check\ satisfaction\ of\ the\ boundary\ condition\ *) \)\(\n\)\(Amp = 
      Join[A, An]; boundary\  = \ MM\  . \ Amp\)\)\)], "Input"],

Cell[BoxData[
    \({0.`, \(-3.3306690738754696`*^-16\), \(-3.3306690738754696`*^-16\), 
      1.3877787807814457`*^-16, 2.7755575615628914`*^-16, 
      2.220446049250313`*^-16, 
      1.1102230246251565`*^-16, \(-2.6098012639863555`*^-12\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fxy[x_, y_] = 
        Sum[Amp[\([l]\)]*Cos[b[l]*y]*Cos[Sqrt[k^2 - b[l]^2]*x], {l, 1, 
            n}];\)\), "\n", 
    \(Do[Print[fxy[x[l], y[l]]], {l, 1, n}]\)}], "Input"],

Cell[BoxData[
    \(0.`\)], "Print"],

Cell[BoxData[
    \(\(-5.874207370526463`*^-16\)\)], "Print"],

Cell[BoxData[
    \(\(-5.072914202423895`*^-16\)\)], "Print"],

Cell[BoxData[
    \(1.4582519219930035`*^-16\)], "Print"],

Cell[BoxData[
    \(2.1250362580715887`*^-17\)], "Print"],

Cell[BoxData[
    \(3.213575239247035`*^-16\)], "Print"],

Cell[BoxData[
    \(\(-3.961674738262033`*^-16\)\)], "Print"],

Cell[BoxData[
    \(\(-2.6098697855636566`*^-12\)\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[pl4]; 
    pl4 = ContourPlot[fxy[x, y], {x, xmin, xmax}, {y, ymin, ymax}, 
        ContourShading \[Rule] False, ContourSmoothing -> 2, 
        PlotPoints \[Rule] 60 (*\(,\)\(Contours \[Rule] {0}\)*) ]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.366317 0.5 0.912652 [
[.13368 -0.0125 -6 -9 ]
[.13368 -0.0125 6 0 ]
[.31684 -0.0125 -12 -9 ]
[.31684 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68316 -0.0125 -9 -9 ]
[.68316 -0.0125 9 0 ]
[.86632 -0.0125 -3 -9 ]
[.86632 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .13494 -24 -4.5 ]
[-0.0125 .13494 0 4.5 ]
[-0.0125 .31747 -24 -4.5 ]
[-0.0125 .31747 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .68253 -18 -4.5 ]
[-0.0125 .68253 0 4.5 ]
[-0.0125 .86506 -18 -4.5 ]
[-0.0125 .86506 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13368 0 m
.13368 .00625 L
s
[(-1)] .13368 -0.0125 0 1 Mshowa
.31684 0 m
.31684 .00625 L
s
[(-0.5)] .31684 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68316 0 m
.68316 .00625 L
s
[(0.5)] .68316 -0.0125 0 1 Mshowa
.86632 0 m
.86632 .00625 L
s
[(1)] .86632 -0.0125 0 1 Mshowa
.125 Mabswid
.17031 0 m
.17031 .00375 L
s
.20695 0 m
.20695 .00375 L
s
.24358 0 m
.24358 .00375 L
s
.28021 0 m
.28021 .00375 L
s
.35347 0 m
.35347 .00375 L
s
.3901 0 m
.3901 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.46337 0 m
.46337 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.57326 0 m
.57326 .00375 L
s
.6099 0 m
.6099 .00375 L
s
.64653 0 m
.64653 .00375 L
s
.71979 0 m
.71979 .00375 L
s
.75642 0 m
.75642 .00375 L
s
.79305 0 m
.79305 .00375 L
s
.82969 0 m
.82969 .00375 L
s
.09705 0 m
.09705 .00375 L
s
.06042 0 m
.06042 .00375 L
s
.02379 0 m
.02379 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.93958 0 m
.93958 .00375 L
s
.97621 0 m
.97621 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13494 m
.00625 .13494 L
s
[(-0.4)] -0.0125 .13494 1 0 Mshowa
0 .31747 m
.00625 .31747 L
s
[(-0.2)] -0.0125 .31747 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .68253 m
.00625 .68253 L
s
[(0.2)] -0.0125 .68253 1 0 Mshowa
0 .86506 m
.00625 .86506 L
s
[(0.4)] -0.0125 .86506 1 0 Mshowa
.125 Mabswid
0 .18057 m
.00375 .18057 L
s
0 .2262 m
.00375 .2262 L
s
0 .27184 m
.00375 .27184 L
s
0 .3631 m
.00375 .3631 L
s
0 .40873 m
.00375 .40873 L
s
0 .45437 m
.00375 .45437 L
s
0 .54563 m
.00375 .54563 L
s
0 .59127 m
.00375 .59127 L
s
0 .6369 m
.00375 .6369 L
s
0 .72816 m
.00375 .72816 L
s
0 .7738 m
.00375 .7738 L
s
0 .81943 m
.00375 .81943 L
s
0 .08931 m
.00375 .08931 L
s
0 .04367 m
.00375 .04367 L
s
0 .91069 m
.00375 .91069 L
s
0 .95633 m
.00375 .95633 L
s
.25 Mabswid
0 0 m
0 1 L
s
.13368 .99375 m
.13368 1 L
s
.31684 .99375 m
.31684 1 L
s
.5 .99375 m
.5 1 L
s
.68316 .99375 m
.68316 1 L
s
.86632 .99375 m
.86632 1 L
s
.125 Mabswid
.17031 .99625 m
.17031 1 L
s
.20695 .99625 m
.20695 1 L
s
.24358 .99625 m
.24358 1 L
s
.28021 .99625 m
.28021 1 L
s
.35347 .99625 m
.35347 1 L
s
.3901 .99625 m
.3901 1 L
s
.42674 .99625 m
.42674 1 L
s
.46337 .99625 m
.46337 1 L
s
.53663 .99625 m
.53663 1 L
s
.57326 .99625 m
.57326 1 L
s
.6099 .99625 m
.6099 1 L
s
.64653 .99625 m
.64653 1 L
s
.71979 .99625 m
.71979 1 L
s
.75642 .99625 m
.75642 1 L
s
.79305 .99625 m
.79305 1 L
s
.82969 .99625 m
.82969 1 L
s
.09705 .99625 m
.09705 1 L
s
.06042 .99625 m
.06042 1 L
s
.02379 .99625 m
.02379 1 L
s
.90295 .99625 m
.90295 1 L
s
.93958 .99625 m
.93958 1 L
s
.97621 .99625 m
.97621 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .13494 m
1 .13494 L
s
.99375 .31747 m
1 .31747 L
s
.99375 .5 m
1 .5 L
s
.99375 .68253 m
1 .68253 L
s
.99375 .86506 m
1 .86506 L
s
.125 Mabswid
.99625 .18057 m
1 .18057 L
s
.99625 .2262 m
1 .2262 L
s
.99625 .27184 m
1 .27184 L
s
.99625 .3631 m
1 .3631 L
s
.99625 .40873 m
1 .40873 L
s
.99625 .45437 m
1 .45437 L
s
.99625 .54563 m
1 .54563 L
s
.99625 .59127 m
1 .59127 L
s
.99625 .6369 m
1 .6369 L
s
.99625 .72816 m
1 .72816 L
s
.99625 .7738 m
1 .7738 L
s
.99625 .81943 m
1 .81943 L
s
.99625 .08931 m
1 .08931 L
s
.99625 .04367 m
1 .04367 L
s
.99625 .91069 m
1 .91069 L
s
.99625 .95633 m
1 .95633 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.01923 .84091 m
.02173 .83409 L
.02473 .8178 L
.02578 .8015 L
.02552 .7852 L
.024 .7689 L
.021 .75261 L
.01923 .74579 L
s
.01923 .25421 m
.021 .24739 L
.024 .2311 L
.02552 .2148 L
.02578 .1985 L
.02473 .1822 L
.02173 .16591 L
.01923 .15909 L
s
.98077 .84091 m
.97827 .83409 L
.97527 .8178 L
.97422 .8015 L
.97448 .7852 L
.976 .7689 L
.979 .75261 L
.98077 .74579 L
s
.98077 .25421 m
.979 .24739 L
.976 .2311 L
.97448 .2148 L
.97422 .1985 L
.97527 .1822 L
.97827 .16591 L
.98077 .15909 L
s
.01923 .86526 m
.02814 .85039 L
.03161 .83409 L
.03385 .8178 L
.03475 .8015 L
.03439 .7852 L
.03287 .7689 L
.03016 .75261 L
.02607 .73631 L
.01987 .72001 L
.01923 .7187 L
s
.01923 .2813 m
.01987 .27999 L
.02607 .26369 L
.03016 .24739 L
.03287 .2311 L
.03439 .2148 L
.03475 .1985 L
.03385 .1822 L
.03161 .16591 L
.02814 .14961 L
.01923 .13474 L
s
.98077 .86526 m
.97186 .85039 L
.96839 .83409 L
.96615 .8178 L
.96525 .8015 L
.96561 .7852 L
.96713 .7689 L
.96984 .75261 L
.97393 .73631 L
.98013 .72001 L
.98077 .7187 L
s
.98077 .2813 m
.98013 .27999 L
.97393 .26369 L
.96984 .24739 L
.96713 .2311 L
.96561 .2148 L
.96525 .1985 L
.96615 .1822 L
.96839 .16591 L
.97186 .14961 L
.98077 .13474 L
s
.01923 .88379 m
.02014 .88299 L
.03482 .86669 L
.03553 .86506 L
.04217 .85039 L
.04649 .83409 L
.04829 .8178 L
.04841 .8015 L
.04727 .7852 L
.04503 .7689 L
.04173 .75261 L
.03731 .73631 L
.03553 .73076 L
.03152 .72001 L
.02355 .70372 L
.01923 .69718 L
s
.01923 .30282 m
.02355 .29628 L
.03152 .27999 L
.03553 .26924 L
.03731 .26369 L
.04173 .24739 L
.04503 .2311 L
.04727 .2148 L
.04841 .1985 L
.04829 .1822 L
.04649 .16591 L
.04217 .14961 L
.03553 .13494 L
.03482 .13331 L
.02014 .11701 L
.01923 .11621 L
s
.98077 .88379 m
.97986 .88299 L
.96518 .86669 L
.96447 .86506 L
.95783 .85039 L
.95351 .83409 L
.95171 .8178 L
.95159 .8015 L
.95273 .7852 L
.95497 .7689 L
.95827 .75261 L
.96269 .73631 L
.96447 .73076 L
.96848 .72001 L
.97645 .70372 L
.98077 .69718 L
s
.98077 .30282 m
.97645 .29628 L
.96848 .27999 L
.96447 .26924 L
.96269 .26369 L
.95827 .24739 L
.95497 .2311 L
.95273 .2148 L
.95159 .1985 L
.95171 .1822 L
.95351 .16591 L
.95783 .14961 L
.96447 .13494 L
.96518 .13331 L
.97986 .11701 L
.98077 .11621 L
s
.92896 .98077 m
.92243 .96447 L
.91558 .95265 L
.91164 .94817 L
.89928 .94219 L
.88299 .94634 L
.87793 .94817 L
.86669 .95966 L
.86229 .96447 L
.85057 .98077 L
s
.14943 .98077 m
.13771 .96447 L
.13331 .95966 L
.12207 .94817 L
.11701 .94634 L
.10072 .94219 L
.08836 .94817 L
.08442 .95265 L
.07757 .96447 L
.07104 .98077 L
s
.92896 .01923 m
.92243 .03553 L
.91558 .04735 L
.91164 .05183 L
.89928 .05781 L
.88299 .05366 L
.87793 .05183 L
.86669 .04034 L
.86229 .03553 L
.85057 .01923 L
s
.14943 .01923 m
.13771 .03553 L
.13331 .04034 L
.12207 .05183 L
.11701 .05366 L
.10072 .05781 L
.08836 .05183 L
.08442 .04735 L
.07757 .03553 L
.07104 .01923 L
s
.98077 .89975 m
.97904 .89928 L
.96447 .89723 L
.95558 .89928 L
.94817 .90608 L
.94433 .91558 L
.94166 .93188 L
.94119 .94817 L
.94195 .96447 L
.94354 .98077 L
s
.98077 .67796 m
.97185 .68742 L
.96447 .69781 L
.96093 .70372 L
.95262 .72001 L
.94817 .73039 L
.94599 .73631 L
.94058 .75261 L
.93591 .7689 L
.93188 .78468 L
.93175 .7852 L
.92794 .8015 L
.92399 .8178 L
.91919 .83409 L
.91558 .84312 L
.91157 .85039 L
.89928 .86461 L
.89698 .86669 L
.88299 .87858 L
.87774 .88299 L
.86669 .89339 L
.86076 .89928 L
.85039 .9107 L
.84619 .91558 L
.83409 .93057 L
.83308 .93188 L
.82064 .94817 L
.8178 .95189 L
.80802 .96447 L
.8015 .97213 L
.79351 .98077 L
s
.60906 .98077 m
.60593 .97976 L
.58963 .97454 L
.57334 .96961 L
.55704 .96529 L
.55366 .96447 L
.54074 .96184 L
.52445 .95944 L
.50815 .95821 L
.49185 .95821 L
.47555 .95944 L
.45926 .96184 L
.44634 .96447 L
.44296 .96529 L
.42666 .96961 L
.41037 .97454 L
.39407 .97976 L
.39094 .98077 L
s
.01923 .67796 m
.02815 .68742 L
.03553 .69781 L
.03907 .70372 L
.04738 .72001 L
.05183 .73039 L
.05401 .73631 L
.05942 .75261 L
.06409 .7689 L
.06812 .78468 L
.06825 .7852 L
.07206 .8015 L
.07601 .8178 L
.08081 .83409 L
.08442 .84312 L
.08843 .85039 L
.10072 .86461 L
.10302 .86669 L
.11701 .87858 L
.12226 .88299 L
.13331 .89339 L
.13924 .89928 L
.14961 .9107 L
.15381 .91558 L
.16591 .93057 L
.16692 .93188 L
.17936 .94817 L
.1822 .95189 L
.19198 .96447 L
.1985 .97213 L
.20649 .98077 L
s
.01923 .89975 m
.02096 .89928 L
.03553 .89723 L
.04442 .89928 L
.05183 .90608 L
.05567 .91558 L
.05834 .93188 L
.05881 .94817 L
.05805 .96447 L
.05646 .98077 L
s
.98077 .10025 m
.97904 .10072 L
.96447 .10277 L
.95558 .10072 L
.94817 .09392 L
.94433 .08442 L
.94166 .06812 L
.94119 .05183 L
.94195 .03553 L
.94354 .01923 L
s
.98077 .32204 m
.97185 .31258 L
.96447 .30219 L
.96093 .29628 L
.95262 .27999 L
.94817 .26961 L
.94599 .26369 L
.94058 .24739 L
.93591 .2311 L
.93188 .21532 L
.93175 .2148 L
.92794 .1985 L
.92399 .1822 L
.91919 .16591 L
.91558 .15688 L
.91157 .14961 L
.89928 .13539 L
.89698 .13331 L
.88299 .12142 L
.87774 .11701 L
.86669 .10661 L
.86076 .10072 L
.85039 .0893 L
.84619 .08442 L
.83409 .06943 L
.83308 .06812 L
.82064 .05183 L
.8178 .04811 L
.80802 .03553 L
.8015 .02787 L
.79351 .01923 L
s
.60906 .01923 m
.60593 .02024 L
.58963 .02546 L
.57334 .03039 L
.55704 .03471 L
.55366 .03553 L
.54074 .03816 L
.52445 .04056 L
.50815 .04179 L
.49185 .04179 L
.47555 .04056 L
.45926 .03816 L
.44634 .03553 L
.44296 .03471 L
.42666 .03039 L
.41037 .02546 L
.39407 .02024 L
.39094 .01923 L
s
.01923 .32204 m
.02815 .31258 L
.03553 .30219 L
.03907 .29628 L
.04738 .27999 L
.05183 .26961 L
.05401 .26369 L
.05942 .24739 L
.06409 .2311 L
.06812 .21532 L
.06825 .2148 L
.07206 .1985 L
.07601 .1822 L
.08081 .16591 L
.08442 .15688 L
.08843 .14961 L
.10072 .13539 L
.10302 .13331 L
.11701 .12142 L
.12226 .11701 L
.13331 .10661 L
.13924 .10072 L
.14961 .0893 L
.15381 .08442 L
.16591 .06943 L
.16692 .06812 L
.17936 .05183 L
.1822 .04811 L
.19198 .03553 L
.1985 .02787 L
.20649 .01923 L
s
.01923 .10025 m
.02096 .10072 L
.03553 .10277 L
.04442 .10072 L
.05183 .09392 L
.05567 .08442 L
.05834 .06812 L
.05881 .05183 L
.05805 .03553 L
.05646 .01923 L
s
.01923 .65974 m
.03553 .67006 L
.03681 .67112 L
.05183 .68656 L
.05251 .68742 L
.06397 .70372 L
.06812 .71048 L
.07353 .72001 L
.08219 .73631 L
.08442 .74061 L
.09069 .75261 L
.0996 .7689 L
.10072 .77084 L
.10964 .7852 L
.11701 .79584 L
.12123 .8015 L
.13331 .81655 L
.13435 .8178 L
.14837 .83409 L
.14961 .83551 L
.16269 .85039 L
.16591 .85403 L
.17718 .86669 L
.1822 .87222 L
.19225 .88299 L
.1985 .88935 L
.20897 .89928 L
.2148 .90428 L
.23021 .91558 L
.2311 .91613 L
.24739 .92467 L
.26369 .93032 L
.2695 .93188 L
.27999 .93376 L
.29628 .93555 L
.31258 .93607 L
.32888 .93555 L
.34518 .93412 L
.36147 .9319 L
.36159 .93188 L
.37777 .92905 L
.39407 .92578 L
.41037 .92236 L
.42666 .91904 L
.44296 .91607 L
.44586 .91558 L
.45926 .91366 L
.47555 .91196 L
.49185 .91109 L
.50815 .91109 L
Mistroke
.52445 .91196 L
.54074 .91366 L
.55414 .91558 L
.55704 .91607 L
.57334 .91904 L
.58963 .92236 L
.60593 .92578 L
.62223 .92905 L
.63841 .93188 L
.63853 .9319 L
.65482 .93412 L
.67112 .93555 L
.68742 .93607 L
.70372 .93555 L
.72001 .93376 L
.7305 .93188 L
.73631 .93032 L
.75261 .92467 L
.7689 .91613 L
.76979 .91558 L
.7852 .90428 L
.79103 .89928 L
.8015 .88935 L
.80775 .88299 L
.8178 .87222 L
.82282 .86669 L
.83409 .85403 L
.83731 .85039 L
.85039 .83551 L
.85163 .83409 L
.86565 .8178 L
.86669 .81655 L
.87877 .8015 L
.88299 .79584 L
.89036 .7852 L
.89928 .77084 L
.9004 .7689 L
.90931 .75261 L
.91558 .74061 L
.91781 .73631 L
.92647 .72001 L
.93188 .71048 L
.93603 .70372 L
.94749 .68742 L
.94817 .68656 L
.96319 .67112 L
.96447 .67006 L
.98077 .65974 L
Mfstroke
.01923 .34026 m
.03553 .32994 L
.03681 .32888 L
.05183 .31344 L
.05251 .31258 L
.06397 .29628 L
.06812 .28952 L
.07353 .27999 L
.08219 .26369 L
.08442 .25939 L
.09069 .24739 L
.0996 .2311 L
.10072 .22916 L
.10964 .2148 L
.11701 .20416 L
.12123 .1985 L
.13331 .18345 L
.13435 .1822 L
.14837 .16591 L
.14961 .16449 L
.16269 .14961 L
.16591 .14597 L
.17718 .13331 L
.1822 .12778 L
.19225 .11701 L
.1985 .11065 L
.20897 .10072 L
.2148 .09572 L
.23021 .08442 L
.2311 .08387 L
.24739 .07533 L
.26369 .06968 L
.2695 .06812 L
.27999 .06624 L
.29628 .06445 L
.31258 .06393 L
.32888 .06445 L
.34518 .06588 L
.36147 .0681 L
.36159 .06812 L
.37777 .07095 L
.39407 .07422 L
.41037 .07764 L
.42666 .08096 L
.44296 .08393 L
.44586 .08442 L
.45926 .08634 L
.47555 .08804 L
.49185 .08891 L
.50815 .08891 L
Mistroke
.52445 .08804 L
.54074 .08634 L
.55414 .08442 L
.55704 .08393 L
.57334 .08096 L
.58963 .07764 L
.60593 .07422 L
.62223 .07095 L
.63841 .06812 L
.63853 .0681 L
.65482 .06588 L
.67112 .06445 L
.68742 .06393 L
.70372 .06445 L
.72001 .06624 L
.7305 .06812 L
.73631 .06968 L
.75261 .07533 L
.7689 .08387 L
.76979 .08442 L
.7852 .09572 L
.79104 .10072 L
.8015 .11065 L
.80775 .11701 L
.8178 .12778 L
.82282 .13331 L
.83409 .14597 L
.83731 .14961 L
.85039 .16449 L
.85163 .16591 L
.86565 .1822 L
.86669 .18345 L
.87877 .1985 L
.88299 .20416 L
.89036 .2148 L
.89928 .22916 L
.9004 .2311 L
.90931 .24739 L
.91558 .25939 L
.91781 .26369 L
.92647 .27999 L
.93188 .28952 L
.93603 .29628 L
.94749 .31258 L
.94817 .31344 L
.96319 .32888 L
.96447 .32994 L
.98077 .34026 L
Mfstroke
.98077 .9143 m
.97687 .91558 L
.96447 .92504 L
.96054 .93188 L
.95536 .94817 L
.95307 .96447 L
.95247 .98077 L
s
.01923 .9143 m
.02313 .91558 L
.03553 .92504 L
.03946 .93188 L
.04464 .94817 L
.04693 .96447 L
.04753 .98077 L
s
.98077 .0857 m
.97687 .08442 L
.96447 .07496 L
.96054 .06812 L
.95536 .05183 L
.95307 .03553 L
.95247 .01923 L
s
.01923 .0857 m
.02313 .08442 L
.03553 .07496 L
.03946 .06812 L
.04464 .05183 L
.04693 .03553 L
.04753 .01923 L
s
.01923 .64175 m
.03553 .64371 L
.05183 .64868 L
.06373 .65482 L
.06812 .65773 L
.08398 .67112 L
.08442 .67156 L
.09883 .68742 L
.10072 .6897 L
.11188 .70372 L
.11701 .7104 L
.12436 .72001 L
.13331 .73167 L
.13691 .73631 L
.14961 .75235 L
.14981 .75261 L
.16318 .7689 L
.16591 .77215 L
.17712 .7852 L
.1822 .79093 L
.19188 .8015 L
.1985 .80841 L
.20796 .8178 L
.2148 .82414 L
.22651 .83409 L
.2311 .83764 L
.24739 .84866 L
.25032 .85039 L
.26369 .85722 L
.27999 .86357 L
.29056 .86669 L
.29628 .86802 L
.31258 .87091 L
.32888 .87249 L
.34518 .87298 L
.36147 .87256 L
.37777 .87143 L
.39407 .8698 L
.41037 .86789 L
.42018 .86669 L
.42666 .8659 L
.44296 .86405 L
.45926 .8625 L
.47555 .86139 L
.49185 .86081 L
.50815 .86081 L
.52445 .86139 L
.54074 .8625 L
.55704 .86405 L
.57334 .8659 L
Mistroke
.57982 .86669 L
.58963 .86789 L
.60593 .8698 L
.62223 .87143 L
.63853 .87256 L
.65482 .87298 L
.67112 .87249 L
.68742 .87091 L
.70372 .86802 L
.70944 .86669 L
.72001 .86357 L
.73631 .85722 L
.74968 .85039 L
.75261 .84866 L
.7689 .83764 L
.77349 .83409 L
.7852 .82414 L
.79204 .8178 L
.8015 .80841 L
.80812 .8015 L
.8178 .79093 L
.82288 .7852 L
.83409 .77215 L
.83682 .7689 L
.85019 .75261 L
.85039 .75235 L
.86309 .73631 L
.86669 .73167 L
.87564 .72001 L
.88299 .7104 L
.88812 .70372 L
.89928 .6897 L
.90117 .68742 L
.91558 .67156 L
.91602 .67112 L
.93188 .65773 L
.93627 .65482 L
.94817 .64868 L
.96447 .64371 L
.98077 .64175 L
Mfstroke
.01923 .35825 m
.03553 .35629 L
.05183 .35132 L
.06373 .34518 L
.06812 .34227 L
.08398 .32888 L
.08442 .32844 L
.09883 .31258 L
.10072 .3103 L
.11188 .29628 L
.11701 .2896 L
.12436 .27999 L
.13331 .26833 L
.13691 .26369 L
.14961 .24765 L
.14981 .24739 L
.16318 .2311 L
.16591 .22785 L
.17712 .2148 L
.1822 .20907 L
.19188 .1985 L
.1985 .19159 L
.20796 .1822 L
.2148 .17586 L
.22651 .16591 L
.2311 .16236 L
.24739 .15134 L
.25032 .14961 L
.26369 .14278 L
.27999 .13643 L
.29056 .13331 L
.29628 .13198 L
.31258 .12909 L
.32888 .12751 L
.34518 .12702 L
.36147 .12744 L
.37777 .12857 L
.39407 .1302 L
.41037 .13211 L
.42018 .13331 L
.42666 .1341 L
.44296 .13595 L
.45926 .1375 L
.47555 .13861 L
.49185 .13919 L
.50815 .13919 L
.52445 .13861 L
.54074 .1375 L
.55704 .13595 L
.57334 .1341 L
Mistroke
.57982 .13331 L
.58963 .13211 L
.60593 .1302 L
.62223 .12857 L
.63853 .12744 L
.65482 .12702 L
.67112 .12751 L
.68742 .12909 L
.70372 .13198 L
.70944 .13331 L
.72001 .13643 L
.73631 .14278 L
.74968 .14961 L
.75261 .15134 L
.7689 .16236 L
.77349 .16591 L
.7852 .17586 L
.79204 .1822 L
.8015 .19159 L
.80812 .1985 L
.8178 .20907 L
.82288 .2148 L
.83409 .22785 L
.83682 .2311 L
.85019 .24739 L
.85039 .24765 L
.86309 .26369 L
.86669 .26833 L
.87564 .27999 L
.88299 .2896 L
.88812 .29628 L
.89928 .3103 L
.90117 .31258 L
.91558 .32844 L
.91602 .32888 L
.93188 .34227 L
.93627 .34518 L
.94817 .35132 L
.96447 .35629 L
.98077 .35825 L
Mfstroke
.98077 .92809 m
.97611 .93188 L
.96632 .94817 L
.96447 .95382 L
.96207 .96447 L
.96008 .98077 L
s
.01923 .92809 m
.02389 .93188 L
.03368 .94817 L
.03553 .95382 L
.03793 .96447 L
.03992 .98077 L
s
.98077 .07191 m
.97611 .06812 L
.96632 .05183 L
.96447 .04618 L
.96207 .03553 L
.96008 .01923 L
s
.01923 .07191 m
.02389 .06812 L
.03368 .05183 L
.03553 .04618 L
.03793 .03553 L
.03992 .01923 L
s
.01923 .62331 m
.02199 .62223 L
.03553 .61659 L
.05183 .60965 L
.06123 .60593 L
.06812 .60369 L
.08442 .60093 L
.10072 .60407 L
.10552 .60593 L
.11701 .61464 L
.12497 .62223 L
.13331 .63165 L
.13892 .63853 L
.14961 .65252 L
.15132 .65482 L
.16326 .67112 L
.16591 .67473 L
.17527 .68742 L
.1822 .6966 L
.1877 .70372 L
.1985 .71717 L
.20087 .72001 L
.2148 .73588 L
.2152 .73631 L
.2311 .75239 L
.23132 .75261 L
.24739 .76653 L
.25044 .7689 L
.26369 .77825 L
.27531 .7852 L
.27999 .78768 L
.29628 .79502 L
.31258 .80053 L
.31597 .8015 L
.32888 .80448 L
.34518 .80711 L
.36147 .80864 L
.37777 .80929 L
.39407 .80927 L
.41037 .80879 L
.42666 .80804 L
.44296 .80721 L
.45926 .80644 L
.47555 .80586 L
.49185 .80555 L
.50815 .80555 L
.52445 .80586 L
.54074 .80644 L
.55704 .80721 L
.57334 .80804 L
Mistroke
.58963 .80879 L
.60593 .80927 L
.62223 .80929 L
.63853 .80864 L
.65482 .80711 L
.67112 .80448 L
.68403 .8015 L
.68742 .80053 L
.70372 .79502 L
.72001 .78768 L
.72469 .7852 L
.73631 .77825 L
.74956 .7689 L
.75261 .76653 L
.76868 .75261 L
.7689 .75239 L
.7848 .73631 L
.7852 .73588 L
.79913 .72001 L
.8015 .71717 L
.8123 .70372 L
.8178 .6966 L
.82473 .68742 L
.83409 .67474 L
.83674 .67112 L
.84868 .65482 L
.85039 .65252 L
.86108 .63853 L
.86669 .63165 L
.87503 .62223 L
.88299 .61464 L
.89448 .60593 L
.89928 .60407 L
.91558 .60093 L
.93188 .60369 L
.93877 .60593 L
.94817 .60965 L
.96447 .61659 L
.97801 .62223 L
.98077 .62331 L
Mfstroke
.01923 .37669 m
.02199 .37777 L
.03553 .38341 L
.05183 .39035 L
.06123 .39407 L
.06812 .39631 L
.08442 .39907 L
.10072 .39593 L
.10552 .39407 L
.11701 .38536 L
.12497 .37777 L
.13331 .36835 L
.13892 .36147 L
.14961 .34748 L
.15132 .34518 L
.16326 .32888 L
.16591 .32527 L
.17527 .31258 L
.1822 .3034 L
.1877 .29628 L
.1985 .28283 L
.20087 .27999 L
.2148 .26412 L
.2152 .26369 L
.2311 .24761 L
.23132 .24739 L
.24739 .23347 L
.25044 .2311 L
.26369 .22175 L
.27531 .2148 L
.27999 .21232 L
.29628 .20498 L
.31258 .19947 L
.31597 .1985 L
.32888 .19552 L
.34518 .19289 L
.36147 .19136 L
.37777 .19071 L
.39407 .19073 L
.41037 .19121 L
.42666 .19196 L
.44296 .19279 L
.45926 .19356 L
.47555 .19414 L
.49185 .19445 L
.50815 .19445 L
.52445 .19414 L
.54074 .19356 L
.55704 .19279 L
.57334 .19196 L
Mistroke
.58963 .19121 L
.60593 .19073 L
.62223 .19071 L
.63853 .19136 L
.65482 .19289 L
.67112 .19552 L
.68403 .1985 L
.68742 .19947 L
.70372 .20498 L
.72001 .21232 L
.72469 .2148 L
.73631 .22175 L
.74956 .2311 L
.75261 .23347 L
.76868 .24739 L
.7689 .24761 L
.7848 .26369 L
.7852 .26412 L
.79913 .27999 L
.8015 .28283 L
.8123 .29628 L
.8178 .3034 L
.82473 .31258 L
.83409 .32526 L
.83674 .32888 L
.84868 .34518 L
.85039 .34748 L
.86108 .36147 L
.86669 .36835 L
.87503 .37777 L
.88299 .38536 L
.89448 .39407 L
.89928 .39593 L
.91558 .39907 L
.93188 .39631 L
.93877 .39407 L
.94817 .39035 L
.96447 .38341 L
.97801 .37777 L
.98077 .37669 L
Mfstroke
.98077 .94155 m
.97583 .94817 L
.96925 .96447 L
.96609 .98077 L
s
.01923 .94155 m
.02417 .94817 L
.03075 .96447 L
.03391 .98077 L
s
.98077 .05845 m
.97583 .05183 L
.96925 .03553 L
.96609 .01923 L
s
.01923 .05845 m
.02417 .05183 L
.03075 .03553 L
.03391 .01923 L
s
.37777 .26242 m
.39407 .26051 L
.41037 .25934 L
.42666 .2587 L
.44296 .25843 L
.45926 .25836 L
.47555 .25838 L
.49185 .25841 L
.50815 .25841 L
.52445 .25838 L
.54074 .25836 L
.55704 .25843 L
.57334 .2587 L
.58963 .25934 L
.60593 .26051 L
.62223 .26242 L
.63027 .26369 L
.63853 .26531 L
.65482 .26942 L
.67112 .27502 L
.68256 .27999 L
.68742 .28241 L
.70372 .29194 L
.71003 .29628 L
.72001 .30399 L
.72978 .31258 L
.73631 .31897 L
.74547 .32888 L
.75261 .33742 L
.75858 .34518 L
.7689 .36005 L
.76982 .36147 L
.77962 .37777 L
.7852 .38813 L
.78818 .39407 L
.79562 .41037 L
.8015 .4253 L
.80199 .42666 L
.80724 .44296 L
.81131 .45926 L
.81412 .47555 L
.81556 .49185 L
.81556 .50815 L
.81412 .52445 L
.81131 .54074 L
.80724 .55704 L
.80199 .57334 L
.8015 .5747 L
.79562 .58963 L
.78818 .60593 L
Mistroke
.7852 .61187 L
.77962 .62223 L
.76982 .63853 L
.7689 .63995 L
.75858 .65482 L
.75261 .66258 L
.74547 .67112 L
.73631 .68103 L
.72978 .68742 L
.72001 .69601 L
.71003 .70372 L
.70372 .70806 L
.68742 .71759 L
.68256 .72001 L
.67112 .72498 L
.65482 .73058 L
.63853 .73469 L
.63027 .73631 L
.62223 .73758 L
.60593 .73949 L
.58963 .74066 L
.57334 .7413 L
.55704 .74157 L
.54074 .74164 L
.52445 .74162 L
.50815 .74159 L
.49185 .74159 L
.47555 .74162 L
.45926 .74164 L
.44296 .74157 L
.42666 .7413 L
.41037 .74066 L
.39407 .73949 L
.37777 .73758 L
.36973 .73631 L
.36147 .73469 L
.34518 .73058 L
.32888 .72498 L
.31744 .72001 L
.31258 .71759 L
.29628 .70806 L
.28997 .70372 L
.27999 .69601 L
.27022 .68742 L
.26369 .68103 L
.25453 .67112 L
.24739 .66258 L
.24142 .65482 L
.2311 .63995 L
.23018 .63853 L
Mistroke
.22038 .62223 L
.2148 .61187 L
.21182 .60593 L
.20438 .58963 L
.1985 .5747 L
.19801 .57334 L
.19276 .55704 L
.18869 .54074 L
.18588 .52445 L
.18444 .50815 L
.18444 .49185 L
.18588 .47555 L
.18869 .45926 L
.19276 .44296 L
.19801 .42666 L
.1985 .4253 L
.20438 .41037 L
.21182 .39407 L
.2148 .38813 L
.22038 .37777 L
.23018 .36147 L
.2311 .36005 L
.24142 .34518 L
.24739 .33742 L
.25453 .32888 L
.26369 .31897 L
.27022 .31258 L
.27999 .30399 L
.28997 .29628 L
.29628 .29194 L
.31258 .28241 L
.31744 .27999 L
.32888 .27502 L
.34518 .26942 L
.36147 .26531 L
.36973 .26369 L
.37777 .26242 L
Mfstroke
.01923 .60362 m
.03323 .58963 L
.03553 .58588 L
.04368 .57334 L
.05183 .55939 L
.05267 .55704 L
.05854 .54074 L
.06295 .52445 L
.06521 .50815 L
.06521 .49185 L
.06295 .47555 L
.05854 .45926 L
.05267 .44296 L
.05183 .44061 L
.04368 .42666 L
.03553 .41412 L
.03323 .41037 L
.01923 .39638 L
s
.98077 .60362 m
.96677 .58963 L
.96447 .58588 L
.95632 .57334 L
.94817 .55939 L
.94733 .55704 L
.94146 .54074 L
.93705 .52445 L
.93479 .50815 L
.93479 .49185 L
.93705 .47555 L
.94146 .45926 L
.94733 .44296 L
.94817 .44061 L
.95632 .42666 L
.96447 .41412 L
.96677 .41037 L
.98077 .39638 L
s
.98077 .95508 m
.97592 .96447 L
.97127 .98077 L
s
.01923 .95508 m
.02408 .96447 L
.02873 .98077 L
s
.98077 .04492 m
.97592 .03553 L
.97127 .01923 L
s
.01923 .04492 m
.02408 .03553 L
.02873 .01923 L
s
.44296 .34436 m
.45926 .34299 L
.47555 .34216 L
.49185 .34177 L
.50815 .34177 L
.52445 .34216 L
.54074 .34299 L
.55704 .34436 L
.56437 .34518 L
.57334 .34643 L
.58963 .34941 L
.60593 .35357 L
.62223 .35928 L
.62738 .36147 L
.63853 .367 L
.65482 .37741 L
.65531 .37777 L
.67112 .39151 L
.67359 .39407 L
.68677 .41037 L
.68742 .4113 L
.69661 .42666 L
.70372 .44245 L
.70391 .44296 L
.70913 .45926 L
.7125 .47555 L
.71415 .49185 L
.71415 .50815 L
.7125 .52445 L
.70913 .54074 L
.70391 .55704 L
.70372 .55755 L
.69661 .57334 L
.68742 .5887 L
.68677 .58963 L
.67359 .60593 L
.67112 .60849 L
.65531 .62223 L
.65482 .62259 L
.63853 .633 L
.62738 .63853 L
.62223 .64072 L
.60593 .64643 L
.58963 .65059 L
.57334 .65357 L
.56437 .65482 L
.55704 .65564 L
.54074 .65701 L
.52445 .65784 L
.50815 .65823 L
Mistroke
.49185 .65823 L
.47555 .65784 L
.45926 .65701 L
.44296 .65564 L
.43563 .65482 L
.42666 .65357 L
.41037 .65059 L
.39407 .64643 L
.37777 .64072 L
.37262 .63853 L
.36147 .633 L
.34518 .62259 L
.34469 .62223 L
.32888 .60849 L
.32641 .60593 L
.31323 .58963 L
.31258 .5887 L
.30339 .57334 L
.29628 .55755 L
.29609 .55704 L
.29087 .54074 L
.2875 .52445 L
.28585 .50815 L
.28585 .49185 L
.2875 .47555 L
.29087 .45926 L
.29609 .44296 L
.29628 .44245 L
.30339 .42666 L
.31258 .4113 L
.31323 .41037 L
.32641 .39407 L
.32888 .39151 L
.34469 .37777 L
.34518 .37741 L
.36147 .367 L
.37262 .36147 L
.37777 .35928 L
.39407 .35357 L
.41037 .34941 L
.42666 .34643 L
.43563 .34518 L
.44296 .34436 L
Mfstroke
.01923 .58131 m
.0254 .57334 L
.03157 .55704 L
.03553 .5422 L
.03585 .54074 L
.03882 .52445 L
.04035 .50815 L
.04035 .49185 L
.03882 .47555 L
.03585 .45926 L
.03553 .4578 L
.03157 .44296 L
.0254 .42666 L
.01923 .41869 L
s
.98077 .58131 m
.9746 .57334 L
.96843 .55704 L
.96447 .5422 L
.96415 .54074 L
.96118 .52445 L
.95965 .50815 L
.95965 .49185 L
.96118 .47555 L
.96415 .45926 L
.96447 .4578 L
.96843 .44296 L
.9746 .42666 L
.98077 .41869 L
s
.98077 .96916 m
.97639 .98077 L
s
.01923 .96916 m
.02361 .98077 L
s
.98077 .03084 m
.97639 .01923 L
s
.01923 .03084 m
.02361 .01923 L
s
.01923 .55267 m
.02355 .54074 L
.02659 .52445 L
.02791 .50815 L
.02791 .49185 L
.02659 .47555 L
.02355 .45926 L
.01923 .44733 L
s
.98077 .55267 m
.97645 .54074 L
.97341 .52445 L
.97209 .50815 L
.97209 .49185 L
.97341 .47555 L
.97645 .45926 L
.98077 .44733 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML00?oG8ML003kG100We`801=L00`3Ge`02e`<09ML202OG
0P04e`030=OG00;G0`0We`@08]L0043G00<0emL09ML0103Ge`0;e`030=OG027G00@0emL09ML0103G
e`0;e`030=OG02KG00<0emL08ML0043G00<0emL09ML0103Ge`0;e`030=OG027G00@0emL09ML0103G
e`0;e`030=OG02KG00<0emL08ML003SG1004e`030=OG01oG1002e`040=OG00SG0`0Te`040=OG02GG
00@0emL02=L302WG00<0emL08ML0043G00<0emL09ML0103Ge`08e`030=OG02CG00@0emL09ML0103G
e`08e`030=OG02WG00<0emL08ML003kG0`0We`040=OG00SG00<0emL09=L0103Ge`0Ue`040=OG00SG
00<0emL09mL302?G0010e`030=OG02KG0P09e`@09=L202OG0P09e`@0:=L00`3Ge`0Qe`00omLQe`00
omLQe`00omLQe`006mOo00D00ML001_G00<0emL00mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3G
e`07e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`06e`030=OG00OG
00<0emL01]L00`3Ge`07e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3G
e`07e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3Ge`07e`030=OG00KG
00<0emL00mL1007G000Ke`030=OG01oG00<0emL0;ML00`3Ge`0]e`030=OG02cG00<0emL0;ML00`3G
e`0Oe`400ML001_G00<0emL0omL1e`400ML001_G00<0emL0omL1e`400ML001_G00<0emL00mL20007
e`00e`3G0003e`030=OG01;G00<0emL02mL00`3Ge`0]e`030=OG03KG00<0emL0;ML00`3Ge`0<e`03
0=OG017G00X0emOG0=L0e`3G0`05e`400ML001_G00<0emL00mL20007e`00e`3G0003e`030=OG017G
00<0emL02mL00`3Ge`0_e`80==L2037G00<0emL03=L00`3Ge`0@e`0:0=OGe`3G0=L0e`<01ML1007G
000Ke`030=OG00;G00@0e`3G0P001=L0e`04e`030=OG013G00<0emL02mL00`3Ge`0ae`D0:mL403?G
00<0emL03=L00`3Ge`0?e`030=OG00;G00H0e`3G0=L20003e`3G00?G0@01e`006mL00`3Ge`02e`80
00KG0=L0e`02e`050=OGe`004ML00`3Ge`0;e`030=OG03OG100Re`D0>=L00`3Ge`0<e`030=OG00kG
00D0emOG0002e`030=OG008000?G00001=L1007G000Ke`030=OG00?G00L0e`3G0=L000;G00<0emL0
0]L00`3Ge`0>e`030=OG00[G00<0emL0?=L301cG0`0ne`030=OG00_G00<0emL03ML00`3Ge`02e`04
0=OG00;G0P000mL0e`04e`400ML001_G00<0emL00mL01`3G0=L0e`000]L00`3Ge`02e`030=OG00gG
00<0emL02mL00`3Ge`0oe`D04]L504;G00<0emL02mL00`3Ge`0<e`030=OG00;G00@0emL00]L20003
e`3G00CG0@01e`006mL00`3Ge`02e`050=L0e`000]L0103Ge`05e`030=OG00[G0P0=e`030=OG04GG
4P18e`030=OG00_G00<0emL02]L00`3Ge`03e`040=OG00;G0P000mL0e`04e`400ML001_G0P03e`07
0=L0e`3G0003e`030=OG00?G00<0emL02ML00`3Ge`0<e`030=OG0:3G00<0emL03=L00`3Ge`09e`03
0=OG00?G00@0emL00]L01@3G0=L000?G0P01e`006mL00`3Ge`03e`030=L000;G00D0emOG0006e`03
0=OG00OG00<0emL03=L00`3Ge`2Re`030=OG00cG00<0emL01mL00`3Ge`04e`090=OGe`3G0=L000KG
0@01e`006mL00`3Ge`03e`030=L000;G00D0emOG0007e`801=L300kG00<0emL0Y=L00`3Ge`0<e`<0
1=L200OG00D0emOG0002e`030=L000GG0@01e`006mL00`3Ge`02e`030=L000?G00D0emOG0009e`@0
4=L00`3Ge`2Ve`030=OG00kG1009e`050=OGe`000]L0103Ge`04e`400ML001_G00<0emL01=L0103G
e`04e`030=OG01[G00<0emL0YmL00`3Ge`0Ke`050=OGe`000mL00`3Ge`04e`400ML001_G00<0emL0
0mL01@3GemL000CG00<0emL06]L00`3Ge`0Lea40CML@01kG00<0emL06]L00`3Ge`02e`040=OG00KG
0@01e`006mL00`3Ge`03e`050=OGe`001=L00`3Ge`0Ie`030=OG01KG1`0Ae`@0A=L5013G1`0He`03
0=OG01WG00<0emL00]L01@3GemL000GG0@01e`006mL00`3Ge`02e`050=OGe`001ML00`3Ge`0He`03
0=OG01GG0P0Le`@0?=L401cG0P0Ge`030=OG01SG00<0emL00]L00`3Ge`02e`030=OG00;G0@01e`00
6mL00`3Ge`06e`030=OG00;G00<0emL06=L00`3Ge`0De`808]L902_G200Re`805ML00`3Ge`0He`03
0=OG00?G00<0emL01]L1007G000Ke`030=OG00CG0P05e`030=OG01SG00<0emL04]L202gG100Re`D0
;=L201CG00<0emL06=L00`3Ge`03e`801]L1007G000Ke`030=OG00?G00<0emL01ML00`3Ge`0Ge`03
0=OG017G0P0ce`D06ML403?G0`0Be`030=OG01OG00<0emL01ML00`3Ge`03e`400ML001_G0P03e`03
0=OG00KG00<0emL05]L00`3Ge`0Ae`030=OG03SG6@0je`030=OG013G0P0Ge`030=OG00KG00@0emOG
0P01e`006mL00`3Ge`0:e`030=OG01KG00<0emL04=L208oG0P0Be`030=OG01GG00<0emL02]L1007G
000Ke`030=OG00[G00<0emL05ML00`3Ge`0@e`030=OG097G00<0emL03mL00`3Ge`0Ee`030=OG00[G
0@01e`006mL00`3Ge`02e`801=L201OG00<0emL03mL209GG00<0emL03mL00`3Ge`0Ee`801=L200CG
0@01e`006mL00`3Ge`04e`@06=L00`3Ge`0?e`030=OG09KG00<0emL03mL00`3Ge`0Fe`@01]L1007G
000Ke`030=OG01oG00<0emL03mL00`3Ge`2He`030=OG00oG00<0emL07mL1007G000Ke`030=OG01kG
00<0emL03mL00`3Ge`2Je`030=OG00oG00<0emL07]L1007G000Ke`030=OG00;G00<0emL06=L00`3G
e`0?e`030=OG09_G00<0emL04=L00`3Ge`0He`030=OG00;G0@01e`006mL00`3Ge`02e`030=OG01OG
00<0emL04=L00`3Ge`2Le`030=OG013G00<0emL05mL00`3Ge`02e`400ML001_G00<0emL00mL00`3G
e`0Ee`030=OG00oG0P2Pe`804ML00`3Ge`0Ee`030=OG00?G0@01e`002=L200CG00<0emL01=L00`3G
e`03e`030=OG00CG00<0emL04mL00`3Ge`0?e`030=OG02;G3014e``09=L00`3Ge`0?e`030=OG01?G
00<0emL01=L1007G0007e`040=OG00[G00<0emL00mL00`3Ge`05e`030=OG013G0P0Ae`030=OG01oG
100<e`P0==L800cG100Pe`030=OG013G0P0Be`030=OG00GG0@01e`001mL0103Ge`07e`D01=L200?G
00D0emOG000@e`030=OG017G00<0emL06ML601SG2@0Re`T06=L601_G00<0emL04ML00`3Ge`0>e`05
0=OGe`000mL2007G00000mL0000200;G00@0emL01mL0103Ge`05e`030=OG00;G00D0emOG000?e`03
0=OG017G00<0emL05mL302OG8P0We`<06ML00`3Ge`0Ae`030=OG00cG00D0emOG0005e`400ML000OG
00@0emL02=L00`3G0005e`030=OG00?G00D0emOG000=e`030=OG017G00<0emL05ML307KG0`0Ge`03
0=OG013G00<0emL03=L01@3GemL000GG0@01e`001mL0103Ge`09e`801ML00`3Ge`03e`050=OGe`00
3ML00`3Ge`0@e`030=OG01CG0P1le`805]L00`3Ge`0@e`030=OG00[G00D0emOG0006e`400ML000SG
0P0;e`030=OG00?G00<0emL01=L01@3GemL000_G00<0emL04=L00`3Ge`0De`030=OG07kG00<0emL0
5=L00`3Ge`0@e`030=OG00WG00D0emOG0006e`400ML001_G00<0emL01=L01@3GemL000[G00<0emL0
4=L00`3Ge`0De`030=OG083G00<0emL05=L00`3Ge`0?e`030=OG00WG00D0emOG0006e`400ML001_G
00<0emL01=L01@3GemL000[G00<0emL03mL00`3Ge`0Ce`80Q=L201GG00<0emL03mL00`3Ge`07e`05
0=OGe`001mL1007G000Ke`030=OG00;G00@0emL00mL00`3Ge`06e`030=OG013G00<0emL04ML208SG
0P0De`030=OG00kG00<0emL01mL01@3GemL000;G00<0emL00]L1007G000Ke`030=OG00;G00@0emL0
0mL00`3Ge`06e`030=OG00kG0P0Ce`030=OG08[G0P0Ce`030=OG00kG00<0emL01]L01@3GemL000;G
00<0emL00]L1007G000Ke`030=OG00;G00@0emL00mL00`3Ge`06e`030=OG00gG00<0emL04]L00`3G
e`2=e`030=OG017G00<0emL03ML00`3Ge`06e`050=OGe`000]L00`3Ge`02e`400ML001_G00<0emL0
0]L0103Ge`03e`030=OG00GG00<0emL03]L00`3Ge`0Ae`030=OG08oG00<0emL04=L00`3Ge`0>e`03
0=OG00GG00D0emOG0002e`030=OG00;G0@01e`006mL00`3Ge`03e`040=OG00;G00<0emL01ML00`3G
e`0=e`030=OG017G00<0emL0TML00`3Ge`0@e`030=OG00gG00<0emL01ML01`3GemL0e`001ML1007G
000Ke`801=L0103Ge`02e`030=OG00CG00<0emL03]L00`3Ge`0@e`030=OG09;G00<0emL04=L00`3G
e`0>e`030=OG00CG00L0emOG0=L000CG0P01e`006mL00`3Ge`03e`040=OG00;G00<0emL01=L00`3G
e`0<e`804]L00`3Ge`2De`030=OG013G0P0>e`030=OG00CG00L0emOG0=L000GG0@01e`006mL00`3G
e`03e`040=OG00;G00<0emL01=L00`3Ge`0;e`030=OG013G0P2He`804]L00`3Ge`0;e`030=OG00CG
00L0emOG0=L000GG0@01e`006mL00`3Ge`03e`040=OG00;G00<0emL00mL00`3Ge`0;e`030=OG013G
00<0emL08]LM01[G7@0Te`030=OG00oG00<0emL02mL00`3Ge`04e`040=OG00;G00<0emL00mL1007G
000Ke`030=OG00?G00@0emL00]L00`3Ge`03e`030=OG00_G00<0emL03mL00`3Ge`0Oe`@07MLJ01gG
100Qe`030=OG00oG00<0emL02mL00`3Ge`03e`040=OG00;G00<0emL00mL1007G000Ke`030=OG00?G
00@0emL00]L00`3Ge`03e`030=OG00[G00<0emL04=L00`3Ge`0Le`<0G=L301oG00<0emL03mL00`3G
e`0:e`030=OG00?G00@0emL00]L00`3Ge`03e`400ML001_G00<0emL00mL0103Ge`02e`030=OG00?G
00<0emL02ML00`3Ge`0@e`030=OG01_G0P1Re`807]L00`3Ge`0?e`030=OG00WG00<0emL00mL0103G
e`02e`030=OG00?G0@01e`006mL00`3Ge`03e`040=OG00;G00<0emL00]L00`3Ge`09e`030=OG013G
00<0emL06=L406KG100Je`030=OG013G00<0emL02=L00`3Ge`03e`040=OG00;G00<0emL00mL1007G
000Ke`030=OG00?G00@0emL00]L00`3Ge`02e`030=OG00WG00<0emL03mL00`3Ge`0Fe`<0K]L301SG
00<0emL03mL00`3Ge`09e`030=OG00;G00@0emL00]L00`3Ge`03e`400ML001_G00<0emL00mL0103G
e`02e`030=OG00;G00<0emL02=L00`3Ge`0?e`030=OG01KG00<0emL0L]L00`3Ge`0Fe`030=OG00oG
00<0emL02=L00`3Ge`02e`040=OG00;G00<0emL00mL1007G000Ke`030=OG00?G00@0emL00]L00`3G
e`02e`030=OG00OG00<0emL03mL00`3Ge`0Ee`80M]L201OG00<0emL03]L00`3Ge`08e`030=OG00;G
00@0emL00]L00`3Ge`03e`400ML001_G00<0emL00mL00`3G0002e`030=OG00;G00<0emL02=L00`3G
e`0>e`030=OG01GG00<0emL0N=L00`3Ge`0Ee`030=OG00kG00<0emL01mL00`3Ge`02e`040=OG00;G
00<0emL00mL1007G000Ke`801=L00`3G0002e`030=OG00;G00<0emL01mL00`3Ge`0>e`030=OG01CG
0P1le`805]L00`3Ge`0=e`030=OG00SG00<0emL00]L01P3Ge`3G00CG0P01e`006mL00`3Ge`03e`03
0=L000;G00<0emL00]L00`3Ge`07e`030=OG00gG00<0emL05=L00`3Ge`1ne`030=OG01CG00<0emL0
3ML200SG00<0emL00]L01P3Ge`3G00GG0@01e`006mL00`3Ge`03e`030=L000;G00<0emL00]L00`3G
e`06e`030=OG00gG00<0emL05=L00`3Ge`20e`030=OG01CG00<0emL03ML00`3Ge`06e`030=OG00;G
00H0emL0e`05e`400ML001_G00<0emL00mL00`3G0002e`030=OG00;G00<0emL01]L00`3Ge`0=e`03
0=OG01?G00<0emL0P]L00`3Ge`0Ce`030=OG00kG00<0emL01ML00`3Ge`02e`060=OG0=L01ML1007G
000Ke`030=OG00;G00@0emL00]L01@3GemL000SG00<0emL03ML00`3Ge`0Ce`030=OG08CG00<0emL0
4mL00`3Ge`0=e`030=OG00KG00<0emL00]L01P3Ge`3G00CG0@01e`006mL00`3Ge`02e`040=OG00;G
00D0emOG0008e`030=OG00gG00<0emL04]L00`3Ge`26e`030=OG01;G00<0emL03]L00`3Ge`05e`03
0=OG00;G00H0emL0e`04e`400ML001_G00<0emL00]L0103Ge`02e`050=OGe`001mL00`3Ge`0=e`03
0=OG01;G00<0emL0R=L00`3Ge`0Be`803]L00`3Ge`05e`030=OG00;G00H0emL0e`04e`400ML001_G
00<0emL00]L01P3Ge`3G00CG00<0emL01ML00`3Ge`0<e`030=OG01;G00<0emL0R]L00`3Ge`0Ce`03
0=OG00_G00<0emL01ML00`3Ge`02e`060=OG0=L01=L1007G000Ke`030=OG00CG00@0emL00mL00`3G
e`05e`030=OG00cG00<0emL04]L00`3Ge`0`ebX0<]L201?G00<0emL03=L00`3Ge`04e`030=OG00;G
00@0emL01]L1007G000Ke`030=OG00CG00<0e`001=L00`3Ge`05e`030=OG00_G00<0emL04]L00`3G
e`0Ve`/0:]L;02WG00<0emL04ML00`3Ge`0;e`030=OG00GG00<0emL00]L0103Ge`05e`400ML001_G
00<0emL01=L00`3G0004e`030=OG00CG00<0emL02mL00`3Ge`0Be`030=OG027G1P10e`H09=L00`3G
e`0Ae`030=OG00_G00<0emL01=L00`3Ge`02e`040=OG00GG0@01e`006mL00`3Ge`03e`040=OG00?G
00<0emL01=L00`3Ge`0;e`030=OG01;G00<0emL07mL304cG0`0Re`030=OG017G00<0emL02]L00`3G
e`05e`050=OGe`000]L00`3Ge`03e`400ML001_G0P04e`040=OG00?G00<0emL01=L00`3Ge`0:e`03
0=OG01;G00<0emL07]L205;G0P0Pe`030=OG01;G00<0emL02]L00`3Ge`04e`050=OGe`000]L00`3G
e`02e`800ML001_G00<0emL00]L0103Ge`03e`030=OG00CG00<0emL02mL00`3Ge`0Ae`030=OG01cG
0`1Fe`<07]L00`3Ge`0Ae`030=OG00[G00<0emL01ML01@3GemL000;G00<0emL00]L1007G000Ke`03
0=OG00;G00@0emL00mL00`3Ge`04e`030=OG00[G00<0emL04ML00`3Ge`0Ke`80G=L201gG00<0emL0
4ML00`3Ge`0:e`030=OG00CG00D0emOG0002e`030=OG00;G0@01e`006mL00`3Ge`04e`050=OGe`00
1]L00`3Ge`0:e`030=OG017G00<0emL06mL00`3Ge`1Ne`030=OG01_G00<0emL04ML00`3Ge`0:e`03
0=OG00?G00D0emOG0007e`400ML001_G00<0emL01=L01@3GemL000GG00<0emL02]L00`3Ge`0Ae`03
0=OG01[G0P1Re`807=L00`3Ge`0Ae`030=OG00[G00<0emL00mL01@3GemL000KG0@01e`006mL00`3G
e`03e`050=OGe`001ML00`3Ge`0:e`030=OG017G00<0emL06ML206KG0P0Ke`030=OG013G00<0emL0
2]L00`3Ge`03e`050=OGe`001]L1007G000Ke`030=OG00?G00D0emOG0005e`030=OG00[G00<0emL0
4=L00`3Ge`0He`80J]L201[G00<0emL04=L00`3Ge`0:e`030=OG00?G00D0emOG0005e`400ML001_G
00<0emL00]L01@3GemL000GG00<0emL02]L00`3Ge`0@e`030=OG01OG0P1^e`806=L00`3Ge`0Ae`03
0=OG00[G00<0emL00]L01@3GemL000GG0@01e`006mL00`3Ge`02e`050=OGe`001=L00`3Ge`0:e`03
0=OG017G00<0emL05]L00`3Ge`1`e`030=OG01KG00<0emL04=L00`3Ge`0:e`030=OG00?G00D0emOG
0004e`400ML001_G00<0emL01ML00`3Ge`03e`030=OG00[G00<0emL04=L00`3Ge`0Fe`030=OG07;G
00<0emL05]L00`3Ge`0@e`030=OG00[G00<0emL00mL00`3Ge`05e`400ML000SG0P04e`030=OG00;G
1004e`030=OG00CG00<0emL00mL00`3Ge`09e`804]L00`3Ge`0Fe`030=OG07CG00<0emL05]L00`3G
e`0@e`802mL00`3Ge`03e`030=OG00CG0@01e`001mL0103Ge`08e`030=OG00GG00<0emL00mL00`3G
e`04e`030=OG00SG00<0emL04ML00`3Ge`0Fe`030=OG07KG00<0emL05ML00`3Ge`0Be`030=OG00SG
00<0emL01=L00`3Ge`03e`400ML000OG00@0emL02ML00`3Ge`04e`801=L00`3Ge`03e`030=OG00WG
00<0emL04ML00`3Ge`0Ee`030=OG07SG00<0emL05ML00`3Ge`0Ae`030=OG00WG00<0emL00mL00`3G
e`02e`800ML00003e`0000800]L0103Ge`0:e`030=OG00?G00<0emL00]L00`3Ge`03e`030=OG00WG
00<0emL04ML00`3Ge`0Ee`030=OG07[G00<0emL05=L00`3Ge`0Be`030=OG00WG00<0emL00mL00`3G
e`02e`400ML000OG00@0emL02mL00`3Ge`02e`030=OG00OG00<0emL02]L00`3Ge`0Ae`030=OG01GG
00<0emL0N]L00`3Ge`0Ee`030=OG017G00<0emL02]L00`3Ge`07e`400ML000OG00@0emL02=L0103G
e`04e`030=OG00KG00<0emL02]L00`3Ge`0Ae`030=OG01GG00<0emL0O=L00`3Ge`0Ee`030=OG017G
0P0;e`030=OG00KG0@01e`002=L200[G0P05e`030=OG00GG00<0emL02ML201?G00<0emL05ML00`3G
e`1ne`030=OG01GG00<0emL04]L00`3Ge`09e`030=OG00GG0@01e`006mL00`3Ge`03e`802]L201CG
00<0emL05ML00`3Ge`20e`030=OG01CG00<0emL04mL200[G0P05e`400ML001_G00<0emL00]L00`3G
e`09e`030=OG01CG00<0emL05=L00`3Ge`0deaP0=]L00`3Ge`0De`030=OG01CG00<0emL02ML00`3G
e`02e`400ML001_G00<0emL03ML00`3Ge`0De`030=OG01CG00<0emL0;=L901SG2@0^e`030=OG01CG
00<0emL05=L00`3Ge`0=e`400ML001_G00<0emL02mL201OG00<0emL04mL00`3Ge`0Ye`@0:]L402[G
00<0emL05ML00`3Ge`0De`803ML1007G000Ke`030=OG00WG0P0He`030=OG01CG00<0emL09]L303;G
0`0Xe`030=OG01GG00<0emL05ML200_G0@01e`006mL00`3Ge`02e`L06ML00`3Ge`0De`030=OG02GG
0P0he`809]L00`3Ge`0Ee`030=OG01OG1`04e`400ML001_G00<0emL08ML00`3Ge`0Ee`030=OG027G
100le`@08mL201KG00<0emL08ML1007G000Ke`808ML00`3Ge`0Ee`030=OG027G00<0emL0@]L202;G
00<0emL05ML00`3Ge`0Oe`800ML001_G00<0emL07mL00`3Ge`0Ee`030=OG023G0P17e`030=OG023G
00<0emL05ML00`3Ge`0Oe`400ML001_G00<0emL07]L00`3Ge`0Fe`030=OG01kG0P1:e`808=L00`3G
e`0Fe`030=OG01kG0@01e`006mL00`3Ge`02e`030=OG01SG00<0emL05]L00`3Ge`0Me`80C]L201oG
00<0emL05]L00`3Ge`0He`030=OG00;G0@01e`006mL00`3Ge`03e`805mL00`3Ge`0Ge`030=OG01cG
00<0emL0D=L00`3Ge`0Me`030=OG01KG00<0emL05ML200GG0@01e`006mL00`3Ge`05e`805=L00`3G
e`0Ge`030=OG01cG00<0emL0D]L00`3Ge`0Le`030=OG01OG00<0emL04]L200OG0@01e`006mL00`3G
e`07e`804ML00`3Ge`0He`030=OG01_G00<0emL0E=L00`3Ge`0Le`030=OG01OG00<0emL03mL200WG
0@01e`006mL00`3Ge`09e`<03ML00`3Ge`0He`030=OG01_G00<0emL0E]L00`3Ge`0Ke`030=OG01SG
00<0emL02mL300_G0@01e`006mL00`3Ge`02e`030=OG00OG1@05e`<06mL00`3Ge`0Je`030=OG05SG
00<0emL06]L00`3Ge`0Ie`<01ML500WG00<0emL00]L1007G000Ke`030=OG00?G00<0emL02mL501gG
00<0emL06]L00`3Ge`1Je`030=OG01WG00<0emL07=L500gG00<0emL00mL1007G000Ke`030=OG00?G
00<0emL0;ML00`3Ge`0Ie`030=OG05_G00<0emL06]L00`3Ge`0/e`030=OG00CG0@01e`006mL200GG
00<0emL0:mL00`3Ge`0Je`030=OG05cG00<0emL06ML00`3Ge`0/e`030=OG00?G0P01e`006mL00`3G
e`05e`030=OG02[G00<0emL06ML00`3Ge`1Ne`030=OG01WG00<0emL0:]L00`3Ge`05e`400ML001_G
00<0emL01]L00`3Ge`0Xe`030=OG01WG00<0emL0H=L00`3Ge`0He`030=OG02WG00<0emL01]L1007G
000Ke`030=OG00;G00<0emL00]L00`3Ge`0We`030=OG01WG00<0emL0H=L00`3Ge`0Ie`030=OG02OG
00<0emL00]L00`3Ge`02e`400ML001_G00<0emL00]L00`3Ge`02e`030=OG02KG00<0emL06ML00`3G
e`1Re`030=OG01SG00<0emL09mL01@3GemL000GG0@01e`006mL00`3Ge`03e`030=OG00;G00<0emL0
9ML00`3Ge`0Ie`030=OG06?G00<0emL06=L00`3Ge`0Ue`030=OG00;G00<0emL00mL1007G000Ke`03
0=OG00?G00<0emL00]L00`3Ge`0Ue`030=OG01SG00<0emL0I=L00`3Ge`0He`030=OG02CG00<0emL0
0]L00`3Ge`04e`400ML001_G00<0emL01=L00`3Ge`02e`030=OG02?G00<0emL06ML00`3Ge`1Te`03
0=OG01SG00<0emL09=L00`3Ge`02e`030=OG00CG0@01e`006mL00`3Ge`04e`030=OG00;G00<0emL0
8mL00`3Ge`0He`030=OG06KG00<0emL06=L00`3Ge`0Re`030=OG00;G00<0emL01ML1007G000Ke`03
0=OG00GG00<0emL00]L00`3Ge`0Re`030=OG01SG00<0emL0I]L201WG00<0emL08]L00`3Ge`02e`03
0=OG00GG0@01e`006mL00`3Ge`02e`040=OG00CG00<0emL08]L00`3Ge`0He`030=OG06OG00<0emL0
5mL00`3Ge`0Re`030=OG00;G00@0emL01=L1007G000Ke`030=OG00;G00@0emL01ML00`3Ge`0Qe`03
0=OG01OG00<0emL0J=L00`3Ge`0Ge`030=OG027G00<0emL00]L01@3GemL000CG0@01e`006mL200?G
00D0emOG0004e`030=OG023G00<0emL06=L00`3Ge`1Ye`030=OG01OG00<0emL08=L00`3Ge`02e`04
0=OG00CG0P01e`006mL00`3Ge`03e`040=OG00GG00<0emL07mL00`3Ge`0Ge`030=OG06[G00<0emL0
5mL00`3Ge`0Oe`030=OG00?G00@0emL01ML1007G000Ke`030=OG00?G00@0emL01ML00`3Ge`0Oe`03
0=OG01OG00<0emL0J]L00`3Ge`0Ge`030=OG01oG00<0emL00mL0103Ge`05e`400ML001_G00<0emL0
0mL0103Ge`05e`030=OG01oG00<0emL05mL00`3Ge`1Ze`030=OG01OG00<0emL07mL00`3Ge`03e`04
0=OG00GG0@01e`006mL00`3Ge`03e`040=OG00GG00<0emL07]L00`3Ge`0Ge`030=OG06_G00<0emL0
5mL00`3Ge`0Ne`030=OG00?G00@0emL01]L1007G000Ke`030=OG00CG00@0emL01ML00`3Ge`0Me`03
0=OG01OG00<0emL0K=L00`3Ge`0Ge`030=OG01gG00<0emL00mL0103Ge`06e`400ML001_G00<0emL0
1=L0103Ge`05e`030=OG01gG00<0emL05mL00`3Ge`1/e`030=OG01OG00<0emL07ML00`3Ge`03e`04
0=OG00KG0@01e`006mL00`3Ge`04e`040=OG00GG00<0emL07ML00`3Ge`0Ge`030=OG06cG00<0emL0
5mL00`3Ge`0Me`030=OG00?G00@0emL01]L1007G000Ke`030=OG00CG00@0emL01ML00`3Ge`0Me`03
0=OG01OG00<0emL0K=L00`3Ge`0Ge`030=OG01cG00<0emL01=L0103Ge`06e`400ML001_G00<0emL0
1=L0103Ge`06e`030=OG01cG00<0emL05mL00`3Ge`1/e`030=OG01OG00<0emL07=L00`3Ge`04e`04
0=OG00KG0@01e`005=L200GG00<0emL01=L0103Ge`06e`030=OG01cG00<0emL05mL00`3Ge`1/e`03
0=OG01OG00<0emL07=L00`3Ge`04e`040=OG00KG0@01e`004mL0103Ge`04e`030=OG00CG00@0emL0
1]L00`3Ge`0Le`030=OG01OG00<0emL0K=L00`3Ge`0Ge`030=OG01cG00<0emL01=L0103Ge`06e`40
0ML001?G00@0emL01=L200GG00@0emL01]L00`3Ge`0Le`030=OG01OG00<0emL0K=L00`3Ge`0Ge`03
0=OG01cG00<0emL01=L0103Ge`05e`800ML001?G00@0emL01=L00`3Ge`04e`040=OG00KG00<0emL0
7=L00`3Ge`0Ge`030=OG06cG00<0emL05mL00`3Ge`0Le`030=OG00CG00@0emL01]L1007G000Ce`04
0=OG00CG00<0emL01=L0103Ge`06e`030=OG01cG00<0emL05mL00`3Ge`1/e`030=OG01OG00<0emL0
7=L00`3Ge`04e`040=OG00KG0@01e`004mL0103Ge`04e`030=OG00CG00@0emL01]L00`3Ge`0Le`03
0=OG01OG00<0emL0K=L00`3Ge`0Ge`030=OG01cG00<0emL01=L0103Ge`06e`400ML001CG0P05e`03
0=OG00CG00@0emL01ML00`3Ge`0Me`030=OG01OG00<0emL0K=L00`3Ge`0Ge`030=OG01cG00<0emL0
1=L0103Ge`06e`400ML001_G00<0emL01=L0103Ge`05e`030=OG01gG00<0emL05mL00`3Ge`1/e`03
0=OG01OG00<0emL07ML00`3Ge`03e`040=OG00KG0@01e`006mL00`3Ge`04e`040=OG00GG00<0emL0
7ML00`3Ge`0Ge`030=OG06cG00<0emL05mL00`3Ge`0Me`030=OG00?G00@0emL01]L1007G000Ke`03
0=OG00CG00@0emL01ML00`3Ge`0Me`030=OG01OG00<0emL0K=L00`3Ge`0Ge`030=OG01gG00<0emL0
0mL0103Ge`06e`400ML001_G00<0emL01=L0103Ge`05e`030=OG01gG00<0emL05mL00`3Ge`1/e`03
0=OG01OG00<0emL07ML00`3Ge`03e`040=OG00KG0@01e`006mL00`3Ge`03e`040=OG00GG00<0emL0
7mL00`3Ge`0Ge`030=OG06[G00<0emL05mL00`3Ge`0Oe`030=OG00?G00@0emL01ML1007G000Ke`03
0=OG00?G00@0emL01ML00`3Ge`0Oe`030=OG01OG00<0emL0J]L00`3Ge`0Ge`030=OG01oG00<0emL0
0mL0103Ge`05e`400ML001_G00<0emL00mL0103Ge`05e`030=OG01oG00<0emL05mL00`3Ge`1Ze`03
0=OG01OG00<0emL07mL00`3Ge`03e`040=OG00GG0@01e`006mL200CG00@0emL01=L00`3Ge`0Pe`03
0=OG01OG00<0emL0J]L00`3Ge`0Ge`030=OG01oG00<0emL00mL0103Ge`04e`800ML001_G00<0emL0
0]L0103Ge`05e`030=OG023G00<0emL06=L00`3Ge`1Xe`030=OG01OG00<0emL08ML00`3Ge`02e`05
0=OGe`001=L1007G000Ke`030=OG00;G00@0emL01=L00`3Ge`0Re`030=OG01OG00<0emL0J=L00`3G
e`0Ge`030=OG027G00<0emL00mL0103Ge`04e`400ML001_G00<0emL01ML00`3Ge`02e`030=OG02;G
00<0emL06=L00`3Ge`1Ve`806ML00`3Ge`0Re`030=OG00;G00<0emL01ML1007G000Ke`030=OG00CG
00<0emL00mL00`3Ge`0Re`030=OG01SG00<0emL0I]L00`3Ge`0He`030=OG02;G00<0emL00]L00`3G
e`05e`400ML001_G00<0emL01=L00`3Ge`02e`030=OG02?G00<0emL06ML00`3Ge`1Te`030=OG01SG
00<0emL09=L00`3Ge`02e`030=OG00CG0@01e`006mL00`3Ge`03e`030=OG00?G00<0emL09=L00`3G
e`0He`030=OG06CG00<0emL06=L00`3Ge`0Te`030=OG00;G00<0emL01=L1007G000Ke`030=OG00?G
00<0emL00]L00`3Ge`0Ue`030=OG01WG00<0emL0HmL00`3Ge`0He`030=OG02GG00<0emL00]L00`3G
e`03e`400ML001_G00<0emL00]L00`3Ge`02e`030=OG02KG00<0emL06ML00`3Ge`1Re`030=OG01WG
00<0emL09]L01@3GemL000GG0@01e`006mL00`3Ge`02e`030=OG00;G00<0emL09mL00`3Ge`0Ie`03
0=OG063G00<0emL06ML00`3Ge`0We`030=OG00;G00<0emL00]L1007G000Ke`030=OG00KG00<0emL0
:=L00`3Ge`0Ie`030=OG063G00<0emL06ML00`3Ge`0Xe`030=OG00KG0@01e`006mL00`3Ge`05e`03
0=OG02[G00<0emL06ML00`3Ge`1Ne`030=OG01WG00<0emL0:]L00`3Ge`05e`400ML001_G0P05e`03
0=OG02_G00<0emL06]L00`3Ge`1Le`030=OG01[G00<0emL0:mL00`3Ge`03e`800ML001_G00<0emL0
0mL00`3Ge`0]e`030=OG01WG00<0emL0G=L00`3Ge`0Ie`030=OG02cG00<0emL01=L1007G000Ke`03
0=OG00?G00<0emL02mL401kG00<0emL06]L00`3Ge`1Je`030=OG01[G00<0emL07=L400gG00<0emL0
0mL1007G000Ke`030=OG00;G00<0emL02ML300CG0`0Le`030=OG01WG00<0emL0F]L00`3Ge`0Ie`03
0=OG01[G0`04e`<02mL00`3Ge`02e`400ML001_G00<0emL03=L200[G00<0emL06ML00`3Ge`0Je`80
F=L201cG00<0emL06ML00`3Ge`08e`803]L1007G000Ke`030=OG00WG0`0=e`806]L00`3Ge`0Ke`03
0=OG05CG00<0emL07=L00`3Ge`0Ge`803ML300_G0@01e`006mL00`3Ge`06e`<04]L00`3Ge`0Ge`03
0=OG01cG00<0emL0D]L00`3Ge`0Le`030=OG01OG00<0emL04=L300SG0@01e`006mL00`3Ge`04e`80
5]L00`3Ge`0Ge`030=OG01cG00<0emL0D=L00`3Ge`0Me`030=OG01KG00<0emL05=L200KG0@01e`00
6mL00`3Ge`02e`806ML00`3Ge`0Fe`030=OG01gG00<0emL0C]L00`3Ge`0Me`030=OG01KG00<0emL0
5mL200CG0@01e`006mL00`3Ge`0Ne`030=OG01KG00<0emL07ML204gG00<0emL07ML00`3Ge`0Fe`03
0=OG01kG0@01e`006mL00`3Ge`0Oe`030=OG01GG00<0emL07mL204WG0P0Pe`030=OG01GG00<0emL0
7mL1007G000Ke`030=OG023G00<0emL05ML00`3Ge`0Pe`030=OG04CG0P0Qe`030=OG01GG00<0emL0
8=L1007G000Ke`808]L00`3Ge`0Ee`030=OG023G0P12e`808]L201KG00<0emL08=L2007G000Ke`03
0=OG00;G1@0Ke`030=OG01CG00<0emL08]L303cG0`0Se`030=OG01GG00<0emL06ML500CG0@01e`00
6mL00`3Ge`07e`806ML00`3Ge`0Ee`030=OG02CG100de`@09]L00`3Ge`0Ee`030=OG01OG0P09e`40
0ML001_G00<0emL02ML301OG00<0emL05=L00`3Ge`0Xe`D0:mL402WG00<0emL05ML00`3Ge`0Ee`<0
2mL1007G000Ke`030=OG00cG0P0Fe`030=OG01CG00<0emL0;=L5023G1P0]e`030=OG01CG0P0Ee`80
3]L1007G000Ke`030=OG00kG00<0emL05=L00`3Ge`0De`030=OG033G800be`030=OG01CG00<0emL0
5=L00`3Ge`0>e`400ML001_G00<0emL00]L00`3Ge`0:e`030=OG01?G00<0emL05ML00`3Ge`20e`03
0=OG01GG00<0emL04mL00`3Ge`0:e`030=OG00;G0@01e`006mL00`3Ge`03e`802mL201CG00<0emL0
5ML00`3Ge`1ne`030=OG01GG00<0emL04mL00`3Ge`09e`801ML1007G000Ke`030=OG00GG0P0;e`03
0=OG017G00<0emL05ML00`3Ge`1ne`030=OG01GG00<0emL04]L00`3Ge`08e`801mL1007G000Ke`03
0=OG00KG00<0emL02]L00`3Ge`0Ae`805]L00`3Ge`1le`030=OG01CG0P0Ce`802mL00`3Ge`06e`40
0ML000SG0P04e`030=OG00;G1004e`030=OG00;G00<0emL00]L00`3Ge`0:e`030=OG017G00<0emL0
5ML00`3Ge`1je`030=OG01CG00<0emL04]L00`3Ge`0:e`030=OG00;G00<0emL00]L1007G0007e`04
0=OG00SG00<0emL01ML00`3Ge`03e`030=OG00;G00<0emL02ML00`3Ge`0Be`030=OG01GG00<0emL0
N=L00`3Ge`0Ee`030=OG017G00<0emL02]L00`3Ge`02e`030=OG00?G0@01e`001mL0103Ge`09e`03
0=OG00CG0P04e`030=OG00?G00<0emL02ML00`3Ge`0Ae`030=OG01KG00<0emL0M]L00`3Ge`0Ee`03
0=OG01;G00<0emL02ML00`3Ge`03e`030=OG00;G0P01e`001mL0103Ge`0:e`030=OG00?G00<0emL0
1=L00`3Ge`03e`030=OG00WG0P0Be`030=OG01KG00<0emL0M=L00`3Ge`0Fe`030=OG013G0P0;e`03
0=OG00?G00<0emL01=L1007G0007e`040=OG00_G00<0emL00]L00`3Ge`05e`030=OG00?G00<0emL0
2]L00`3Ge`0@e`030=OG01KG00<0emL0L]L00`3Ge`0Fe`030=OG013G00<0emL02]L00`3Ge`03e`03
0=OG00GG0@01e`001mL0103Ge`08e`040=OG00CG00<0emL00]L01@3GemL000CG00<0emL02]L00`3G
e`0Ae`030=OG01KG00<0emL0L=L00`3Ge`0Fe`030=OG013G00<0emL02]L00`3Ge`03e`050=OGe`00
1=L1007G0008e`802]L200GG00<0emL00]L01@3GemL000GG00<0emL02]L00`3Ge`0@e`030=OG01OG
0P1^e`806=L00`3Ge`0Ae`030=OG00[G00<0emL00]L01@3GemL000GG0@01e`006mL00`3Ge`03e`05
0=OGe`001ML00`3Ge`0:e`030=OG013G00<0emL06=L00`3Ge`1Ze`030=OG01SG00<0emL04=L00`3G
e`0:e`030=OG00?G00D0emOG0005e`400ML001_G00<0emL00mL01@3GemL000GG00<0emL02]L00`3G
e`0Ae`030=OG01SG0P1Xe`806]L00`3Ge`0@e`030=OG00[G00<0emL00mL01@3GemL000KG0@01e`00
6mL00`3Ge`04e`050=OGe`001ML00`3Ge`0:e`030=OG013G00<0emL06]L00`3Ge`1Te`030=OG01WG
00<0emL04ML00`3Ge`0:e`030=OG00?G00D0emOG0006e`400ML001_G00<0emL01=L01@3GemL000KG
00<0emL02]L00`3Ge`0@e`030=OG01[G0P1Re`807=L00`3Ge`0@e`030=OG00[G00<0emL00mL01@3G
emL000OG0@01e`006mL00`3Ge`02e`040=OG00?G00<0emL01=L00`3Ge`0:e`030=OG013G0P0Le`80
G]L201cG0P0Be`030=OG00[G00<0emL01=L01@3GemL000;G00<0emL00]L1007G000Ke`030=OG00;G
00@0emL00mL00`3Ge`04e`030=OG00_G00<0emL04ML00`3Ge`0Ke`80F]L201gG00<0emL04ML00`3G
e`0:e`030=OG00GG00D0emOG0002e`030=OG00;G0@01e`006mL200CG00@0emL00mL00`3Ge`04e`03
0=OG00[G00<0emL04]L00`3Ge`0Le`80E]L201kG00<0emL04]L00`3Ge`0:e`030=OG00CG00D0emOG
0002e`030=OG00;G0P01e`006mL00`3Ge`03e`040=OG00?G00<0emL01=L00`3Ge`0;e`030=OG01;G
00<0emL07ML504gG100Pe`030=OG017G00<0emL02]L00`3Ge`05e`050=OGe`000]L00`3Ge`03e`40
0ML001_G00<0emL01=L00`3G0004e`030=OG00CG00<0emL02mL00`3Ge`0Be`030=OG027G1@12e`H0
8mL00`3Ge`0Ae`030=OG00_G00<0emL01=L00`3Ge`02e`040=OG00GG0@01e`006mL00`3Ge`04e`03
0=L000CG00<0emL01=L00`3Ge`0<e`030=OG01;G00<0emL09ML703CG1`0Xe`030=OG017G00<0emL0
2mL00`3Ge`05e`030=OG00;G00@0emL01ML1007G000Ke`030=OG00CG00@0emL00mL00`3Ge`05e`03
0=OG00cG00<0emL04]L00`3Ge`0[ec@0;]L00`3Ge`0Be`030=OG00_G00<0emL01ML00`3Ge`02e`04
0=OG00GG0@01e`006mL00`3Ge`02e`060=OG0=L01=L00`3Ge`04e`030=OG00cG00<0emL04]L00`3G
e`2<e`030=OG01;G00<0emL03=L00`3Ge`04e`030=OG00;G00H0emL0e`04e`400ML001_G00<0emL0
0]L0103Ge`02e`050=OGe`001mL00`3Ge`0<e`030=OG01;G00<0emL0R]L00`3Ge`0Ce`030=OG00_G
00<0emL01ML00`3Ge`02e`060=OG0=L01=L1007G000Ke`030=OG00;G00@0emL00]L01@3GemL000OG
00<0emL03ML00`3Ge`0Be`030=OG08SG00<0emL04]L200kG00<0emL01ML00`3Ge`02e`060=OG0=L0
1=L1007G000Ke`030=OG00;G00@0emL00]L01@3GemL000SG00<0emL03ML00`3Ge`0Be`030=OG08KG
00<0emL04]L00`3Ge`0=e`030=OG00KG00<0emL00]L01P3Ge`3G00CG0@01e`006mL00`3Ge`02e`04
0=OG00;G00D0emOG0008e`030=OG00gG00<0emL04mL208CG0P0De`030=OG00kG00<0emL01ML00`3G
e`02e`060=OG0=L01ML1007G000Ke`030=OG00?G00<0e`000]L00`3Ge`02e`030=OG00KG00<0emL0
3ML00`3Ge`0De`030=OG083G00<0emL05=L00`3Ge`0=e`030=OG00KG00<0emL00]L01P3Ge`3G00GG
0@01e`006mL00`3Ge`03e`030=L000;G00<0emL00]L00`3Ge`07e`030=OG00gG00<0emL05=L00`3G
e`1ne`030=OG01CG00<0emL03ML200SG00<0emL00]L01P3Ge`3G00GG0@01e`006mL200CG00<0e`00
0]L00`3Ge`02e`030=OG00OG00<0emL03]L00`3Ge`0De`80O=L201KG00<0emL03ML00`3Ge`08e`03
0=OG00;G00H0emL0e`04e`800ML001_G00<0emL00mL00`3G0002e`030=OG00;G00<0emL02=L00`3G
e`0>e`030=OG01GG00<0emL0N=L00`3Ge`0Ee`030=OG00kG00<0emL01mL00`3Ge`02e`040=OG00;G
00<0emL00mL1007G000Ke`030=OG00?G00@0emL00]L00`3Ge`02e`030=OG00OG00<0emL03mL00`3G
e`0Ee`80M]L201OG00<0emL03]L00`3Ge`08e`030=OG00;G00@0emL00]L00`3Ge`03e`400ML001_G
00<0emL00mL0103Ge`02e`030=OG00;G00<0emL02=L00`3Ge`0?e`030=OG01KG00<0emL0L]L00`3G
e`0Fe`030=OG00oG00<0emL02=L00`3Ge`02e`040=OG00;G00<0emL00mL1007G000Ke`030=OG00?G
00@0emL00]L00`3Ge`02e`030=OG00WG00<0emL03]L00`3Ge`0Ge`80L=L201SG00<0emL03mL00`3G
e`09e`030=OG00;G00@0emL00]L00`3Ge`03e`400ML001_G00<0emL00mL0103Ge`02e`030=OG00;G
00<0emL02ML00`3Ge`0?e`030=OG01SG0P1/e`806]L00`3Ge`0?e`030=OG00SG00<0emL00mL0103G
e`02e`030=OG00?G0@01e`006mL00`3Ge`03e`040=OG00;G00<0emL00mL00`3Ge`09e`030=OG00oG
0P0Je`<0I]L301_G00<0emL03mL00`3Ge`09e`030=OG00?G00@0emL00]L00`3Ge`03e`400ML001_G
00<0emL00mL0103Ge`02e`030=OG00?G00<0emL02]L00`3Ge`0@e`030=OG01[G1@1Le`D07ML00`3G
e`0?e`030=OG00[G00<0emL00mL0103Ge`02e`030=OG00?G0@01e`006mL00`3Ge`03e`040=OG00;G
00<0emL00mL00`3Ge`0;e`030=OG00oG00<0emL07mL302OG200We`<08ML00`3Ge`0?e`030=OG00_G
00<0emL00mL0103Ge`02e`030=OG00?G0@01e`006mL00`3Ge`03e`040=OG00;G00<0emL00mL00`3G
e`0;e`030=OG013G00<0emL08MLW00SG9`0Se`030=OG00oG00<0emL03=L00`3Ge`03e`040=OG00;G
00<0emL00mL1007G000Ke`030=OG00?G00@0emL00]L00`3Ge`04e`030=OG00_G00<0emL04=L00`3G
e`2He`030=OG013G00<0emL02mL00`3Ge`04e`070=OGe`3G0005e`400ML001_G00<0emL00mL0103G
e`02e`030=OG00CG00<0emL03=L00`3Ge`0@e`030=OG09KG00<0emL04=L00`3Ge`0<e`030=OG00CG
00L0emOG0=L000GG0@01e`006mL200CG00@0emL00]L00`3Ge`04e`030=OG00gG00<0emL04=L00`3G
e`2De`030=OG013G00<0emL03ML00`3Ge`04e`070=OGe`3G0004e`800ML001_G00<0emL00mL0103G
e`02e`030=OG00CG00<0emL03]L00`3Ge`0@e`80TmL00`3Ge`0@e`030=OG00gG00<0emL01ML01`3G
emL0e`001ML1007G000Ke`030=OG00;G00@0emL00mL00`3Ge`05e`030=OG00gG00<0emL04]L00`3G
e`2?e`030=OG013G00<0emL03]L00`3Ge`05e`070=OGe`3G0005e`400ML001_G00<0emL00]L0103G
e`03e`030=OG00GG00<0emL03]L00`3Ge`0Be`030=OG08gG00<0emL04ML00`3Ge`0=e`030=OG00KG
00D0emOG0002e`030=OG00;G0@01e`006mL00`3Ge`02e`040=OG00?G00<0emL01]L00`3Ge`0>e`80
4mL00`3Ge`2;e`030=OG017G00<0emL03]L00`3Ge`06e`050=OGe`000]L00`3Ge`02e`400ML001_G
00<0emL00]L0103Ge`03e`030=OG00KG00<0emL04=L00`3Ge`0Ae`030=OG08SG0P0Ce`030=OG00kG
00<0emL01mL01@3GemL000;G00<0emL00]L1007G000Ke`030=OG00;G00<0e`000mL00`3Ge`08e`03
0=OG00oG00<0emL04]L00`3Ge`26e`030=OG01;G00<0emL03mL00`3Ge`07e`050=OGe`000]L00`3G
e`02e`400ML001_G00<0emL01=L01@3GemL000[G00<0emL04=L00`3Ge`0Be`80Q=L201CG00<0emL0
3mL00`3Ge`09e`050=OGe`001]L1007G000Ke`030=OG00CG00D0emOG000;e`030=OG013G00<0emL0
4mL2083G0P0Ee`030=OG013G00<0emL02ML01@3GemL000KG0@01e`006mL00`3Ge`03e`050=OGe`00
3ML00`3Ge`0@e`030=OG01CG0P1le`805]L00`3Ge`0@e`030=OG00[G00D0emOG0006e`400ML000SG
0P04e`030=OG00CG00<0emL00mL00`3Ge`03e`050=OGe`003ML00`3Ge`0Ae`030=OG01GG00<0emL0
N=L00`3Ge`0Ee`030=OG013G00<0emL03=L01@3GemL000GG0@01e`001mL0103Ge`0:e`030=OG00?G
00<0emL00]L01@3GemL000oG00<0emL04ML00`3Ge`0Ee`80;mLH02oG0P0Ge`030=OG017G00<0emL0
3=L01@3GemL000GG0@01e`001mL0103Ge`07e`D01=L200?G00D0emOG000@e`030=OG017G00<0emL0
5]L5023G2P0He`X08=L501SG00<0emL04ML00`3Ge`0>e`050=OGe`000mL2007G0007e`040=OG00OG
00@0emL01ML00`3Ge`05e`030=OG013G00<0emL04=L00`3Ge`0Ke`L04]L702cG1`0Be`L07=L00`3G
e`0Ae`030=OG013G00<0emL01ML1007G0007e`040=OG00SG00<0e`001ML00`3Ge`04e`030=OG01;G
0P0Ae`030=OG027G4P0jea808mL00`3Ge`0?e`805=L00`3Ge`04e`400ML000OG00@0emL02ML200GG
00<0emL01=L00`3Ge`0De`030=OG00oG00<0emL0X=L00`3Ge`0?e`030=OG01CG00<0emL01=L1007G
0008e`802mL00`3Ge`03e`030=OG00?G00<0emL05ML00`3Ge`0@e`030=OG09kG00<0emL03mL00`3G
e`0Fe`030=OG00?G0@01e`006mL00`3Ge`02e`030=OG01OG00<0emL04=L00`3Ge`2Le`030=OG013G
00<0emL05mL00`3Ge`02e`400ML001_G00<0emL07ML2017G00<0emL0V]L00`3Ge`0?e`807mL1007G
000Ke`030=OG01oG00<0emL03mL00`3Ge`2He`030=OG00oG00<0emL07mL1007G000Ke`030=OG00GG
0P0Ie`030=OG00oG00<0emL0U]L00`3Ge`0?e`030=OG01OG0P07e`400ML001_G00<0emL00]L300;G
0P0He`030=OG00oG00<0emL0U=L00`3Ge`0?e`030=OG01KG0P02e`<01=L1007G000Ke`030=OG00WG
00<0emL05]L00`3Ge`0?e`80TmL00`3Ge`0?e`030=OG01KG00<0emL02ML1007G000Ke`030=OG00[G
00<0emL05]L00`3Ge`0@e`030=OG08oG00<0emL04=L00`3Ge`0Ee`030=OG00[G0@01e`006mL200_G
00<0emL05mL00`3Ge`0@e`80?]L@03oG0P0Be`030=OG01GG00<0emL02]L2007G000Ke`030=OG00;G
0P07e`030=OG01OG00<0emL04ML00`3Ge`0ce`P04=L903CG0P0Be`806=L00`3Ge`05e`801=L1007G
000Ke`030=OG00CG0P05e`030=OG01SG00<0emL04ML202kG1@0Qe`@0;]L201?G00<0emL06=L00`3G
e`03e`801]L1007G000Ke`030=OG00KG00<0emL00]L00`3Ge`0He`030=OG01?G0P0Xe`@0:]L402SG
0P0De`030=OG01SG00<0emL00mL00`3Ge`06e`400ML001_G00<0emL00]L01@3GemL000GG00<0emL0
6=L00`3Ge`0De`808]L403;G100Re`805]L00`3Ge`0He`030=OG00;G00<0emL00]L00`3Ge`02e`40
0ML001_G00<0emL00mL01@3GemL000CG00<0emL06ML00`3Ge`0Ee`@05ML903[G2@0Ee`@05mL00`3G
e`0Ie`030=OG00;G00D0emOG0005e`400ML001_G00<0emL00mL01@3GemL000CG00<0emL06]L00`3G
e`0HeaD0C=LE01[G00<0emL06]L00`3Ge`02e`040=OG00KG0@01e`006mL00`3Ge`04e`040=OG00CG
00<0emL06]L00`3Ge`2We`030=OG01_G00D0emOG0003e`030=OG00CG0@01e`006mL00`3Ge`02e`03
0=L000?G00D0emOG0009e`<04ML00`3Ge`2Ve`030=OG00oG0`09e`050=OGe`000]L0103Ge`04e`40
0ML001_G00<0emL00mL00`3G0002e`050=OGe`001mL200?G100>e`030=OG0:CG00<0emL03=L400?G
0P07e`050=OGe`000]L00`3G0005e`400ML001_G00<0emL00mL00`3G0002e`050=OGe`001]L00`3G
e`07e`030=OG00cG00<0emL0X]L00`3Ge`0<e`030=OG00KG00<0emL01ML01`3GemL0e`000]L00`3G
e`03e`400ML001_G00<0emL00]L01`3G0=L0e`000mL00`3Ge`04e`030=OG00SG00<0emL03=L00`3G
e`2Pe`030=OG00cG00<0emL02=L00`3Ge`04e`0;0=OGe`3G0=L0e`001=L1007G000Ke`800mL01@3G
0=L000;G00@0emL01ML00`3Ge`0:e`030=OG00_G00<0emL0AmL@04WG00<0emL02mL00`3Ge`0:e`03
0=OG00?G00@0emL00]L01@3G0=L000?G0P01e`006mL00`3Ge`03e`070=L0e`3G0002e`030=OG00?G
00<0emL02mL00`3Ge`0;e`030=OG04;G100@e`@0A=L00`3Ge`0;e`030=OG00_G00<0emL00mL0103G
e`02e`8000?G0=L01=L1007G000Ke`030=OG00?G00L0e`3G0=L000;G00<0emL00]L00`3Ge`0=e`03
0=OG00_G00<0emL0?ML401SG1@0oe`030=OG00_G00<0emL03=L00`3Ge`02e`040=OG00;G0P000mL0
e`04e`400ML001_G00<0emL00]L20006e`3G0=L00]L01@3GemL0017G00<0emL02]L00`3Ge`0he`D0
8ML403[G00<0emL02mL00`3Ge`0=e`030=OG00;G00@0emL00]L20003e`0000CG0@01e`006mL00`3G
e`02e`8000SG0=L0e`3G00CG00<0emL03mL00`3Ge`0;e`030=OG03CG0`0Ze`<0=]L00`3Ge`0;e`03
0=OG00oG00D0emOG0002e`040=L0e`8000?G0=L00mL1007G000Ke`030=OG00?G0P001mL00=L0e`00
0mL00`3Ge`0Ae`030=OG00_G00<0emL0<ML2033G0P0ce`030=OG00cG00<0emL03mL00`3Ge`02e`06
0=L0e`3G0`05e`400ML001_G00<0emL00mL20007e`00e`3G0003e`030=OG01;G00<0emL02mL00`3G
e`0]e`<0==L302oG00<0emL03=L00`3Ge`0Ae`0:0=OGe`3G0=L0e`<01ML1007G000Ke`030=OG0?oG
0ML1007G000Ke`030=OG0?oG0ML1007G000Ke`030=OG01oG00<0emL0;ML00`3Ge`0]e`030=OG02cG
00<0emL0;ML00`3Ge`0Oe`400ML001_G00<0emL00mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3G
e`07e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`06e`030=OG00OG
00<0emL01]L00`3Ge`07e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3G
e`07e`030=OG00KG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL01]L00`3Ge`07e`030=OG00KG
00<0emL00mL1007G000Keol01@01e`00omLQe`00omLQe`00omLQe`00omLQe`00omLQe`00omLQe`00
omLQe`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.65143, -0.631455, 0.0105146, \
0.00422032}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[pl2, pl4, AspectRatio \[Rule] 1, 
      DisplayFunction \[Rule] $DisplayFunction, 
      Prolog \[Rule] AbsolutePointSize[6]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.362828 0.473871 0.854358 [
[.13717 .46137 -6 -9 ]
[.13717 .46137 6 0 ]
[.31859 .46137 -12 -9 ]
[.31859 .46137 12 0 ]
[.68141 .46137 -9 -9 ]
[.68141 .46137 9 0 ]
[.86283 .46137 -3 -9 ]
[.86283 .46137 3 0 ]
[.4875 .13213 -24 -4.5 ]
[.4875 .13213 0 4.5 ]
[.4875 .303 -24 -4.5 ]
[.4875 .303 0 4.5 ]
[.4875 .64474 -18 -4.5 ]
[.4875 .64474 0 4.5 ]
[.4875 .81561 -18 -4.5 ]
[.4875 .81561 0 4.5 ]
[.4875 .98649 -18 -4.5 ]
[.4875 .98649 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13717 .47387 m
.13717 .48012 L
s
[(-1)] .13717 .46137 0 1 Mshowa
.31859 .47387 m
.31859 .48012 L
s
[(-0.5)] .31859 .46137 0 1 Mshowa
.68141 .47387 m
.68141 .48012 L
s
[(0.5)] .68141 .46137 0 1 Mshowa
.86283 .47387 m
.86283 .48012 L
s
[(1)] .86283 .46137 0 1 Mshowa
.125 Mabswid
.17345 .47387 m
.17345 .47762 L
s
.20974 .47387 m
.20974 .47762 L
s
.24602 .47387 m
.24602 .47762 L
s
.2823 .47387 m
.2823 .47762 L
s
.35487 .47387 m
.35487 .47762 L
s
.39115 .47387 m
.39115 .47762 L
s
.42743 .47387 m
.42743 .47762 L
s
.46372 .47387 m
.46372 .47762 L
s
.53628 .47387 m
.53628 .47762 L
s
.57257 .47387 m
.57257 .47762 L
s
.60885 .47387 m
.60885 .47762 L
s
.64513 .47387 m
.64513 .47762 L
s
.7177 .47387 m
.7177 .47762 L
s
.75398 .47387 m
.75398 .47762 L
s
.79026 .47387 m
.79026 .47762 L
s
.82655 .47387 m
.82655 .47762 L
s
.10089 .47387 m
.10089 .47762 L
s
.06461 .47387 m
.06461 .47762 L
s
.02832 .47387 m
.02832 .47762 L
s
.89911 .47387 m
.89911 .47762 L
s
.93539 .47387 m
.93539 .47762 L
s
.97168 .47387 m
.97168 .47762 L
s
.25 Mabswid
0 .47387 m
1 .47387 L
s
.5 .13213 m
.50625 .13213 L
s
[(-0.4)] .4875 .13213 1 0 Mshowa
.5 .303 m
.50625 .303 L
s
[(-0.2)] .4875 .303 1 0 Mshowa
.5 .64474 m
.50625 .64474 L
s
[(0.2)] .4875 .64474 1 0 Mshowa
.5 .81561 m
.50625 .81561 L
s
[(0.4)] .4875 .81561 1 0 Mshowa
.5 .98649 m
.50625 .98649 L
s
[(0.6)] .4875 .98649 1 0 Mshowa
.125 Mabswid
.5 .17485 m
.50375 .17485 L
s
.5 .21756 m
.50375 .21756 L
s
.5 .26028 m
.50375 .26028 L
s
.5 .34572 m
.50375 .34572 L
s
.5 .38843 m
.50375 .38843 L
s
.5 .43115 m
.50375 .43115 L
s
.5 .51659 m
.50375 .51659 L
s
.5 .55931 m
.50375 .55931 L
s
.5 .60202 m
.50375 .60202 L
s
.5 .68746 m
.50375 .68746 L
s
.5 .73018 m
.50375 .73018 L
s
.5 .7729 m
.50375 .7729 L
s
.5 .85833 m
.50375 .85833 L
s
.5 .90105 m
.50375 .90105 L
s
.5 .94377 m
.50375 .94377 L
s
.5 .08941 m
.50375 .08941 L
s
.5 .04669 m
.50375 .04669 L
s
.5 .00397 m
.50375 .00397 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
6 Mabswid
.95412 .68657 Mdot
.89243 .85663 Mdot
.80485 .95351 Mdot
.71332 .97619 Mdot
.63792 .9599 Mdot
.582 .94002 Mdot
.53835 .92784 Mdot
.5 .92393 Mdot
.5 Mabswid
.02381 .793 m
.02628 .78662 L
.02925 .77137 L
.03029 .75611 L
.03004 .74086 L
.02853 .7256 L
.02556 .71034 L
.02381 .70396 L
s
.02381 .24378 m
.02556 .2374 L
.02853 .22214 L
.03004 .20689 L
.03029 .19163 L
.02925 .17637 L
.02628 .16112 L
.02381 .15474 L
s
.97619 .793 m
.97372 .78662 L
.97075 .77137 L
.96971 .75611 L
.96996 .74086 L
.97147 .7256 L
.97444 .71034 L
.97619 .70396 L
s
.97619 .24378 m
.97444 .2374 L
.97147 .22214 L
.96996 .20689 L
.96971 .19163 L
.97075 .17637 L
.97372 .16112 L
.97619 .15474 L
s
.02381 .8158 m
.03264 .80188 L
.03607 .78662 L
.03829 .77137 L
.03918 .75611 L
.03883 .74086 L
.03732 .7256 L
.03464 .71034 L
.03059 .69509 L
.02444 .67983 L
.02381 .6786 L
s
.02381 .26914 m
.02444 .26791 L
.03059 .25265 L
.03464 .2374 L
.03732 .22214 L
.03883 .20689 L
.03918 .19163 L
.03829 .17637 L
.03607 .16112 L
.03264 .14586 L
.02381 .13194 L
s
.97619 .8158 m
.96736 .80188 L
.96393 .78662 L
.96171 .77137 L
.96082 .75611 L
.96117 .74086 L
.96268 .7256 L
.96536 .71034 L
.96941 .69509 L
.97556 .67983 L
.97619 .6786 L
s
.97619 .26914 m
.97556 .26791 L
.96941 .25265 L
.96536 .2374 L
.96268 .22214 L
.96117 .20689 L
.96082 .19163 L
.96171 .17637 L
.96393 .16112 L
.96736 .14586 L
.97619 .13194 L
s
.02381 .83315 m
.02471 .83239 L
.03925 .81714 L
.03995 .81561 L
.04653 .80188 L
.05081 .78662 L
.05259 .77137 L
.05271 .75611 L
.05158 .74086 L
.04936 .7256 L
.0461 .71034 L
.04172 .69509 L
.03995 .68989 L
.03598 .67983 L
.02809 .66457 L
.02381 .65845 L
s
.02381 .28929 m
.02809 .28317 L
.03598 .26791 L
.03995 .25785 L
.04172 .25265 L
.0461 .2374 L
.04936 .22214 L
.05158 .20689 L
.05271 .19163 L
.05259 .17637 L
.05081 .16112 L
.04653 .14586 L
.03995 .13213 L
.03925 .1306 L
.02471 .11535 L
.02381 .11459 L
s
.97619 .83315 m
.97529 .83239 L
.96075 .81714 L
.96005 .81561 L
.95347 .80188 L
.94919 .78662 L
.94741 .77137 L
.94729 .75611 L
.94842 .74086 L
.95064 .7256 L
.9539 .71034 L
.95828 .69509 L
.96005 .68989 L
.96402 .67983 L
.97191 .66457 L
.97619 .65845 L
s
.97619 .28929 m
.97191 .28317 L
.96402 .26791 L
.96005 .25785 L
.95828 .25265 L
.9539 .2374 L
.95064 .22214 L
.94842 .20689 L
.94729 .19163 L
.94741 .17637 L
.94919 .16112 L
.95347 .14586 L
.96005 .13213 L
.96075 .1306 L
.97529 .11535 L
.97619 .11459 L
s
.92487 .92393 m
.9184 .90868 L
.91162 .89761 L
.90772 .89342 L
.89548 .88781 L
.87934 .8917 L
.87433 .89342 L
.8632 .90417 L
.85884 .90868 L
.84723 .92393 L
s
.15277 .92393 m
.14116 .90868 L
.1368 .90417 L
.12567 .89342 L
.12066 .8917 L
.10452 .88781 L
.09228 .89342 L
.08838 .89761 L
.0816 .90868 L
.07513 .92393 L
s
.92487 .02381 m
.9184 .03907 L
.91162 .05013 L
.90772 .05432 L
.89548 .05993 L
.87934 .05604 L
.87433 .05432 L
.8632 .04357 L
.85884 .03907 L
.84723 .02381 L
s
.15277 .02381 m
.14116 .03907 L
.1368 .04357 L
.12567 .05432 L
.12066 .05604 L
.10452 .05993 L
.09228 .05432 L
.08838 .05013 L
.0816 .03907 L
.07513 .02381 L
s
.97619 .84808 m
.97447 .84765 L
.96005 .84573 L
.95124 .84765 L
.94391 .85401 L
.9401 .86291 L
.93745 .87816 L
.93698 .89342 L
.93774 .90868 L
.93932 .92393 L
s
.97619 .64047 m
.96736 .64932 L
.96005 .65905 L
.95654 .66457 L
.94831 .67983 L
.94391 .68954 L
.94174 .69509 L
.93639 .71034 L
.93176 .7256 L
.92776 .74036 L
.92764 .74086 L
.92386 .75611 L
.91995 .77137 L
.91519 .78662 L
.91162 .79507 L
.90765 .80188 L
.89548 .81519 L
.8932 .81714 L
.87934 .82827 L
.87414 .83239 L
.8632 .84213 L
.85732 .84765 L
.84705 .85834 L
.84289 .86291 L
.83091 .87694 L
.82991 .87816 L
.81759 .89342 L
.81477 .8969 L
.80509 .90868 L
.79863 .91584 L
.79071 .92393 L
s
.60802 .92393 m
.60492 .92299 L
.58878 .9181 L
.57264 .91349 L
.5565 .90944 L
.55314 .90868 L
.54036 .90621 L
.52421 .90397 L
.50807 .90282 L
.49193 .90282 L
.47579 .90397 L
.45964 .90621 L
.44686 .90868 L
.4435 .90944 L
.42736 .91349 L
.41122 .9181 L
.39508 .92299 L
.39198 .92393 L
s
.02381 .64047 m
.03264 .64932 L
.03995 .65905 L
.04346 .66457 L
.05169 .67983 L
.05609 .68954 L
.05826 .69509 L
.06361 .71034 L
.06824 .7256 L
.07224 .74036 L
.07236 .74086 L
.07614 .75611 L
.08005 .77137 L
.08481 .78662 L
.08838 .79507 L
.09235 .80188 L
.10452 .81519 L
.1068 .81714 L
.12066 .82827 L
.12586 .83239 L
.1368 .84213 L
.14268 .84765 L
.15295 .85834 L
.15711 .86291 L
.16909 .87694 L
.17009 .87816 L
.18241 .89342 L
.18523 .8969 L
.19491 .90868 L
.20137 .91584 L
.20929 .92393 L
s
.02381 .84808 m
.02553 .84765 L
.03995 .84573 L
.04876 .84765 L
.05609 .85401 L
.0599 .86291 L
.06255 .87816 L
.06302 .89342 L
.06226 .90868 L
.06068 .92393 L
s
.97619 .09966 m
.97447 .10009 L
.96005 .10201 L
.95124 .10009 L
.94391 .09373 L
.9401 .08483 L
.93745 .06958 L
.93698 .05432 L
.93774 .03907 L
.93932 .02381 L
s
.97619 .30727 m
.96736 .29842 L
.96005 .2887 L
.95654 .28317 L
.94831 .26791 L
.94391 .2582 L
.94174 .25265 L
.93639 .2374 L
.93176 .22214 L
.92776 .20738 L
.92764 .20689 L
.92386 .19163 L
.91995 .17637 L
.91519 .16112 L
.91162 .15267 L
.90765 .14586 L
.89548 .13255 L
.8932 .1306 L
.87934 .11947 L
.87414 .11535 L
.8632 .10561 L
.85732 .10009 L
.84705 .08941 L
.84289 .08483 L
.83091 .0708 L
.82991 .06958 L
.81759 .05432 L
.81477 .05084 L
.80509 .03907 L
.79863 .0319 L
.79071 .02381 L
s
.60802 .02381 m
.60492 .02475 L
.58878 .02964 L
.57264 .03426 L
.5565 .0383 L
.55314 .03907 L
.54036 .04153 L
.52421 .04377 L
.50807 .04492 L
.49193 .04492 L
.47579 .04377 L
.45964 .04153 L
.44686 .03907 L
.4435 .0383 L
.42736 .03426 L
.41122 .02964 L
.39508 .02475 L
.39198 .02381 L
s
.02381 .30727 m
.03264 .29842 L
.03995 .2887 L
.04346 .28317 L
.05169 .26791 L
.05609 .2582 L
.05826 .25265 L
.06361 .2374 L
.06824 .22214 L
.07224 .20738 L
.07236 .20689 L
.07614 .19163 L
.08005 .17637 L
.08481 .16112 L
.08838 .15267 L
.09235 .14586 L
.10452 .13255 L
.1068 .1306 L
.12066 .11947 L
.12586 .11535 L
.1368 .10561 L
.14268 .10009 L
.15295 .08941 L
.15711 .08483 L
.16909 .0708 L
.17009 .06958 L
.18241 .05432 L
.18523 .05084 L
.19491 .03907 L
.20137 .0319 L
.20929 .02381 L
s
.02381 .09966 m
.02553 .10009 L
.03995 .10201 L
.04876 .10009 L
.05609 .09373 L
.0599 .08483 L
.06255 .06958 L
.06302 .05432 L
.06226 .03907 L
.06068 .02381 L
s
.02381 .62341 m
.03995 .63307 L
.04122 .63406 L
.05609 .64851 L
.05677 .64932 L
.06812 .66457 L
.07224 .67091 L
.07759 .67983 L
.08617 .69509 L
.08838 .69911 L
.09459 .71034 L
.10342 .7256 L
.10452 .72741 L
.11336 .74086 L
.12066 .75082 L
.12483 .75611 L
.1368 .7702 L
.13784 .77137 L
.15172 .78662 L
.15295 .78795 L
.1659 .80188 L
.16909 .80529 L
.18026 .81714 L
.18523 .82232 L
.19518 .83239 L
.20137 .83835 L
.21174 .84765 L
.21751 .85233 L
.23278 .86291 L
.23366 .86342 L
.2498 .87141 L
.26594 .87671 L
.2717 .87816 L
.28208 .87992 L
.29822 .8816 L
.31437 .88209 L
.33051 .8816 L
.34665 .88026 L
.36279 .87818 L
.36291 .87816 L
.37893 .87551 L
.39508 .87246 L
.41122 .86925 L
.42736 .86614 L
.4435 .86337 L
.44637 .86291 L
.45964 .86111 L
.47579 .85952 L
.49193 .8587 L
.50807 .8587 L
Mistroke
.52421 .85952 L
.54036 .86111 L
.55363 .86291 L
.5565 .86337 L
.57264 .86614 L
.58878 .86925 L
.60492 .87246 L
.62107 .87551 L
.63709 .87816 L
.63721 .87818 L
.65335 .88026 L
.66949 .8816 L
.68563 .88209 L
.70178 .8816 L
.71792 .87992 L
.7283 .87816 L
.73406 .87671 L
.7502 .87141 L
.76634 .86342 L
.76722 .86291 L
.78249 .85233 L
.78826 .84765 L
.79863 .83835 L
.80482 .83239 L
.81477 .82232 L
.81974 .81714 L
.83091 .80529 L
.8341 .80188 L
.84705 .78795 L
.84828 .78662 L
.86216 .77137 L
.8632 .7702 L
.87517 .75611 L
.87934 .75082 L
.88664 .74086 L
.89548 .72741 L
.89658 .7256 L
.90541 .71034 L
.91162 .69911 L
.91383 .69509 L
.92241 .67983 L
.92776 .67091 L
.93188 .66457 L
.94323 .64932 L
.94391 .64851 L
.95878 .63406 L
.96005 .63307 L
.97619 .62341 L
Mfstroke
.02381 .32433 m
.03995 .31467 L
.04122 .31368 L
.05609 .29923 L
.05677 .29842 L
.06812 .28317 L
.07224 .27683 L
.07759 .26791 L
.08617 .25265 L
.08838 .24863 L
.09459 .2374 L
.10342 .22214 L
.10452 .22033 L
.11336 .20689 L
.12066 .19692 L
.12483 .19163 L
.1368 .17754 L
.13784 .17637 L
.15172 .16112 L
.15295 .15979 L
.1659 .14586 L
.16909 .14245 L
.18026 .1306 L
.18523 .12542 L
.19518 .11535 L
.20137 .10939 L
.21174 .10009 L
.21751 .09541 L
.23278 .08483 L
.23366 .08432 L
.2498 .07633 L
.26594 .07103 L
.2717 .06958 L
.28208 .06782 L
.29822 .06614 L
.31437 .06565 L
.33051 .06614 L
.34665 .06748 L
.36279 .06956 L
.36291 .06958 L
.37893 .07223 L
.39508 .07528 L
.41122 .07849 L
.42736 .0816 L
.4435 .08438 L
.44637 .08483 L
.45964 .08663 L
.47579 .08822 L
.49193 .08904 L
.50807 .08904 L
Mistroke
.52421 .08822 L
.54036 .08663 L
.55363 .08483 L
.5565 .08438 L
.57264 .0816 L
.58878 .07849 L
.60492 .07528 L
.62107 .07223 L
.63709 .06958 L
.63721 .06956 L
.65335 .06748 L
.66949 .06614 L
.68563 .06565 L
.70178 .06614 L
.71792 .06782 L
.7283 .06958 L
.73406 .07103 L
.7502 .07633 L
.76634 .08432 L
.76722 .08483 L
.78249 .09541 L
.78826 .10009 L
.79863 .10939 L
.80482 .11535 L
.81477 .12542 L
.81974 .1306 L
.83091 .14245 L
.8341 .14586 L
.84705 .15979 L
.84828 .16112 L
.86216 .17637 L
.8632 .17754 L
.87517 .19163 L
.87934 .19692 L
.88664 .20689 L
.89548 .22033 L
.89658 .22214 L
.90541 .2374 L
.91162 .24863 L
.91383 .25265 L
.92241 .26791 L
.92776 .27683 L
.93188 .28317 L
.94323 .29842 L
.94391 .29923 L
.95878 .31368 L
.96005 .31467 L
.97619 .32433 L
Mfstroke
.97619 .86171 m
.97232 .86291 L
.96005 .87176 L
.95615 .87816 L
.95102 .89342 L
.94875 .90868 L
.94816 .92393 L
s
.02381 .86171 m
.02768 .86291 L
.03995 .87176 L
.04385 .87816 L
.04898 .89342 L
.05125 .90868 L
.05184 .92393 L
s
.97619 .08603 m
.97232 .08483 L
.96005 .07598 L
.95615 .06958 L
.95102 .05432 L
.94875 .03907 L
.94816 .02381 L
s
.02381 .08603 m
.02768 .08483 L
.03995 .07598 L
.04385 .06958 L
.04898 .05432 L
.05125 .03907 L
.05184 .02381 L
s
.02381 .60656 m
.03995 .6084 L
.05609 .61305 L
.06788 .61881 L
.07224 .62152 L
.08794 .63406 L
.08838 .63447 L
.10265 .64932 L
.10452 .65145 L
.11557 .66457 L
.12066 .67083 L
.12794 .67983 L
.1368 .69074 L
.14037 .69509 L
.15295 .71011 L
.15315 .71034 L
.16638 .7256 L
.16909 .72864 L
.1802 .74086 L
.18523 .74622 L
.19481 .75611 L
.20137 .76259 L
.21074 .77137 L
.21751 .77731 L
.22911 .78662 L
.23366 .78995 L
.2498 .80026 L
.2527 .80188 L
.26594 .80828 L
.28208 .81422 L
.29256 .81714 L
.29822 .81839 L
.31437 .82109 L
.33051 .82257 L
.34665 .82302 L
.36279 .82263 L
.37893 .82158 L
.39508 .82005 L
.41122 .81826 L
.42094 .81714 L
.42736 .8164 L
.4435 .81466 L
.45964 .81321 L
.47579 .81217 L
.49193 .81163 L
.50807 .81163 L
.52421 .81217 L
.54036 .81321 L
.5565 .81466 L
.57264 .8164 L
Mistroke
.57906 .81714 L
.58878 .81826 L
.60492 .82005 L
.62107 .82158 L
.63721 .82263 L
.65335 .82302 L
.66949 .82257 L
.68563 .82109 L
.70178 .81839 L
.70744 .81714 L
.71792 .81422 L
.73406 .80828 L
.7473 .80188 L
.7502 .80026 L
.76634 .78995 L
.77089 .78662 L
.78249 .77731 L
.78926 .77137 L
.79863 .76259 L
.80519 .75611 L
.81477 .74622 L
.8198 .74086 L
.83091 .72864 L
.83362 .7256 L
.84685 .71034 L
.84705 .71011 L
.85963 .69509 L
.8632 .69074 L
.87206 .67983 L
.87934 .67083 L
.88443 .66457 L
.89548 .65145 L
.89735 .64932 L
.91162 .63447 L
.91206 .63406 L
.92776 .62152 L
.93212 .61881 L
.94391 .61305 L
.96005 .6084 L
.97619 .60656 L
Mfstroke
.02381 .34118 m
.03995 .33934 L
.05609 .33469 L
.06788 .32894 L
.07224 .32622 L
.08794 .31368 L
.08838 .31327 L
.10265 .29842 L
.10452 .29629 L
.11557 .28317 L
.12066 .27691 L
.12794 .26791 L
.1368 .257 L
.14037 .25265 L
.15295 .23763 L
.15315 .2374 L
.16638 .22214 L
.16909 .2191 L
.1802 .20689 L
.18523 .20152 L
.19481 .19163 L
.20137 .18516 L
.21074 .17637 L
.21751 .17044 L
.22911 .16112 L
.23366 .15779 L
.2498 .14748 L
.2527 .14586 L
.26594 .13946 L
.28208 .13353 L
.29256 .1306 L
.29822 .12935 L
.31437 .12665 L
.33051 .12517 L
.34665 .12472 L
.36279 .12511 L
.37893 .12616 L
.39508 .12769 L
.41122 .12948 L
.42094 .1306 L
.42736 .13134 L
.4435 .13308 L
.45964 .13453 L
.47579 .13557 L
.49193 .13611 L
.50807 .13611 L
.52421 .13557 L
.54036 .13453 L
.5565 .13308 L
.57264 .13134 L
Mistroke
.57906 .1306 L
.58878 .12948 L
.60492 .12769 L
.62107 .12616 L
.63721 .12511 L
.65335 .12472 L
.66949 .12517 L
.68563 .12665 L
.70178 .12935 L
.70744 .1306 L
.71792 .13353 L
.73406 .13946 L
.7473 .14586 L
.7502 .14748 L
.76634 .15779 L
.77089 .16112 L
.78249 .17044 L
.78926 .17637 L
.79863 .18516 L
.80519 .19163 L
.81477 .20152 L
.8198 .20689 L
.83091 .2191 L
.83362 .22214 L
.84685 .2374 L
.84705 .23763 L
.85963 .25265 L
.8632 .257 L
.87206 .26791 L
.87934 .27691 L
.88443 .28317 L
.89548 .29629 L
.89735 .29842 L
.91162 .31327 L
.91206 .31368 L
.92776 .32622 L
.93212 .32894 L
.94391 .33469 L
.96005 .33934 L
.97619 .34118 L
Mfstroke
.97619 .87462 m
.97157 .87816 L
.96188 .89342 L
.96005 .8987 L
.95767 .90868 L
.9557 .92393 L
s
.02381 .87462 m
.02843 .87816 L
.03812 .89342 L
.03995 .8987 L
.04233 .90868 L
.0443 .92393 L
s
.97619 .07312 m
.97157 .06958 L
.96188 .05432 L
.96005 .04904 L
.95767 .03907 L
.9557 .02381 L
s
.02381 .07312 m
.02843 .06958 L
.03812 .05432 L
.03995 .04904 L
.04233 .03907 L
.0443 .02381 L
s
.02381 .5893 m
.02654 .58829 L
.03995 .58302 L
.05609 .57652 L
.06541 .57304 L
.07224 .57093 L
.08838 .56835 L
.10452 .57129 L
.10928 .57304 L
.12066 .58119 L
.12854 .58829 L
.1368 .59711 L
.14236 .60355 L
.15295 .61665 L
.15464 .61881 L
.16647 .63406 L
.16909 .63744 L
.17836 .64932 L
.18523 .65792 L
.19067 .66457 L
.20137 .67717 L
.20372 .67983 L
.21751 .69468 L
.21791 .69509 L
.23366 .71014 L
.23388 .71034 L
.2498 .72337 L
.25281 .7256 L
.26594 .73435 L
.27745 .74086 L
.28208 .74317 L
.29822 .75004 L
.31437 .75521 L
.31772 .75611 L
.33051 .75891 L
.34665 .76136 L
.36279 .7628 L
.37893 .7634 L
.39508 .76339 L
.41122 .76294 L
.42736 .76224 L
.4435 .76146 L
.45964 .76074 L
.47579 .7602 L
.49193 .75991 L
.50807 .75991 L
.52421 .7602 L
.54036 .76074 L
.5565 .76146 L
.57264 .76224 L
Mistroke
.58878 .76294 L
.60492 .76339 L
.62107 .7634 L
.63721 .7628 L
.65335 .76136 L
.66949 .75891 L
.68228 .75611 L
.68563 .75521 L
.70178 .75004 L
.71792 .74317 L
.72255 .74086 L
.73406 .73435 L
.74719 .7256 L
.7502 .72337 L
.76612 .71034 L
.76634 .71014 L
.78209 .69509 L
.78249 .69468 L
.79628 .67983 L
.79863 .67717 L
.80933 .66457 L
.81477 .65792 L
.82164 .64932 L
.83091 .63744 L
.83353 .63406 L
.84536 .61881 L
.84705 .61665 L
.85764 .60355 L
.8632 .59711 L
.87146 .58829 L
.87934 .58119 L
.89072 .57304 L
.89548 .57129 L
.91162 .56835 L
.92776 .57093 L
.93459 .57304 L
.94391 .57652 L
.96005 .58302 L
.97346 .58829 L
.97619 .5893 L
Mfstroke
.02381 .35844 m
.02654 .35945 L
.03995 .36472 L
.05609 .37122 L
.06541 .3747 L
.07224 .37681 L
.08838 .37939 L
.10452 .37645 L
.10928 .3747 L
.12066 .36655 L
.12854 .35945 L
.1368 .35063 L
.14236 .34419 L
.15295 .33109 L
.15464 .32894 L
.16647 .31368 L
.16909 .3103 L
.17836 .29842 L
.18523 .28982 L
.19067 .28317 L
.20137 .27057 L
.20372 .26791 L
.21751 .25306 L
.21791 .25265 L
.23366 .2376 L
.23388 .2374 L
.2498 .22437 L
.25281 .22214 L
.26594 .21339 L
.27745 .20689 L
.28208 .20457 L
.29822 .1977 L
.31437 .19253 L
.31772 .19163 L
.33051 .18884 L
.34665 .18638 L
.36279 .18494 L
.37893 .18434 L
.39508 .18435 L
.41122 .1848 L
.42736 .1855 L
.4435 .18628 L
.45964 .187 L
.47579 .18754 L
.49193 .18784 L
.50807 .18784 L
.52421 .18754 L
.54036 .187 L
.5565 .18628 L
.57264 .1855 L
Mistroke
.58878 .1848 L
.60492 .18435 L
.62107 .18434 L
.63721 .18494 L
.65335 .18638 L
.66949 .18884 L
.68228 .19163 L
.68563 .19253 L
.70178 .1977 L
.71792 .20457 L
.72255 .20689 L
.73406 .21339 L
.74719 .22214 L
.7502 .22437 L
.76612 .2374 L
.76634 .2376 L
.78209 .25265 L
.78249 .25306 L
.79628 .26791 L
.79863 .27057 L
.80933 .28317 L
.81477 .28982 L
.82164 .29842 L
.83091 .3103 L
.83353 .31368 L
.84536 .32894 L
.84705 .33109 L
.85764 .34419 L
.8632 .35063 L
.87146 .35945 L
.87934 .36655 L
.89072 .3747 L
.89548 .37645 L
.91162 .37939 L
.92776 .37681 L
.93459 .3747 L
.94391 .37122 L
.96005 .36472 L
.97346 .35945 L
.97619 .35844 L
Mfstroke
.97619 .88722 m
.9713 .89342 L
.96478 .90868 L
.96165 .92393 L
s
.02381 .88722 m
.0287 .89342 L
.03522 .90868 L
.03835 .92393 L
s
.97619 .06052 m
.9713 .05432 L
.96478 .03907 L
.96165 .02381 L
s
.02381 .06052 m
.0287 .05432 L
.03522 .03907 L
.03835 .02381 L
s
.37893 .25147 m
.39508 .24968 L
.41122 .24858 L
.42736 .24799 L
.4435 .24773 L
.45964 .24766 L
.47579 .24768 L
.49193 .24771 L
.50807 .24771 L
.52421 .24768 L
.54036 .24766 L
.5565 .24773 L
.57264 .24799 L
.58878 .24858 L
.60492 .24968 L
.62107 .25147 L
.62903 .25265 L
.63721 .25417 L
.65335 .25801 L
.66949 .26326 L
.68082 .26791 L
.68563 .27018 L
.70178 .2791 L
.70803 .28317 L
.71792 .29038 L
.72759 .29842 L
.73406 .30441 L
.74313 .31368 L
.7502 .32168 L
.75611 .32894 L
.76634 .34286 L
.76725 .34419 L
.77696 .35945 L
.78249 .36915 L
.78543 .3747 L
.79281 .38996 L
.79863 .40394 L
.79911 .40522 L
.80431 .42047 L
.80835 .43573 L
.81113 .45099 L
.81255 .46624 L
.81255 .4815 L
.81113 .49675 L
.80835 .51201 L
.80431 .52727 L
.79911 .54252 L
.79863 .5438 L
.79281 .55778 L
.78543 .57304 L
Mistroke
.78249 .57859 L
.77696 .58829 L
.76725 .60355 L
.76634 .60488 L
.75611 .61881 L
.7502 .62606 L
.74313 .63406 L
.73406 .64333 L
.72759 .64932 L
.71792 .65736 L
.70803 .66457 L
.70178 .66864 L
.68563 .67756 L
.68082 .67983 L
.66949 .68448 L
.65335 .68973 L
.63721 .69357 L
.62903 .69509 L
.62107 .69627 L
.60492 .69806 L
.58878 .69916 L
.57264 .69975 L
.5565 .70001 L
.54036 .70008 L
.52421 .70006 L
.50807 .70003 L
.49193 .70003 L
.47579 .70006 L
.45964 .70008 L
.4435 .70001 L
.42736 .69975 L
.41122 .69916 L
.39508 .69806 L
.37893 .69627 L
.37097 .69509 L
.36279 .69357 L
.34665 .68973 L
.33051 .68448 L
.31918 .67983 L
.31437 .67756 L
.29822 .66864 L
.29197 .66457 L
.28208 .65736 L
.27241 .64932 L
.26594 .64333 L
.25687 .63406 L
.2498 .62606 L
.24389 .61881 L
.23366 .60488 L
.23275 .60355 L
Mistroke
.22304 .58829 L
.21751 .57859 L
.21457 .57304 L
.20719 .55778 L
.20137 .5438 L
.20089 .54252 L
.19569 .52727 L
.19165 .51201 L
.18887 .49675 L
.18745 .4815 L
.18745 .46624 L
.18887 .45099 L
.19165 .43573 L
.19569 .42047 L
.20089 .40522 L
.20137 .40394 L
.20719 .38996 L
.21457 .3747 L
.21751 .36915 L
.22304 .35945 L
.23275 .34419 L
.23366 .34286 L
.24389 .32894 L
.2498 .32168 L
.25687 .31368 L
.26594 .30441 L
.27241 .29842 L
.28208 .29038 L
.29197 .28317 L
.29822 .2791 L
.31437 .27018 L
.31918 .26791 L
.33051 .26326 L
.34665 .25801 L
.36279 .25417 L
.37097 .25265 L
.37893 .25147 L
Mfstroke
.02381 .57088 m
.03767 .55778 L
.03995 .55427 L
.04803 .54252 L
.05609 .52947 L
.05693 .52727 L
.06274 .51201 L
.06711 .49675 L
.06936 .4815 L
.06936 .46624 L
.06711 .45099 L
.06274 .43573 L
.05693 .42047 L
.05609 .41827 L
.04803 .40522 L
.03995 .39347 L
.03767 .38996 L
.02381 .37687 L
s
.97619 .57088 m
.96233 .55778 L
.96005 .55427 L
.95197 .54252 L
.94391 .52947 L
.94307 .52727 L
.93726 .51201 L
.93289 .49675 L
.93064 .4815 L
.93064 .46624 L
.93289 .45099 L
.93726 .43573 L
.94307 .42047 L
.94391 .41827 L
.95197 .40522 L
.96005 .39347 L
.96233 .38996 L
.97619 .37687 L
s
.97619 .89988 m
.97138 .90868 L
.96678 .92393 L
s
.02381 .89988 m
.02862 .90868 L
.03322 .92393 L
s
.97619 .04786 m
.97138 .03907 L
.96678 .02381 L
s
.02381 .04786 m
.02862 .03907 L
.03322 .02381 L
s
.4435 .32817 m
.45964 .32689 L
.47579 .32611 L
.49193 .32575 L
.50807 .32575 L
.52421 .32611 L
.54036 .32689 L
.5565 .32817 L
.56376 .32894 L
.57264 .33011 L
.58878 .3329 L
.60492 .33679 L
.62107 .34214 L
.62617 .34419 L
.63721 .34937 L
.65335 .35911 L
.65384 .35945 L
.66949 .37231 L
.67193 .3747 L
.68499 .38996 L
.68563 .39083 L
.69474 .40522 L
.70178 .41999 L
.70197 .42047 L
.70714 .43573 L
.71047 .45099 L
.71211 .46624 L
.71211 .4815 L
.71047 .49675 L
.70714 .51201 L
.70197 .52727 L
.70178 .52775 L
.69474 .54252 L
.68563 .55691 L
.68499 .55778 L
.67193 .57304 L
.66949 .57543 L
.65384 .58829 L
.65335 .58863 L
.63721 .59837 L
.62617 .60355 L
.62107 .6056 L
.60492 .61095 L
.58878 .61485 L
.57264 .61763 L
.56376 .61881 L
.5565 .61957 L
.54036 .62085 L
.52421 .62163 L
.50807 .62199 L
Mistroke
.49193 .62199 L
.47579 .62163 L
.45964 .62085 L
.4435 .61957 L
.43624 .61881 L
.42736 .61763 L
.41122 .61485 L
.39508 .61095 L
.37893 .6056 L
.37383 .60355 L
.36279 .59837 L
.34665 .58863 L
.34616 .58829 L
.33051 .57543 L
.32807 .57304 L
.31501 .55778 L
.31437 .55691 L
.30526 .54252 L
.29822 .52775 L
.29803 .52727 L
.29286 .51201 L
.28953 .49675 L
.28789 .4815 L
.28789 .46624 L
.28953 .45099 L
.29286 .43573 L
.29803 .42047 L
.29822 .41999 L
.30526 .40522 L
.31437 .39083 L
.31501 .38996 L
.32807 .3747 L
.33051 .37231 L
.34616 .35945 L
.34665 .35911 L
.36279 .34937 L
.37383 .34419 L
.37893 .34214 L
.39508 .33679 L
.41122 .3329 L
.42736 .33011 L
.43624 .32894 L
.4435 .32817 L
Mfstroke
.02381 .54999 m
.02992 .54252 L
.03603 .52727 L
.03995 .51337 L
.04027 .51201 L
.04322 .49675 L
.04472 .4815 L
.04472 .46624 L
.04322 .45099 L
.04027 .43573 L
.03995 .43437 L
.03603 .42047 L
.02992 .40522 L
.02381 .39775 L
s
.97619 .54999 m
.97008 .54252 L
.96397 .52727 L
.96005 .51337 L
.95973 .51201 L
.95678 .49675 L
.95528 .4815 L
.95528 .46624 L
.95678 .45099 L
.95973 .43573 L
.96005 .43437 L
.96397 .42047 L
.97008 .40522 L
.97619 .39775 L
s
.97619 .91306 m
.97185 .92393 L
s
.02381 .91306 m
.02815 .92393 L
s
.97619 .03468 m
.97185 .02381 L
s
.02381 .03468 m
.02815 .02381 L
s
.02381 .52318 m
.02809 .51201 L
.0311 .49675 L
.0324 .4815 L
.0324 .46624 L
.0311 .45099 L
.02809 .43573 L
.02381 .42456 L
s
.97619 .52318 m
.97191 .51201 L
.9689 .49675 L
.9676 .4815 L
.9676 .46624 L
.9689 .45099 L
.97191 .43573 L
.97619 .42456 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooohoG00<0emL0S]L008oG00<0emL0S]L008oG
0P2?e`00SmL00`3Ge`2>e`00SmL00`3Ge`2>e`00SmL00`3Ge`2>e`00SmL00`3Ge`2>e`002=L20008
e`3G0=L0e`03e`030=OG01CG00<0emL03ML00`3Ge`0ae`030=OG01cG00<0emL07=L00`3Ge`0ae`03
0=OG00gG00<0emL05=L0303GemL0e`3G0=L0e`802ML000SG0P002=L0e`3G0=L00mL00`3Ge`0Ce`03
0=OG00gG00<0emL0<mL301_G00<0emL06ML303GG00<0emL03ML00`3Ge`0Ce`0<0=OGe`3G0=L0e`3G
0P09e`001mL02`3G0=L0e`3G0=L000CG00<0emL04ML00`3Ge`0=e`030=OG03OG100Ge`030=OG01GG
100ie`030=OG00gG00<0emL04ML00`3Ge`02e`0;0=L0e`3G0=L0e`002=L000OG0P001]L0e`3G00?G
00D0emOG000Ce`030=OG00cG00<0emL0?=L501;G00<0emL04=L503kG00<0emL03=L00`3Ge`0Ae`05
0=OGe`000mL01P3G0=L0e`802=L000SG00L0e`3G0=L000?G00<0emL00]L00`3Ge`0?e`030=OG00cG
00<0emL0@]L300oG00<0emL03ML304?G00<0emL03ML00`3Ge`0?e`030=OG00;G00/0emOG0=L0e`3G
0009e`002=L01`3G0=L0e`000mL00`3Ge`02e`030=OG00kG00<0emL03ML00`3Ge`15e`H02ML00`3G
e`07e`H0AmL00`3Ge`0=e`030=OG00kG00<0emL00]L02`3GemL0e`3G0=L000WG0007e`030=L000;G
00<0e`000mL00`3Ge`03e`030=OG00cG00<0emL03ML00`3Ge`1<ea<0C]L00`3Ge`0=e`030=OG00cG
00<0emL00mL02`3GemL0e`3G0=L000WG0007e`050=L0e`000]L01@3GemL000GG00<0emL02mL00`3G
e`0=e`030=OG05KG0P1Ge`030=OG00gG00<0emL02mL00`3Ge`03e`050=OGe`000]L01@3G0=L000SG
0008e`040=OG00;G00D0emOG0006e`030=OG00WG00<0emL03ML00`3Ge`1Ge`030=OG05OG00<0emL0
3ML00`3Ge`09e`030=OG00CG00D0emOG0002e`030=L000[G0008e`040=OG00;G00D0emOG0007e`03
0=OG00OG00<0emL03ML00`3Ge`1He`030=OG05SG00<0emL03ML00`3Ge`07e`030=OG00GG00D0emOG
0002e`040=OG00WG0007e`040=OG00;G00<0emL00]L00`3Ge`06e`801=L300oG00<0emL0FML00`3G
e`1Ie`030=OG00gG0`04e`802=L01@3GemL000?G00<0e`002ML000OG00<0e`000mL00`3Ge`02e`03
0=OG00SG100Ae`030=OG05[G00<0emL0FML00`3Ge`0@e`@02]L00`3Ge`02e`040=OG00;G00<0emL0
1]L000WG00@0emL01ML00`3Ge`0Me`030=OG01oG3@0^e`030=OG02cG3@0Qe`030=OG01gG00<0emL0
0]L01@3GemL000[G0008e`050=OGe`001ML00`3Ge`0Le`030=OG01[G1P0=e`T09ML00`3Ge`0Se`T0
3ML601cG00<0emL07=L00`3Ge`03e`050=OGe`002ML000OG00D0emOG0006e`030=OG01_G00<0emL0
5mL401cG1@0Pe`030=OG01kG1@0Le`@06ML00`3Ge`0Ke`030=OG00?G00<0emL00]L00`3Ge`06e`00
2mL00`3Ge`04e`030=OG01[G00<0emL05ML302GG1@0Ke`030=OG01WG1@0Ue`<05mL00`3Ge`0Je`03
0=OG00CG00<0emL02]L000[G00<0emL01=L00`3Ge`0Je`030=OG01GG00<0emL0:mL401OG00<0emL0
5ML402gG00<0emL05=L00`3Ge`0Ke`030=OG00CG00<0emL02ML000WG00<0emL01ML00`3Ge`0Je`03
0=OG01?G0P0be`D04]L00`3Ge`0@e`D0<]L201GG00<0emL06]L00`3Ge`05e`030=OG00SG0007e`80
2=L00`3Ge`0Ie`030=OG01;G0P0ie`T02ML00`3Ge`07e`T0>ML201CG00<0emL06ML00`3Ge`06e`80
2=L0013G00<0emL06ML00`3Ge`0Be`030=OG04;G4`14e`030=OG01;G00<0emL06=L00`3Ge`0@e`00
4=L00`3Ge`0He`030=OG017G0P1>e`030=OG04cG0P0Ce`030=OG01SG00<0emL03mL000oG00<0emL0
6=L00`3Ge`0Ae`030=OG04kG00<0emL0C]L00`3Ge`0Ae`030=OG01SG00<0emL03]L000OG0P04e`80
6]L00`3Ge`0@e`80DML00`3Ge`1?e`804]L00`3Ge`0He`801=L200SG0009e`@06mL00`3Ge`0@e`03
0=OG057G00<0emL0DML00`3Ge`0@e`030=OG01WG100:e`009mL00`3Ge`0@e`030=OG05;G00<0emL0
D]L00`3Ge`0@e`030=OG02KG000Ve`030=OG013G00<0emL0DmL00`3Ge`1Ce`030=OG013G00<0emL0
9ML000OG00<0emL06mL00`3Ge`0@e`030=OG05CG00<0emL0DmL00`3Ge`0Ae`030=OG01_G00<0emL0
1]L000OG00<0emL06]L00`3Ge`0Ae`030=OG05CG00<0emL0E=L00`3Ge`0Ae`030=OG01[G00<0emL0
1]L000SG00<0emL05mL201;G0P1Ge`030=OG05GG0P0Be`806ML00`3Ge`07e`002ML00`3Ge`0Ee`03
0=OG017G00<0emL09ML=017G0P04e`030=OG00CG00<0emL01=L00`3Ge`0Se`d09mL00`3Ge`0Ae`03
0=OG01GG00<0emL02=L000[G00<0emL04]L201?G00<0emL08ML500gG2P06e`040=OG00[G00<0emL0
1=L00`3Ge`0Ie`X03ML502?G00<0emL04ML201CG00<0emL02ML000OG00D0emOG000Be`030=OG01;G
00<0emL07ML501cG2P07e`D01ML3013G2@0Le`D07mL00`3Ge`0Be`030=OG013G00D0emOG0008e`00
1mL01@3GemL0017G00<0emL04]L00`3Ge`0Je`@08ML400;G00<0emL09@0Ze`@07=L00`3Ge`0Be`03
0=OG00kG00D0emOG0009e`002=L01@3GemL000oG00<0emL04]L00`3Ge`0He`<0:mL0103Ge`08e`03
0=L000KG00<0emL0?]L301[G00<0emL04]L00`3Ge`0=e`050=OGe`002ML000SG00D0emOG000>e`03
0=OG01;G00<0emL05mL202kG00@0emL02ML200KG00<0emL0@ML201WG00<0emL04]L00`3Ge`0;e`05
0=OGe`002]L000WG00D0emOG000<e`030=OG01;G00<0emL05]L2037G0P0;e`030=OG00CG00<0emL0
@mL201SG00<0emL04]L00`3Ge`0:e`050=OGe`002]L000WG00D0emOG000;e`030=OG01;G00<0emL0
5]L00`3Ge`15e`030=OG04GG00<0emL05]L00`3Ge`0Ae`030=OG00[G00D0emOG000:e`002ML01@3G
emL000_G00<0emL04ML00`3Ge`0Fe`030=OG04KG00<0emL0A]L00`3Ge`0Ee`030=OG01;G00<0emL0
2ML01@3GemL000[G0007e`040=OG00?G00<0emL02=L00`3Ge`0Ae`030=OG01CG0P19e`030=OG04OG
0P0Fe`030=OG017G00<0emL02=L01@3GemL000;G00<0emL01]L000OG00@0emL00mL00`3Ge`07e`03
0=OG017G00<0emL05=L00`3Ge`19e`030=OG04WG00<0emL05=L00`3Ge`0Ae`030=OG00OG00D0emOG
0002e`030=OG00KG0007e`040=OG00?G00<0emL01mL00`3Ge`0@e`030=OG01?G0P1<e`030=OG04[G
0P0Ee`030=OG013G00<0emL01mL01@3GemL000;G00<0emL01]L000OG00@0emL00mL00`3Ge`07e`03
0=OG00oG00<0emL04]L204kG00<0emL0C=L201CG00<0emL03mL00`3Ge`07e`050=OGe`000]L00`3G
e`06e`001mL0103Ge`03e`030=OG00KG00<0emL03mL00`3Ge`0Be`030=OG04kG00<0emL0C]L00`3G
e`0Be`030=OG00kG00<0emL01]L01@3GemL000;G00<0emL01mL000SG00@0emL00mL00`3Ge`05e`03
0=OG00kG00<0emL04]L00`3Ge`1?e`030=OG04oG00<0emL04]L00`3Ge`0>e`030=OG00GG00D0emOG
0002e`030=OG00OG0008e`040=OG00?G00<0emL01ML00`3Ge`0=e`030=OG01;G00<0emL0D=L2057G
00<0emL04]L00`3Ge`0=e`030=OG00GG00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL0
1ML00`3Ge`0<e`030=OG01;G00<0emL0DML00`3Ge`1Ae`030=OG01;G00<0emL03=L00`3Ge`05e`05
0=OGe`000]L00`3Ge`07e`002=L0103Ge`03e`030=OG00CG00<0emL03=L00`3Ge`0Be`030=OG02WG
4P0Ge`030=OG01GG4P0[e`030=OG017G00<0emL03=L00`3Ge`05e`050=OGe`000]L00`3Ge`07e`00
2=L0103Ge`03e`030=OG00CG00<0emL03=L00`3Ge`0Ae`030=OG02GG1@0Bebl04]L502OG00<0emL0
4ML00`3Ge`0<e`030=OG00CG00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL01=L00`3G
e`0;e`030=OG017G00<0emL08=L602kG00<0emL0;=L602;G00<0emL04ML00`3Ge`0;e`030=OG00CG
00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL01=L00`3Ge`0:e`030=OG017G00<0emL0
7]L303CG00<0emL0<]L3023G00<0emL04ML00`3Ge`0:e`030=OG00CG00D0emOG0002e`030=OG00OG
0008e`040=OG00?G00<0emL01=L00`3Ge`09e`030=OG017G00<0emL07=L303OG00<0emL0=ML301kG
00<0emL04ML00`3Ge`09e`030=OG00CG00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL0
0mL00`3Ge`09e`030=OG017G00<0emL06mL203[G00<0emL0>=L201gG00<0emL04ML00`3Ge`09e`03
0=OG00?G00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL00mL00`3Ge`09e`030=OG013G
00<0emL06]L203cG00<0emL0>]L201cG00<0emL04=L00`3Ge`09e`030=OG00?G00D0emOG0002e`03
0=OG00OG0008e`040=OG00?G00<0emL00mL00`3Ge`08e`030=OG013G00<0emL06ML203kG00<0emL0
?=L201_G00<0emL04=L00`3Ge`08e`030=OG00?G00D0emOG0002e`030=OG00OG0008e`040=OG00?G
00<0emL00]L00`3Ge`08e`030=OG013G00<0emL06=L2043G00<0emL0?]L201[G00<0emL03mL00`3G
e`08e`030=OG00?G00D0emOG0002e`030=OG00OG0008e`040=OG00;G00<0emL00mL00`3Ge`08e`03
0=OG00oG00<0emL06=L00`3Ge`10e`030=OG043G00<0emL06=L00`3Ge`0?e`030=OG00SG00<0emL0
0]L01@3GemL000;G00<0emL01mL000SG00@0emL00]L00`3Ge`02e`030=OG00SG00<0emL03mL00`3G
e`0Ge`80@mL204;G0P0Ie`030=OG00kG00<0emL02=L00`3Ge`03e`040=OG00;G00<0emL01mL000SG
00@0emL00]L00`3Ge`02e`030=OG00OG0P0@e`030=OG01KG0P15e`030=OG04?G0P0He`030=OG00kG
0P09e`030=OG00;G00@0emL00]L00`3Ge`07e`002=L0103Ge`02e`030=OG00;G00<0emL01]L00`3G
e`0?e`030=OG01KG00<0emL0AML00`3Ge`15e`030=OG01KG00<0emL03]L00`3Ge`07e`030=OG00;G
00@0emL00]L00`3Ge`07e`001mL0103Ge`02e`030=OG00;G00<0emL01mL00`3Ge`0>e`030=OG01KG
00<0emL0A]L00`3Ge`16e`030=OG01GG00<0emL03mL00`3Ge`06e`030=OG00;G00@0emL00]L00`3G
e`07e`001mL0103Ge`02e`030=OG00;G00<0emL01]L00`3Ge`0?e`030=OG01CG0P19e`030=OG04OG
0P0Fe`030=OG00kG00<0emL01mL00`3Ge`02e`040=OG00;G00<0emL01]L000OG00@0emL00]L00`3G
e`02e`030=OG00KG00<0emL03]L00`3Ge`0De`030=OG04WG00<0emL0BML00`3Ge`0De`030=OG00kG
00<0emL01]L00`3Ge`02e`040=OG00;G00<0emL01]L000OG00@0emL00]L00`3Ge`02e`030=OG00GG
00<0emL03mL00`3Ge`0De`030=OG04WG00<0emL0BML00`3Ge`0De`030=OG00kG00<0emL01]L00`3G
e`02e`040=OG00;G00<0emL01]L000OG00@0emL00]L00`3Ge`02e`030=OG00GG00<0emL03]L00`3G
e`0De`030=OG04[G00<0emL0B]L00`3Ge`0De`030=OG00kG00<0emL01]L01@3GemL000;G00@0emL0
2=L000WG00@0emL01=L00`3Ge`05e`030=OG00kG00<0emL04mL203_G9@0ke`805ML00`3Ge`0=e`03
0=OG00KG00<0emL00]L0103Ge`0:e`002ML0103Ge`04e`030=OG00GG00<0emL03ML00`3Ge`0Ce`03
0=OG02gG3P0Be`030=OG013G3P0_e`030=OG01?G00<0emL03ML00`3Ge`06e`050=OGe`000]L00`3G
e`08e`002ML0103Ge`04e`030=OG00CG00<0emL03ML00`3Ge`0Ce`030=OG02GG2@0Pe`030=OG01kG
2@0We`030=OG01?G00<0emL03ML00`3Ge`05e`050=OGe`000]L00`3Ge`08e`002=L0103Ge`04e`03
0=OG00CG00<0emL03ML00`3Ge`0Ce`030=OG02;G100Ye`030=OG02OG100Te`030=OG01?G00<0emL0
3=L00`3Ge`05e`030=OG00;G00<0e`002]L000SG00@0emL01=L00`3Ge`04e`030=OG00cG00<0emL0
4mL00`3Ge`0Qe`80;ML202cG0P0Se`030=OG01?G00<0emL03=L00`3Ge`04e`030=OG00;G00@0emL0
2ML000OG00@0emL01=L00`3Ge`04e`030=OG00cG00<0emL04mL00`3Ge`0Oe`<0;mL00`3Ge`0]e`<0
8ML00`3Ge`0Ce`030=OG00_G00<0emL01ML00`3Ge`02e`030=L000WG0007e`040=OG00CG00<0emL0
1=L00`3Ge`0;e`030=OG01?G00<0emL07]L203;G00<0emL0<=L2023G00<0emL04mL00`3Ge`0;e`03
0=OG00CG00<0emL00]L0103Ge`08e`001mL0103Ge`03e`030=OG00GG00<0emL02]L00`3Ge`0Ce`03
0=OG01gG0P0de`030=OG03;G0P0Oe`030=OG01?G00<0emL02]L00`3Ge`05e`050=OGe`000]L00`3G
e`06e`002ML00`3Ge`02e`030=OG00CG00<0emL02mL00`3Ge`0Be`030=OG01cG0P0fe`030=OG03CG
0P0Ne`030=OG01;G00<0emL02mL00`3Ge`04e`030=OG00;G00<0emL02=L000WG00D0emOG0007e`03
0=OG00[G00<0emL04]L00`3Ge`0Ke`80>=L00`3Ge`0fe`807=L00`3Ge`0Ce`030=OG00[G00<0emL0
1ML01@3GemL000[G0008e`030=OG00;G00<0emL01=L00`3Ge`0:e`030=OG01?G00<0emL06]L00`3G
e`0he`030=OG03SG00<0emL06]L00`3Ge`0Be`030=OG00_G00<0emL01=L00`3Ge`02e`030=OG00OG
0008e`050=OGe`001]L00`3Ge`0;e`030=OG01;G00<0emL06]L00`3Ge`0ie`030=OG03WG00<0emL0
6]L00`3Ge`0Be`030=OG00_G00<0emL01=L01@3GemL000WG0007e`050=OGe`001]L00`3Ge`0;e`03
0=OG01;G00<0emL06]L00`3Ge`0je`030=OG03[G00<0emL06]L00`3Ge`0Be`030=OG00_G00<0emL0
1=L01@3GemL000SG000:e`030=OG00CG00<0emL02mL00`3Ge`0Be`030=OG01[G00<0emL0>mL00`3G
e`0ke`030=OG01[G00<0emL04]L00`3Ge`0:e`030=OG00GG00<0emL02ML000[G00<0emL01=L00`3G
e`0:e`030=OG01?G00<0emL06=L202[G0P04e`030=OG00;G1005e`030=OG03cG0P0Je`030=OG01?G
00<0emL02]L00`3Ge`04e`030=OG00WG0009e`030=OG00CG00<0emL02]L00`3Ge`0Ce`030=OG01SG
00<0emL0:ML0103Ge`08e`030=OG00KG00<0emL0?]L00`3Ge`0He`030=OG01?G00<0emL02]L00`3G
e`04e`030=OG00SG0008e`030=OG00CG00<0emL02]L00`3Ge`0Ce`030=OG01SG00<0emL0:]L0103G
e`09e`030=OG00GG0`0oe`030=OG01SG00<0emL04mL00`3Ge`0:e`030=OG00CG00<0emL01mL000OG
00<0emL01=L00`3Ge`0:e`030=OG01?G00<0emL06=L00`3Ge`0Ue`@00]L0103Ge`0:e`030=OG00CG
00<0emL0@=L00`3Ge`0He`030=OG01?G00<0emL02]L00`3Ge`04e`030=OG00KG000=e`030=OG00[G
00<0emL04mL00`3Ge`0Ge`80;]L0103Ge`0;e`030=OG00?G00<0emL0@ML201WG00<0emL04mL00`3G
e`0:e`030=OG00cG000<e`030=OG00[G00<0emL04mL00`3Ge`0Ge`030=OG02kG00@0emL02=L0103G
e`05e`030=OG04?G00<0emL05mL00`3Ge`0Ce`030=OG00[G00<0emL02mL000_G00<0emL02]L00`3G
e`0Ce`030=OG01OG00<0emL0<=L200[G0P06e`030=OG04CG00<0emL05mL00`3Ge`0Ce`030=OG00[G
00<0emL02]L000WG0P0<e`030=OG01CG00<0emL05mL00`3Ge`14e`030=OG04CG00<0emL05mL00`3G
e`0De`030=OG00[G0P0:e`001mL200gG00<0emL05=L00`3Ge`0Ge`030=OG04GG00<0emL0AML00`3G
e`0Ge`030=OG01CG00<0emL02mL200SG000Ee`030=OG01GG00<0emL05]L00`3Ge`0feb40=mL00`3G
e`0Ge`030=OG01GG00<0emL05=L001;G0`0Ge`030=OG01OG00<0emL0<=L6013G00<0emL03]L603;G
00<0emL05mL00`3Ge`0Ee`<04mL000oG0`0Ie`030=OG01OG00<0emL0;=L501KG00<0emL05=L502kG
00<0emL05mL00`3Ge`0Ge`<04=L000gG0P0Ke`030=OG01OG00<0emL0:=L501_G00<0emL06ML502WG
00<0emL05mL00`3Ge`0Je`803]L000OG1P0Me`030=OG01OG00<0emL09ML3023G00<0emL07]L302OG
00<0emL05mL00`3Ge`0Ke`H02=L002WG00<0emL05]L202OG00<0emL08ML00`3Ge`0Qe`030=OG02GG
0P0He`030=OG02SG000Xe`030=OG01KG00<0emL09ML202CG0P0Se`809]L00`3Ge`0Ge`030=OG02OG
000We`030=OG01OG00<0emL08mL202KG00<0emL09=L202GG00<0emL05mL00`3Ge`0Ve`009]L00`3G
e`0Ge`030=OG02;G0P0Xe`030=OG02KG0P0Se`030=OG01SG00<0emL09ML000OG00<0emL06mL00`3G
e`0He`030=OG023G0P0Ze`030=OG02SG0P0Re`030=OG01SG00<0emL06mL00`3Ge`06e`002=L201WG
0P0Je`030=OG023G00<0emL0:]L00`3Ge`0Ze`030=OG023G00<0emL06=L201WG0P09e`002]L301GG
00<0emL06]L00`3Ge`0Ne`80;ML00`3Ge`0[e`808=L00`3Ge`0Je`030=OG01?G0`0;e`003ML201;G
00<0emL06]L00`3Ge`0Ne`030=OG02gG00<0emL0;ML00`3Ge`0Ne`030=OG01[G00<0emL04=L200kG
000?e`<03]L00`3Ge`0Je`030=OG01kG00<0emL0;]L00`3Ge`0^e`030=OG01gG00<0emL06mL00`3G
e`0<e`<04=L000OG00<0emL02=L500GG100Me`030=OG01kG00<0emL0;]L00`3Ge`0^e`030=OG01kG
00<0emL06mL400GG1@0:e`030=OG00KG0008e`030=OG00cG1@0Pe`030=OG01kG00<0emL0;mL00`3G
e`0_e`030=OG01gG00<0emL07mL500kG00<0emL01mL000WG00<0emL0<=L00`3Ge`0Me`030=OG033G
00<0emL0<=L00`3Ge`0Me`030=OG033G00<0emL02=L000[G00<0emL0;]L00`3Ge`0Me`030=OG037G
00<0emL0<ML00`3Ge`0Le`030=OG02oG00<0emL02ML000_G00<0emL0;ML00`3Ge`0Le`030=OG03;G
0P0ce`030=OG01cG00<0emL0;ML00`3Ge`0:e`002mL00`3Ge`0/e`030=OG01cG00<0emL0<mL00`3G
e`0ce`030=OG01_G00<0emL0;ML00`3Ge`0:e`001mL00`3Ge`02e`030=OG02_G00<0emL07=L00`3G
e`0ce`030=OG03?G00<0emL07=L00`3Ge`0[e`030=OG00;G00<0emL01]L000OG00<0emL00]L00`3G
e`0Ze`030=OG01cG00<0emL0==L00`3Ge`0de`030=OG01_G00<0emL0:]L00`3Ge`03e`030=OG00KG
0008e`030=OG00;G00<0emL0:ML00`3Ge`0Le`030=OG03CG00<0emL0==L00`3Ge`0Le`030=OG02WG
00<0emL00]L00`3Ge`07e`002=L00`3Ge`03e`030=OG02SG00<0emL06mL00`3Ge`0ee`030=OG03GG
00<0emL06mL00`3Ge`0Xe`030=OG00?G00<0emL01mL000SG00<0emL01=L00`3Ge`0We`030=OG01[G
00<0emL0=]L00`3Ge`0ee`030=OG01_G00<0emL09mL00`3Ge`03e`030=OG00SG0009e`030=OG00?G
00<0emL09]L00`3Ge`0Ke`030=OG03KG00<0emL0=]L00`3Ge`0Je`030=OG02OG00<0emL00mL00`3G
e`08e`002ML00`3Ge`04e`030=OG02GG00<0emL06]L00`3Ge`0ge`030=OG03KG00<0emL06mL00`3G
e`0Ue`030=OG00?G00<0emL02ML000[G00<0emL00mL00`3Ge`0Ue`030=OG01[G00<0emL0=mL00`3G
e`0ge`030=OG01[G00<0emL09ML00`3Ge`03e`030=OG00WG0007e`040=OG00GG00<0emL09ML00`3G
e`0Je`030=OG03OG00<0emL0=mL00`3Ge`0Je`030=OG02CG00<0emL01=L0103Ge`08e`001mL0103G
e`06e`030=OG02?G00<0emL06]L00`3Ge`0he`030=OG03OG00<0emL06]L00`3Ge`0Te`030=OG00?G
00D0emOG0008e`002=L0103Ge`05e`030=OG02?G00<0emL06]L00`3Ge`0he`80>ML00`3Ge`0Je`03
0=OG02;G00<0emL01=L0103Ge`09e`002=L0103Ge`06e`030=OG02;G00<0emL06]L00`3Ge`0he`03
0=OG03SG00<0emL06]L00`3Ge`0Re`030=OG00CG00@0emL02ML000SG00@0emL01]L00`3Ge`0Ce`@0
2mL00`3Ge`0Je`030=OG00801=L00`3Ge`02e`<0:]L00`3Ge`0Ze`801=L00`3Ge`02e`@07=L00`3G
e`0;e`@04mL00`3Ge`04e`040=OG00WG0008e`040=OG00KG00<0emL05ML00`3Ge`0:e`030=OG01[G
00<0e`000]L00`3Ge`09e`030=OG02OG00<0emL0:ML0103Ge`0;e`030=OG01[G00<0emL03ML00`3G
e`0Be`030=OG00CG00@0emL02ML000WG00@0emL01]L00`3Ge`0De`030=OG00WG00<0emL06]L0103G
e`02e`030=OG00WG00<0emL09mL00`3Ge`0Ye`040=OG00_G0P0Le`030=OG00cG00<0emL04ML00`3G
e`04e`040=OG00[G0009e`040=OG00KG00<0emL03=L400CG00<0emL02ML00`3Ge`0Ge`@00]L0103G
e`08e`<0:]L00`3Ge`0Ye`040=OG00SG0`000mL0e`0Ke`030=OG00cG00<0emL04ML00`3Ge`04e`04
0=OG00[G0009e`040=OG00KG00<0emL05=L00`3Ge`09e`030=OG01[G00@0emL00]L00`3Ge`06e`03
0=OG02[G00<0emL0:ML0103Ge`08e`050=OGe`007=L00`3Ge`0<e`030=OG017G00<0emL01=L0103G
e`0:e`002ML0103Ge`06e`030=OG01;G0`0;e`030=OG01[G00@0emL00]L00`3Ge`06e`030=OG02[G
00<0emL0:ML0103Ge`08e`050=OGe`007=L00`3Ge`0:e`<04mL00`3Ge`04e`040=OG00[G0009e`04
0=OG00KG00<0emL05=L00`3Ge`08e`030=OG01[G00<0emL00]L200WG100Ye`030=OG02[G0P09e`D0
7=L00`3Ge`0<e`030=OG013G00<0emL01=L01@3GemL000[G0009e`050=OGe`001]L00`3Ge`0Ne`03
0=OG01[G00<0emL0>]L00`3Ge`0je`030=OG01[G00<0emL07]L00`3Ge`04e`050=OGe`002]L000WG
00D0emOG0006e`030=OG01kG00<0emL06]L00`3Ge`0je`030=OG03[G00<0emL06]L00`3Ge`0Ne`03
0=OG00CG00D0emOG000:e`002ML01@3GemL000KG00<0emL07]L00`3Ge`0Je`030=OG03[G00<0emL0
>]L00`3Ge`0Je`030=OG01kG00<0emL01=L01@3GemL000[G003o02000ML000SG0P03e`030=OG00;G
00<0e`002=L00`3Ge`07e`030=OG00OG00D0emOG0006e`030=OG00OG00<0emL02=L200SG00<0emL0
1mL00`3Ge`08e`030=OG00OG00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`07e`03
0=OG00SG00<0emL01mL00`3Ge`06e`802]L00`3Ge`07e`030=OG00CG00D0emOG0009e`030=OG00OG
00<0emL01]L00`3G0004e`040=OGe`802ML000WG00D0emOG0006e`030=OG013G00<0emL02mL00`3G
e`0Je`030=OG00KG00<0emL0<ML00`3Ge`0ae`030=OG00KG00<0emL06]L00`3Ge`0;e`030=OG013G
00<0emL01=L01@3GemL000[G0009e`050=OGe`001]L00`3Ge`0Ne`030=OG01[G00<0emL0>]L00`3G
e`0je`030=OG01[G00<0emL07]L00`3Ge`04e`050=OGe`002]L000WG00D0emOG0006e`030=OG01kG
00<0emL06]L00`3Ge`0je`030=OG03[G00<0emL06]L00`3Ge`0Ne`030=OG00CG00D0emOG000:e`00
2ML0103Ge`06e`030=OG023G00<0emL06]L00`3Ge`0ie`030=OG03WG00<0emL06]L00`3Ge`0Pe`03
0=OG00CG00@0emL02]L000WG00@0emL01]L00`3Ge`0Pe`030=OG01[G00<0emL0>ML00`3Ge`0ie`03
0=OG01[G00<0emL08=L00`3Ge`04e`040=OG00[G0009e`040=OG00KG00<0emL08=L00`3Ge`0Je`03
0=OG03WG00<0emL0>ML00`3Ge`0Je`030=OG023G00<0emL01=L0103Ge`0:e`002ML0103Ge`06e`03
0=OG023G00<0emL06]L00`3Ge`0ie`030=OG03WG00<0emL06]L00`3Ge`0Pe`030=OG00CG00@0emL0
2]L000SG00@0emL01]L00`3Ge`0Qe`030=OG01[G00<0emL0>ML00`3Ge`0he`030=OG01[G00<0emL0
8ML00`3Ge`04e`040=OG00[G0008e`040=OG00KG00<0emL08]L00`3Ge`0Je`030=OG03SG00<0emL0
>=L00`3Ge`0Je`030=OG02;G00<0emL01=L0103Ge`09e`002=L0103Ge`06e`030=OG02;G00<0emL0
6]L00`3Ge`0he`030=OG03SG00<0emL06]L00`3Ge`0Re`030=OG00CG00@0emL02ML000SG00@0emL0
1ML00`3Ge`0Se`030=OG01[G00<0emL0>=L203WG00<0emL06]L00`3Ge`0Re`030=OG00CG00@0emL0
2ML000OG00D0emOG0005e`030=OG02?G00<0emL06]L00`3Ge`0he`030=OG03OG00<0emL06]L00`3G
e`0Te`030=OG00?G00D0emOG0008e`001mL0103Ge`05e`030=OG02GG00<0emL06]L00`3Ge`0ge`03
0=OG03OG00<0emL06]L00`3Ge`0Te`030=OG00CG00@0emL02=L000[G00<0emL00mL00`3Ge`0Ue`03
0=OG01[G00<0emL0=mL00`3Ge`0ge`030=OG01[G00<0emL09ML00`3Ge`03e`030=OG00WG000:e`03
0=OG00?G00<0emL09ML00`3Ge`0Je`030=OG03OG00<0emL0=mL00`3Ge`0Je`030=OG02GG00<0emL0
0mL00`3Ge`09e`002ML00`3Ge`03e`030=OG02KG00<0emL06]L00`3Ge`0ge`030=OG03KG00<0emL0
6mL00`3Ge`0Ue`030=OG00CG00<0emL02=L000WG00<0emL00mL00`3Ge`0We`030=OG01[G00<0emL0
=]L00`3Ge`0fe`030=OG01[G00<0emL09mL00`3Ge`03e`030=OG00SG0008e`030=OG00?G00<0emL0
:=L00`3Ge`0Je`030=OG03KG00<0emL0=ML00`3Ge`0Ke`030=OG02OG00<0emL01=L00`3Ge`07e`00
2=L00`3Ge`03e`030=OG02SG00<0emL06mL00`3Ge`0ee`030=OG03GG00<0emL06mL00`3Ge`0Xe`03
0=OG00?G00<0emL01mL000OG00<0emL00mL00`3Ge`0Ye`030=OG01cG00<0emL0==L00`3Ge`0de`03
0=OG01_G00<0emL0:]L00`3Ge`02e`030=OG00OG0007e`030=OG00;G00<0emL0:mL00`3Ge`0Ke`03
0=OG03CG00<0emL0<mL00`3Ge`0Le`030=OG02_G00<0emL00]L00`3Ge`06e`002mL00`3Ge`0/e`03
0=OG01cG00<0emL0<mL00`3Ge`0ce`030=OG01_G00<0emL0;ML00`3Ge`0:e`002mL00`3Ge`0]e`03
0=OG01cG00<0emL0<]L00`3Ge`0be`030=OG01cG00<0emL0;ML00`3Ge`0:e`002]L00`3Ge`0^e`03
0=OG01gG00<0emL0<ML203;G00<0emL07ML00`3Ge`0^e`030=OG00WG0009e`030=OG033G00<0emL0
7ML00`3Ge`0`e`030=OG033G00<0emL07ML00`3Ge`0`e`030=OG00SG0008e`030=OG00gG100Pe`03
0=OG01gG00<0emL0<=L00`3Ge`0`e`030=OG01gG00<0emL07]L400oG00<0emL01mL000OG00<0emL0
2mL300CG0`0Ne`030=OG01gG00<0emL0;mL00`3Ge`0_e`030=OG01gG00<0emL07=L300CG0`0=e`03
0=OG00KG000Be`<02]L00`3Ge`0Ke`030=OG01kG00<0emL0;]L00`3Ge`0^e`030=OG01kG00<0emL0
6mL00`3Ge`08e`<04mL000kG100>e`807=L00`3Ge`0Ne`030=OG02gG00<0emL0;ML00`3Ge`0Ne`03
0=OG01[G0P0>e`@03mL000_G0`0De`030=OG01[G00<0emL07]L202gG00<0emL0:mL2023G00<0emL0
6]L00`3Ge`0Be`<03=L000WG0P0He`806]L00`3Ge`0Pe`030=OG02[G00<0emL0:]L00`3Ge`0Pe`03
0=OG01SG0P0He`802]L000OG0P0Le`030=OG01SG00<0emL08=L00`3Ge`0Ye`030=OG02WG00<0emL0
8=L00`3Ge`0He`030=OG01[G0P08e`009]L00`3Ge`0Ge`030=OG027G0P0Ye`030=OG02OG0P0Re`03
0=OG01SG00<0emL09ML002OG00<0emL05mL00`3Ge`0Re`809mL00`3Ge`0Ue`809=L00`3Ge`0Ge`03
0=OG02KG000Xe`030=OG01KG00<0emL09=L202GG00<0emL08mL202GG00<0emL05mL00`3Ge`0We`00
:ML00`3Ge`0Fe`030=OG02GG0P0Se`808]L202OG00<0emL05]L00`3Ge`0Xe`001mL2027G00<0emL0
5]L00`3Ge`0Ve`<08=L00`3Ge`0Ne`<0:=L00`3Ge`0Fe`030=OG01oG0P08e`002ML501cG00<0emL0
5mL00`3Ge`0Xe`@07=L00`3Ge`0Je`@0:]L00`3Ge`0Fe`030=OG01_G1@0:e`003]L301[G00<0emL0
5]L00`3Ge`0/e`806]L00`3Ge`0He`80;ML00`3Ge`0Ge`030=OG01SG0`0?e`004ML201WG00<0emL0
5]L00`3Ge`0]e`L04mL00`3Ge`0Ae`L0;mL00`3Ge`0Fe`030=OG01OG0P0Be`004mL301KG00<0emL0
5mL00`3Ge`0ce`X02ML00`3Ge`07e`X0=ML00`3Ge`0Ge`030=OG01CG0`0De`001mL00`3Ge`0<e`03
0=OG01CG00<0emL05]L00`3Ge`0mea<0?]L00`3Ge`0Ge`030=OG01CG00<0emL03=L00`3Ge`06e`00
2=L00`3Ge`0<e`030=OG01?G00<0emL05mL00`3Ge`15e`030=OG04GG00<0emL05]L00`3Ge`0De`03
0=OG00cG00<0emL01mL000WG0P0=e`030=OG01?G00<0emL05mL00`3Ge`14e`030=OG04CG00<0emL0
5mL00`3Ge`0Ce`030=OG00_G0P0:e`002mL200cG00<0emL04mL00`3Ge`0Ge`030=OG04?G00<0emL0
@mL00`3Ge`0Ge`030=OG01?G00<0emL02]L200cG000=e`030=OG00[G00<0emL04mL00`3Ge`0Ge`03
0=OG02kG0P04e`030=OG00;G1005e`030=OG04;G00<0emL05mL00`3Ge`0Ce`030=OG00[G00<0emL0
3=L000OG00<0emL01=L00`3Ge`0:e`030=OG01?G00<0emL05mL00`3Ge`0/e`040=OG00SG00<0emL0
1]L00`3Ge`11e`030=OG01OG00<0emL04mL00`3Ge`0:e`030=OG00CG00<0emL01]L000SG00<0emL0
1=L00`3Ge`0:e`030=OG01?G00<0emL05mL00`3Ge`0[e`040=OG00WG00<0emL01ML3043G00<0emL0
5mL00`3Ge`0Ce`030=OG00[G00<0emL01=L00`3Ge`07e`002ML00`3Ge`04e`030=OG00[G00<0emL0
4mL00`3Ge`0Ge`80:mL0103Ge`0:e`030=OG00CG00<0emL0?]L201WG00<0emL04mL00`3Ge`0:e`03
0=OG00CG00<0emL02=L000[G00<0emL01=L00`3Ge`0:e`030=OG01?G00<0emL06=L00`3Ge`0Xe`04
0=OG00_G00<0emL00mL00`3Ge`0me`030=OG01SG00<0emL04mL00`3Ge`0:e`030=OG00CG00<0emL0
2ML000[G00<0emL01=L00`3Ge`0;e`030=OG01;G00<0emL06ML00`3Ge`0We`040=OG00SG00@0emL0
1ML00`3Ge`0le`030=OG01WG00<0emL04]L00`3Ge`0;e`030=OG00CG00<0emL02ML000OG00D0emOG
0006e`030=OG00[G00<0emL04mL00`3Ge`0Ie`030=OG02OG0P0:e`801]L00`3Ge`0ke`030=OG01WG
00<0emL04]L00`3Ge`0;e`030=OG00CG00D0emOG0008e`001mL01@3GemL000KG00<0emL02mL00`3G
e`0Be`030=OG01[G00<0emL0>]L00`3Ge`0je`030=OG01WG00<0emL04mL00`3Ge`0;e`030=OG00?G
00D0emOG0009e`002=L01@3GemL000KG00<0emL02mL00`3Ge`0Be`030=OG01[G00<0emL0>ML00`3G
e`0ie`030=OG01[G00<0emL04]L00`3Ge`0;e`030=OG00CG00D0emOG0009e`002=L00`3Ge`02e`03
0=OG00CG00<0emL02]L00`3Ge`0Ce`030=OG01[G0P0ie`030=OG03OG0P0Le`030=OG01;G00<0emL0
2mL00`3Ge`04e`050=OGe`002]L000WG00D0emOG0007e`030=OG00[G00<0emL04mL00`3Ge`0Ke`80
=mL00`3Ge`0ee`807ML00`3Ge`0Ce`030=OG00[G00<0emL01=L00`3Ge`02e`030=OG00SG0009e`03
0=OG00;G00<0emL01=L00`3Ge`0;e`030=OG01?G00<0emL07=L203GG00<0emL0<mL201kG00<0emL0
4mL00`3Ge`0:e`030=OG00GG00D0emOG000;e`001mL0103Ge`04e`030=OG00CG00<0emL02mL00`3G
e`0Ce`030=OG01gG0P0ce`030=OG037G0P0Oe`030=OG01?G00<0emL02mL00`3Ge`04e`H00]L00`3G
e`06e`001mL0103Ge`04e`030=OG00CG00<0emL03=L00`3Ge`0Ce`030=OG01kG0P0ae`030=OG02oG
0P0Pe`030=OG01?G00<0emL03=L00`3Ge`04e`H00]L00`3Ge`06e`002=L0103Ge`04e`030=OG00CG
00<0emL03=L00`3Ge`0Ce`030=OG01oG0`0^e`80;ML3027G00<0emL04mL00`3Ge`0<e`030=OG00CG
1`000mL0e`08e`002=L0103Ge`04e`030=OG00CG00<0emL03ML00`3Ge`0Ce`030=OG027G1@0Ye`03
0=OG02OG1@0Se`030=OG01?G00<0emL03ML00`3Ge`04e`030=L000@000?G0=L02=L000WG00<0e`00
1=L00`3Ge`05e`030=OG00cG00<0emL05=L00`3Ge`0Ue`<09]L00`3Ge`0Te`<09mL00`3Ge`0Ce`03
0=OG00gG00<0emL01ML00`3G000500[G0009e`040=OG00CG00<0emL01=L00`3Ge`0=e`030=OG01?G
00<0emL0:=L;01_G00<0emL06ML;02[G00<0emL04mL00`3Ge`0=e`030=OG00GG00D0emOG0002e`03
0=OG00SG0009e`040=OG00CG00<0emL01ML00`3Ge`0=e`030=OG01?G00<0emL0<]Lg03CG00<0emL0
4mL00`3Ge`0=e`030=OG00GG00<0emL00]L0103Ge`0:e`001mL00`3G0002e`030=OG00;G00<0emL0
1]L00`3Ge`0=e`030=OG01?G0P1=e`030=OG04_G0P0Ee`030=OG00gG00<0emL01]L01@3GemL000;G
00@0emL02=L000OG00@0emL00]L00`3Ge`02e`030=OG00GG00<0emL03]L00`3Ge`0De`030=OG04[G
00<0emL0B]L00`3Ge`0De`030=OG00kG00<0emL01ML00`3Ge`02e`040=OG00;G00<0emL01]L000OG
00@0emL00]L00`3Ge`02e`030=OG00KG00<0emL03]L00`3Ge`0De`030=OG04WG00<0emL0BML00`3G
e`0De`030=OG00kG00<0emL01]L00`3Ge`02e`040=OG00;G00<0emL01]L000OG00@0emL00]L00`3G
e`02e`030=OG00KG00<0emL03mL00`3Ge`0De`030=OG04SG00<0emL0B=L00`3Ge`0De`030=OG00kG
00<0emL01mL00`3Ge`02e`040=OG00;G00<0emL01]L000OG00@0emL00]L00`3Ge`02e`030=OG00OG
00<0emL03]L00`3Ge`0Ee`030=OG04OG00<0emL0AmL00`3Ge`0De`030=OG00oG00<0emL01]L00`3G
e`02e`040=OG00;G00<0emL01mL000SG00@0emL00]L00`3Ge`02e`030=OG00KG00<0emL03mL00`3G
e`0Ee`030=OG04KG00<0emL0A]L00`3Ge`0Ee`030=OG00kG00<0emL01mL00`3Ge`02e`040=OG00;G
00<0emL01mL000SG00@0emL00]L00`3Ge`02e`030=OG00OG00<0emL03mL00`3Ge`0Ee`80A]L00`3G
e`14e`805mL00`3Ge`0?e`030=OG00OG00<0emL00]L0103Ge`02e`030=OG00OG0008e`040=OG00;G
00<0emL00]L00`3Ge`08e`030=OG00oG00<0emL05]L00`3Ge`13e`030=OG04?G00<0emL05]L00`3G
e`0?e`030=OG00SG00<0emL00]L0103Ge`02e`030=OG00OG0008e`040=OG00;G00<0emL00mL00`3G
e`07e`030=OG013G00<0emL05]L204?G0P12e`806=L00`3Ge`0?e`030=OG00SG00<0emL00mL0103G
e`02e`030=OG00OG0008e`040=OG00?G00<0emL00]L00`3Ge`08e`030=OG00oG00<0emL06=L00`3G
e`10e`030=OG043G00<0emL05mL00`3Ge`0@e`030=OG00SG00<0emL00]L01@3GemL000;G00<0emL0
1mL000SG00@0emL00mL00`3Ge`03e`030=OG00OG00<0emL04=L00`3Ge`0He`80@=L00`3Ge`0ne`80
6]L00`3Ge`0?e`030=OG00SG00<0emL00mL01@3GemL000;G00<0emL01mL000SG00@0emL00mL00`3G
e`03e`030=OG00SG00<0emL04=L00`3Ge`0Ie`<0?ML00`3Ge`0ke`<06mL00`3Ge`0@e`030=OG00SG
00<0emL00mL01@3GemL000;G00<0emL01mL000SG00@0emL00mL00`3Ge`03e`030=OG00WG00<0emL0
4=L201cG0P0ke`030=OG03WG0P0Le`804]L00`3Ge`09e`030=OG00?G00D0emOG0002e`030=OG00OG
0008e`040=OG00?G00<0emL00mL00`3Ge`09e`030=OG01;G00<0emL06mL303SG00<0emL0=]L301gG
00<0emL04]L00`3Ge`08e`030=OG00CG00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL0
1=L00`3Ge`09e`030=OG01;G00<0emL07ML203KG00<0emL0==L201oG00<0emL04]L00`3Ge`09e`03
0=OG00CG00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL01=L00`3Ge`0:e`804mL00`3G
e`0Ne`@0<]L00`3Ge`0`e`@08=L00`3Ge`0Ae`803=L00`3Ge`04e`050=OGe`000]L00`3Ge`07e`00
2=L0103Ge`03e`030=OG00CG00<0emL03=L00`3Ge`0@e`030=OG02;G100Qea/08ML402?G00<0emL0
4ML00`3Ge`0<e`030=OG00CG00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL01=L00`3G
e`0<e`030=OG017G00<0emL09MLQ00gG00<0emL02mLQ02OG00<0emL04=L00`3Ge`0<e`030=OG00GG
00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL01ML00`3Ge`0<e`030=OG017G0P1Ce`03
0=OG057G0P0Ce`030=OG00cG00<0emL01ML01@3GemL000;G00<0emL01mL000SG00@0emL00mL00`3G
e`05e`030=OG00gG00<0emL04]L00`3Ge`1@e`030=OG053G00<0emL04]L00`3Ge`0=e`030=OG00GG
00D0emOG0002e`030=OG00OG0008e`040=OG00?G00<0emL01ML00`3Ge`0>e`030=OG01;G00<0emL0
CmL2053G00<0emL04]L00`3Ge`0>e`030=OG00GG00D0emOG0002e`030=OG00OG0008e`040=OG00?G
00<0emL01ML00`3Ge`0?e`030=OG01;G00<0emL0C]L00`3Ge`1>e`030=OG01;G00<0emL03mL00`3G
e`05e`050=OGe`000]L00`3Ge`07e`001mL0103Ge`03e`030=OG00OG00<0emL03]L00`3Ge`0Ce`03
0=OG04gG00<0emL0CML00`3Ge`0Ce`030=OG00kG00<0emL01mL01@3GemL000;G00<0emL01]L000OG
00@0emL00mL00`3Ge`07e`030=OG00oG00<0emL04mL00`3Ge`1<e`030=OG04cG00<0emL04mL00`3G
e`0?e`030=OG00OG00D0emOG0002e`030=OG00KG0007e`040=OG00?G00<0emL01mL00`3Ge`0@e`80
5=L00`3Ge`1;e`030=OG04_G00<0emL04]L201;G00<0emL01mL01@3GemL000;G00<0emL01]L000OG
00@0emL00mL00`3Ge`07e`030=OG01;G00<0emL04]L204_G00<0emL0BML201CG00<0emL04ML00`3G
e`08e`050=OGe`000]L00`3Ge`06e`001mL00`3G0003e`030=OG00WG00<0emL04ML00`3Ge`0De`03
0=OG04SG00<0emL0B=L00`3Ge`0Ce`030=OG01;G00<0emL02=L01@3GemL000;G00<0emL01]L000WG
00D0emOG000;e`030=OG01;G00<0emL05=L204SG00<0emL0A]L201KG00<0emL04ML00`3Ge`0:e`05
0=OGe`002]L000WG00D0emOG000<e`030=OG01;G00<0emL05ML204KG00<0emL0A=L201OG00<0emL0
4]L00`3Ge`0:e`050=OGe`002]L000SG00D0emOG000>e`030=OG01;G00<0emL05]L204CG00<0emL0
@]L201SG00<0emL04]L00`3Ge`0;e`050=OGe`002]L000SG00D0emOG000?e`030=OG01;G00<0emL0
5mL302gG0P04e`030=OG00CG00<0emL01=L00`3Ge`0oe`<06ML00`3Ge`0Be`030=OG00gG00D0emOG
0009e`001mL01@3GemL0017G00<0emL04ML00`3Ge`0Je`80:]L0103Ge`04ea/0<]L201_G00<0emL0
4]L00`3Ge`0>e`050=OGe`002ML000OG00D0emOG000Be`030=OG017G00<0emL06mL302OG2003e`D0
1ML300_G200We`<07ML00`3Ge`0Ae`030=OG013G00D0emOG0008e`002mL00`3Ge`0@e`030=OG01;G
00<0emL07ML501OG3002e`030=OG00GG00@0emL01]L00`3Ge`0Ce`/05mL501oG00<0emL04]L00`3G
e`0@e`030=OG00[G000:e`030=OG01;G00<0emL04]L202;G5`0;e`040=OG00SG00<0e`001]L00`3G
e`0NeaL08]L201CG00<0emL04]L00`3Ge`09e`002ML00`3Ge`0De`805=L00`3Ge`11e`040=OG00WG
0P06e`030=OG05KG00<0emL04]L201KG00<0emL02=L000SG00<0emL05mL00`3Ge`0Be`030=OG047G
0P0;e`030=OG00CG00<0emL0EML00`3Ge`0Be`030=OG01OG00<0emL01mL000OG00<0emL06ML201?G
00<0emL0E=L00`3Ge`1De`030=OG017G0P0Ke`030=OG00KG000Ue`030=OG013G00<0emL0E=L00`3G
e`1Ce`030=OG017G00<0emL09=L002KG00<0emL04=L00`3Ge`1Ce`030=OG05?G00<0emL04=L00`3G
e`0Ue`009mL00`3Ge`0@e`80DmL00`3Ge`1Ae`804]L00`3Ge`0Ve`001mL801WG0P0Be`030=OG053G
00<0emL0D=L00`3Ge`0@e`801mL500gG2008e`003mL00`3Ge`0He`030=OG013G00<0emL0CmL00`3G
e`1?e`030=OG013G00<0emL01mL500cG00<0emL03]L0013G00<0emL06=L00`3Ge`0@e`030=OG04kG
00<0emL0C]L00`3Ge`0@e`030=OG00OG1P0;e`030=OG00oG000@e`030=OG01WG00<0emL04=L00`3G
e`19e`T0BmL00`3Ge`0@e`030=OG00WG1@0;e`030=OG00oG0007e`030=OG00OG00<0emL06=L00`3G
e`0Ae`80@=L900CG00<0emL00]L9043G0P0Be`030=OG00[G1@0:e`030=OG00OG00<0emL01]L000SG
00<0emL01]L00`3Ge`0Ie`030=OG01;G0P0ie`D03ML00`3Ge`0;e`D0>ML201CG00<0emL03=L00`3G
e`0:e`030=OG00KG00<0emL01mL000WG0P06e`030=OG01[G00<0emL04mL202kG2@0Be`030=OG013G
2@0^e`805ML00`3Ge`0Je`030=OG00CG0P0:e`002mL00`3Ge`03e`030=OG01[G00<0emL05ML302KG
1@0Ke`030=OG01WG1@0Ve`<05]L00`3Ge`0Je`030=OG00CG00<0emL02]L000OG00D0emOG0006e`03
0=OG01[G00<0emL05mL2023G100Pe`030=OG01kG100Pe`806ML00`3Ge`0Je`030=OG00?G00<0emL0
0]L00`3Ge`06e`002=L01@3GemL000GG00<0emL06mL201WG200Ce`D09=L00`3Ge`0Re`D04mL801WG
0P0Me`030=OG00?G00D0emOG0009e`002ML0103Ge`05e`030=OG01gG00<0emL07]LC02WG00<0emL0
9mLC023G00<0emL07ML00`3Ge`02e`050=OGe`002]L000WG00D0emOG0004e`030=OG01gG00<0emL0
F]L00`3Ge`1Ie`030=OG01kG00<0emL00]L0103Ge`0;e`001mL0103Ge`02e`030=OG00;G00<0emL0
2=L301?G00<0emL0FML00`3Ge`1Ie`030=OG017G0`0:e`050=OGe`000mL0103Ge`08e`002=L0103G
e`02e`050=OGe`001mL300?G1@0?e`030=OG05SG00<0emL0F=L00`3Ge`0=e`D00mL300OG00D0emOG
0002e`040=OG00WG0008e`040=OG00;G00D0emOG0006e`030=OG00WG00<0emL03ML00`3Ge`1Ge`03
0=OG05OG00<0emL03ML00`3Ge`08e`030=OG00GG00D0emOG0002e`040=OG00WG0007e`050=L0e`00
0]L01@3GemL000KG00<0emL02]L00`3Ge`0=e`030=OG05KG00<0emL0E]L00`3Ge`0=e`030=OG00[G
00<0emL01=L01@3GemL000;G00D0e`3G0008e`001mL01@3G0=L000;G00D0emOG0005e`030=OG00cG
00<0emL03=L00`3Ge`1=ea<0C]L00`3Ge`0=e`030=OG00cG00<0emL00mL01@3GemL000;G00D0e`3G
0008e`002=L01`3G0=L0e`000mL00`3Ge`03e`030=OG00cG00<0emL03ML00`3Ge`18e`@02ML00`3G
e`07e`@0B]L00`3Ge`0<e`030=OG00gG00<0emL00mL02`3GemL0e`3G0=L000WG0008e`070=L0e`3G
0003e`030=OG00;G00<0emL03]L00`3Ge`0=e`030=OG04;G1@0=e`030=OG00_G1@14e`030=OG00gG
00<0emL03]L00`3Ge`02e`0;0=OGe`3G0=L0e`002ML000OG0P001]L0e`3G00?G00D0emOG000Be`03
0=OG00cG00<0emL0?]L401;G00<0emL04=L403oG00<0emL03ML00`3Ge`0?e`030=OG00;G00X0emOG
0=L0e`3G0P08e`001mL20006e`3G0=L00]L00`3Ge`02e`030=OG017G00<0emL03=L00`3Ge`0ie`@0
5ML501?G100ke`030=OG00cG00<0emL04ML01@3GemL000;G00T0e`3G0=L0e`002=L000SG0P002=L0
e`3G0=L00mL00`3Ge`0Ce`030=OG00cG0P0ge`806ML500GG1@0=e`80=mL200kG00<0emL04]L00`3G
e`02e`080=L0e`3G0=L200WG0008e`8000SG0=L0e`3G00?G00<0emL05=L00`3Ge`0=e`030=OG037G
0`0Je`H01ML500oG0`0ce`030=OG00gG00<0emL05=L0303GemL0e`3G0=L0e`802ML008kG1@04e`H0
PmL008kG1@05e`D02=L507KG002?e`801mL500SG1@1fe`00SmL00`3Ge`08e`030=OG00OG1P1fe`00
SmL00`3Ge`0Ce`D0M]L008oG0P0De`D0>mL503KG002?e`030=OG01GG00<0emL0>mL503KG002?e`03
0=OG02?G1@0Ze`H0=]L008oG00<0emL08mL502_G1@0fe`00SmL00`3Ge`0Re`H0:mL503KG002?e`03
0=OG02?G1@0]e`030=OG03KG002?e`030=OG02?G1@1Ve`00SmL00`3Ge`0Ue`030=OG017G1@1@e`00
SmL00`3Ge`0ie`D0D=L008oG00<0emL0>=L6053G001ke`801=L00`3Ge`03e`801]L00`3Ge`0ie`D0
D=L007[G00@0emL02=L0103Ge`05e`030=OG03WG1@1@e`00N]L0103Ge`08e`040=OG00GG0`0ke`03
0=OG053G001je`040=OG00SG0`06e`030=OG08kG001je`040=OG00SG00<0emL01]L00`3Ge`2>e`00
N]L0103Ge`08e`030=OG00KG00<0emL0S]L007_G0P0:e`<01ML00`3Ge`2>e`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.38111, -0.554657, 0.00962449, \
0.00408732}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[pl3, pl4, AspectRatio \[Rule] 1, 
      DisplayFunction \[Rule] $DisplayFunction, 
      Prolog \[Rule] AbsolutePointSize[6]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.362828 0.5 0.809599 [
[.13717 .4875 -6 -9 ]
[.13717 .4875 6 0 ]
[.31859 .4875 -12 -9 ]
[.31859 .4875 12 0 ]
[.68141 .4875 -9 -9 ]
[.68141 .4875 9 0 ]
[.86283 .4875 -3 -9 ]
[.86283 .4875 3 0 ]
[.4875 .01424 -24 -4.5 ]
[.4875 .01424 0 4.5 ]
[.4875 .17616 -24 -4.5 ]
[.4875 .17616 0 4.5 ]
[.4875 .33808 -24 -4.5 ]
[.4875 .33808 0 4.5 ]
[.4875 .66192 -18 -4.5 ]
[.4875 .66192 0 4.5 ]
[.4875 .82384 -18 -4.5 ]
[.4875 .82384 0 4.5 ]
[.4875 .98576 -18 -4.5 ]
[.4875 .98576 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13717 .5 m
.13717 .50625 L
s
[(-1)] .13717 .4875 0 1 Mshowa
.31859 .5 m
.31859 .50625 L
s
[(-0.5)] .31859 .4875 0 1 Mshowa
.68141 .5 m
.68141 .50625 L
s
[(0.5)] .68141 .4875 0 1 Mshowa
.86283 .5 m
.86283 .50625 L
s
[(1)] .86283 .4875 0 1 Mshowa
.125 Mabswid
.17345 .5 m
.17345 .50375 L
s
.20974 .5 m
.20974 .50375 L
s
.24602 .5 m
.24602 .50375 L
s
.2823 .5 m
.2823 .50375 L
s
.35487 .5 m
.35487 .50375 L
s
.39115 .5 m
.39115 .50375 L
s
.42743 .5 m
.42743 .50375 L
s
.46372 .5 m
.46372 .50375 L
s
.53628 .5 m
.53628 .50375 L
s
.57257 .5 m
.57257 .50375 L
s
.60885 .5 m
.60885 .50375 L
s
.64513 .5 m
.64513 .50375 L
s
.7177 .5 m
.7177 .50375 L
s
.75398 .5 m
.75398 .50375 L
s
.79026 .5 m
.79026 .50375 L
s
.82655 .5 m
.82655 .50375 L
s
.10089 .5 m
.10089 .50375 L
s
.06461 .5 m
.06461 .50375 L
s
.02832 .5 m
.02832 .50375 L
s
.89911 .5 m
.89911 .50375 L
s
.93539 .5 m
.93539 .50375 L
s
.97168 .5 m
.97168 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .01424 m
.50625 .01424 L
s
[(-0.6)] .4875 .01424 1 0 Mshowa
.5 .17616 m
.50625 .17616 L
s
[(-0.4)] .4875 .17616 1 0 Mshowa
.5 .33808 m
.50625 .33808 L
s
[(-0.2)] .4875 .33808 1 0 Mshowa
.5 .66192 m
.50625 .66192 L
s
[(0.2)] .4875 .66192 1 0 Mshowa
.5 .82384 m
.50625 .82384 L
s
[(0.4)] .4875 .82384 1 0 Mshowa
.5 .98576 m
.50625 .98576 L
s
[(0.6)] .4875 .98576 1 0 Mshowa
.125 Mabswid
.5 .05472 m
.50375 .05472 L
s
.5 .0952 m
.50375 .0952 L
s
.5 .13568 m
.50375 .13568 L
s
.5 .21664 m
.50375 .21664 L
s
.5 .25712 m
.50375 .25712 L
s
.5 .2976 m
.50375 .2976 L
s
.5 .37856 m
.50375 .37856 L
s
.5 .41904 m
.50375 .41904 L
s
.5 .45952 m
.50375 .45952 L
s
.5 .54048 m
.50375 .54048 L
s
.5 .58096 m
.50375 .58096 L
s
.5 .62144 m
.50375 .62144 L
s
.5 .7024 m
.50375 .7024 L
s
.5 .74288 m
.50375 .74288 L
s
.5 .78336 m
.50375 .78336 L
s
.5 .86432 m
.50375 .86432 L
s
.5 .9048 m
.50375 .9048 L
s
.5 .94528 m
.50375 .94528 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .49986 m
.02544 .44394 L
.0303 .38861 L
.03838 .33474 L
.04961 .28305 L
.06392 .23424 L
.0812 .18902 L
.10135 .14805 L
.12422 .112 L
.14966 .08147 L
.17748 .057 L
.20752 .03907 L
.23955 .02798 L
.27336 .02381 L
.30872 .02626 L
.34538 .0344 L
.3831 .04643 L
.42162 .05943 L
.46068 .06963 L
.5 .07352 L
.53932 .06963 L
.57838 .05943 L
.6169 .04643 L
.65462 .0344 L
.69128 .02626 L
.72664 .02381 L
.76045 .02798 L
.79248 .03907 L
.82252 .057 L
.85034 .08147 L
.87578 .112 L
.89865 .14805 L
.9188 .18902 L
.93608 .23424 L
.95039 .28305 L
.96162 .33474 L
.9697 .38861 L
.97456 .44394 L
.97619 .49986 L
s
.02381 .50014 m
.02544 .55606 L
.0303 .61139 L
.03838 .66526 L
.04961 .71695 L
.06392 .76576 L
.0812 .81098 L
.10135 .85195 L
.12422 .888 L
.14966 .91853 L
.17748 .943 L
.20752 .96093 L
.23955 .97202 L
.27336 .97619 L
.30872 .97374 L
.34538 .9656 L
.3831 .95357 L
.42162 .94057 L
.46068 .93037 L
.5 .92648 L
.53932 .93037 L
.57838 .94057 L
.6169 .95357 L
.65462 .9656 L
.69128 .97374 L
.72664 .97619 L
.76045 .97202 L
.79248 .96093 L
.82252 .943 L
.85034 .91853 L
.87578 .888 L
.89865 .85195 L
.9188 .81098 L
.93608 .76576 L
.95039 .71695 L
.96162 .66526 L
.9697 .61139 L
.97456 .55606 L
.97619 .50014 L
s
6 Mabswid
.95412 .70156 Mdot
.89243 .86271 Mdot
.80485 .95451 Mdot
.71332 .976 Mdot
.63792 .96057 Mdot
.582 .94172 Mdot
.53835 .93019 Mdot
.5 .92648 Mdot
.5 Mabswid
.02381 .80241 m
.02628 .79637 L
.02925 .78191 L
.03029 .76746 L
.03004 .753 L
.02853 .73854 L
.02556 .72408 L
.02381 .71803 L
s
.02381 .28197 m
.02556 .27592 L
.02853 .26146 L
.03004 .247 L
.03029 .23254 L
.02925 .21809 L
.02628 .20363 L
.02381 .19759 L
s
.97619 .80241 m
.97372 .79637 L
.97075 .78191 L
.96971 .76746 L
.96996 .753 L
.97147 .73854 L
.97444 .72408 L
.97619 .71803 L
s
.97619 .28197 m
.97444 .27592 L
.97147 .26146 L
.96996 .247 L
.96971 .23254 L
.97075 .21809 L
.97372 .20363 L
.97619 .19759 L
s
.02381 .82402 m
.03264 .81083 L
.03607 .79637 L
.03829 .78191 L
.03918 .76746 L
.03883 .753 L
.03732 .73854 L
.03464 .72408 L
.03059 .70963 L
.02444 .69517 L
.02381 .694 L
s
.02381 .306 m
.02444 .30483 L
.03059 .29037 L
.03464 .27592 L
.03732 .26146 L
.03883 .247 L
.03918 .23254 L
.03829 .21809 L
.03607 .20363 L
.03264 .18917 L
.02381 .17598 L
s
.97619 .82402 m
.96736 .81083 L
.96393 .79637 L
.96171 .78191 L
.96082 .76746 L
.96117 .753 L
.96268 .73854 L
.96536 .72408 L
.96941 .70963 L
.97556 .69517 L
.97619 .694 L
s
.97619 .306 m
.97556 .30483 L
.96941 .29037 L
.96536 .27592 L
.96268 .26146 L
.96117 .247 L
.96082 .23254 L
.96171 .21809 L
.96393 .20363 L
.96736 .18917 L
.97619 .17598 L
s
.02381 .84046 m
.02471 .83974 L
.03925 .82528 L
.03995 .82384 L
.04653 .81083 L
.05081 .79637 L
.05259 .78191 L
.05271 .76746 L
.05158 .753 L
.04936 .73854 L
.0461 .72408 L
.04172 .70963 L
.03995 .7047 L
.03598 .69517 L
.02809 .68071 L
.02381 .67491 L
s
.02381 .32509 m
.02809 .31929 L
.03598 .30483 L
.03995 .2953 L
.04172 .29037 L
.0461 .27592 L
.04936 .26146 L
.05158 .247 L
.05271 .23254 L
.05259 .21809 L
.05081 .20363 L
.04653 .18917 L
.03995 .17616 L
.03925 .17472 L
.02471 .16026 L
.02381 .15954 L
s
.97619 .84046 m
.97529 .83974 L
.96075 .82528 L
.96005 .82384 L
.95347 .81083 L
.94919 .79637 L
.94741 .78191 L
.94729 .76746 L
.94842 .753 L
.95064 .73854 L
.9539 .72408 L
.95828 .70963 L
.96005 .7047 L
.96402 .69517 L
.97191 .68071 L
.97619 .67491 L
s
.97619 .32509 m
.97191 .31929 L
.96402 .30483 L
.96005 .2953 L
.95828 .29037 L
.9539 .27592 L
.95064 .26146 L
.94842 .247 L
.94729 .23254 L
.94741 .21809 L
.94919 .20363 L
.95347 .18917 L
.96005 .17616 L
.96075 .17472 L
.97529 .16026 L
.97619 .15954 L
s
.92487 .92648 m
.9184 .91203 L
.91162 .90154 L
.90772 .89757 L
.89548 .89226 L
.87934 .89594 L
.87433 .89757 L
.8632 .90776 L
.85884 .91203 L
.84723 .92648 L
s
.15277 .92648 m
.14116 .91203 L
.1368 .90776 L
.12567 .89757 L
.12066 .89594 L
.10452 .89226 L
.09228 .89757 L
.08838 .90154 L
.0816 .91203 L
.07513 .92648 L
s
.92487 .07352 m
.9184 .08797 L
.91162 .09846 L
.90772 .10243 L
.89548 .10774 L
.87934 .10406 L
.87433 .10243 L
.8632 .09224 L
.85884 .08797 L
.84723 .07352 L
s
.15277 .07352 m
.14116 .08797 L
.1368 .09224 L
.12567 .10243 L
.12066 .10406 L
.10452 .10774 L
.09228 .10243 L
.08838 .09846 L
.0816 .08797 L
.07513 .07352 L
s
.97619 .85461 m
.97447 .8542 L
.96005 .85238 L
.95124 .8542 L
.94391 .86022 L
.9401 .86865 L
.93745 .88311 L
.93698 .89757 L
.93774 .91203 L
.93932 .92648 L
s
.97619 .65787 m
.96736 .66626 L
.96005 .67547 L
.95654 .68071 L
.94831 .69517 L
.94391 .70437 L
.94174 .70963 L
.93639 .72408 L
.93176 .73854 L
.92776 .75253 L
.92764 .753 L
.92386 .76746 L
.91995 .78191 L
.91519 .79637 L
.91162 .80437 L
.90765 .81083 L
.89548 .82344 L
.8932 .82528 L
.87934 .83583 L
.87414 .83974 L
.8632 .84897 L
.85732 .8542 L
.84705 .86432 L
.84289 .86865 L
.83091 .88195 L
.82991 .88311 L
.81759 .89757 L
.81477 .90087 L
.80509 .91203 L
.79863 .91882 L
.79071 .92648 L
s
.60802 .92648 m
.60492 .92559 L
.58878 .92096 L
.57264 .91658 L
.5565 .91275 L
.55314 .91203 L
.54036 .90969 L
.52421 .90756 L
.50807 .90647 L
.49193 .90647 L
.47579 .90756 L
.45964 .90969 L
.44686 .91203 L
.4435 .91275 L
.42736 .91658 L
.41122 .92096 L
.39508 .92559 L
.39198 .92648 L
s
.02381 .65787 m
.03264 .66626 L
.03995 .67547 L
.04346 .68071 L
.05169 .69517 L
.05609 .70437 L
.05826 .70963 L
.06361 .72408 L
.06824 .73854 L
.07224 .75253 L
.07236 .753 L
.07614 .76746 L
.08005 .78191 L
.08481 .79637 L
.08838 .80437 L
.09235 .81083 L
.10452 .82344 L
.1068 .82528 L
.12066 .83583 L
.12586 .83974 L
.1368 .84897 L
.14268 .8542 L
.15295 .86432 L
.15711 .86865 L
.16909 .88195 L
.17009 .88311 L
.18241 .89757 L
.18523 .90087 L
.19491 .91203 L
.20137 .91882 L
.20929 .92648 L
s
.02381 .85461 m
.02553 .8542 L
.03995 .85238 L
.04876 .8542 L
.05609 .86022 L
.0599 .86865 L
.06255 .88311 L
.06302 .89757 L
.06226 .91203 L
.06068 .92648 L
s
.97619 .14539 m
.97447 .1458 L
.96005 .14762 L
.95124 .1458 L
.94391 .13978 L
.9401 .13135 L
.93745 .11689 L
.93698 .10243 L
.93774 .08797 L
.93932 .07352 L
s
.97619 .34213 m
.96736 .33374 L
.96005 .32453 L
.95654 .31929 L
.94831 .30483 L
.94391 .29563 L
.94174 .29037 L
.93639 .27592 L
.93176 .26146 L
.92776 .24747 L
.92764 .247 L
.92386 .23254 L
.91995 .21809 L
.91519 .20363 L
.91162 .19563 L
.90765 .18917 L
.89548 .17656 L
.8932 .17472 L
.87934 .16417 L
.87414 .16026 L
.8632 .15103 L
.85732 .1458 L
.84705 .13568 L
.84289 .13135 L
.83091 .11805 L
.82991 .11689 L
.81759 .10243 L
.81477 .09913 L
.80509 .08797 L
.79863 .08118 L
.79071 .07352 L
s
.60802 .07352 m
.60492 .07441 L
.58878 .07904 L
.57264 .08342 L
.5565 .08725 L
.55314 .08797 L
.54036 .09031 L
.52421 .09244 L
.50807 .09353 L
.49193 .09353 L
.47579 .09244 L
.45964 .09031 L
.44686 .08797 L
.4435 .08725 L
.42736 .08342 L
.41122 .07904 L
.39508 .07441 L
.39198 .07352 L
s
.02381 .34213 m
.03264 .33374 L
.03995 .32453 L
.04346 .31929 L
.05169 .30483 L
.05609 .29563 L
.05826 .29037 L
.06361 .27592 L
.06824 .26146 L
.07224 .24747 L
.07236 .247 L
.07614 .23254 L
.08005 .21809 L
.08481 .20363 L
.08838 .19563 L
.09235 .18917 L
.10452 .17656 L
.1068 .17472 L
.12066 .16417 L
.12586 .16026 L
.1368 .15103 L
.14268 .1458 L
.15295 .13568 L
.15711 .13135 L
.16909 .11805 L
.17009 .11689 L
.18241 .10243 L
.18523 .09913 L
.19491 .08797 L
.20137 .08118 L
.20929 .07352 L
s
.02381 .14539 m
.02553 .1458 L
.03995 .14762 L
.04876 .1458 L
.05609 .13978 L
.0599 .13135 L
.06255 .11689 L
.06302 .10243 L
.06226 .08797 L
.06068 .07352 L
s
.02381 .64171 m
.03995 .65086 L
.04122 .6518 L
.05609 .66549 L
.05677 .66626 L
.06812 .68071 L
.07224 .68672 L
.07759 .69517 L
.08617 .70963 L
.08838 .71344 L
.09459 .72408 L
.10342 .73854 L
.10452 .74026 L
.11336 .753 L
.12066 .76244 L
.12483 .76746 L
.1368 .78081 L
.13784 .78191 L
.15172 .79637 L
.15295 .79762 L
.1659 .81083 L
.16909 .81405 L
.18026 .82528 L
.18523 .83019 L
.19518 .83974 L
.20137 .84538 L
.21174 .8542 L
.21751 .85863 L
.23278 .86865 L
.23366 .86914 L
.2498 .87671 L
.26594 .88173 L
.2717 .88311 L
.28208 .88478 L
.29822 .88637 L
.31437 .88683 L
.33051 .88637 L
.34665 .8851 L
.36279 .88313 L
.36291 .88311 L
.37893 .8806 L
.39508 .8777 L
.41122 .87467 L
.42736 .87172 L
.4435 .86909 L
.44637 .86865 L
.45964 .86695 L
.47579 .86545 L
.49193 .86467 L
.50807 .86467 L
Mistroke
.52421 .86545 L
.54036 .86695 L
.55363 .86865 L
.5565 .86909 L
.57264 .87172 L
.58878 .87467 L
.60492 .8777 L
.62107 .8806 L
.63709 .88311 L
.63721 .88313 L
.65335 .8851 L
.66949 .88637 L
.68563 .88683 L
.70178 .88637 L
.71792 .88478 L
.7283 .88311 L
.73406 .88173 L
.7502 .87671 L
.76634 .86914 L
.76722 .86865 L
.78249 .85863 L
.78826 .8542 L
.79863 .84538 L
.80482 .83974 L
.81477 .83019 L
.81974 .82528 L
.83091 .81405 L
.8341 .81083 L
.84705 .79762 L
.84828 .79637 L
.86216 .78191 L
.8632 .78081 L
.87517 .76746 L
.87934 .76244 L
.88664 .753 L
.89548 .74026 L
.89658 .73854 L
.90541 .72408 L
.91162 .71344 L
.91383 .70963 L
.92241 .69517 L
.92776 .68672 L
.93188 .68071 L
.94323 .66626 L
.94391 .66549 L
.95878 .6518 L
.96005 .65086 L
.97619 .64171 L
Mfstroke
.02381 .35829 m
.03995 .34914 L
.04122 .3482 L
.05609 .33451 L
.05677 .33374 L
.06812 .31929 L
.07224 .31328 L
.07759 .30483 L
.08617 .29037 L
.08838 .28656 L
.09459 .27592 L
.10342 .26146 L
.10452 .25974 L
.11336 .247 L
.12066 .23756 L
.12483 .23254 L
.1368 .21919 L
.13784 .21809 L
.15172 .20363 L
.15295 .20238 L
.1659 .18917 L
.16909 .18595 L
.18026 .17472 L
.18523 .16981 L
.19518 .16026 L
.20137 .15462 L
.21174 .1458 L
.21751 .14137 L
.23278 .13135 L
.23366 .13086 L
.2498 .12329 L
.26594 .11827 L
.2717 .11689 L
.28208 .11522 L
.29822 .11363 L
.31437 .11317 L
.33051 .11363 L
.34665 .1149 L
.36279 .11687 L
.36291 .11689 L
.37893 .1194 L
.39508 .1223 L
.41122 .12533 L
.42736 .12828 L
.4435 .13091 L
.44637 .13135 L
.45964 .13305 L
.47579 .13455 L
.49193 .13533 L
.50807 .13533 L
Mistroke
.52421 .13455 L
.54036 .13305 L
.55363 .13135 L
.5565 .13091 L
.57264 .12828 L
.58878 .12533 L
.60492 .1223 L
.62107 .1194 L
.63709 .11689 L
.63721 .11687 L
.65335 .1149 L
.66949 .11363 L
.68563 .11317 L
.70178 .11363 L
.71792 .11522 L
.7283 .11689 L
.73406 .11827 L
.7502 .12329 L
.76634 .13086 L
.76722 .13135 L
.78249 .14137 L
.78826 .1458 L
.79863 .15462 L
.80482 .16026 L
.81477 .16981 L
.81974 .17472 L
.83091 .18595 L
.8341 .18917 L
.84705 .20238 L
.84828 .20363 L
.86216 .21809 L
.8632 .21919 L
.87517 .23254 L
.87934 .23756 L
.88664 .247 L
.89548 .25974 L
.89658 .26146 L
.90541 .27592 L
.91162 .28656 L
.91383 .29037 L
.92241 .30483 L
.92776 .31328 L
.93188 .31929 L
.94323 .33374 L
.94391 .33451 L
.95878 .3482 L
.96005 .34914 L
.97619 .35829 L
Mfstroke
.97619 .86752 m
.97232 .86865 L
.96005 .87705 L
.95615 .88311 L
.95102 .89757 L
.94875 .91203 L
.94816 .92648 L
s
.02381 .86752 m
.02768 .86865 L
.03995 .87705 L
.04385 .88311 L
.04898 .89757 L
.05125 .91203 L
.05184 .92648 L
s
.97619 .13248 m
.97232 .13135 L
.96005 .12295 L
.95615 .11689 L
.95102 .10243 L
.94875 .08797 L
.94816 .07352 L
s
.02381 .13248 m
.02768 .13135 L
.03995 .12295 L
.04385 .11689 L
.04898 .10243 L
.05125 .08797 L
.05184 .07352 L
s
.02381 .62574 m
.03995 .62749 L
.05609 .63189 L
.06788 .63734 L
.07224 .63992 L
.08794 .6518 L
.08838 .65218 L
.10265 .66626 L
.10452 .66828 L
.11557 .68071 L
.12066 .68664 L
.12794 .69517 L
.1368 .70551 L
.14037 .70963 L
.15295 .72386 L
.15315 .72408 L
.16638 .73854 L
.16909 .74142 L
.1802 .753 L
.18523 .75808 L
.19481 .76746 L
.20137 .77359 L
.21074 .78191 L
.21751 .78754 L
.22911 .79637 L
.23366 .79952 L
.2498 .80929 L
.2527 .81083 L
.26594 .81689 L
.28208 .82251 L
.29256 .82528 L
.29822 .82647 L
.31437 .82903 L
.33051 .83043 L
.34665 .83086 L
.36279 .83049 L
.37893 .82949 L
.39508 .82805 L
.41122 .82635 L
.42094 .82528 L
.42736 .82459 L
.4435 .82294 L
.45964 .82157 L
.47579 .82058 L
.49193 .82007 L
.50807 .82007 L
.52421 .82058 L
.54036 .82157 L
.5565 .82294 L
.57264 .82459 L
Mistroke
.57906 .82528 L
.58878 .82635 L
.60492 .82805 L
.62107 .82949 L
.63721 .83049 L
.65335 .83086 L
.66949 .83043 L
.68563 .82903 L
.70178 .82647 L
.70744 .82528 L
.71792 .82251 L
.73406 .81689 L
.7473 .81083 L
.7502 .80929 L
.76634 .79952 L
.77089 .79637 L
.78249 .78754 L
.78926 .78191 L
.79863 .77359 L
.80519 .76746 L
.81477 .75808 L
.8198 .753 L
.83091 .74142 L
.83362 .73854 L
.84685 .72408 L
.84705 .72386 L
.85963 .70963 L
.8632 .70551 L
.87206 .69517 L
.87934 .68664 L
.88443 .68071 L
.89548 .66828 L
.89735 .66626 L
.91162 .65218 L
.91206 .6518 L
.92776 .63992 L
.93212 .63734 L
.94391 .63189 L
.96005 .62749 L
.97619 .62574 L
Mfstroke
.02381 .37426 m
.03995 .37251 L
.05609 .36811 L
.06788 .36266 L
.07224 .36008 L
.08794 .3482 L
.08838 .34782 L
.10265 .33374 L
.10452 .33172 L
.11557 .31929 L
.12066 .31336 L
.12794 .30483 L
.1368 .29449 L
.14037 .29037 L
.15295 .27614 L
.15315 .27592 L
.16638 .26146 L
.16909 .25858 L
.1802 .247 L
.18523 .24192 L
.19481 .23254 L
.20137 .22641 L
.21074 .21809 L
.21751 .21246 L
.22911 .20363 L
.23366 .20048 L
.2498 .19071 L
.2527 .18917 L
.26594 .18311 L
.28208 .17749 L
.29256 .17472 L
.29822 .17353 L
.31437 .17097 L
.33051 .16957 L
.34665 .16914 L
.36279 .16951 L
.37893 .17051 L
.39508 .17195 L
.41122 .17365 L
.42094 .17472 L
.42736 .17541 L
.4435 .17706 L
.45964 .17843 L
.47579 .17942 L
.49193 .17993 L
.50807 .17993 L
.52421 .17942 L
.54036 .17843 L
.5565 .17706 L
.57264 .17541 L
Mistroke
.57906 .17472 L
.58878 .17365 L
.60492 .17195 L
.62107 .17051 L
.63721 .16951 L
.65335 .16914 L
.66949 .16957 L
.68563 .17097 L
.70178 .17353 L
.70744 .17472 L
.71792 .17749 L
.73406 .18311 L
.7473 .18917 L
.7502 .19071 L
.76634 .20048 L
.77089 .20363 L
.78249 .21246 L
.78926 .21809 L
.79863 .22641 L
.80519 .23254 L
.81477 .24192 L
.8198 .247 L
.83091 .25858 L
.83362 .26146 L
.84685 .27592 L
.84705 .27614 L
.85963 .29037 L
.8632 .29449 L
.87206 .30483 L
.87934 .31336 L
.88443 .31929 L
.89548 .33172 L
.89735 .33374 L
.91162 .34782 L
.91206 .3482 L
.92776 .36008 L
.93212 .36266 L
.94391 .36811 L
.96005 .37251 L
.97619 .37426 L
Mfstroke
.97619 .87976 m
.97157 .88311 L
.96188 .89757 L
.96005 .90258 L
.95767 .91203 L
.9557 .92648 L
s
.02381 .87976 m
.02843 .88311 L
.03812 .89757 L
.03995 .90258 L
.04233 .91203 L
.0443 .92648 L
s
.97619 .12024 m
.97157 .11689 L
.96188 .10243 L
.96005 .09742 L
.95767 .08797 L
.9557 .07352 L
s
.02381 .12024 m
.02843 .11689 L
.03812 .10243 L
.03995 .09742 L
.04233 .08797 L
.0443 .07352 L
s
.02381 .60938 m
.02654 .60843 L
.03995 .60343 L
.05609 .59727 L
.06541 .59397 L
.07224 .59198 L
.08838 .58953 L
.10452 .59232 L
.10928 .59397 L
.12066 .60169 L
.12854 .60843 L
.1368 .61678 L
.14236 .62288 L
.15295 .6353 L
.15464 .63734 L
.16647 .6518 L
.16909 .655 L
.17836 .66626 L
.18523 .6744 L
.19067 .68071 L
.20137 .69265 L
.20372 .69517 L
.21751 .70924 L
.21791 .70963 L
.23366 .72389 L
.23388 .72408 L
.2498 .73643 L
.25281 .73854 L
.26594 .74683 L
.27745 .753 L
.28208 .75519 L
.29822 .76171 L
.31437 .7666 L
.31772 .76746 L
.33051 .7701 L
.34665 .77243 L
.36279 .77379 L
.37893 .77437 L
.39508 .77435 L
.41122 .77392 L
.42736 .77326 L
.4435 .77252 L
.45964 .77184 L
.47579 .77133 L
.49193 .77105 L
.50807 .77105 L
.52421 .77133 L
.54036 .77184 L
.5565 .77252 L
.57264 .77326 L
Mistroke
.58878 .77392 L
.60492 .77435 L
.62107 .77437 L
.63721 .77379 L
.65335 .77243 L
.66949 .7701 L
.68228 .76746 L
.68563 .7666 L
.70178 .76171 L
.71792 .75519 L
.72255 .753 L
.73406 .74683 L
.74719 .73854 L
.7502 .73643 L
.76612 .72408 L
.76634 .72389 L
.78209 .70963 L
.78249 .70924 L
.79628 .69517 L
.79863 .69265 L
.80933 .68071 L
.81477 .6744 L
.82164 .66626 L
.83091 .655 L
.83353 .6518 L
.84536 .63734 L
.84705 .6353 L
.85764 .62288 L
.8632 .61678 L
.87146 .60843 L
.87934 .60169 L
.89072 .59397 L
.89548 .59232 L
.91162 .58953 L
.92776 .59198 L
.93459 .59397 L
.94391 .59727 L
.96005 .60343 L
.97346 .60843 L
.97619 .60938 L
Mfstroke
.02381 .39062 m
.02654 .39157 L
.03995 .39657 L
.05609 .40273 L
.06541 .40603 L
.07224 .40802 L
.08838 .41047 L
.10452 .40768 L
.10928 .40603 L
.12066 .39831 L
.12854 .39157 L
.1368 .38322 L
.14236 .37712 L
.15295 .3647 L
.15464 .36266 L
.16647 .3482 L
.16909 .345 L
.17836 .33374 L
.18523 .3256 L
.19067 .31929 L
.20137 .30735 L
.20372 .30483 L
.21751 .29076 L
.21791 .29037 L
.23366 .27611 L
.23388 .27592 L
.2498 .26357 L
.25281 .26146 L
.26594 .25317 L
.27745 .247 L
.28208 .24481 L
.29822 .23829 L
.31437 .2334 L
.31772 .23254 L
.33051 .2299 L
.34665 .22757 L
.36279 .22621 L
.37893 .22563 L
.39508 .22565 L
.41122 .22608 L
.42736 .22674 L
.4435 .22748 L
.45964 .22816 L
.47579 .22867 L
.49193 .22895 L
.50807 .22895 L
.52421 .22867 L
.54036 .22816 L
.5565 .22748 L
.57264 .22674 L
Mistroke
.58878 .22608 L
.60492 .22565 L
.62107 .22563 L
.63721 .22621 L
.65335 .22757 L
.66949 .2299 L
.68228 .23254 L
.68563 .2334 L
.70178 .23829 L
.71792 .24481 L
.72255 .247 L
.73406 .25317 L
.74719 .26146 L
.7502 .26357 L
.76612 .27592 L
.76634 .27611 L
.78209 .29037 L
.78249 .29076 L
.79628 .30483 L
.79863 .30735 L
.80933 .31929 L
.81477 .3256 L
.82164 .33374 L
.83091 .345 L
.83353 .3482 L
.84536 .36266 L
.84705 .3647 L
.85764 .37712 L
.8632 .38322 L
.87146 .39157 L
.87934 .39831 L
.89072 .40603 L
.89548 .40768 L
.91162 .41047 L
.92776 .40802 L
.93459 .40603 L
.94391 .40273 L
.96005 .39657 L
.97346 .39157 L
.97619 .39062 L
Mfstroke
.97619 .8917 m
.9713 .89757 L
.96478 .91203 L
.96165 .92648 L
s
.02381 .8917 m
.0287 .89757 L
.03522 .91203 L
.03835 .92648 L
s
.97619 .1083 m
.9713 .10243 L
.96478 .08797 L
.96165 .07352 L
s
.02381 .1083 m
.0287 .10243 L
.03522 .08797 L
.03835 .07352 L
s
.37893 .28925 m
.39508 .28755 L
.41122 .28651 L
.42736 .28595 L
.4435 .2857 L
.45964 .28564 L
.47579 .28566 L
.49193 .28569 L
.50807 .28569 L
.52421 .28566 L
.54036 .28564 L
.5565 .28571 L
.57264 .28595 L
.58878 .28651 L
.60492 .28755 L
.62107 .28925 L
.62903 .29037 L
.63721 .29181 L
.65335 .29545 L
.66949 .30042 L
.68082 .30483 L
.68563 .30698 L
.70178 .31544 L
.70803 .31929 L
.71792 .32612 L
.72759 .33374 L
.73406 .33941 L
.74313 .3482 L
.7502 .35578 L
.75611 .36266 L
.76634 .37585 L
.76725 .37712 L
.77696 .39157 L
.78249 .40076 L
.78543 .40603 L
.79281 .42049 L
.79863 .43373 L
.79911 .43494 L
.80431 .4494 L
.80835 .46386 L
.81113 .47831 L
.81255 .49277 L
.81255 .50723 L
.81113 .52169 L
.80835 .53614 L
.80431 .5506 L
.79911 .56506 L
.79863 .56627 L
.79281 .57951 L
.78543 .59397 L
Mistroke
.78249 .59924 L
.77696 .60843 L
.76725 .62288 L
.76634 .62415 L
.75611 .63734 L
.7502 .64422 L
.74313 .6518 L
.73406 .66059 L
.72759 .66626 L
.71792 .67388 L
.70803 .68071 L
.70178 .68456 L
.68563 .69302 L
.68082 .69517 L
.66949 .69958 L
.65335 .70455 L
.63721 .70819 L
.62903 .70963 L
.62107 .71075 L
.60492 .71245 L
.58878 .71349 L
.57264 .71405 L
.5565 .71429 L
.54036 .71436 L
.52421 .71434 L
.50807 .71431 L
.49193 .71431 L
.47579 .71434 L
.45964 .71436 L
.4435 .7143 L
.42736 .71405 L
.41122 .71349 L
.39508 .71245 L
.37893 .71075 L
.37097 .70963 L
.36279 .70819 L
.34665 .70455 L
.33051 .69958 L
.31918 .69517 L
.31437 .69302 L
.29822 .68456 L
.29197 .68071 L
.28208 .67388 L
.27241 .66626 L
.26594 .66059 L
.25687 .6518 L
.2498 .64422 L
.24389 .63734 L
.23366 .62415 L
.23275 .62288 L
Mistroke
.22304 .60843 L
.21751 .59924 L
.21457 .59397 L
.20719 .57951 L
.20137 .56627 L
.20089 .56506 L
.19569 .5506 L
.19165 .53614 L
.18887 .52169 L
.18745 .50723 L
.18745 .49277 L
.18887 .47831 L
.19165 .46386 L
.19569 .4494 L
.20089 .43494 L
.20137 .43373 L
.20719 .42049 L
.21457 .40603 L
.21751 .40076 L
.22304 .39157 L
.23275 .37712 L
.23366 .37585 L
.24389 .36266 L
.2498 .35578 L
.25687 .3482 L
.26594 .33941 L
.27241 .33374 L
.28208 .32612 L
.29197 .31929 L
.29822 .31544 L
.31437 .30698 L
.31918 .30483 L
.33051 .30042 L
.34665 .29545 L
.36279 .29181 L
.37097 .29037 L
.37893 .28925 L
Mfstroke
.02381 .59192 m
.03767 .57951 L
.03995 .57618 L
.04803 .56506 L
.05609 .55269 L
.05693 .5506 L
.06274 .53614 L
.06711 .52169 L
.06936 .50723 L
.06936 .49277 L
.06711 .47831 L
.06274 .46386 L
.05693 .4494 L
.05609 .44731 L
.04803 .43494 L
.03995 .42382 L
.03767 .42049 L
.02381 .40808 L
s
.97619 .59192 m
.96233 .57951 L
.96005 .57618 L
.95197 .56506 L
.94391 .55269 L
.94307 .5506 L
.93726 .53614 L
.93289 .52169 L
.93064 .50723 L
.93064 .49277 L
.93289 .47831 L
.93726 .46386 L
.94307 .4494 L
.94391 .44731 L
.95197 .43494 L
.96005 .42382 L
.96233 .42049 L
.97619 .40808 L
s
.97619 .90369 m
.97138 .91203 L
.96678 .92648 L
s
.02381 .90369 m
.02862 .91203 L
.03322 .92648 L
s
.97619 .09631 m
.97138 .08797 L
.96678 .07352 L
s
.02381 .09631 m
.02862 .08797 L
.03322 .07352 L
s
.4435 .36194 m
.45964 .36072 L
.47579 .35998 L
.49193 .35964 L
.50807 .35964 L
.52421 .35998 L
.54036 .36072 L
.5565 .36194 L
.56376 .36266 L
.57264 .36377 L
.58878 .36641 L
.60492 .37011 L
.62107 .37517 L
.62617 .37712 L
.63721 .38202 L
.65335 .39125 L
.65384 .39157 L
.66949 .40376 L
.67193 .40603 L
.68499 .42049 L
.68563 .42131 L
.69474 .43494 L
.70178 .44895 L
.70197 .4494 L
.70714 .46386 L
.71047 .47831 L
.71211 .49277 L
.71211 .50723 L
.71047 .52169 L
.70714 .53614 L
.70197 .5506 L
.70178 .55105 L
.69474 .56506 L
.68563 .57869 L
.68499 .57951 L
.67193 .59397 L
.66949 .59624 L
.65384 .60843 L
.65335 .60875 L
.63721 .61798 L
.62617 .62288 L
.62107 .62483 L
.60492 .62989 L
.58878 .63359 L
.57264 .63623 L
.56376 .63734 L
.5565 .63806 L
.54036 .63928 L
.52421 .64002 L
.50807 .64036 L
Mistroke
.49193 .64036 L
.47579 .64002 L
.45964 .63928 L
.4435 .63806 L
.43624 .63734 L
.42736 .63623 L
.41122 .63359 L
.39508 .62989 L
.37893 .62483 L
.37383 .62288 L
.36279 .61798 L
.34665 .60875 L
.34616 .60843 L
.33051 .59624 L
.32807 .59397 L
.31501 .57951 L
.31437 .57869 L
.30526 .56506 L
.29822 .55105 L
.29803 .5506 L
.29286 .53614 L
.28953 .52169 L
.28789 .50723 L
.28789 .49277 L
.28953 .47831 L
.29286 .46386 L
.29803 .4494 L
.29822 .44895 L
.30526 .43494 L
.31437 .42131 L
.31501 .42049 L
.32807 .40603 L
.33051 .40376 L
.34616 .39157 L
.34665 .39125 L
.36279 .38202 L
.37383 .37712 L
.37893 .37517 L
.39508 .37011 L
.41122 .36641 L
.42736 .36377 L
.43624 .36266 L
.4435 .36194 L
Mfstroke
.02381 .57213 m
.02992 .56506 L
.03603 .5506 L
.03995 .53743 L
.04027 .53614 L
.04322 .52169 L
.04472 .50723 L
.04472 .49277 L
.04322 .47831 L
.04027 .46386 L
.03995 .46257 L
.03603 .4494 L
.02992 .43494 L
.02381 .42787 L
s
.97619 .57213 m
.97008 .56506 L
.96397 .5506 L
.96005 .53743 L
.95973 .53614 L
.95678 .52169 L
.95528 .50723 L
.95528 .49277 L
.95678 .47831 L
.95973 .46386 L
.96005 .46257 L
.96397 .4494 L
.97008 .43494 L
.97619 .42787 L
s
.97619 .91618 m
.97185 .92648 L
s
.02381 .91618 m
.02815 .92648 L
s
.97619 .08382 m
.97185 .07352 L
s
.02381 .08382 m
.02815 .07352 L
s
.02381 .54672 m
.02809 .53614 L
.0311 .52169 L
.0324 .50723 L
.0324 .49277 L
.0311 .47831 L
.02809 .46386 L
.02381 .45328 L
s
.97619 .54672 m
.97191 .53614 L
.9689 .52169 L
.9676 .50723 L
.9676 .49277 L
.9689 .47831 L
.97191 .46386 L
.97619 .45328 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML008oG00<0emL0S]L008oG00<0emL0
S]L007_G0P04e`030=OG00?G0P06e`030=OG08kG001je`040=OG00SG00@0emL01ML00`3Ge`2>e`00
N]L0103Ge`08e`040=OG00GG0`2>e`00M=L400;G00@0emL02=L300KG00<0emL0S]L007[G00@0emL0
2=L00`3Ge`06e`030=OG08kG001:ea008=L0103Ge`08e`030=OG00KG00<0emL0<mL@04_G0013e`L0
4=L401gG0P0:e`<01ML00`3Ge`0_e`@04=L704CG0010e`<06mL402gG00<0emL0:mL401_G0`11e`00
?ML302;G0`0Ze`030=OG02SG0`0Re`<0?]L003_G0P0Xe`@09]L00`3Ge`0Te`@0:=L203cG000ie`80
;]L402;G00<0emL08=L402kG0P0je`00>=L00`3Ge`0be`<07mL00`3Ge`0Me`<0==L00`3Ge`0ge`00
=]L203SG0`0Le`030=OG01[G0`0he`80=mL003CG0P0me`806]L00`3Ge`0He`80?ML203GG000ce`03
0=OG03oG0`0Ge`805]L3047G00<0emL0<]L003;G00<0emL0@mL301CG00<0emL04]L304GG00<0emL0
<ML0037G00<0emL0AmL4013G00<0emL03]L404WG00<0emL0<=L0033G00<0emL0C=L400cG00<0emL0
2]L404kG00<0emL0;mL002kG0P1Ce`L01ML00`3Ge`03e`L0DmL202oG0008e`8000SG0=L0e`3G00?G
00<0emL05=L200kG00<0emL0<ML301OG2`0Ge`<0<mL00`3Ge`0<e`805]L0303GemL0e`3G0=L0e`80
2ML000SG0P002=L0e`3G0=L00mL00`3Ge`0Ce`803]L00`3Ge`0ee`806]L00`3Ge`0He`80=mL00`3G
e`0<e`805=L00`3Ge`02e`080=L0e`3G0=L200WG0007e`8000CG0=L00]L00`3G0004e`030=OG017G
0P0>e`030=OG03SG0`0Ge`030=OG01GG0`0je`030=OG00cG0P0Ce`050=OGe`000]L02@3G0=L0e`3G
0008e`001mL20004e`3G00;G00@0emL00mL00`3Ge`0@e`803]L00`3Ge`0le`D04]L00`3Ge`0@e`D0
?]L00`3Ge`0<e`804ML00`3Ge`02e`040=OG00;G00@0e`3G0P08e`002=L01@3G0=L000;G00@0emL0
1=L00`3Ge`0>e`803]L00`3Ge`12e`D03ML00`3Ge`0;e`D0A=L00`3Ge`0<e`804=L00`3Ge`02e`04
0=OG00;G00D0e`3G0009e`001mL00`3G0002e`040=OG00;G00<0emL00mL00`3Ge`0<e`803]L00`3G
e`18e`T01=L00`3Ge`02e`T0B]L00`3Ge`0<e`803]L00`3Ge`03e`040=OG00;G00D0e`3G0009e`00
1mL01@3G0=L000;G00D0emOG0005e`030=OG00_G0P0>e`030=OG05;G2@1De`030=OG00cG0P0=e`03
0=OG00?G00@0emL00mL01@3G0=L000SG0008e`040=OG00;G00D0emOG0006e`030=OG00WG00<0e`00
3ML00`3Ge`1Ge`030=OG05OG00<0emL02mL00`3G000;e`030=OG00CG00D0emOG0002e`030=L000[G
0008e`040=OG00;G00D0emOG0007e`030=OG00OG00<0e`003ML00`3Ge`1He`030=OG05SG00<0emL0
2mL00`3G0009e`030=OG00GG00D0emOG0002e`040=OG00WG0007e`040=OG00;G00<0emL00]L00`3G
e`06e`801=L30003e`3G00cG00<0emL0FML00`3Ge`1Ie`030=OG00_G00<0e`000P04e`802=L01@3G
emL000?G00<0e`002ML000OG00<0e`000mL00`3Ge`02e`030=OG00SG1003e`030=OG00_G00<0emL0
F]L00`3Ge`1Ie`030=OG00cG00@0emOG100:e`030=OG00;G00@0emL00]L00`3Ge`06e`002ML0103G
e`05e`030=OG00kG00<0emL03=L00`3Ge`0Oe`d0;]L00`3Ge`0/e`d08ML00`3Ge`0<e`030=OG00kG
00<0emL00]L01@3GemL000[G0008e`050=OGe`001ML00`3Ge`0=e`030=OG00cG00<0emL06]L600gG
2@0Ue`030=OG02?G2@0=e`H07=L00`3Ge`0<e`030=OG00gG00<0emL00mL01@3GemL000WG0007e`05
0=OGe`001]L00`3Ge`0=e`030=OG00_G00<0emL05mL401cG1@0Pe`030=OG01kG1@0Le`@06ML00`3G
e`0;e`030=OG00gG00<0emL00mL00`3Ge`02e`030=OG00KG000;e`030=OG00CG00<0emL03=L00`3G
e`0;e`030=OG01GG0`0Ue`D06mL00`3Ge`0Ie`D09ML301OG00<0emL02mL00`3Ge`0<e`030=OG00CG
00<0emL02]L000[G00<0emL01=L00`3Ge`0=e`030=OG00[G00<0emL05=L202gG100Ge`030=OG01GG
100]e`805ML00`3Ge`0;e`030=OG00gG00<0emL01=L00`3Ge`09e`002ML00`3Ge`05e`030=OG00cG
00<0emL02mL00`3Ge`0Be`80<mL800oG00<0emL03ML803?G0P0De`030=OG00_G00<0emL03=L00`3G
e`05e`030=OG00SG0007e`802=L00`3Ge`0;e`030=OG00_G00<0emL04]L203cG2`04e`030=OG00;G
2`0le`805=L00`3Ge`0;e`030=OG00_G00<0emL01]L200SG000@e`030=OG00cG00<0emL02]L00`3G
e`0Ae`80BML904WG0P0Ce`030=OG00[G00<0emL02mL00`3Ge`0@e`004=L00`3Ge`0;e`030=OG00[G
00<0emL04=L204oG00<0emL0CML201;G00<0emL02]L00`3Ge`0;e`030=OG00oG000?e`030=OG00cG
00<0emL02ML00`3Ge`0@e`030=OG04oG00<0emL0C]L00`3Ge`0Ae`030=OG00WG00<0emL03=L00`3G
e`0>e`001mL800kG00<0emL02ML00`3Ge`0Ae`030=OG04oG00<0emL0CmL00`3Ge`0Ae`030=OG00WG
00<0emL03=L800SG000Le`030=OG00SG0P0Be`80D]L00`3Ge`1@e`804]L200WG00<0emL07=L001cG
00<0emL01mL00`3Ge`0Ae`030=OG05;G00<0emL0D]L00`3Ge`0Ae`030=OG00OG00<0emL06mL001_G
00<0emL01mL00`3Ge`0Ae`030=OG05?G00<0emL0DmL00`3Ge`0Ae`030=OG00KG00<0emL06mL000OG
00<0emL04ML00`3Ge`06e`030=OG017G00<0emL0E=L00`3Ge`1De`030=OG017G00<0emL01]L00`3G
e`0Ae`030=OG00KG0008e`030=OG00oG00<0emL01ML201?G00<0emL0EML00`3Ge`1Ee`030=OG017G
0P06e`030=OG013G00<0emL01mL000WG00<0emL03]L00`3Ge`04e`030=OG01;G00<0emL09=L=017G
0P04e`030=OG00CG00<0emL01=L00`3Ge`0Se`d09]L00`3Ge`0Be`030=OG00CG00<0emL03]L00`3G
e`08e`002]L00`3Ge`0<e`030=OG00?G0P0De`030=OG023G1@0=e`X01]L0103Ge`0:e`030=OG00CG
00<0emL06ML:00gG1@0Re`030=OG01;G0P04e`030=OG00gG00<0emL02ML000OG00D0emOG000=e`03
0=OG00;G00<0emL04mL00`3Ge`0Le`D07=L:00OG1@05e`<04=L901cG1@0Ne`030=OG01?G00<0emL0
0]L00`3Ge`0;e`050=OGe`002=L000OG00D0emOG000<e`030=OG00;G00<0emL04mL00`3Ge`0Ie`@0
8ML400;G00<0emL09@0Ze`@06mL00`3Ge`0Ce`050=OGe`003=L01@3GemL000WG0008e`050=OGe`00
2mL01@3GemL001CG0P0Ie`<0:mL0103Ge`08e`030=L000KG00<0emL0?]L301WG0P0De`050=OGe`00
2mL01@3GemL000WG0008e`050=OGe`002]L01@3GemL001CG00<0emL05mL202kG00@0emL02ML200KG
00<0emL0@ML201WG00<0emL04]L0103Ge`0:e`050=OGe`002]L000WG00D0emOG0009e`040=OG01CG
00<0emL05ML3037G0P0;e`030=OG00CG00<0emL0@mL301OG00<0emL04]L0103Ge`09e`050=OGe`00
2]L000WG00D0emOG0009e`030=L001CG00<0emL05ML00`3Ge`16e`030=OG04KG00<0emL05ML00`3G
e`0Ae`040=OG00WG00D0emOG000:e`001mL00`3G0003e`030=OG00KG00@0emL04mL00`3Ge`0De`80
BML00`3Ge`17e`805ML00`3Ge`0Be`040=OG00OG00D0emOG0002e`030=OG00KG0007e`040=OG00?G
00<0emL01ML00`3G000De`030=OG01?G00<0emL0BML00`3Ge`19e`030=OG01?G00<0emL04ML0103G
e`07e`050=OGe`000]L00`3Ge`06e`001mL0103Ge`03e`030=OG00CG00@0emL04]L201CG0P1<e`03
0=OG04[G0P0De`804]L0103Ge`06e`050=OGe`000]L00`3Ge`06e`001mL0103Ge`03e`030=OG00CG
00@0emL04ML00`3Ge`0Ce`030=OG04cG00<0emL0C=L00`3Ge`0Ce`030=OG00oG00@0emL01]L01@3G
emL000;G00<0emL01]L000OG00@0emL00mL00`3Ge`04e`030=L0017G00<0emL04mL00`3Ge`1=e`03
0=OG04gG00<0emL04mL00`3Ge`0>e`040=OG00GG00D0emOG0002e`030=OG00OG0008e`040=OG00?G
00<0emL00]L0103Ge`0@e`030=OG01?G00<0emL0C]L00`3Ge`1>e`030=OG01?G00<0emL03]L0103G
e`04e`050=OGe`000]L00`3Ge`07e`002=L0103Ge`03e`030=OG00;G00@0emL03mL00`3Ge`0Be`80
DML2053G0P0De`030=OG00gG00@0emL01=L01@3GemL000;G00<0emL01mL000SG00@0emL00mL00`3G
e`02e`040=OG00oG00<0emL04ML00`3Ge`1Ae`030=OG057G00<0emL04ML00`3Ge`0=e`040=OG00CG
00D0emOG0002e`030=OG00OG0008e`040=OG00?G00D0emOG0002e`030=OG00gG00<0emL04]L00`3G
e`0]e`T06mL00`3Ge`0Ie`T0;mL00`3Ge`0Be`030=OG00cG00D0emOG0003e`070=OGe`3G000:e`00
2ML00`3G0003e`050=OGe`000]L00`3Ge`0<e`030=OG01;G00<0emL09ML900WG=`09e`X09]L00`3G
e`0Be`030=OG00cG00@0emL00mL01`3GemL0e`002]L000WG00<0e`000mL0103Ge`03e`030=OG00_G
00<0emL04ML2027G1`0]e`030=OG02cG1P0Qe`804mL00`3Ge`0;e`050=OGe`000]L01`3GemL0e`00
2]L000WG00<0e`000mL0103Ge`03e`030=OG00[G00<0emL04ML00`3Ge`0Ne`<0==L00`3Ge`0be`<0
8=L00`3Ge`0Ae`030=OG00[G00D0emOG0002e`070=OGe`3G000:e`002ML00`3G0003e`040=OG00?G
00<0emL02ML00`3Ge`0Ae`030=OG01cG0`0ge`030=OG03GG0`0Ne`030=OG017G00<0emL02ML01@3G
emL000;G00L0emOG0=L000[G0009e`030=L000?G00<0e`000mL00`3Ge`09e`030=OG017G00<0emL0
6mL203[G00<0emL0>=L201gG00<0emL04ML00`3Ge`09e`070=OGe`3G0003e`030=L000[G0009e`03
0=L000?G00<0e`000mL00`3Ge`09e`030=OG013G00<0emL06]L203cG00<0emL0>]L201cG00<0emL0
4=L00`3Ge`09e`070=OGe`3G0003e`030=L000[G0009e`030=L000?G00<0e`000mL00`3Ge`08e`03
0=OG013G00<0emL06=L303kG00<0emL0?=L301[G00<0emL04=L00`3Ge`08e`070=OGe`3G0003e`03
0=L000[G0009e`030=L000?G00<0e`000]L00`3Ge`08e`030=OG013G00<0emL05mL2047G00<0emL0
?mL201WG00<0emL04=L00`3Ge`07e`070=OGe`3G0003e`030=L000[G0008e`040=OG00;G00<0e`00
0mL00`3Ge`08e`030=OG00oG00<0emL05mL00`3Ge`11e`80@]L00`3Ge`0Ge`030=OG00oG00<0emL0
2=L0103GemL200?G00<0e`002]L000SG00@0emL00]L00`3G0002e`030=OG00SG00<0emL03mL00`3G
e`0Fe`80A=L00`3Ge`12e`806=L00`3Ge`0?e`030=OG00OG00L0emOG0=L000;G00@0emL02ML000SG
00@0emL00]L00`3G0002e`030=OG00SG00<0emL03mL00`3Ge`0De`80A]L00`3Ge`14e`805]L00`3G
e`0?e`030=OG00SG00H0emL0e`02e`040=OG00WG0008e`040=OG00;G0P03e`030=OG00OG00<0emL0
3mL00`3Ge`0De`030=OG04KG00<0emL0A]L00`3Ge`0De`030=OG00oG00<0emL01mL0103GemL200;G
00@0emL02ML000OG00@0emL00]L00`3G0002e`030=OG00OG00<0emL03mL00`3Ge`0De`030=OG04OG
00<0emL0AmL00`3Ge`0De`030=OG00kG00<0emL01mL0103GemL200;G00@0emL02ML000OG00@0emL0
0]L00`3G0002e`030=OG00OG00<0emL03]L00`3Ge`0De`030=OG04SG00<0emL0B=L00`3Ge`0De`03
0=OG00kG00<0emL01mL01P3Ge`3G00;G00@0emL02=L000OG00@0emL00]L00`3G0002e`030=OG00KG
00<0emL03]L00`3Ge`0De`030=OG04WG00<0emL0BML00`3Ge`0De`030=OG00kG00<0emL01]L01P3G
e`3G00;G00@0emL02=L000OG00@0emL00]L200?G00<0emL01ML00`3Ge`0>e`030=OG01CG00<0emL0
B]L00`3Ge`1:e`030=OG01CG00<0emL03]L00`3Ge`05e`040=OGe`800]L0103Ge`08e`001mL00`3G
0002e`030=L000;G00<0emL01]L00`3Ge`0=e`030=OG01?G0P1=e`030=OG04_G0P0Ee`030=OG00gG
00<0emL01ML0103GemL200;G00@0emL02=L000WG00H0emL0e`02e`030=OG00GG00<0emL03ML00`3G
e`0Ce`030=OG02gG@@0_e`030=OG01?G00<0emL03ML00`3Ge`05e`060=OG0=L00]L00`3Ge`08e`00
2ML01P3Ge`3G00;G00<0emL01ML00`3Ge`0<e`030=OG01?G00<0emL09ML9023G00<0emL07]L902OG
00<0emL04mL00`3Ge`0<e`030=OG00GG00H0emL0e`02e`030=OG00SG0008e`060=OG0=L00]L00`3G
e`05e`030=OG00cG00<0emL04mL00`3Ge`0Se`<0:ML00`3Ge`0We`@09=L00`3Ge`0Ce`030=OG00cG
00<0emL01=L02@3GemL0e`3G000:e`002=L01P3Ge`3G00;G00<0emL01=L00`3Ge`0<e`030=OG01?G
00<0emL08]L202cG0P0/e`808mL00`3Ge`0Ce`030=OG00_G00<0emL01ML01P3Ge`3G00;G00<0emL0
1mL000OG00@0emL00]L00`3G0007e`030=OG00cG00<0emL04]L00`3Ge`0Pe`<0;]L00`3Ge`0]e`<0
8ML00`3Ge`0Be`030=OG00cG00<0emL01=L0103Ge`02e`030=L000WG0007e`040=OG00;G00<0e`00
1]L00`3Ge`0<e`030=OG01;G00<0emL07]L3037G00<0emL0<=L2023G00<0emL04]L00`3Ge`0<e`03
0=OG00CG00<0e`000]L0103Ge`08e`002ML0103GemL200OG00<0emL02mL00`3Ge`0Ce`030=OG01cG
0P0de`030=OG03;G0P0Ne`030=OG01?G00<0emL02mL00`3Ge`05e`800]L00`3Ge`09e`002ML00`3G
e`0200OG00<0emL02mL00`3Ge`0Ce`030=OG01_G0P0fe`030=OG03CG0P0Me`030=OG01?G00<0emL0
2mL00`3Ge`04e`030=L000;G00<0emL02=L000SG00@0emOG0P07e`030=OG00[G00<0emL04]L201cG
0P0he`030=OG03KG0P0Le`805=L00`3Ge`0:e`030=OG00GG0P02e`030=OG00SG0008e`050=OGe`00
1]L200cG00<0emL04]L00`3Ge`0Je`80>]L00`3Ge`0he`807=L00`3Ge`0Be`030=OG00[G0P06e`05
0=OGe`002ML000OG00@0emOG0P05e`030=OG00_G00<0emL04]L00`3Ge`0Je`030=OG03[G00<0emL0
>]L00`3Ge`0Ie`030=OG01?G00<0emL02mL00`3Ge`03e`050=OGe`002ML000OG00@0emOG0P04e`03
0=OG00_G00<0emL04mL00`3Ge`0Ie`030=OG03_G00<0emL0>mL00`3Ge`0Ie`030=OG01;G00<0emL0
2mL00`3Ge`03e`800mL00`3Ge`06e`002]L200GG00<0emL02mL00`3Ge`0Be`030=OG01SG0P0ne`03
0=OG03cG0P0Je`030=OG01;G00<0emL02mL00`3Ge`03e`802mL000WG00<0e`001=L00`3Ge`0:e`80
5=L00`3Ge`0He`030=OG02[G0P04e`030=OG00;G1005e`030=OG03kG00<0emL06=L00`3Ge`0Be`80
3=L00`3Ge`02e`030=L000[G0008e`040=OG00CG00<0emL02ML00`3Ge`0Ce`030=OG01SG00<0emL0
:]L0103Ge`08e`030=OG00KG00<0emL0?mL00`3Ge`0He`030=OG01?G00<0emL02ML00`3Ge`02e`04
0=OG00WG0008e`040=OG00?G00<0emL02ML00`3Ge`0Ce`030=OG01SG00<0emL0:mL0103Ge`09e`03
0=OG00GG0`10e`030=OG01OG00<0emL05=L00`3Ge`09e`050=OGe`000]L00`3Ge`07e`001mL01@3G
emL000;G00<0emL02ML00`3Ge`0De`030=OG01OG00<0emL09]L400;G00@0emL02]L00`3Ge`04e`03
0=OG047G00<0emL05mL00`3Ge`0De`030=OG00WG00@0emL00mL00`3Ge`06e`002mL00`3G000;e`03
0=OG01CG00<0emL05mL00`3Ge`0]e`040=OG00_G00<0emL00mL00`3Ge`12e`030=OG01OG00<0emL0
5=L00`3Ge`09e`030=L000cG000:e`<03=L00`3Ge`0De`030=OG01KG00<0emL0;]L0103Ge`08e`04
0=OG00GG00<0emL0@mL00`3Ge`0Fe`030=OG01CG00<0emL02]L300_G0009e`803ML00`3Ge`0De`03
0=OG01KG00<0emL0<=L200[G0P06e`030=OG04CG00<0emL05]L00`3Ge`0De`030=OG00_G0P0:e`00
1mL20003e`3G00[G0P0Fe`030=OG01KG00<0emL0AML00`3Ge`15e`030=OG01KG00<0emL05=L200_G
00@0e`002=L000[G00<0emL02=L00`3Ge`0Ee`030=OG01KG00<0emL0=]LQ03OG00<0emL05mL00`3G
e`0Ee`030=OG00SG00<0emL02ML000[G00<0emL01ML301OG00<0emL05mL00`3Ge`0`e`H04=L00`3G
e`0>e`H0<]L00`3Ge`0Ge`030=OG01GG0`07e`030=OG00WG000:e`030=OG00;G0`0Ie`030=OG01OG
00<0emL0;=L501KG00<0emL05=L502kG00<0emL05mL00`3Ge`0Ge`<01=L00`3Ge`09e`002]L00`3G
e`0201_G00<0emL05mL00`3Ge`0Xe`D06mL00`3Ge`0Ie`D0:]L00`3Ge`0Fe`030=OG01[G0P02e`03
0=OG00WG0007e`H07ML00`3Ge`0Fe`030=OG02KG0`0Pe`030=OG01kG0`0Xe`030=OG01KG00<0emL0
6mL600SG0009e`030=OG01gG00<0emL05mL00`3Ge`0Te`808mL202;G0P0Ve`030=OG01OG00<0emL0
7ML00`3Ge`08e`002ML00`3Ge`0Le`030=OG01OG00<0emL08mL202GG00<0emL08mL202GG00<0emL0
5mL00`3Ge`0Le`030=OG00SG0009e`030=OG01_G00<0emL05mL00`3Ge`0Re`809mL00`3Ge`0Ue`80
8mL00`3Ge`0He`030=OG01_G00<0emL02=L000WG00<0emL06]L00`3Ge`0He`030=OG023G0P0Ye`03
0=OG02OG0P0Re`030=OG01SG00<0emL06]L00`3Ge`08e`001mL301_G00<0emL06=L00`3Ge`0Pe`03
0=OG02WG00<0emL0:ML00`3Ge`0Pe`030=OG01SG00<0emL06ML300SG0009e`@05]L201[G00<0emL0
8=L00`3Ge`0Ze`030=OG02[G0P0Qe`030=OG01SG0P0Fe`@02]L000WG00@0emOG0P0Ce`030=OG01[G
00<0emL07]L202gG00<0emL0;=L201oG00<0emL06]L00`3Ge`0Ae`800mL00`3Ge`08e`002=L00`3G
e`04e`<03]L201cG00<0emL07]L00`3Ge`0]e`030=OG02kG00<0emL07ML00`3Ge`0Je`803]L300GG
00<0emL02=L000SG00<0emL01mL200_G00<0emL06mL00`3Ge`0Ne`030=OG02kG00<0emL0;]L00`3G
e`0Ne`030=OG01_G00<0emL02ML200WG00<0emL01mL000OG0P0;e`/07ML00`3Ge`0Ne`030=OG02oG
00<0emL0;mL00`3Ge`0Me`030=OG01cG2`0;e`802=L000SG00<0emL0<ML00`3Ge`0Me`030=OG033G
00<0emL0<=L00`3Ge`0Me`030=OG037G00<0emL01mL000SG0`0`e`030=OG01gG00<0emL0<ML00`3G
e`0ae`030=OG01cG00<0emL0;mL300WG0008e`040=OG02oG00<0emL07=L00`3Ge`0be`80<mL00`3G
e`0Le`030=OG02gG00@0emL02ML000SG00@0emL0;mL00`3Ge`0Ke`030=OG03?G00<0emL0<mL00`3G
e`0Ke`030=OG02gG00@0emL02ML000OG0P03e`030=OG02_G00<0emL06mL00`3Ge`0de`030=OG03?G
00<0emL06mL00`3Ge`0/e`040=OGe`802=L000OG00<0emL00mL00`3Ge`0Ze`030=OG01_G00<0emL0
==L00`3Ge`0de`030=OG01_G00<0emL0:]L00`3Ge`02e`030=OG00OG0007e`801ML00`3Ge`0Xe`80
7=L00`3Ge`0ee`030=OG03GG00<0emL06]L202[G00<0emL00mL200SG0007e`801ML00`3Ge`0Xe`03
0=OG01[G00<0emL0=]L00`3Ge`0ee`030=OG01_G00<0emL09mL00`3Ge`04e`802=L000OG00<0e`00
1ML00`3Ge`0We`030=OG01[G00<0emL0=]L00`3Ge`0fe`030=OG01[G00<0emL09mL00`3Ge`03e`03
0=L000SG0007e`030=L000GG00<0emL09]L00`3Ge`0Je`030=OG03OG00<0emL0=]L00`3Ge`0Ke`03
0=OG02GG00<0emL01=L00`3G0008e`001mL0103Ge`05e`030=OG02GG00<0emL06]L00`3Ge`0ge`03
0=OG03OG00<0emL06]L00`3Ge`0Ue`030=OG00?G00@0emL02=L000OG00@0emL01ML00`3Ge`0Ue`03
0=OG01[G00<0emL0=mL00`3Ge`0ge`030=OG01[G00<0emL09ML00`3Ge`03e`040=OG00SG0007e`04
0=OG00GG00<0emL09ML00`3Ge`0Je`030=OG03OG00<0emL0=mL00`3Ge`0Je`030=OG02CG00<0emL0
1=L0103Ge`08e`001mL01@3GemL000GG00<0emL08mL00`3Ge`0Je`030=OG03SG0P0he`030=OG01[G
00<0emL09=L00`3Ge`03e`050=OGe`002=L000OG0P02e`030=OG00?G00<0emL05=L400_G00<0emL0
6]L00`3Ge`0200CG00<0emL00]L302[G00<0emL0:]L200CG00<0emL00]L401cG00<0emL02mL401?G
00<0emL01=L00`3Ge`0200SG0007e`800]L00`3Ge`04e`030=OG01GG00<0emL02]L00`3Ge`0Je`03
0=L000;G00<0emL02ML00`3Ge`0We`030=OG02WG00@0emL02mL00`3Ge`0Je`030=OG00gG00<0emL0
4]L00`3Ge`04e`030=OG00802=L000OG0P02e`030=OG00CG00<0emL05ML00`3Ge`0:e`030=OG01[G
00<0e`000]L00`3Ge`09e`030=OG02OG00<0emL0:ML0103Ge`0;e`030=OG01[G00<0emL03ML00`3G
e`0Be`030=OG00CG00<0emL00P08e`001mL200;G00<0emL01=L00`3Ge`0=e`@01=L00`3Ge`09e`03
0=OG01OG1002e`040=OG00SG0`0Ze`030=OG02WG00@0emL02=L401cG00<0emL03ML00`3Ge`0Ae`03
0=OG00CG00H0emL0e`08e`001mL00`3G0002e`030=OG00CG00<0emL05=L00`3Ge`09e`030=OG01[G
00@0emL00]L00`3Ge`06e`030=OG02[G00<0emL0:ML0103Ge`08e`050=OGe`007=L00`3Ge`0<e`03
0=OG017G00<0emL01=L01P3Ge`3G00SG0007e`030=L000;G00<0emL01=L00`3Ge`0Be`<02mL00`3G
e`0Je`040=OG00;G00<0emL01]L00`3Ge`0Ze`030=OG02WG00@0emL02=L01@3GemL001cG00<0emL0
2]L301?G00<0emL01=L01P3Ge`3G00SG0007e`030=L000;G00<0emL01=L00`3Ge`0De`030=OG00WG
00<0emL06]L0103GemL200WG100Ye`030=OG02[G0P09e`D07=L00`3Ge`0<e`030=OG017G00<0emL0
1=L01P3Ge`3G00SG0007e`030=L000;G00<0emL01=L00`3Ge`0Pe`030=OG01WG00<0emL0>]L00`3G
e`0ie`030=OG01[G00<0emL07mL00`3Ge`04e`070=OGe`3G0008e`001mL00`3G0003e`030=OG00CG
00<0emL07mL00`3Ge`0Ie`030=OG03[G00<0emL0>]L00`3Ge`0Ie`030=OG01oG00<0emL01=L01`3G
emL0e`002=L000OG00<0e`000mL00`3Ge`04e`030=OG01oG00<0emL06ML00`3Ge`0je`030=OG03[G
00<0emL06ML00`3Ge`0Oe`030=OG00CG00L0emOG0=L000SG0007e`030=L000?G00<0emL01=L00`3G
e`0Oe`030=OG01WG00<0emL0>]L00`3Ge`0je`030=OG01WG00<0emL07mL00`3Ge`04e`070=OGe`3G
0008e`00o`0P007G0007e`<00mL00`3Ge`02e`030=L000SG00<0emL01mL00`3Ge`08e`050=OGe`00
1ML00`3Ge`07e`030=OG00SG0P08e`030=OG00OG00<0emL02=L00`3Ge`07e`030=OG00SG00<0emL0
1mL00`3Ge`07e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00OG00<0emL01]L200[G00<0emL0
1mL00`3Ge`03e`050=OGe`002]L00`3Ge`07e`030=OG00KG00<0e`001=L0103GemL300SG0007e`03
0=L000?G00<0emL01=L00`3Ge`0@e`030=OG00cG00<0emL06ML00`3Ge`06e`030=OG037G00<0emL0
<ML00`3Ge`06e`030=OG01WG00<0emL03=L00`3Ge`0@e`030=OG00CG00L0emOG0=L000SG0007e`03
0=L000?G00<0emL01=L00`3Ge`0Oe`030=OG01WG00<0emL0>]L00`3Ge`0je`030=OG01WG00<0emL0
7mL00`3Ge`04e`070=OGe`3G0008e`001mL00`3G0002e`030=OG00CG00<0emL08=L00`3Ge`0Ie`03
0=OG03[G00<0emL0>ML00`3Ge`0Je`030=OG01oG00<0emL01=L01`3GemL0e`002=L000OG00<0e`00
0]L00`3Ge`04e`030=OG023G00<0emL06]L00`3Ge`0ie`030=OG03WG00<0emL06]L00`3Ge`0Pe`03
0=OG00CG00H0emL0e`08e`001mL00`3G0002e`030=OG00CG00<0emL08=L00`3Ge`0Je`030=OG03WG
00<0emL0>ML00`3Ge`0Je`030=OG023G00<0emL01=L01P3Ge`3G00SG0007e`030=L000;G00<0emL0
1=L00`3Ge`0Pe`030=OG01[G00<0emL0>ML00`3Ge`0ie`030=OG01[G00<0emL08=L00`3Ge`04e`06
0=OG0=L02=L000OG0P02e`030=OG00CG00<0emL08ML00`3Ge`0Je`030=OG03WG00<0emL0>=L00`3G
e`0Je`030=OG027G00<0emL01=L01P3Ge`3G00SG0007e`800]L00`3Ge`04e`030=OG02;G00<0emL0
6]L00`3Ge`0he`030=OG03SG00<0emL06]L00`3Ge`0Re`030=OG00CG00<0emL00P08e`001mL200;G
00<0emL01=L00`3Ge`0Re`030=OG01[G00<0emL0>=L00`3Ge`0he`030=OG01[G00<0emL08]L00`3G
e`04e`030=OG00802=L000OG0P02e`030=OG00?G00<0emL08mL00`3Ge`0Je`030=OG03SG00<0emL0
>=L00`3Ge`0Je`030=OG02;G00<0emL01=L00`3Ge`0200SG0007e`050=OGe`001ML00`3Ge`0Se`03
0=OG01[G00<0emL0>=L203SG00<0emL06]L00`3Ge`0Te`030=OG00?G00D0emOG0008e`001mL0103G
e`05e`030=OG02GG00<0emL06]L00`3Ge`0ge`030=OG03OG00<0emL06]L00`3Ge`0Te`030=OG00CG
00@0emL02=L000OG00@0emL01ML00`3Ge`0Ue`030=OG01[G00<0emL0=mL00`3Ge`0ge`030=OG01[G
00<0emL09ML00`3Ge`03e`040=OG00SG0007e`040=OG00GG00<0emL09ML00`3Ge`0Je`030=OG03OG
00<0emL0=mL00`3Ge`0Je`030=OG02GG00<0emL00mL0103Ge`08e`001mL00`3G0005e`030=OG02KG
00<0emL06]L00`3Ge`0ge`030=OG03KG00<0emL06mL00`3Ge`0Ue`030=OG00CG00<0e`002=L000OG
00<0e`001ML00`3Ge`0We`030=OG01[G00<0emL0=]L00`3Ge`0fe`030=OG01[G00<0emL09mL00`3G
e`03e`030=L000SG0007e`801ML00`3Ge`0Xe`030=OG01[G00<0emL0=]L00`3Ge`0ee`030=OG01_G
00<0emL09mL00`3Ge`04e`802=L000OG0P05e`030=OG02SG0P0Le`030=OG03GG00<0emL0=ML00`3G
e`0Je`80:]L00`3Ge`03e`802=L000OG00<0emL00mL00`3Ge`0Ze`030=OG01_G00<0emL0==L00`3G
e`0de`030=OG01_G00<0emL0:]L00`3Ge`02e`030=OG00OG0007e`800mL00`3Ge`0[e`030=OG01_G
00<0emL0==L00`3Ge`0ce`030=OG01_G00<0emL0;=L0103GemL200SG0008e`040=OG02oG00<0emL0
6mL00`3Ge`0ce`030=OG03?G00<0emL06mL00`3Ge`0]e`040=OG00WG0008e`040=OG02oG00<0emL0
7=L00`3Ge`0be`80<mL00`3Ge`0Le`030=OG02gG00@0emL02ML000SG00<0e`00<=L00`3Ge`0Me`03
0=OG037G00<0emL0<ML00`3Ge`0Le`030=OG02oG00<0e`002ML000SG0P0be`030=OG01gG00<0emL0
<=L00`3Ge`0`e`030=OG01gG00<0emL0<=L200WG0007e`803=L:01gG00<0emL07]L00`3Ge`0_e`03
0=OG02oG00<0emL07ML00`3Ge`0Le`X03=L200SG0008e`030=OG00OG0`0:e`030=OG01_G00<0emL0
7]L00`3Ge`0^e`030=OG02kG00<0emL07]L00`3Ge`0Ke`030=OG00SG0`09e`030=OG00OG0008e`03
0=OG00CG0`0>e`807=L00`3Ge`0Ne`030=OG02gG00<0emL0;]L00`3Ge`0Me`030=OG01[G0P0>e`<0
1ML00`3Ge`08e`002ML0103GemL201?G00<0emL06]L00`3Ge`0Ne`030=OG02cG00<0emL0;=L201oG
00<0emL06]L00`3Ge`0Ae`800mL00`3Ge`08e`002ML401KG0P0Je`030=OG01oG0P0/e`030=OG02[G
0P0Qe`030=OG01SG0P0Fe`@02]L000OG0`0Ke`030=OG01SG00<0emL08=L00`3Ge`0Ye`030=OG02WG
00<0emL08=L00`3Ge`0He`030=OG01WG0`08e`002ML00`3Ge`0Je`030=OG01SG00<0emL08=L202WG
00<0emL09mL202;G00<0emL06=L00`3Ge`0Je`030=OG00SG0009e`030=OG01_G00<0emL05mL00`3G
e`0Re`809mL00`3Ge`0Ue`808mL00`3Ge`0He`030=OG01_G00<0emL02=L000WG00<0emL07=L00`3G
e`0Ge`030=OG02?G0P0Ue`030=OG02?G0P0Ue`030=OG01OG00<0emL07=L00`3Ge`08e`002ML00`3G
e`0Me`030=OG01OG00<0emL09=L202?G0P0Re`809]L00`3Ge`0Ge`030=OG01gG00<0emL02=L000OG
1P0Me`030=OG01KG00<0emL09]L3023G00<0emL07]L302SG00<0emL05]L00`3Ge`0Ke`H02=L000[G
00<0emL00P0Ke`030=OG01OG00<0emL0:=L501_G00<0emL06ML502[G00<0emL05]L00`3Ge`0Je`80
0]L00`3Ge`09e`002]L00`3Ge`02e`<06ML00`3Ge`0Ge`030=OG02cG100Ge`030=OG01GG100^e`03
0=OG01OG00<0emL05mL300CG00<0emL02ML000[G00<0emL01ML201SG00<0emL05mL00`3Ge`0_e`H0
4ML00`3Ge`0?e`H0<ML00`3Ge`0Ge`030=OG01KG0P07e`030=OG00WG000:e`030=OG00OG0P0Ge`03
0=OG01KG00<0emL0=MLS03KG00<0emL05mL00`3Ge`0Ee`802ML00`3Ge`09e`001mL0103Ge`0;e`03
0=OG01GG00<0emL05]L00`3Ge`15e`030=OG04GG00<0emL05]L00`3Ge`0Ee`030=OG00WG00@0emL0
2=L000SG0`0<e`805]L00`3Ge`0Fe`030=OG04CG00<0emL0A=L00`3Ge`0Fe`030=OG01CG0P0<e`<0
2ML000[G0`0<e`030=OG01CG00<0emL05]L00`3Ge`13e`030=OG04?G00<0emL05]L00`3Ge`0De`03
0=OG00[G0`0;e`002mL00`3G000;e`030=OG01CG00<0emL05mL00`3Ge`0^e`801=L00`3Ge`02e`@0
1ML00`3Ge`12e`030=OG01OG00<0emL05=L00`3Ge`09e`030=L000cG0007e`050=OGe`000]L00`3G
e`09e`030=OG01CG00<0emL05mL00`3Ge`0/e`040=OG00SG00<0emL01]L00`3Ge`11e`030=OG01OG
00<0emL05=L00`3Ge`09e`040=OG00?G00<0emL01]L000SG00@0emL00mL00`3Ge`09e`030=OG01?G
00<0emL06=L00`3Ge`0[e`040=OG00WG00<0emL01ML3043G00<0emL05mL00`3Ge`0De`030=OG00WG
00D0emOG0002e`030=OG00OG0008e`040=OG00CG00<0emL02ML00`3Ge`0Ce`030=OG01SG00<0emL0
:]L0103Ge`0:e`030=OG00CG00<0emL0?mL00`3Ge`0He`030=OG01?G00<0emL02ML00`3Ge`02e`04
0=OG00WG0009e`030=L000CG00<0emL02]L201CG00<0emL06=L00`3Ge`0Ye`040=OG00_G00<0emL0
0mL00`3Ge`0ne`030=OG01SG00<0emL04]L200cG00<0emL00]L00`3G000:e`002]L200GG00<0emL0
2mL00`3Ge`0Be`030=OG01SG0P0Ye`040=OG00SG00@0emL01ML00`3Ge`0le`806]L00`3Ge`0Be`03
0=OG00_G00<0emL00mL200_G0007e`040=OGe`801=L00`3Ge`0;e`030=OG01?G00<0emL06ML00`3G
e`0We`802]L200KG00<0emL0>mL00`3Ge`0Ie`030=OG01;G00<0emL02mL00`3Ge`03e`800mL00`3G
e`06e`001mL0103GemL200GG00<0emL02mL00`3Ge`0Be`030=OG01[G00<0emL0>]L00`3Ge`0je`03
0=OG01WG00<0emL04mL00`3Ge`0;e`030=OG00?G00D0emOG0009e`002=L01@3GemL000KG00<0emL0
2mL00`3Ge`0Be`030=OG01[G00<0emL0>ML00`3Ge`0ie`030=OG01[G00<0emL04]L00`3Ge`0;e`03
0=OG00CG00D0emOG0009e`002=L0103GemL200KG0P0<e`030=OG01;G00<0emL06]L303SG00<0emL0
=]L301cG00<0emL04]L00`3Ge`0:e`801]L200;G00<0emL02=L000WG00<0emL00P07e`030=OG00_G
00<0emL04]L201gG0P0fe`030=OG03CG0P0Me`805=L00`3Ge`0;e`030=OG00CG00<0e`000]L00`3G
e`08e`002ML0103GemL200OG00<0emL02mL00`3Ge`0Ce`030=OG01cG0P0de`030=OG03;G0P0Ne`03
0=OG01?G00<0emL02mL00`3Ge`04e`H02mL000OG00@0emL00]L00`3G0006e`030=OG00cG00<0emL0
4]L00`3Ge`0Ne`80<]L00`3Ge`0`e`808=L00`3Ge`0Be`030=OG00cG00<0emL01=L600;G00<0emL0
1]L000OG00@0emL00]L00`3G0007e`030=OG00cG00<0emL04]L00`3Ge`0Oe`<0;mL00`3Ge`0]e`<0
8ML00`3Ge`0Be`030=OG00cG00<0emL01=L70003e`3G00SG0008e`060=OG0=L00]L00`3Ge`04e`03
0=OG00cG00<0emL04mL00`3Ge`0Qe`80;ML202cG0P0Se`030=OG01?G00<0emL02mL00`3Ge`05e`H0
0]L00`3Ge`07e`002=L01P3Ge`3G00;G00<0emL01ML00`3Ge`0<e`030=OG01?G00<0emL08]L402WG
00<0emL09mL402CG00<0emL04mL00`3Ge`0<e`030=OG00CG00<0e`0010000mL0e`09e`002ML01P3G
e`3G00;G00<0emL01ML00`3Ge`0<e`030=OG01?G00<0emL09ML9023G00<0emL07]L902OG00<0emL0
4mL00`3Ge`0<e`030=OG00GG00<0emL00`02e`030=OG00SG0009e`060=OG0=L00]L00`3Ge`05e`03
0=OG00gG00<0emL04mL00`3Ge`0]ed40;mL00`3Ge`0Ce`030=OG00gG00<0emL01ML01P3Ge`3G00;G
00<0emL02=L000OG00<0e`000]L00`3G0002e`030=OG00KG00<0emL03ML00`3Ge`0Ce`80CML00`3G
e`1;e`805ML00`3Ge`0=e`030=OG00GG00@0emOG0P02e`040=OG00SG0007e`040=OG00;G0P03e`03
0=OG00GG00<0emL03]L00`3Ge`0De`030=OG04[G00<0emL0B]L00`3Ge`0De`030=OG00kG00<0emL0
1ML0103GemL200;G00@0emL02=L000OG00@0emL00]L00`3G0002e`030=OG00KG00<0emL03]L00`3G
e`0De`030=OG04WG00<0emL0BML00`3Ge`0De`030=OG00kG00<0emL01]L01P3Ge`3G00;G00@0emL0
2=L000OG00@0emL00]L00`3G0002e`030=OG00OG00<0emL03]L00`3Ge`0De`030=OG04SG00<0emL0
B=L00`3Ge`0De`030=OG00kG00<0emL01mL01P3Ge`3G00;G00@0emL02=L000OG00@0emL00]L00`3G
0002e`030=OG00OG00<0emL03mL00`3Ge`0De`030=OG04OG00<0emL0AmL00`3Ge`0De`030=OG00kG
00<0emL01mL0103GemL200;G00@0emL02ML000SG00@0emL00]L200?G00<0emL01mL00`3Ge`0?e`03
0=OG01CG00<0emL0A]L00`3Ge`16e`030=OG01CG00<0emL03mL00`3Ge`07e`040=OGe`800]L0103G
e`09e`002=L0103Ge`02e`030=L000;G00<0emL02=L00`3Ge`0?e`030=OG01CG0P16e`030=OG04CG
0P0Fe`030=OG00oG00<0emL02=L01P3Ge`3G00;G00@0emL02ML000SG00@0emL00]L00`3G0002e`03
0=OG00SG00<0emL03mL00`3Ge`0Fe`030=OG04?G0P14e`030=OG01KG00<0emL03mL00`3Ge`07e`07
0=OGe`3G0002e`040=OG00WG0008e`040=OG00;G00<0e`000mL00`3Ge`08e`030=OG00oG00<0emL0
5]L204?G00<0emL0@ML201SG00<0emL03mL00`3Ge`08e`040=OGe`800mL00`3G000:e`002ML00`3G
0003e`030=L000;G00<0emL02=L00`3Ge`0@e`030=OG01OG0P11e`030=OG03oG0P0Ie`030=OG013G
00<0emL01mL01`3GemL0e`000mL00`3G000:e`002ML00`3G0003e`030=L000?G00<0emL02=L00`3G
e`0@e`030=OG01SG0P0oe`030=OG03gG0P0Je`030=OG013G00<0emL02=L01`3GemL0e`000mL00`3G
000:e`002ML00`3G0003e`030=L000?G00<0emL02ML00`3Ge`0@e`030=OG01WG0P0me`030=OG03_G
0P0Ke`030=OG013G00<0emL02ML01`3GemL0e`000mL00`3G000:e`002ML00`3G0003e`030=L000?G
00<0emL02ML00`3Ge`0Ae`030=OG01[G0P0ke`030=OG03WG0P0Le`030=OG017G00<0emL02ML01`3G
emL0e`000mL00`3G000:e`002ML00`3G0003e`040=OG00?G00<0emL02ML00`3Ge`0Ae`030=OG01_G
100ge`030=OG03GG100Me`030=OG017G00<0emL02ML01@3GemL000;G00L0emOG0=L000[G0009e`03
0=L000?G00@0emL00mL00`3Ge`0:e`030=OG017G00<0emL07]L303CG00<0emL0<]L3023G00<0emL0
4ML00`3Ge`0:e`050=OGe`000]L01`3GemL0e`002]L000WG00<0e`000mL0103Ge`03e`030=OG00_G
00<0emL04ML00`3Ge`0Pe`H0;]L00`3Ge`0/e`H08]L00`3Ge`0Ae`030=OG00_G00D0emOG0002e`07
0=OGe`3G000:e`002ML00`3G0003e`050=OGe`000]L00`3Ge`0<e`030=OG017G0P0Ve`T02]Lg00[G
2@0Ve`804mL00`3Ge`0<e`040=OG00?G00L0emOG0=L000[G0008e`040=OG00?G00D0emOG0002e`03
0=OG00gG00<0emL04]L00`3Ge`0/e`X06mL00`3Ge`0Ie`X0;]L00`3Ge`0Be`030=OG00cG00D0emOG
0003e`070=OGe`3G000:e`002=L0103Ge`03e`030=OG00;G00@0emL03mL00`3Ge`0Ae`030=OG057G
00<0emL0DML00`3Ge`0Ae`030=OG00gG00@0emL01=L01@3GemL000;G00<0emL01mL000SG00@0emL0
0mL00`3Ge`02e`040=OG00oG00<0emL04]L00`3Ge`1@e`80DML00`3Ge`0Be`030=OG00gG00@0emL0
1=L01@3GemL000;G00<0emL01mL000SG00@0emL00mL00`3Ge`02e`040=OG013G00<0emL04]L2053G
00<0emL0C]L201CG00<0emL03]L0103Ge`04e`050=OGe`000]L00`3Ge`07e`001mL0103Ge`03e`03
0=OG00CG00<0e`004ML00`3Ge`0Ce`030=OG04gG00<0emL0CML00`3Ge`0Ce`030=OG00kG00@0emL0
1ML01@3GemL000;G00<0emL01mL000OG00@0emL00mL00`3Ge`04e`040=OG017G00<0emL04mL00`3G
e`1<e`030=OG04cG00<0emL04mL00`3Ge`0?e`040=OG00KG00D0emOG0002e`030=OG00KG0007e`04
0=OG00?G00<0emL01=L0103Ge`0Be`805=L00`3Ge`1;e`030=OG04_G00<0emL04]L201;G00@0emL0
1]L01@3GemL000;G00<0emL01]L000OG00@0emL00mL00`3Ge`05e`030=L001CG00<0emL04]L204_G
00<0emL0BML201CG00<0emL04ML0103Ge`07e`050=OGe`000]L00`3Ge`06e`001mL00`3G0003e`03
0=OG00KG00@0emL04mL00`3Ge`0De`030=OG04SG00<0emL0B=L00`3Ge`0Ce`030=OG01;G00@0emL0
1mL01@3GemL000;G00<0emL01]L000WG00D0emOG0009e`030=L001CG00<0emL05=L204SG00<0emL0
A]L201KG00<0emL04ML0103Ge`09e`050=OGe`002]L000WG00D0emOG0009e`040=OG01CG00<0emL0
5ML204KG00<0emL0A=L201OG00<0emL04]L0103Ge`09e`050=OGe`002]L000SG00D0emOG000:e`05
0=OGe`005=L00`3Ge`0Fe`80A=L00`3Ge`12e`806=L00`3Ge`0Be`040=OG00[G00D0emOG000:e`00
2=L01@3GemL000_G00D0emOG000De`030=OG01OG100/e`801=L00`3Ge`04e`030=OG00CG00<0emL0
?]L401WG00<0emL04]L01@3GemL000_G00D0emOG0009e`001mL01@3GemL000cG00<0emL00]L00`3G
e`0Be`806mL402OG00<0emL09@0Ze`@06mL201CG00D0emOG000<e`050=OGe`002ML000OG00D0emOG
000=e`030=OG00;G00<0emL04mL00`3Ge`0Le`D07=L:00OG1@05e`<04=L901cG1@0Ne`030=OG01?G
00<0emL00]L00`3Ge`0;e`050=OGe`002=L000[G00<0emL03=L00`3Ge`03e`030=OG01?G00<0emL0
8=L500kG2@06e`040=OG00OG00@0emL01]L00`3Ge`0Ie`T03mL402;G00<0emL04mL00`3Ge`02e`03
0=OG00gG00<0emL02ML000WG00<0emL03]L00`3Ge`03e`805=L00`3Ge`0Te`h03mL0103Ge`08e`03
0=L000KG00<0emL08]L?02GG00<0emL04]L200GG00<0emL03]L00`3Ge`08e`002=L00`3Ge`0?e`03
0=OG00GG00<0emL04]L00`3Ge`10e`040=OG00WG0P06e`030=OG05GG00<0emL04]L00`3Ge`04e`03
0=OG013G00<0emL01mL000OG00<0emL04ML00`3Ge`05e`804mL00`3Ge`10e`802mL00`3Ge`04e`03
0=OG05CG00<0emL04ML200OG00<0emL04ML00`3Ge`06e`006mL00`3Ge`07e`030=OG017G00<0emL0
DmL00`3Ge`1Ce`030=OG017G00<0emL01]L00`3Ge`0Ke`007=L00`3Ge`07e`030=OG017G00<0emL0
D]L00`3Ge`1Be`030=OG017G00<0emL01mL00`3Ge`0Ke`007=L00`3Ge`08e`030=OG017G0P1Be`03
0=OG053G0P0Ce`030=OG00OG00<0emL07=L000OG200>e`030=OG00SG0P0Ce`030=OG04oG00<0emL0
CmL00`3Ge`0Ae`801mL500gG2008e`003mL00`3Ge`0<e`030=OG00WG00<0emL04=L00`3Ge`1?e`03
0=OG04kG00<0emL04ML00`3Ge`07e`D03=L00`3Ge`0>e`004=L00`3Ge`0;e`030=OG00[G00<0emL0
4=L204oG00<0emL0CML201;G00<0emL01mL600_G00<0emL03mL0013G00<0emL03=L00`3Ge`0:e`03
0=OG017G0P19e`T0BML201?G00<0emL02ML500[G00<0emL04=L000OG0P08e`030=OG00_G00<0emL0
2mL00`3Ge`0Be`80?=L;00CG00<0emL00]L;03cG0P0De`030=OG00[G1@0:e`030=OG00KG0P08e`00
2ML00`3Ge`05e`030=OG00cG00<0emL02mL00`3Ge`0Be`030=OG03?G1`0?e`030=OG00gG1`0ee`03
0=OG01;G00<0emL02mL00`3G000<e`030=OG00GG00<0emL02=L000[G00<0emL01=L00`3Ge`0=e`03
0=OG00[G00<0emL04mL202kG1@0Fe`030=OG01CG1@0^e`805=L00`3Ge`0;e`030=OG00gG00<0emL0
1=L00`3Ge`09e`002mL00`3Ge`04e`030=OG00cG00<0emL02mL00`3Ge`0De`@09ML501_G00<0emL0
6ML502GG100Fe`030=OG00_G00<0emL03=L00`3Ge`04e`030=OG00[G0007e`050=OGe`001]L00`3G
e`0=e`030=OG00_G00<0emL05mL301kG100Pe`030=OG01kG100Ne`<06ML00`3Ge`0;e`030=OG00gG
00<0emL00mL00`3Ge`02e`030=OG00KG0008e`050=OGe`001ML00`3Ge`0=e`030=OG00cG00<0emL0
6ML600oG2@0Te`030=OG02;G2P0>e`H06mL00`3Ge`0<e`030=OG00gG00<0emL00mL01@3GemL000WG
0009e`040=OG00GG00<0emL03]L00`3Ge`0<e`030=OG01kG3`0]e`030=OG02cG3P0Pe`030=OG00cG
00<0emL03]L00`3Ge`02e`050=OGe`002]L000OG00<0e`000mL00`3Ge`02e`030=OG00WG0P04e`03
0=OG00_G00<0emL0F]L00`3Ge`1Ie`030=OG00cG00<0emL00]L200_G00<0emL00]L0103Ge`02e`03
0=OG00KG0007e`040=OG00;G00<0emL00]L00`3Ge`07e`800]L300;G00<0emL02mL00`3Ge`1Ie`03
0=OG05WG00<0emL02mL00`3Ge`0300;G0P09e`050=OGe`000mL00`3G0009e`002=L0103Ge`02e`05
0=OGe`001mL200OG0P000mL0e`0<e`030=OG05SG00<0emL0F=L00`3Ge`0;e`040=L000OG0P07e`05
0=OGe`000]L0103Ge`09e`002=L0103Ge`02e`050=OGe`001]L00`3Ge`09e`030=L000gG00<0emL0
EmL00`3Ge`1Ge`030=OG00_G00<0e`002mL00`3Ge`04e`050=OGe`000]L00`3G000:e`001mL01@3G
0=L000;G00D0emOG0005e`030=OG00_G0P0>e`030=OG05;G2@1De`030=OG00cG0P0=e`030=OG00?G
00@0emL00mL01@3G0=L000SG0007e`030=L000;G00@0emL00]L00`3Ge`03e`030=OG00cG0P0>e`03
0=OG04SG2@04e`030=OG00;G2@1:e`030=OG00cG0P0>e`030=OG00?G00@0emL00]L01@3G0=L000WG
0008e`050=L0e`000]L0103Ge`04e`030=OG00kG0P0>e`030=OG04;G1@0=e`030=OG00_G1@14e`03
0=OG00cG0P0@e`030=OG00;G00@0emL00]L01@3G0=L000WG0007e`8000CG0=L00]L0103Ge`03e`03
0=OG013G0P0>e`030=OG03gG100Be`030=OG013G100oe`030=OG00cG0P0Ae`030=OG00;G00@0emL0
0]L0103G0=L200SG0007e`8000CG0=L00]L00`3G0004e`030=OG017G0P0>e`030=OG03SG100Ee`D0
4mL403[G00<0emL03=L201?G00D0emOG0002e`090=L0e`3G0=L000SG0008e`8000SG0=L0e`3G00?G
00<0emL04mL200kG00<0emL0=ML201WG1@05e`D03ML203OG00<0emL03=L201CG00<0emL00]L0203G
0=L0e`3G0P09e`002=L20008e`3G0=L0e`03e`030=OG01CG0P0>e`030=OG037G0`0Ge`/00mL500oG
0`0ce`030=OG00cG0P0Fe`0<0=OGe`3G0=L0e`3G0P09e`00;]L00`3Ge`1Be`L01=L500;G201Ce`03
0=OG02gG000_e`80C]L400_G1@05e`P01ML504CG0P0`e`00<ML00`3Ge`17e`@04=L200OG1@03e`@0
00?G00000`13e`030=OG033G000be`030=OG04?G0`0De`030=OG00SG00<0emL01mL604;G00<0emL0
<ML003?G00<0emL0?mL301OG0P0De`D0@ML00`3Ge`0be`00==L203gG0P0Je`030=OG01?G1`0ie`H0
=ML003KG00<0emL0=mL301cG00<0emL05ML00`3Ge`02e`<01]L502_G1@0fe`00=mL203CG0`0Oe`03
0=OG01gG0`03e`D0:]L603KG000ie`80;]L402;G00<0emL08=L802[G1P0fe`00>mL202SG100Ve`03
0=OG02?G1@0Xe`8000?G00000`0fe`00?ML302;G0`0Ze`030=OG02?G200Re`<01ML00`3Ge`0fe`00
@=L301_G100]e`030=OG02GG00<0emL00mL400[G1@0<e`<0@ML004?G1P0Ae`@0<ML00`3Ge`0_e`@0
1]L500KG1P14e`00BMLA03GG00<0emL0<mLA04[G001ke`801=L00`3Ge`03e`801]L00`3Ge`0ie`D0
D=L007[G00@0emL02=L0103Ge`05e`030=OG03WG1@1@e`00N]L0103Ge`08e`040=OG00GG0`0ke`03
0=OG053G001je`040=OG00SG0`06e`030=OG08kG001je`040=OG00SG00<0emL01]L00`3Ge`2>e`00
N]L0103Ge`08e`030=OG00KG00<0emL0S]L007_G0P0:e`<01ML00`3Ge`2>e`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.38217, -0.619431, 0.00963187, \
0.0043166}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{846, 768},
WindowMargins->{{150, Automatic}, {Automatic, 52}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 344, 9, 132, "Input"],
Cell[2074, 63, 35, 1, 31, "Output"]
}, Open  ]],
Cell[2124, 67, 539, 9, 193, "Input"],
Cell[2666, 78, 282, 5, 101, "Input"],
Cell[2951, 85, 205, 4, 101, "Input"],

Cell[CellGroupData[{
Cell[3181, 93, 42, 1, 32, "Input"],
Cell[3226, 96, 117, 2, 31, "Output"]
}, Open  ]],
Cell[3358, 101, 311, 6, 101, "Input"],

Cell[CellGroupData[{
Cell[3694, 111, 169, 3, 78, "Input"],
Cell[3866, 116, 17714, 489, 296, 4316, 319, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[21595, 608, 296, 6, 101, "Input"],

Cell[CellGroupData[{
Cell[21916, 618, 374, 8, 147, "Input"],
Cell[22293, 628, 57, 1, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22387, 634, 247, 6, 78, "Input"],
Cell[22637, 642, 106, 2, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22780, 649, 44, 1, 32, "Input"],
Cell[22827, 652, 42, 1, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22906, 658, 395, 8, 124, "Input"],
Cell[23304, 668, 224, 4, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23565, 677, 191, 4, 78, "Input"],
Cell[23759, 683, 256, 4, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24052, 692, 196, 4, 78, "Input"],
Cell[24251, 698, 36, 1, 27, "Print"],
Cell[24290, 701, 61, 1, 32, "Print"],
Cell[24354, 704, 61, 1, 32, "Print"],
Cell[24418, 707, 57, 1, 32, "Print"],
Cell[24478, 710, 57, 1, 32, "Print"],
Cell[24538, 713, 56, 1, 32, "Print"],
Cell[24597, 716, 61, 1, 32, "Print"],
Cell[24661, 719, 62, 1, 32, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24760, 725, 241, 4, 101, "Input"],
Cell[25004, 731, 57515, 2183, 296, 25681, 1785, "GraphicsData", "PostScript", \
"Graphics"],
Cell[82522, 2916, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82696, 2924, 163, 3, 55, "Input"],
Cell[82862, 2929, 55642, 2025, 296, 24480, 1636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[138507, 4956, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138674, 4964, 163, 3, 55, "Input"],
Cell[138840, 4969, 57146, 2116, 296, 25661, 1723, "GraphicsData", \
"PostScript", "Graphics"],
Cell[195989, 7087, 130, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

