(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29077,        766]*)
(*NotebookOutlinePosition[     29708,        788]*)
(*  CellTagsIndexPosition[     29664,        784]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(\(\( (*\ c46 : \ Laplace\ equation\ with\ two\ different\ boundaries, \ 
      inner\ inhomogeneous\ on\ a\ square, \ 
      outer\ homogeneous\ on\ circle\ *) \)\(\n\)\( (*\ 
      Step\ 1 : \ 
        define\ 6\ collocation\ points\ on\ square\ of\ length\ 2. \ *) \)\(\n\
\)\(Clear[x, y, r, fi]; Table[x[i] = 0.9999, {i, 1, 6}]; y[1] = 0.00001; 
    y[2] = 0.2; y[3] = 0.4; y[4] = 0.6; y[5] = 0.8; y[6] = 0.99; 
    Clear[l1, GL1, L2, GL2, Ci, CiG, GG]; 
    L1 = ListPlot[Table[{x[i], y[i]}, {i, 1, 6}], 
        Prolog \[Rule] AbsolutePointSize[6], 
        DisplayFunction \[Rule] Identity]; GL1 = Graphics[L1]; 
    L2 = ListPlot[{{\(-1.0\), \(-1.0\)}, {1.0, \(-1.0\)}, {1.0, 
            1.0}, {\(-1.0\), 1.0}, {\(-1.0\), \(-1.0\)}}, 
        Prolog \[Rule] AbsolutePointSize[6], PlotJoined \[Rule] True, 
        Axes \[Rule] False, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] Identity]; GL2 = Graphics[L2]; 
    Ci = Circle[{0. , 0. }, 2]; CiG = Graphics[Ci]; 
    Show[GL1, GL2, CiG, Frame \[Rule] True, 
      DisplayFunction \[Rule] $DisplayFunction, 
      AspectRatio \[Rule] 1]\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -12 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .2619 -12 -4.5 ]
[-0.0125 .2619 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .7381 -6 -4.5 ]
[-0.0125 .7381 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(-2)] -0.0125 .02381 1 0 Mshowa
0 .2619 m
.00625 .2619 L
s
[(-1)] -0.0125 .2619 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .7381 m
.00625 .7381 L
s
[(1)] -0.0125 .7381 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(2)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .21429 m
.00375 .21429 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .40476 m
.00375 .40476 L
s
0 .45238 m
.00375 .45238 L
s
0 .54762 m
.00375 .54762 L
s
0 .59524 m
.00375 .59524 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .78571 m
.00375 .78571 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.2619 .99375 m
.2619 1 L
s
.5 .99375 m
.5 1 L
s
.7381 .99375 m
.7381 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.21429 .99625 m
.21429 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.40476 .99625 m
.40476 1 L
s
.45238 .99625 m
.45238 1 L
s
.54762 .99625 m
.54762 1 L
s
.59524 .99625 m
.59524 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.78571 .99625 m
.78571 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .5 m
1 .5 L
s
.99375 .7381 m
1 .7381 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .40476 m
1 .40476 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .78571 m
1 .78571 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
6 Mabswid
.73807 .5 Mdot
.73807 .54762 Mdot
.73807 .59524 Mdot
.73807 .64286 Mdot
.73807 .69048 Mdot
.73807 .73571 Mdot
.5 Mabswid
.2619 .2619 m
.7381 .2619 L
.7381 .7381 L
.2619 .7381 L
.2619 .2619 L
s
newpath
.5 .5 .47619 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML001KG
100me`@0>mL203gG100me`@01]L001KG00<0emL0@=L00`3Ge`0ie`040=OG03kG00<0emL0?=L00`3G
e`07e`005mL00`3Ge`0oe`030=OG03WG00@0emL0?]L00`3Ge`0me`030=OG00KG000@e`@01=L00`3G
e`0fe`@01=L00`3Ge`0ie`040=OG03kG00<0emL0?]L00`3Ge`05e`006ML00`3Ge`0me`030=OG03WG
00@0emL0?]L00`3Ge`0oe`030=OG00CG000Fe`040=OG03gG0`0ke`040=OG03cG0`0ne`040=OG00KG
000Ge`80@=L00`3Ge`0je`80?mL00`3Ge`0me`801mL00?oG8ML00?oG8ML00?oG8ML000oGo`0A007G
000?e`030=OG00?G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G
00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00WG00<0emL02]L00`3G
e`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00?G
0@01e`003mL00`3Ge`03e`030=OG03kG00<0emL0?]L00`3Ge`0me`030=OG03kG00<0emL00mL1007G
000?e`030=OG08GG00<0emL0Q=L1007G000?e`030=OG08GG00<0emL0Q=L1007G0007e`@01=L00`3G
e`25e`030=OG08CG0@01e`001mL00`3Ge`05e`030=OG08GG00<0emL0Q=L1007G0008e`030=OG00CG
0`1ieaP0N]L2007G00000mL0000200CG00<0emL00mL00`3Ge`1ae`P03=L00`3Ge`09e`P0LmL1007G
000:e`030=OG00;G00<0emL0JmL601CG00<0emL04ML606gG0@01e`001mL0103Ge`04e`030=OG06SG
0`0Je`030=OG01OG0`1Ze`400ML000SG0P05e`030=OG06?G1@0Me`030=OG01[G1@1Ue`400ML000oG
00<0emL0H=L302;G00<0emL07mL306;G0@01e`003mL00`3Ge`1Me`<09ML00`3Ge`0Re`<0GmL1007G
000?e`030=OG05[G0`0Xe`030=OG02GG0`1Le`400ML000oG00<0emL0EmL302_G00<0emL0:=L305WG
0@01e`003mL00`3Ge`1De`<0;]L00`3Ge`0[e`<0E]L1007G000?e`030=OG057G0`0ae`030=OG02kG
0`1Ce`400ML000oG00<0emL0CmL203CG00<0emL0<ML2057G0@01e`003mL00`3Ge`1>e`030=OG03CG
00<0emL0<mL204oG0@01e`003mL204gG0P0ge`030=OG03GG0P1<e`800ML000oG00<0emL0B]L203WG
00<0emL0=mL204_G0@01e`003mL00`3Ge`18e`80>mL00`3Ge`0ie`030=OG04SG0@01e`003mL00`3G
e`16e`80?ML00`3Ge`0je`80B=L1007G000?e`030=OG04CG0P0oe`030=OG03cG0P16e`400ML000oG
00<0emL0@]L2047G00<0emL0?]L204CG0@01e`003mL00`3Ge`11e`030=OG047G00<0emL0@=L00`3G
e`11e`400ML000oG00<0emL0@=L00`3Ge`12e`030=OG047G0P11e`400ML000oG00<0emL0?]L204GG
00<0emL0@mL00`3Ge`0ne`400ML000oG00<0emL0?=L204OG00<0emL0A=L203kG0@01e`003mL00`3G
e`0je`80BML00`3Ge`16e`80?=L1007G000?e`030=OG03WG00<0emL0BML00`3Ge`18e`030=OG03WG
0@01e`003mL00`3Ge`0he`030=OG04[G00<0emL0BML203WG0@01e`003mL203SG00<0emL0BmL00`3G
e`1;e`030=OG03GG0P01e`003mL00`3Ge`0ee`80C]L00`3Ge`1<e`030=OG03GG0@01e`003mL00`3G
e`0de`030=OG04kG00<0emL0CML00`3Ge`0de`400ML000oG00<0emL0<mL00`3Ge`1?e`030=OG04kG
0P0de`400ML000oG00<0emL0<]L00`3Ge`1@e`030=OG053G00<0emL0<ML1007G000?e`030=OG033G
0P1Ce`030=OG057G00<0emL0<=L1007G000?e`030=OG02oG00<0emL0DmL00`3Ge`1Be`030=OG02oG
0@01e`003mL00`3Ge`0^e`030=OG05CG00<0emL0DmL202oG0@01e`003mL00`3Ge`0]e`030=OG05GG
00<0emL0EML00`3Ge`0/e`400ML000oG00<0emL0;=L00`3Ge`1Fe`030=OG05KG00<0emL0:mL1007G
000?e`030=OG02_G00<0emL0EmL00`3Ge`1Fe`030=OG02_G0@01e`003mL00`3Ge`0Ze`030=OG05SG
00<0emL0EmL00`3Ge`0Ze`400ML000oG00<0emL0:ML00`3Ge`1Ie`030=OG05SG00<0emL0:ML1007G
000?e`80:ML00`3Ge`1Je`030=OG05WG00<0emL09mL2007G000?e`030=OG02OG00<0emL0FmL00`3G
e`1Je`030=OG02OG0@01e`003mL00`3Ge`0Ve`030=OG05cG00<0emL0FmL00`3Ge`0Ve`400ML000oG
00<0emL09ML00`3Ge`1Me`030=OG05cG00<0emL09ML1007G000?e`030=OG02GG00<0emL0GML00`3G
e`1Me`030=OG02CG0@01e`003mL00`3Ge`0Te`030=OG05kG00<0emL0G]L00`3Ge`0Se`400ML000oG
00<0emL08mL00`3Ge`1Oe`030=OG05oG00<0emL08]L1007G000?e`030=OG02;G00<0emL0H=L00`3G
e`1Pe`030=OG027G0@01e`003mL00`3Ge`0Qe`030=OG067G00<0emL0HML00`3Ge`0Pe`400ML000oG
00<0emL08ML00`3Ge`1Qe`030=OG067G00<0emL08=L1007G000?e`030=OG023G00<0emL0H]L00`3G
e`1Re`030=OG01oG0@01e`003mL00`3Ge`0Oe`030=OG06?G00<0emL0HmL00`3Ge`0Ne`400ML000oG
00<0emL07]L00`3Ge`1Te`030=OG06CG00<0emL07ML1007G000?e`807]L00`3Ge`1Ue`030=OG06GG
00<0emL06mL2007G000?e`030=OG01gG00<0emL0IML00`3Ge`1Ue`030=OG01cG0@01e`003mL00`3G
e`0Le`030=OG06KG00<0emL0I]L00`3Ge`0Ke`400ML000oG00<0emL06mL00`3Ge`1We`030=OG06KG
00<0emL06mL1007G000?e`030=OG01[G00<0emL0J=L00`3Ge`1We`030=OG01[G0@01e`003mL00`3G
e`0Ie`030=OG06WG00<0emL0J=L00`3Ge`0Ie`400ML000oG00<0emL06ML00`3Ge`1Ye`030=OG06SG
00<0emL06ML1007G000?e`030=OG01SG00<0emL0J]L00`3Ge`1Ye`030=OG01SG0@01e`003mL00`3G
e`0Ge`030=OG06_G00<0emL0J]L00`3Ge`0Ge`400ML000oG00<0emL05mL00`3Ge`1[e`030=OG06[G
00<0emL05mL1007G000?e`030=OG01KG00<0emL0K=L00`3Ge`1[e`030=OG01KG0@01e`001mL400CG
00<0emL05]L00`3Ge`1/e`030=OG06cG00<0emL05ML1007G0009e`030=OG00?G00<0emL05ML00`3G
e`1]e`030=OG06cG00<0emL05ML1007G0009e`030=OG00?G0`0Ee`030=OG02cGPP0_e`030=OG01?G
0P01e`0000?G00000P04e`030=OG00?G00<0emL05=L00`3Ge`0]e`030=OG03kG00<0emL0?ML00`3G
e`0]e`030=OG01CG0@01e`002ML00`3Ge`03e`030=OG01?G00<0emL0;]L00`3Ge`0ne`030=OG03gG
00<0emL0;]L00`3Ge`0Ce`400ML000OG0`05e`030=OG01?G00<0emL0;]L00`3Ge`0ne`030=OG03gG
00<0emL0;mL00`3Ge`0Be`400ML000WG00<0emL00mL00`3Ge`0Be`030=OG02oG00<0emL0?]L00`3G
e`0me`030=OG02oG00<0emL04]L1007G000?e`030=OG01;G00<0emL0;mL00`3Ge`0ne`030=OG03gG
00<0emL0<=L00`3Ge`0Ae`400ML000oG00<0emL04ML00`3Ge`0`e`030=OG03kG00<0emL0?ML00`3G
e`0`e`030=OG017G0@01e`003mL00`3Ge`0Ae`030=OG033G00<0emL0?]L00`3Ge`0me`030=OG037G
00<0emL04=L1007G000?e`030=OG013G00<0emL0<ML00`3Ge`0ne`030=OG03gG00<0emL0<ML00`3G
e`0@e`400ML000oG00<0emL04=L00`3Ge`0ae`030=OG03kG00<0emL0?ML00`3Ge`0ae`030=OG013G
0@01e`003mL00`3Ge`0?e`030=OG03;G00<0emL0?]L00`3Ge`0me`030=OG03;G00<0emL03mL1007G
000?e`030=OG00oG00<0emL0<]L00`3Ge`0ne`030=OG03gG00<0emL0<]L00`3Ge`0?e`400ML000oG
0P0@e`030=OG03;G00<0emL0?]L00`3Ge`0me`030=OG03?G00<0emL03ML2007G000?e`030=OG00kG
00<0emL0<mL00`3Ge`0ne`030=OG03gG00<0emL0<mL00`3Ge`0>e`400ML000oG00<0emL03]L00`3G
e`0ce`030=OG03kG00<0emL0?ML00`3Ge`0de`030=OG00gG0@01e`003mL00`3Ge`0=e`030=OG03CG
00<0emL0?]L00`3Ge`0me`030=OG03CG00<0emL03ML1007G000?e`030=OG00gG00<0emL0==L00`3G
e`0ne`030=OG03gG00<0emL0=ML00`3Ge`0<e`400ML000oG00<0emL03=L00`3Ge`0ee`030=OG03kG
00<0emL0?ML00`3Ge`0ee`030=OG00cG0@01e`003mL00`3Ge`0<e`030=OG03GG00<0emL0?]L00`3G
e`0me`030=OG03GG00<0emL03=L1007G000?e`030=OG00_G00<0emL0=]L00`3Ge`0ne`030=OG03gG
00<0emL0=]L00`3Ge`0;e`400ML000oG00<0emL02mL00`3Ge`0fe`030=OG03kG00<0emL0?ML00`3G
e`0fe`030=OG00_G0@01e`003mL00`3Ge`0;e`030=OG03KG00<0emL0?]L00`3Ge`0me`030=OG03KG
00<0emL02mL1007G000?e`030=OG00[G00<0emL0=mL00`3Ge`0ne`030=OG03gG00<0emL0=mL00`3G
e`0:e`400ML000oG00<0emL02]L00`3Ge`0ge`030=OG03kG00<0emL0?ML00`3Ge`0ge`030=OG00[G
0@01e`003mL00`3Ge`0:e`030=OG03OG00<0emL0?]L00`3Ge`0me`030=OG03OG00<0emL02]L1007G
000?e`802mL00`3Ge`0ge`030=OG03kG00<0emL0?ML00`3Ge`0he`030=OG00SG0P01e`003mL00`3G
e`09e`030=OG03SG00<0emL0?]L00`3Ge`0me`030=OG03SG00<0emL02ML1007G000?e`030=OG00WG
00<0emL0>=L00`3Ge`0ne`030=OG03gG00<0emL0>=L00`3Ge`09e`400ML000oG00<0emL02ML00`3G
e`0he`030=OG03kG00<0emL0?ML00`3Ge`0ie`030=OG00SG0@01e`003mL00`3Ge`08e`030=OG03WG
00<0emL0?]L00`3Ge`0me`030=OG03WG00<0emL02=L1007G000?e`030=OG00SG00<0emL0>ML00`3G
e`0ne`030=OG03gG00<0emL0>ML00`3Ge`08e`400ML000oG00<0emL02=L00`3Ge`0ie`030=OG03kG
00<0emL0?ML00`3Ge`0je`030=OG00OG0@01e`003mL00`3Ge`07e`030=OG03[G00<0emL0?]L00`3G
e`0me`030=OG03[G00<0emL01mL1007G000?e`030=OG00OG00<0emL0>]L00`3Ge`0ne`030=OG03gG
00<0emL0>]L00`3Ge`07e`400ML000oG00<0emL01mL00`3Ge`0je`030=OG03kG00<0emL0?ML00`3G
e`0je`030=OG00OG0@01e`003mL00`3Ge`07e`030=OG03[G00<0emL0?]L00`3Ge`0me`030=OG03_G
00<0emL01]L1007G000?e`030=OG00KG00<0emL0>mL00`3Ge`0ne`030=OG03gG00<0emL0>mL00`3G
e`06e`400ML000oG00<0emL01]L00`3Ge`0ke`030=OG03kG00<0emL0?ML00`3Ge`0ke`030=OG00KG
0@01e`003mL200OG00<0emL0>mL00`3Ge`0ne`030=OG03gG00<0emL0>mL00`3Ge`05e`800ML000oG
00<0emL01]L00`3Ge`0ke`030=OG03kG00<0emL0?ML00`3Ge`0ke`030=OG00KG0@01e`003mL00`3G
e`06e`030=OG03_G00<0emL0?]L00`3Ge`0me`030=OG03cG00<0emL01ML1007G000?e`030=OG00GG
00<0emL0?=L00`3Ge`0ne`030=OG03gG00<0emL0?=L00`3Ge`05e`400ML000oG00<0emL01ML00`3G
e`0le`030=OG03kG00<0emL0?ML00`3Ge`0le`030=OG00GG0@01e`003mL00`3Ge`05e`030=OG03cG
00<0emL0?]L00`3Ge`0me`030=OG03cG00<0emL01ML1007G000?e`030=OG00GG00<0emL0?=L00`3G
e`0ne`030=OG03gG00<0emL0?=L00`3Ge`05e`400ML000oG00<0emL01ML00`3Ge`0le`030=OG03kG
00<0emL0?ML00`3Ge`0le`030=OG00GG0@01e`003mL00`3Ge`05e`030=OG03cG00<0emL0?]L00`3G
e`0me`030=OG03cG00<0emL01ML1007G000?e`030=OG00GG00<0emL0?=L00`3Ge`0ne`030=OG03gG
00<0emL0?ML00`3Ge`04e`400ML000oG00<0emL01=L00`3Ge`0me`030=OG03kG00<0emL0?ML00`3G
e`0me`030=OG00CG0@01e`003mL00`3Ge`04e`030=OG03gG00<0emL0?]L00`3Ge`0me`030=OG03gG
00<0emL01=L1007G000?e`030=OG00CG00<0emL0?ML00`3Ge`0ne`030=OG03gG00<0emL0?ML00`3G
e`04e`400ML000oG0P05e`030=OG03gG00<0emL0?]L00`3Ge`0me`030=OG03gG00<0emL00mL2007G
000?e`030=OG00CG00<0emL0?ML00`3Ge`0ne`030=OG03gG00<0emL0?ML00`3Ge`04e`400ML000oG
00<0emL01=L00`3Ge`0me`030=OG03kG00<0emL0?ML00`3Ge`0me`030=OG00CG0@01e`003mL00`3G
e`04e`030=OG03gG00<0emL0?]L00`3Ge`0me`030=OG03gG00<0emL01=L1007G000?e`030=OG00CG
00<0emL0?ML00`3Ge`0ne`030=OG03gG00<0emL0?]L00`3Ge`03e`400ML000oG00<0emL01=L00`3G
e`0me`030=OG03kG00<0emL0?ML00`3Ge`0ne`030=OG00?G0@01e`003mL00`3Ge`04e`030=OG03gG
00<0emL0?]L00`3Ge`0me`030=OG03kG00<0emL00mL1007G000?e`030=OG00CG00<0emL0?ML00`3G
e`0ne`030=OG03gG00<0emL0?]L00`3Ge`03e`400ML000oG00<0emL00mL00`3Ge`0ne`030=OG03kG
00<0emL0?ML00`3Ge`0ne`030=OG00?G0@01e`003mL00`3Ge`03e`030=OG03kG00<0emL0?]L00`3G
e`0me`030=OG03kG00<0emL00mL1007G000?e`030=OG00?G00<0emL0?]L00`3Ge`0ne`030=OG03gG
00<0emL0?]L00`3Ge`03e`400ML000SG0P05e`030=OG00?G00<0emL0?]L00`3Ge`0ne`030=OG03cG
1@0me`030=OG00?G0@01e`001mL0103Ge`04e`030=OG00?G00<0emL0?]L00`3Ge`0ne`030=OG03cG
1@0me`030=OG00?G0@01e`001mL0103Ge`04eol04@01e`001mL0103Ge`04e`030=OG00?G00<0emL0
?]L00`3Ge`0ne`030=OG03cG1@0me`030=OG00?G0@01e`001mL0103Ge`04e`030=OG00?G00<0emL0
?]L00`3Ge`0ne`030=OG03cG1@0me`030=OG00?G0@01e`001mL0103Ge`04e`030=OG00?G00<0emL0
?]L00`3Ge`0ne`030=OG03gG0P0oe`030=OG00?G0@01e`002=L200GG00<0emL00mL00`3Ge`0ne`03
0=OG03kG00<0emL0?ML00`3Ge`0ne`030=OG00?G0@01e`003mL00`3Ge`03e`030=OG03kG00<0emL0
?]L00`3Ge`0me`030=OG03kG00<0emL00mL1007G000?e`030=OG00?G00<0emL0?]L00`3Ge`0ne`03
0=OG03gG00<0emL0?]L00`3Ge`03e`400ML000oG00<0emL01=L00`3Ge`0me`030=OG03kG00<0emL0
?ML00`3Ge`0ne`030=OG00?G0@01e`003mL00`3Ge`04e`030=OG03gG00<0emL0?]L00`3Ge`0me`03
0=OG03kG00<0emL00mL1007G000?e`030=OG00CG00<0emL0?ML00`3Ge`0ne`030=OG03gG00<0emL0
?]L00`3Ge`03e`400ML000oG00<0emL01=L00`3Ge`0me`030=OG03kG00<0emL0?ML00`3Ge`0ne`03
0=OG00?G0@01e`003mL00`3Ge`04e`030=OG03gG00<0emL0?]L00`3Ge`0le`D0?=L00`3Ge`04e`40
0ML000oG00<0emL01=L00`3Ge`0me`030=OG03kG00<0emL0?=L503cG00<0emL01=L1007G000?e`80
1ML00`3Ge`0me`030=OG03kG00<0emL0>mL603cG00<0emL00mL2007G000?e`030=OG00CG00<0emL0
?ML00`3Ge`0ne`030=OG03cG1@0le`030=OG00CG0@01e`003mL00`3Ge`04e`030=OG03gG00<0emL0
?]L00`3Ge`0le`D0?=L00`3Ge`04e`400ML000oG00<0emL01=L00`3Ge`0me`030=OG03kG00<0emL0
?ML203kG00<0emL01=L1007G000?e`030=OG00CG00<0emL0?ML00`3Ge`0ne`030=OG03gG00<0emL0
?ML00`3Ge`04e`400ML000oG00<0emL01ML00`3Ge`0le`030=OG03kG00<0emL0?ML00`3Ge`0me`03
0=OG00CG0@01e`003mL00`3Ge`05e`030=OG03cG00<0emL0?]L00`3Ge`0me`030=OG03cG00<0emL0
1ML1007G000?e`030=OG00GG00<0emL0?=L00`3Ge`0ne`030=OG03gG00<0emL0?=L00`3Ge`05e`40
0ML000oG00<0emL01ML00`3Ge`0le`030=OG03kG00<0emL0?ML00`3Ge`0le`030=OG00GG0@01e`00
3mL00`3Ge`05e`030=OG03cG00<0emL0?]L00`3Ge`0me`030=OG03cG00<0emL01ML1007G000?e`03
0=OG00GG00<0emL0?=L00`3Ge`0ne`030=OG03gG00<0emL0?=L00`3Ge`05e`400ML000oG00<0emL0
1]L00`3Ge`0ke`030=OG03kG00<0emL0?=L503_G00<0emL01ML1007G000?e`030=OG00KG00<0emL0
>mL00`3Ge`0ne`030=OG03cG1@0je`030=OG00KG0@01e`003mL200OG00<0emL0>mL00`3Ge`0ne`03
0=OG03_G1P0je`030=OG00GG0P01e`003mL00`3Ge`06e`030=OG03_G00<0emL0?]L00`3Ge`0le`D0
>]L00`3Ge`06e`400ML000oG00<0emL01]L00`3Ge`0ke`030=OG03kG00<0emL0?=L503[G00<0emL0
1]L1007G000?e`030=OG00OG00<0emL0>]L00`3Ge`0ne`030=OG03gG0P0le`030=OG00KG0@01e`00
3mL00`3Ge`07e`030=OG03[G00<0emL0?]L00`3Ge`0me`030=OG03[G00<0emL01mL1007G000?e`03
0=OG00OG00<0emL0>]L00`3Ge`0ne`030=OG03gG00<0emL0>]L00`3Ge`07e`400ML000oG00<0emL0
1mL00`3Ge`0je`030=OG03kG00<0emL0?ML00`3Ge`0je`030=OG00OG0@01e`003mL00`3Ge`07e`03
0=OG03[G00<0emL0?]L00`3Ge`0me`030=OG03[G00<0emL01mL1007G000?e`030=OG00SG00<0emL0
>ML00`3Ge`0ne`030=OG03gG00<0emL0>]L00`3Ge`07e`400ML000oG00<0emL02=L00`3Ge`0ie`03
0=OG03kG00<0emL0?ML00`3Ge`0ie`030=OG00SG0@01e`003mL00`3Ge`08e`030=OG03WG00<0emL0
?]L00`3Ge`0le`D0>=L00`3Ge`08e`400ML000oG00<0emL02ML00`3Ge`0he`030=OG03kG00<0emL0
?=L503SG00<0emL02=L1007G000?e`030=OG00WG00<0emL0>=L00`3Ge`0ne`030=OG03_G1P0ge`03
0=OG00WG0@01e`003mL200[G00<0emL0>=L00`3Ge`0ne`030=OG03cG1@0ge`030=OG00SG0P01e`00
3mL00`3Ge`0:e`030=OG03OG00<0emL0?]L00`3Ge`0le`D0=mL00`3Ge`09e`400ML000oG00<0emL0
2]L00`3Ge`0ge`030=OG03kG00<0emL0?ML203SG00<0emL02]L1007G000?e`030=OG00[G00<0emL0
=mL00`3Ge`0ne`030=OG03gG00<0emL0=mL00`3Ge`0:e`400ML000oG00<0emL02mL00`3Ge`0fe`03
0=OG03kG00<0emL0?ML00`3Ge`0fe`030=OG00_G0@01e`003mL00`3Ge`0;e`030=OG03KG00<0emL0
?]L00`3Ge`0me`030=OG03KG00<0emL02mL1007G000?e`030=OG00_G00<0emL0=]L00`3Ge`0ne`03
0=OG03gG00<0emL0=]L00`3Ge`0;e`400ML000oG00<0emL03=L00`3Ge`0ee`030=OG03kG00<0emL0
?ML00`3Ge`0ee`030=OG00cG0@01e`003mL00`3Ge`0<e`030=OG03GG00<0emL0?]L00`3Ge`0me`03
0=OG03GG00<0emL03=L1007G000?e`030=OG00gG00<0emL0==L00`3Ge`0ne`030=OG03gG00<0emL0
=ML00`3Ge`0<e`400ML000oG00<0emL03ML00`3Ge`0de`030=OG03kG00<0emL0?=L503?G00<0emL0
3ML1007G000?e`030=OG00kG00<0emL0<mL00`3Ge`0ne`030=OG03cG1@0ce`030=OG00gG0@01e`00
3mL00`3Ge`0>e`030=OG03?G00<0emL0?]L00`3Ge`0ke`H0<]L00`3Ge`0>e`400ML000oG0P0@e`03
0=OG03;G00<0emL0?]L00`3Ge`0le`D0<]L00`3Ge`0=e`800ML000oG00<0emL03mL00`3Ge`0be`03
0=OG03kG00<0emL0?=L5037G00<0emL03mL1007G000?e`030=OG00oG00<0emL0<]L00`3Ge`0ne`03
0=OG03gG0P0ce`030=OG00oG0@01e`003mL00`3Ge`0@e`030=OG037G00<0emL0?]L00`3Ge`0me`03
0=OG037G00<0emL04=L1007G000?e`030=OG013G00<0emL0<ML00`3Ge`0ne`030=OG03gG00<0emL0
<ML00`3Ge`0@e`400ML000oG00<0emL04ML00`3Ge`0`e`030=OG03kG00<0emL0?ML00`3Ge`0ae`03
0=OG013G0@01e`003mL00`3Ge`0Ae`030=OG033G00<0emL0?]L00`3Ge`0me`030=OG033G00<0emL0
4ML1007G000?e`030=OG01;G00<0emL0;mL00`3Ge`0ne`030=OG03gG00<0emL0<=L00`3Ge`0Ae`40
0ML000oG00<0emL04]L00`3Ge`0_e`030=OG03kG00<0emL0?ML00`3Ge`0_e`030=OG01;G0@01e`00
3mL00`3Ge`0Ce`030=OG02kG00<0emL0?]L00`3Ge`0me`030=OG02oG00<0emL04]L1007G000?e`03
0=OG01?G00<0emL0;]L00`3Ge`0ne`030=OG03cG1@0]e`030=OG01?G0@01e`001mL400CG00<0emL0
5=L00`3Ge`0]e`030=OG03kG00<0emL0?=L502gG00<0emL04mL1007G0009e`030=OG00?G00<0emL0
5=L00`3Ge`0]e`030=OG03kG00<0emL0>mL602cG00<0emL05=L1007G0009e`030=OG00?G0`0Ee`03
0=OG02cGQ@0/e`030=OG01?G0P01e`002ML00`3Ge`03e`030=OG01GG00<0emL0KML00`3Ge`0le`D0
:mL00`3Ge`0Ee`400ML000WG00<0emL00mL00`3Ge`0Fe`030=OG06cG00<0emL0?]L00`3Ge`0[e`03
0=OG01GG0@01e`001mL300GG00<0emL05]L00`3Ge`1/e`030=OG06_G00<0emL05]L1007G0009e`03
0=OG00?G00<0emL05mL00`3Ge`1[e`030=OG06[G00<0emL05mL1007G000?e`030=OG01SG00<0emL0
J]L00`3Ge`1Ye`030=OG01SG0@01e`003mL00`3Ge`0Ie`030=OG06WG00<0emL0J=L00`3Ge`0Ie`40
0ML000oG00<0emL06ML00`3Ge`1Ye`030=OG06SG00<0emL06ML1007G000?e`030=OG01[G00<0emL0
J=L00`3Ge`1We`030=OG01[G0@01e`003mL00`3Ge`0Ke`030=OG06OG00<0emL0ImL00`3Ge`0Je`40
0ML000oG00<0emL06mL00`3Ge`1We`030=OG06KG00<0emL06mL1007G000?e`030=OG01cG00<0emL0
I]L00`3Ge`1Ve`030=OG01_G0@01e`003mL00`3Ge`0Me`030=OG06GG00<0emL0IML00`3Ge`0Le`40
0ML000oG0P0Oe`030=OG06CG00<0emL0I=L00`3Ge`0Le`800ML000oG00<0emL07mL00`3Ge`1Se`03
0=OG06?G00<0emL07]L1007G000?e`030=OG01oG00<0emL0HmL00`3Ge`1Se`030=OG01kG0@01e`00
3mL00`3Ge`0Pe`030=OG06;G00<0emL0H]L00`3Ge`0Oe`400ML000oG00<0emL08ML00`3Ge`1Qe`03
0=OG067G00<0emL08=L1007G000?e`030=OG02;G00<0emL0H=L00`3Ge`1Pe`030=OG027G0@01e`00
3mL00`3Ge`0Se`030=OG05oG00<0emL0GmL00`3Ge`0Re`400ML000oG00<0emL08mL00`3Ge`1Oe`03
0=OG05oG00<0emL08]L1007G000?e`030=OG02CG00<0emL0G]L00`3Ge`1Ne`030=OG02?G0@01e`00
3mL00`3Ge`0Ue`030=OG05gG00<0emL0G=L202KG0@01e`003mL00`3Ge`0Ve`030=OG05cG00<0emL0
FmL00`3Ge`0Ve`400ML000oG00<0emL09mL00`3Ge`1Ke`030=OG05[G00<0emL09mL1007G000?e`03
0=OG02SG00<0emL0F]L00`3Ge`1Ie`030=OG02SG0@01e`003mL202[G00<0emL0FML00`3Ge`1He`03
0=OG02SG0P01e`003mL00`3Ge`0Ye`030=OG05WG00<0emL0F=L00`3Ge`0Ye`400ML000oG00<0emL0
:]L00`3Ge`1He`030=OG05OG00<0emL0:]L1007G000?e`030=OG02_G0P1He`030=OG05KG00<0emL0
:mL1007G000?e`030=OG02gG00<0emL0EML00`3Ge`1Ee`030=OG02cG0@01e`003mL00`3Ge`0^e`03
0=OG05CG00<0emL0DmL202oG0@01e`003mL00`3Ge`0_e`030=OG05?G00<0emL0D]L00`3Ge`0_e`40
0ML000oG00<0emL0<=L205?G00<0emL0DML00`3Ge`0`e`400ML000oG00<0emL0<]L00`3Ge`1@e`03
0=OG053G00<0emL0<ML1007G000?e`030=OG03?G00<0emL0CmL00`3Ge`1>e`80==L1007G000?e`03
0=OG03CG00<0emL0C]L00`3Ge`1=e`030=OG03CG0@01e`003mL00`3Ge`0ee`80C]L00`3Ge`1<e`03
0=OG03GG0@01e`003mL00`3Ge`0ge`030=OG04_G00<0emL0BmL00`3Ge`0fe`400ML000oG0P0ie`03
0=OG04[G00<0emL0BML203SG0P01e`003mL00`3Ge`0ie`030=OG04WG00<0emL0B=L00`3Ge`0ie`40
0ML000oG00<0emL0>]L204WG00<0emL0A]L203cG0@01e`003mL00`3Ge`0le`030=OG04KG00<0emL0
AML00`3Ge`0le`400ML000oG00<0emL0?ML00`3Ge`15e`030=OG04CG00<0emL0?ML1007G000?e`03
0=OG03kG0P15e`030=OG04?G00<0emL0?]L1007G000?e`030=OG043G0P13e`030=OG047G0P11e`40
0ML000oG00<0emL0@]L2047G00<0emL0?mL204?G0@01e`003mL00`3Ge`14e`030=OG03kG00<0emL0
?ML204GG0@01e`003mL00`3Ge`15e`80?]L00`3Ge`0ke`80AmL1007G000?e`030=OG04OG0P0le`03
0=OG03[G00<0emL0AmL1007G000?e`030=OG04WG0P0je`030=OG03SG0P1:e`400ML000oG00<0emL0
BmL203SG00<0emL0=]L204cG0@01e`003mL204kG00<0emL0=ML00`3Ge`0de`80CML2007G000?e`03
0=OG04kG0`0de`030=OG037G0`1@e`400ML000oG00<0emL0DML203;G00<0emL0;mL205?G0@01e`00
3mL00`3Ge`1Ce`80<=L00`3Ge`0]e`80EML1007G000?e`030=OG05GG0P0^e`030=OG02_G0P1Ge`40
0ML000oG00<0emL0EmL402[G00<0emL0:=L305WG0@01e`003mL00`3Ge`1Ke`<09mL00`3Ge`0Te`@0
G=L1007G000?e`030=OG05kG0`0Te`030=OG027G0`1Pe`400ML000oG00<0emL0HML501oG00<0emL0
7ML406?G0@01e`003mL00`3Ge`1Ve`<07=L00`3Ge`0Ie`@0ImL1007G0007e`@01=L00`3Ge`1Ye`D0
5mL00`3Ge`0Ee`@0JmL1007G0007e`030=OG00GG00<0emL0K]L800oG00<0emL03ML806oG0@01e`00
2=L00`3Ge`04e`<0M]LO07KG0P01e`002ML00`3Ge`03e`030=OG08GG00<0emL0Q=L1007G000:e`03
0=OG00;G00<0emL0QML00`3Ge`24e`400ML000OG00@0emL01=L00`3Ge`25e`030=OG08CG0@01e`00
2=L200GG00<0emL0QML00`3Ge`24e`400ML000oG00<0emL00mL00`3Ge`0ne`030=OG03kG00<0emL0
?ML00`3Ge`0ne`030=OG00?G0@01e`003mL00`3Ge`03e`030=OG00[G00<0emL02]L00`3Ge`0:e`03
0=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL0
2]L00`3Ge`09e`030=OG00[G00<0emL02]L00`3Ge`0:e`030=OG00[G00<0emL02]L00`3Ge`0:e`03
0=OG00[G00<0emL02]L00`3Ge`03e`400ML000oGo`0A007G003oeb7G0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.33817, -2.31593, 0.0154708, \
0.0154708}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Step\ 2 : \ 
        transformation\ to\ polar\ coordinates\ and\ using\ the\ solution\ in\
\ these\ coordinates\ *) \)\(\n\)\(Clear[U, c0, c]; 
    Table[r[i] = Sqrt[x[i]^2 + y[i]^2], {i, 1, 6}]; 
    Table[\[CurlyPhi][i] = ArcTan[x[i], y[i]], {i, 1, 6}] /; 
      ArcTan[x[i], y[i]] \[GreaterEqual] 0; 
    U[r[i], \[CurlyPhi][i]] = \(-c0\)*Log[r[i]/R] + 
        Sum[c[n]*\((r[i]^n - R^\((2*n)\)*r[i]^\((\(-n\))\))\)*
            Cos[n*\[CurlyPhi][i]], {n, 5}]\)\)\)], "Input"],

Cell[BoxData[
    \(\(-c0\)\ Log[r[i]\/R] + 
      c[1]\ Cos[\[CurlyPhi][i]]\ \((\(-\(R\^2\/r[i]\)\) + r[i])\) + 
      c[2]\ Cos[2\ \[CurlyPhi][i]]\ \((\(-\(R\^4\/r[i]\^2\)\) + r[i]\^2)\) + 
      c[3]\ Cos[3\ \[CurlyPhi][i]]\ \((\(-\(R\^6\/r[i]\^3\)\) + r[i]\^3)\) + 
      c[4]\ Cos[4\ \[CurlyPhi][i]]\ \((\(-\(R\^8\/r[i]\^4\)\) + r[i]\^4)\) + 
      c[5]\ Cos[
          5\ \[CurlyPhi][i]]\ \((\(-\(R\^10\/r[i]\^5\)\) + 
            r[i]\^5)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Step\ 3 : \ 
        define\ the\ matrix\ and\ solve\ the\ linear\ system\ for\ the\ \
partial\ amplitudes\ c\ *) \)\(\n\)\(M = Table[k*l, {k, 1, 6}, {l, 1, 6}]; 
    M = Table[{\(-Log[r[i]/R]\), 
          Cos[\[CurlyPhi][i]]*\((\(-R^2\)/r[i] + r[i])\), 
          Cos[2*\[CurlyPhi][i]]*\((\(-R^4\)/r[i]^2 + r[i]^2)\), 
          Cos[3*\[CurlyPhi][i]]*\((\(-R^6\)/r[i]^3 + r[i]^3)\), 
          Cos[4*\[CurlyPhi][i]]*\((\(-R^8\)/r[i]^4 + r[i]^4)\), 
          Cos[5*\[CurlyPhi][i]]*\((\(-R^10\)/r[i]^5 + r[i]^5)\)}, {i, 1, 6}]; 
    R = 1. ; U0 = 10; MatrixForm[M]; b = {U0, U0, U0, U0, U0, U0}; 
    B = LinearSolve[M, b]\)\)\)], "Input"],

Cell[BoxData[
    \({\(-3.380196202715362`*^11\), \(-2.8547071041691095`*^11\), 
      8.487964482400444`*^10, \(-2.266248387694368`*^10\), 
      4.1363773763321733`*^9, \(-3.7129944777686316`*^8\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(c0 = \(-3.380196202715362`*^11\); c[1] = \(-2.8547071041691095`*^11\); 
    c[2] = 8.487964482400444`*^10; c[3] = \(-2.266248387694368`*^10\); 
    c[4] = 4.1363773763321733`*^9; 
    c[5] = \(-3.7129944777686316`*^8\);\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\n\)\( (*\ 
      Step\ 4 : \ 
        define\ the\ amplitudes\ and\ check\ the\ satisfaction\ of\ both\ \
boundary\ values\ *) \)\(\n\)\(V[r_, \[CurlyPhi]_] = \(-c0\)*Log[r/R] + 
        Sum[c[n]*\((r^n - R^\((2*n)\)*r^\((\(-n\))\))\)*
            Cos[n*\[CurlyPhi]], {n, 5}]; 
    Table[V[r[i], \[CurlyPhi][i]], {i, 1, 6}]\)\)\)], "Input"],

Cell[BoxData[
    \({10.`, 9.999999046325684`, 10.`, 10.000007629394531`, 10.`, 
      10.`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[V[R, \[CurlyPhi][i]], {i, 1, 6}]\)], "Input"],

Cell[BoxData[
    \({0.`, 0.`, 0.`, 0.`, 0.`, 0.`}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1006, 640},
WindowMargins->{{34, Automatic}, {Automatic, 70}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 1142, 20, 285, "Input"],
Cell[2872, 74, 23169, 606, 296, 4245, 368, "GraphicsData", "PostScript", \
"Graphics"],
Cell[26044, 682, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26211, 690, 516, 10, 147, "Input"],
Cell[26730, 702, 461, 8, 175, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27228, 715, 676, 12, 193, "Input"],
Cell[27907, 729, 213, 3, 69, "Output"]
}, Open  ]],
Cell[28135, 735, 252, 4, 101, "Input"],

Cell[CellGroupData[{
Cell[28412, 743, 365, 7, 124, "Input"],
Cell[28780, 752, 106, 2, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28923, 759, 71, 1, 32, "Input"],
Cell[28997, 762, 64, 1, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

