(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    869336,      22450]*)
(*NotebookOutlinePosition[    869967,      22472]*)
(*  CellTagsIndexPosition[    869923,      22468]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(\( (*\ 
      c47 : \ Membrane\ with\ an\ homogeneous\ boundary\ condition\ on\ an\ \
inner\ circle\ and\ an\ inhomogeneous\ outer\ boundary\ condition\ on\ a\ \
rectangle*) \)\(\n\)\( (*\ 
      Step\ 1 : \ define\ collocation\ points*) \)\(\(n = 18;\)\n
     (*on\ inner\ circle*) \(Clear[x, y, n, f, r];\)\n
    x[1] = 0.5; \ y[1] = 0. ; \ x[2] = 0.45; \ y[2] = Sqrt[0.5^2 - x[2]^2];\n
    x[3] = 0.35; y[3] = Sqrt[0.5^2 - x[3]^2]; x[4] = 0.15;\n
    \(y[4] = Sqrt[0.5^2 - x[4]^2];\)\n
    x[5] = 0; \ y[5] = 0.5; x[6] = \(-x[4]\); \ y[6] = y[4];\n
    x[7] = \(-x[3]\); \ y[7] = y[3]; x[8] = \(-x[2]\); \ y[8] = y[2];\n
    x[9] = \(-x[1]\); \ y[9] = 0. ;\n (*\ on\ rectangle\ *) \n
    x[10] = 2. ; \ \ \ y[10] = 0. ; x[11] = 2. ; \ \ \ y[11] = 0.5;\n
    x[12] = 2. ; \ \ \ y[12] = 1. ; x[13] = 1. ; \ \ \ y[13] = 1. ;\n
    x[14] = 0. ; \ \ \ y[14] = 1. ; x[15] = \(-1. \); \ \ y[15] = 1. ;\n
    x[16] = \(-2. \); \ \ y[16] = 1. ; x[17] = \(-2. \); \ \ y[17] = 0.5;\n
    x[18] = \(-2.0\); \ y[18] = 0. ; n = 18;\n
    \(Table[f[l] = N[ArcTan[x[l], y[l]]], {l, 1, n}];\)\n
    \(Table[r[l] = N[Sqrt[x[l]^2 + y[l]^2]], {l, 1, n}];\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Clear[p1];p1=ListPlot[Table[{x[l],y[l]},{l,1,n}],
PlotStyle->PointSize[1/40],AspectRatio->0.5,
PlotRange->{{-2.,2.},{0.,2.}}];\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0 0.25 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .0625 -24 -4.5 ]
[.4875 .0625 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .1875 -24 -4.5 ]
[.4875 .1875 0 4.5 ]
[.4875 .25 -6 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .3125 -24 -4.5 ]
[.4875 .3125 0 4.5 ]
[.4875 .375 -18 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .4375 -24 -4.5 ]
[.4875 .4375 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-2)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-1.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.5)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .0625 m
.50625 .0625 L
s
[(0.25)] .4875 .0625 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(0.5)] .4875 .125 1 0 Mshowa
.5 .1875 m
.50625 .1875 L
s
[(0.75)] .4875 .1875 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1)] .4875 .25 1 0 Mshowa
.5 .3125 m
.50625 .3125 L
s
[(1.25)] .4875 .3125 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(1.5)] .4875 .375 1 0 Mshowa
.5 .4375 m
.50625 .4375 L
s
[(1.75)] .4875 .4375 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(2)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .0125 m
.50375 .0125 L
s
.5 .025 m
.50375 .025 L
s
.5 .0375 m
.50375 .0375 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .0875 m
.50375 .0875 L
s
.5 .1 m
.50375 .1 L
s
.5 .1125 m
.50375 .1125 L
s
.5 .1375 m
.50375 .1375 L
s
.5 .15 m
.50375 .15 L
s
.5 .1625 m
.50375 .1625 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .2125 m
.50375 .2125 L
s
.5 .225 m
.50375 .225 L
s
.5 .2375 m
.50375 .2375 L
s
.5 .2625 m
.50375 .2625 L
s
.5 .275 m
.50375 .275 L
s
.5 .2875 m
.50375 .2875 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .3375 m
.50375 .3375 L
s
.5 .35 m
.50375 .35 L
s
.5 .3625 m
.50375 .3625 L
s
.5 .3875 m
.50375 .3875 L
s
.5 .4 m
.50375 .4 L
s
.5 .4125 m
.50375 .4125 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .4625 m
.50375 .4625 L
s
.5 .475 m
.50375 .475 L
s
.5 .4875 m
.50375 .4875 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.025 w
.625 0 Mdot
.6125 .05449 Mdot
.5875 .08927 Mdot
.5375 .11924 Mdot
.5 .125 Mdot
.4625 .11924 Mdot
.4125 .08927 Mdot
.3875 .05449 Mdot
.375 0 Mdot
1 0 Mdot
1 .125 Mdot
1 .25 Mdot
.75 .25 Mdot
.5 .25 Mdot
.25 .25 Mdot
0 .25 Mdot
0 .125 Mdot
0 0 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML001?G100Fe`@00mL00`3G
e`02e`<05]L401OG0P04e`030=OG00;G0`0^e`801=L00`3Ge`02e`<05mL401GG1003e`030=OG00;G
0`0Ge`@03mL001?G00<0emL06ML00`3Ge`0:e`030=OG01GG00<0emL05ML0103Ge`0;e`030=OG02[G
00@0emL02mL00`3Ge`0Fe`030=OG01KG00<0emL02]L00`3Ge`0De`030=OG013G000De`030=OG01SG
00<0emL02]L00`3Ge`0Ee`030=OG01GG00@0emL02mL00`3Ge`0Ze`040=OG00_G00<0emL05]L00`3G
e`0Fe`030=OG00[G00<0emL05ML00`3Ge`0?e`003ML400CG00<0emL03mL400CG00<0emL01mL3013G
1004e`030=OG00oG1002e`040=OG00SG0`0]e`040=OG00SG0`0Ie`030=OG01KG00<0emL01mL301WG
00<0emL03]L001KG00<0emL05]L00`3Ge`07e`030=OG01SG00<0emL05ML0103Ge`08e`030=OG02gG
00@0emL02=L00`3Ge`0Ie`030=OG01KG00<0emL01mL00`3Ge`0Je`030=OG00gG000Ce`040=OG01KG
0`09e`030=OG01KG0`0Ge`040=OG00SG00<0emL0;ML0103Ge`08e`030=OG01OG0`0Fe`<02ML00`3G
e`0Ge`040=OG00oG000De`806ML00`3Ge`07e`@05mL00`3Ge`0Fe`802ML402gG0P09e`@06=L00`3G
e`0Fe`030=OG00OG100Ge`804=L00?oG8ML0017G1@1Ie`D0>]L505[G1@0>e`004ML505WG1@0je`D0
F]L500kG000@e`H0F=L603WG1P1Ie`H03]L0017Go`0200kG000Ae`D00]L00`3Ge`04e`030=OG00?G
00<0emL00mL00`3Ge`04e`030=OG00?G00<0emL00mL00`3Ge`04e`030=OG00?G00<0emL00mL00`3G
e`04e`030=OG00?G00<0emL00mL00`3Ge`04e`040=OGe`D00mL00`3Ge`04e`030=OG00?G00<0emL0
0mL00`3Ge`04e`030=OG00?G00<0emL00mL00`3Ge`03e`030=OG00CG00@0emOG1@03e`030=OG00CG
00<0emL00mL00`3Ge`03e`030=OG00CG00<0emL00mL00`3Ge`03e`030=OG00CG00<0emL00mL00`3G
e`03e`030=OG00CG00<0emL00mL00`3Ge`03e`030=OG00CG00@0emOG1@0>e`004mL00`3Ge`1Ke`03
0=OG01gG00<0emL07=L00`3Ge`1Le`030=OG00kG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`03
0=OG08cG001be`D06]L00`3Ge`0Ge`D0L=L007;G1@0Je`030=OG01OG1@1`e`00LML800CG00<0emL0
0]L400;G0`06e`030=OG01KG1P1`e`00L]L500;G00<0emL01]L00`3Ge`06e`030=OG00?G00<0emL0
5mL5073G001be`D00]L00`3Ge`07e`030=OG00GG00<0emL00mL201SG1@1`e`00M=L00`3G0002e`03
0=OG00SG00@0emOG0`06e`030=OG01WG00<0emL0L=L007KG00@0emL02mL0103Ge`08e`030=OG08cG
001fe`040=OG00SG00@0emL00]L00`3Ge`06e`030=OG08cG001ge`802]L200?G1005e`030=OG08cG
001ie`D04mL00`3Ge`0Ae`D0M]L007WG1@0Ce`030=OG017G1@1fe`00N=L601?G00<0emL04=L607KG
001ie`D04mL00`3Ge`0Ae`D0M]L007WG1@0Ce`030=OG017G1@1fe`00NmL00`3Ge`0Ce`030=OG01?G
00<0emL0M]L0097G00<0emL0S=L008GG1@07e`030=OG00CG1@23e`00QML500OG00<0emL01=L508?G
000Ae`D0ImL200CG2004e`D00mL6073G1@0>e`004ML506KG00@0emL01ML50003e`3G00;G1@04e`D0
L=L500kG000@e`H0I]L0103Ge`05e`D000CG0=OG1P04e`D0KmL600kG000Ae`D0I]L0103Ge`07e`@0
1=L500KG00<0emL0L=L500kG000Ae`D0I]L0103Ge`08e`030=OG00CG1@1ie`D03]L001?G00<0emL0
I]L0103Ge`08e`030=OG00KG00<0emL0NmL00`3Ge`0>e`00OML200WG1005e`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG001ge`801=L00`3Ge`03e`03
0=OG00;G0`06e`030=OG08cG001fe`040=OG00WG00<0emL01ML00`3Ge`03e`030=OG08cG001fe`04
0=OG00[G00<0emL01=L00`3Ge`03e`80SML007KG00@0emL02]L0103GemL300KG00<0emL0S=L007KG
00@0emL02mL0103Ge`08e`030=OG08cG001fe`040=OG00SG00@0emL00]L00`3Ge`06e`030=OG08cG
001ge`802ML400;G1005e`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG
002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG
000Ae`D0>]L503[G1@0je`D0>]L500kG000Ae`D0>]L503?G1003e`D0>]L503[G1@0>e`004=L603WG
1P0ee`040=OGe`H0>ML603WG1P0>e`004ML503[G1@0ee`030=OG00;G1@0je`D0>]L500kG000Ae`D0
>]L503GG00<0emL00]L503[G1@0je`D03]L001?G00<0emL0?=L00`3Ge`0ee`030=OG00CG00<0emL0
?=L00`3Ge`0le`030=OG00kG0028e`<01]L00`3Ge`2<e`00R]L00`3Ge`04e`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG001fe`@00mL00`3Ge`02e`@0
0]L300KG00<0emL0S=L007SG00<0emL01mL00`3Ge`06e`030=OG00?G00<0emL0S=L007SG00<0emL0
2=L00`3Ge`05e`030=OG00?G0P2=e`00N=L00`3Ge`09e`040=OGe`<01]L00`3Ge`2<e`00N=L00`3G
e`0:e`040=OG00SG00<0emL0S=L007KG0`09e`040=OG00;G00<0emL01]L00`3Ge`2<e`00N=L00`3G
e`08e`800mL400GG00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G
00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L007cG
1003e`030=OG00;G0`06e`030=OG08cG001ne`030=OG00[G00<0emL00mL00`3Ge`2<e`00O]L00`3G
e`0:e`030=OG00?G0P2=e`00O]L00`3Ge`07e`<01]L00`3Ge`2<e`00O]L00`3Ge`07e`030=OG00KG
00<0emL0S=L007cG0`09e`030=OG00KG00<0emL0S=L007kG00<0emL01mL400GG00<0emL0S=L0097G
00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G
00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L007KG1003e`030=OG00?G
00<0emL00]L300KG00<0emL0S=L007SG00<0emL02=L00`3Ge`05e`030=OG00?G00<0emL0S=L007SG
00<0emL02ML00`3Ge`04e`030=OG00?G0P2=e`00N=L00`3Ge`09e`040=OGe`<01]L00`3Ge`2<e`00
N=L00`3Ge`0:e`040=OG00SG00<0emL0S=L007KG0`09e`040=OG00;G00<0emL01]L00`3Ge`2<e`00
N=L00`3Ge`07e`@00]L400GG00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0
S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0
S=L0097G00<0emL0S=L008SG1005e`030=OG08cG0028e`030=OG00KG00<0emL0S=L008WG00<0emL0
1ML208gG002:e`030=OG09?G002;e`030=OG09;G0028e`040=OG09CG0029e`80UML00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-2.29539, -0.192483, 0.0158303, \
0.0158303}}]
}, Open  ]],

Cell["\<\
(* Step 2: define matrix m to be filled later*)Clear[m];
m=Table[i*j,{i,1,n},{j,1,n}];
Table[m[[l,k]]=BesselJ[(k/2-1/2),r[l]]*
Cos[(k/2-1/2)*f[l]],{l,1,n},{k,1,n,2}];
Table[m[[l,k]]=BesselY[(k/2-1),r[l]]*
Cos[(k/2-1)*f[l]],{l,1,n},{k,2,n,2}];\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell["\<\

MatrixForm[m];\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[m]\)], "Input"],

Cell[BoxData[
    \(1.0255733117137`*^16\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(* Step 3: define boundary values and solve linear equ. *)
Clear[b,kolist,A];
b={0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1};
LinearSolve[m,b];
kolist=% ;
Table[A[k]=kolist[[k]],{k,1,n}];\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \(LinearSolve::"luc" \(\(:\)\(\ \)\) 
      "Result for \!\(LinearSolve\) of badly conditioned matrix \
\!\({\(\({0.9384698072408131`, \(\(\[LeftSkeleton] 16 \[RightSkeleton]\)\), \
\(\(-1.060818575158798`*^8\)\)}\)\), \(\(\[LeftSkeleton] 17 \
\[RightSkeleton]\)\)}\) may contain significant numerical errors."\)], \
"Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(* Step 4: verify satisfaction of boundary conditions \
*)Clear[r,f,g1,g2,g];
r[x_,y_]:=N[Sqrt[x^2+y^2]]
f[x_,y_]:=N[ArcTan[x,y]]
g1[x_,y_]:=Sum[A[k]*BesselJ[(k/2-1/2),r[x,y]]*
Cos[(k/2-1/2)*f[x,y]],{k,1,n-1,2}] ;
g2[x_,y_]:=Sum[A[k]*BesselY[(k/2-1),r[x,y]]
*Cos[(k/2-1)*f[x,y]],{k,2,n,2}]; 
g[x_,y_]:=g1[x,y]+g2[x,y](*/; x^2+y^2>=1*)

Table[g[x[i],y[i]],{i,1,n}]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \({0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 1.0000000000000002`, 1.`, 
      1.`, 1.`, 1.0000000000000002`, 1.`, 1.0000000000000002`, 
      0.9999999999999998`, 1.0000000000000002`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[0.45, 0.2]\)], "Input",
  FontSize->18],

Cell[BoxData[
    \(\(-0.01785780143409854`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[p2]; 
    p2 = ContourPlot[
        g[x, y], {x, \(-2.0\), 2.0}, \[IndentingNewLine]{y, \(-1.0\), 
          1.0}, \[IndentingNewLine]ContourShading -> False, 
        ContourSmoothing -> 2, \[IndentingNewLine]PlotPoints -> 30, 
        Contours -> {0}, AspectRatio -> 0.5]\)], "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.25 0.240385 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -6 -9 ]
[.25962 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00962 -12 -4.5 ]
[-0.0125 .00962 0 4.5 ]
[-0.0125 .12981 -24 -4.5 ]
[-0.0125 .12981 0 4.5 ]
[-0.0125 .25 -6 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .37019 -18 -4.5 ]
[-0.0125 .37019 0 4.5 ]
[-0.0125 .49038 -6 -4.5 ]
[-0.0125 .49038 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-1)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(1)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(2)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00962 m
.00625 .00962 L
s
[(-1)] -0.0125 .00962 1 0 Mshowa
0 .12981 m
.00625 .12981 L
s
[(-0.5)] -0.0125 .12981 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0)] -0.0125 .25 1 0 Mshowa
0 .37019 m
.00625 .37019 L
s
[(0.5)] -0.0125 .37019 1 0 Mshowa
0 .49038 m
.00625 .49038 L
s
[(1)] -0.0125 .49038 1 0 Mshowa
.125 Mabswid
0 .03365 m
.00375 .03365 L
s
0 .05769 m
.00375 .05769 L
s
0 .08173 m
.00375 .08173 L
s
0 .10577 m
.00375 .10577 L
s
0 .15385 m
.00375 .15385 L
s
0 .17788 m
.00375 .17788 L
s
0 .20192 m
.00375 .20192 L
s
0 .22596 m
.00375 .22596 L
s
0 .27404 m
.00375 .27404 L
s
0 .29808 m
.00375 .29808 L
s
0 .32212 m
.00375 .32212 L
s
0 .34615 m
.00375 .34615 L
s
0 .39423 m
.00375 .39423 L
s
0 .41827 m
.00375 .41827 L
s
0 .44231 m
.00375 .44231 L
s
0 .46635 m
.00375 .46635 L
s
.25 Mabswid
0 0 m
0 .5 L
s
.01923 .49375 m
.01923 .5 L
s
.25962 .49375 m
.25962 .5 L
s
.5 .49375 m
.5 .5 L
s
.74038 .49375 m
.74038 .5 L
s
.98077 .49375 m
.98077 .5 L
s
.125 Mabswid
.06731 .49625 m
.06731 .5 L
s
.11538 .49625 m
.11538 .5 L
s
.16346 .49625 m
.16346 .5 L
s
.21154 .49625 m
.21154 .5 L
s
.30769 .49625 m
.30769 .5 L
s
.35577 .49625 m
.35577 .5 L
s
.40385 .49625 m
.40385 .5 L
s
.45192 .49625 m
.45192 .5 L
s
.54808 .49625 m
.54808 .5 L
s
.59615 .49625 m
.59615 .5 L
s
.64423 .49625 m
.64423 .5 L
s
.69231 .49625 m
.69231 .5 L
s
.78846 .49625 m
.78846 .5 L
s
.83654 .49625 m
.83654 .5 L
s
.88462 .49625 m
.88462 .5 L
s
.93269 .49625 m
.93269 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 .00962 m
1 .00962 L
s
.99375 .12981 m
1 .12981 L
s
.99375 .25 m
1 .25 L
s
.99375 .37019 m
1 .37019 L
s
.99375 .49038 m
1 .49038 L
s
.125 Mabswid
.99625 .03365 m
1 .03365 L
s
.99625 .05769 m
1 .05769 L
s
.99625 .08173 m
1 .08173 L
s
.99625 .10577 m
1 .10577 L
s
.99625 .15385 m
1 .15385 L
s
.99625 .17788 m
1 .17788 L
s
.99625 .20192 m
1 .20192 L
s
.99625 .22596 m
1 .22596 L
s
.99625 .27404 m
1 .27404 L
s
.99625 .29808 m
1 .29808 L
s
.99625 .32212 m
1 .32212 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .39423 m
1 .39423 L
s
.99625 .41827 m
1 .41827 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .46635 m
1 .46635 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.45027 .14058 m
.48342 .13096 L
.51658 .13096 L
.54973 .14058 L
.55354 .14224 L
.57851 .15882 L
.58289 .16295 L
.59422 .1754 L
.60522 .19198 L
.61281 .20855 L
.61605 .21789 L
.61758 .22513 L
.61988 .24171 L
.61988 .25829 L
.61758 .27487 L
.61605 .28211 L
.61281 .29145 L
.60522 .30802 L
.59422 .3246 L
.58289 .33705 L
.57851 .34118 L
.55354 .35776 L
.54973 .35942 L
.51658 .36904 L
.48342 .36904 L
.45027 .35942 L
.44646 .35776 L
.42149 .34118 L
.41711 .33705 L
.40578 .3246 L
.39478 .30802 L
.38719 .29145 L
.38395 .28211 L
.38242 .27487 L
.38012 .25829 L
.38012 .24171 L
.38242 .22513 L
.38395 .21789 L
.38719 .20855 L
.39478 .19198 L
.40578 .1754 L
.41711 .16295 L
.42149 .15882 L
.44646 .14224 L
.45027 .14058 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML002;G100je`@0>=L203[G
100je`@01]L002;G00<0emL0?ML00`3Ge`0fe`040=OG03_G00<0emL0>ML00`3Ge`07e`008mL00`3G
e`0le`030=OG03KG00@0emL0>mL00`3Ge`0je`030=OG00KG000Le`@01=L00`3Ge`0ce`@01=L00`3G
e`0fe`040=OG03_G00<0emL0>mL00`3Ge`05e`009ML00`3Ge`0je`030=OG03KG00@0emL0>mL00`3G
e`0le`030=OG00CG000Re`040=OG03[G0`0he`040=OG03WG0`0ke`040=OG00KG000Se`80?ML00`3G
e`0ge`80?=L00`3Ge`0je`801mL00?oG8ML00?oG8ML00?oG8ML00?oG8ML001CG1004eol00`02e`00
5]L00`3Ge`03e`030=OG00;G00<0emL02ML00`3Ge`0:e`030=OG00WG00<0emL02ML00`3Ge`0:e`03
0=OG00WG00<0emL02ML00`3Ge`0:e`030=OG00WG00<0emL02]L00`3Ge`09e`030=OG00WG00<0emL0
2]L00`3Ge`09e`030=OG00WG00<0emL02]L00`3Ge`09e`030=OG00[G00<0emL02ML00`3Ge`09e`03
0=OG00;G0@01e`7G000Fe`030=OG00?G0P3ne`800]L000kG1004e`030=OG00?G00<0emL0o]L1007G
0ML001KG00<0emL00mL00`3Ge`3ne`400ML1e`005=L300GG00<0emL0o]L1007G0ML001KG00<0emL0
0mL00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`007=L20?kG0P02e`007=L00`3Ge`3ne`40
0ML1e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`00
7=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`007=L20?kG0P02e`007=L00`3Ge`3ne`40
0ML1e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`00
7=L00`3Ge`3ne`400ML1e`007=L20?kG0P02e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`40
0ML1e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`00
7=L20?kG0P02e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`400ML1e`007=L00`3Ge`3ne`40
0ML1e`002ML200CG00<0emL00]L300GG00<0emL0o]L1007G0ML000SG00@0emL02mL00`3Ge`02e`03
0=OG0?kG0@01e`7G0008e`040=OG00_G00<0emL00]L207WG301ie`800]L000;G1002e`040=OG00SG
0`05e`030=OG07KG0P0<e`80N=L1007G0ML000SG00@0emL02=L00`3Ge`05e`030=OG07?G0`0@e`<0
MML1007G0ML000SG00@0emL02=L00`3Ge`05e`030=OG073G0`0Fe`<0L]L1007G0ML000WG0P09e`@0
1=L00`3Ge`1^e`807=L2073G0@01e`7G000Le`030=OG06gG00<0emL07]L00`3Ge`1]e`400ML1e`00
7=L206gG00<0emL08=L00`3Ge`1[e`800]L001cG00<0emL0J]L202CG0P1/e`400ML1e`007=L00`3G
e`1Ye`030=OG02KG00<0emL0JML1007G0ML001cG00<0emL0J=L00`3Ge`0Xe`030=OG06SG0@01e`7G
000Le`030=OG06OG00<0emL0:]L00`3Ge`1We`400ML1e`007=L00`3Ge`1Ve`030=OG02cG00<0emL0
I]L1007G0ML001cG00<0emL0IML00`3Ge`0^e`030=OG06GG0@01e`7G000Le`80IML00`3Ge`0`e`03
0=OG06?G0P02e`007=L00`3Ge`1Se`030=OG037G00<0emL0I=L1007G0ML001cG00<0emL0HmL00`3G
e`0be`030=OG06?G0@01e`7G000Le`030=OG06;G00<0emL0==L00`3Ge`1Re`400ML1e`007=L00`3G
e`1Qe`030=OG03GG00<0emL0H]L1007G0ML001cG00<0emL0HML00`3Ge`0fe`030=OG067G0@01e`7G
000Le`80HML00`3Ge`0ge`030=OG063G0P02e`007=L00`3Ge`1Pe`030=OG03SG00<0emL0H=L1007G
0ML001cG00<0emL0H=L00`3Ge`0he`030=OG063G0@01e`7G000Le`030=OG063G00<0emL0>=L00`3G
e`1Pe`400ML1e`007=L00`3Ge`1Pe`030=OG03SG00<0emL0H=L1007G0ML001cG00<0emL0GmL00`3G
e`0ie`030=OG063G0@01e`7G000Le`80H=L00`3Ge`0je`030=OG05kG0P02e`007=L00`3Ge`1Oe`03
0=OG03[G00<0emL0GmL1007G0ML001cG00<0emL0GmL00`3Ge`0je`030=OG05oG0@01e`7G000Le`03
0=OG05oG00<0emL0>]L00`3Ge`1Oe`400ML1e`005ML200GG00<0emL0GmL00`3Ge`0je`030=OG05oG
0@01e`7G000De`040=OG00CG00<0emL0GmL00`3Ge`0je`030=OG05oG0@01e`7G000De`040=OG00CG
0P1Pe`030=OG03[G00<0emL0G]L200;G000De`040=OG00CG00<0emL0GmL00`3Ge`0je`030=OG05oG
0@01e`7G000De`040=OG00CG00<0emL0GmL00`3Ge`0je`030=OG05oG0@01e`7G000De`040=OG00CG
00<0emL0GmL00`3Ge`0je`030=OG05oG0@01e`7G000Ee`801ML00`3Ge`1Oe`030=OG03[G00<0emL0
GmL1007G0ML001cG00<0emL0GmL00`3Ge`0je`030=OG05oG0@01e`7G000Le`80H=L00`3Ge`0je`03
0=OG05kG0P02e`007=L00`3Ge`1Oe`030=OG03[G00<0emL0GmL1007G0ML001cG00<0emL0H=L00`3G
e`0he`030=OG063G0@01e`7G000Le`030=OG063G00<0emL0>=L00`3Ge`1Pe`400ML1e`007=L00`3G
e`1Pe`030=OG03SG00<0emL0H=L1007G0ML001cG00<0emL0H=L00`3Ge`0he`030=OG063G0@01e`7G
000Le`80HML00`3Ge`0ge`030=OG063G0P02e`007=L00`3Ge`1Qe`030=OG03KG00<0emL0HML1007G
0ML001cG00<0emL0HML00`3Ge`0ee`030=OG06;G0@01e`7G000Le`030=OG06;G00<0emL0==L00`3G
e`1Re`400ML1e`007=L00`3Ge`1Se`030=OG03;G00<0emL0HmL1007G0ML001cG00<0emL0HmL00`3G
e`0ae`030=OG06CG0@01e`7G000Le`030=OG06CG00<0emL0<=L00`3Ge`1Te`400ML1e`007=L206KG
00<0emL0;]L00`3Ge`1Te`800]L001cG00<0emL0I]L00`3Ge`0/e`030=OG06KG0@01e`7G000Le`03
0=OG06KG00<0emL0:mL00`3Ge`1We`400ML1e`007=L00`3Ge`1We`030=OG02[G00<0emL0ImL1007G
0ML001cG00<0emL0J=L00`3Ge`0Xe`030=OG06SG0@01e`7G000Le`030=OG06WG00<0emL09]L00`3G
e`1Ye`400ML1e`007=L206_G0P0Te`80JmL200;G000Le`030=OG06cG0P0Pe`80K]L1007G0ML001cG
00<0emL0K]L201cG0P1`e`400ML1e`007=L00`3Ge`1`e`<05]L307;G0@01e`7G0009e`801=L00`3G
e`02e`<01ML00`3Ge`1ce`804]L207GG0@01e`7G0008e`040=OG00_G00<0emL00]L00`3Ge`1ee`<0
3=L307OG0@01e`7G0008e`040=OG00_G00<0emL00]L207WG301ie`800]L000SG00@0emL02=L300GG
00<0emL0o]L1007G0ML000SG00@0emL02=L00`3Ge`05e`030=OG0?kG0@01e`7G0008e`040=OG00SG
00<0emL01ML00`3Ge`3ne`400ML1e`002ML200WG1004e`030=OG0?kG0@01e`7G000Le`030=OG0?kG
0@01e`7G000Le`80o]L200;G000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`03
0=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`80o]L200;G
000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`03
0=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`80o]L200;G
000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`03
0=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000Le`80o]L200;G000Le`030=OG0?kG0@01e`7G
000Le`030=OG0?kG0@01e`7G000Le`030=OG0?kG0@01e`7G000De`@01=L00`3Ge`3ne`400ML1e`00
5]L00`3Ge`03e`030=OG0?kG0@01e`7G000Fe`030=OG00?G0P3ne`800]L001KG00<0emL00mL00`3G
e`02e`030=OG03_G00<0emL0>mL00`3Ge`0je`030=OG03_G00<0emL00]L1007G0ML001KG00<0emL0
0mOo00<00]L001CG0`3oe`[G000Fe`030=OG0?oG2=L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-2.537, -1.2374, 0.0161544, \
0.0161544}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[p1], Graphics[p2]]\)], "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0 0.25 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .0625 -24 -4.5 ]
[.4875 .0625 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .1875 -24 -4.5 ]
[.4875 .1875 0 4.5 ]
[.4875 .25 -6 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .3125 -24 -4.5 ]
[.4875 .3125 0 4.5 ]
[.4875 .375 -18 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .4375 -24 -4.5 ]
[.4875 .4375 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-2)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-1.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.5)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .0625 m
.50625 .0625 L
s
[(0.25)] .4875 .0625 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(0.5)] .4875 .125 1 0 Mshowa
.5 .1875 m
.50625 .1875 L
s
[(0.75)] .4875 .1875 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1)] .4875 .25 1 0 Mshowa
.5 .3125 m
.50625 .3125 L
s
[(1.25)] .4875 .3125 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(1.5)] .4875 .375 1 0 Mshowa
.5 .4375 m
.50625 .4375 L
s
[(1.75)] .4875 .4375 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(2)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .0125 m
.50375 .0125 L
s
.5 .025 m
.50375 .025 L
s
.5 .0375 m
.50375 .0375 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .0875 m
.50375 .0875 L
s
.5 .1 m
.50375 .1 L
s
.5 .1125 m
.50375 .1125 L
s
.5 .1375 m
.50375 .1375 L
s
.5 .15 m
.50375 .15 L
s
.5 .1625 m
.50375 .1625 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .2125 m
.50375 .2125 L
s
.5 .225 m
.50375 .225 L
s
.5 .2375 m
.50375 .2375 L
s
.5 .2625 m
.50375 .2625 L
s
.5 .275 m
.50375 .275 L
s
.5 .2875 m
.50375 .2875 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .3375 m
.50375 .3375 L
s
.5 .35 m
.50375 .35 L
s
.5 .3625 m
.50375 .3625 L
s
.5 .3875 m
.50375 .3875 L
s
.5 .4 m
.50375 .4 L
s
.5 .4125 m
.50375 .4125 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .4625 m
.50375 .4625 L
s
.5 .475 m
.50375 .475 L
s
.5 .4875 m
.50375 .4875 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.025 w
.625 0 Mdot
.6125 .05449 Mdot
.5875 .08927 Mdot
.5375 .11924 Mdot
.5 .125 Mdot
.4625 .11924 Mdot
.4125 .08927 Mdot
.3875 .05449 Mdot
.375 0 Mdot
1 0 Mdot
1 .125 Mdot
1 .25 Mdot
.75 .25 Mdot
.5 .25 Mdot
.25 .25 Mdot
0 .25 Mdot
0 .125 Mdot
0 0 Mdot
.5 Mabswid
.62467 0 m
.62467 .00862 L
.62228 .02586 L
.62069 .03339 L
.61732 .0431 L
.60943 .06034 L
.59799 .07759 L
.58621 .09053 L
.58165 .09483 L
.55568 .11207 L
.55172 .1138 L
.51724 .1238 L
.48276 .1238 L
.44828 .1138 L
.44432 .11207 L
.41835 .09483 L
.41379 .09053 L
.40201 .07759 L
.39057 .06034 L
.38268 .0431 L
.37931 .03339 L
.37772 .02586 L
.37533 .00862 L
s
.37533 .00862 m
.37533 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML001?G100Fe`@00mL00`3G
e`02e`<05]L401OG0P04e`030=OG00;G0`0^e`801=L00`3Ge`02e`<05mL401GG1003e`030=OG00;G
0`0Ge`@03mL001?G00<0emL06ML00`3Ge`0:e`030=OG01GG00<0emL05ML0103Ge`0;e`030=OG02[G
00@0emL02mL00`3Ge`0Fe`030=OG01KG00<0emL02]L00`3Ge`0De`030=OG013G000De`030=OG01SG
00<0emL02]L00`3Ge`0Ee`030=OG01GG00@0emL02mL00`3Ge`0Ze`040=OG00_G00<0emL05]L00`3G
e`0Fe`030=OG00[G00<0emL05ML00`3Ge`0?e`003ML400CG00<0emL03mL400CG00<0emL01mL3013G
1004e`030=OG00oG1002e`040=OG00SG0`0]e`040=OG00SG0`0Ie`030=OG01KG00<0emL01mL301WG
00<0emL03]L001KG00<0emL05]L00`3Ge`07e`030=OG01SG00<0emL05ML0103Ge`08e`030=OG02gG
00@0emL02=L00`3Ge`0Ie`030=OG01KG00<0emL01mL00`3Ge`0Je`030=OG00gG000Ce`040=OG01KG
0`09e`030=OG01KG0`0Ge`040=OG00SG00<0emL0;ML0103Ge`08e`030=OG01OG0`0Fe`<02ML00`3G
e`0Ge`040=OG00oG000De`806ML00`3Ge`07e`@05mL00`3Ge`0Fe`802ML402gG0P09e`@06=L00`3G
e`0Fe`030=OG00OG100Ge`804=L00?oG8ML0017G1@1Ie`D0>]L505[G1@0>e`004ML505WG1@0je`D0
F]L500kG000@e`H0F=L603WG1P1Ie`H03]L0017Go`0200kG000Ae`D00]L00`3Ge`04e`030=OG00?G
00<0emL00mL00`3Ge`04e`030=OG00?G00<0emL00mL00`3Ge`04e`030=OG00?G00<0emL00mL00`3G
e`04e`030=OG00?G00<0emL00mL00`3Ge`04e`040=OGe`D00mL00`3Ge`04e`030=OG00?G00<0emL0
0mL00`3Ge`04e`030=OG00?G00<0emL00mL00`3Ge`03e`030=OG00CG00@0emOG1@03e`030=OG00CG
00<0emL00mL00`3Ge`03e`030=OG00CG00<0emL00mL00`3Ge`03e`030=OG00CG00<0emL00mL00`3G
e`03e`030=OG00CG00<0emL00mL00`3Ge`03e`030=OG00CG00@0emOG1@0>e`004mL00`3Ge`1Ke`03
0=OG01gG00<0emL07=L00`3Ge`1Le`030=OG00kG001ae`030=OG01gG00<0emL07=L00`3Ge`1]e`00
LML00`3Ge`0Me`030=OG01_G00<0emL0K]L007;G00<0emL07=L00`3Ge`0Ke`030=OG06kG001be`03
0=OG01cG00<0emL06mL00`3Ge`1^e`00L]L00`3Ge`0Le`030=OG01_G00<0emL0K]L007;G00<0emL0
7=L00`3Ge`0Ke`030=OG06kG001be`030=OG01cG00<0emL06mL00`3Ge`1^e`00LmL00`3Ge`0Ke`03
0=OG01[G00<0emL0KmL007;G1@0Je`030=OG01OG1@1`e`00L]L501[G00<0emL05mL5073G001ae`P0
1=L00`3Ge`02e`@00]L300KG00<0emL05]L6073G001be`D00]L00`3Ge`06e`030=OG00KG00<0emL0
0mL00`3Ge`0Ge`D0L=L007;G1@02e`030=OG00OG00<0emL01ML00`3Ge`03e`806=L5073G001de`03
0=L000;G00<0emL02=L0103GemL300KG00<0emL05mL00`3G001be`00M]L0103Ge`0;e`040=OG00SG
00<0emL05]L00`3Ge`1ce`00M]L20003e`3G00OG00@0emL00]L00`3Ge`06e`030=OG01KG00<0emL0
LmL007OG0P0:e`800mL400GG00<0emL05ML00`3Ge`1de`00NML501?G00<0emL04ML507KG001ie`D0
4mL00`3Ge`0Ae`D0M]L007SG1P0Ce`030=OG013G1P1fe`00NML501?G00<0emL04ML507KG001ie`D0
4mL00`3Ge`0Ae`D0M]L007_G00@0e`004]L00`3Ge`0?e`800]L00`3Ge`1fe`00OmL00`3Ge`0?e`03
0=OG00kG00<0emL0NmL0083G0P03e`D01mL00`3Ge`04e`D00mL207kG0022e`P01mL00`3Ge`04e`P0
P=L0017G1@1We`801=L800CG1@03e`H0L=L500kG000Ae`D0I]L0103Ge`05e`L00mL500?G1P1`e`D0
3]L0013G1P1Ve`040=OG00GG1@000mL0000:0003e`0000<0KmL600kG000Ae`D0I]L0103Ge`07e`@0
1=L500KG00<0emL0L=L500kG000Ae`D0I]L0103Ge`08e`030=OG00CG1@1ie`D03]L001?G00<0emL0
I]L0103Ge`08e`030=OG00KG00<0emL0NmL00`3Ge`0>e`00OML200WG1005e`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG001ge`801=L00`3Ge`03e`03
0=OG00;G0`06e`030=OG08cG001fe`040=OG00WG00<0emL01ML00`3Ge`03e`030=OG08cG001fe`04
0=OG00[G00<0emL01=L00`3Ge`03e`80SML007KG00@0emL02]L0103GemL300KG00<0emL0S=L007KG
00@0emL02mL0103Ge`08e`030=OG08cG001fe`040=OG00SG00@0emL00]L00`3Ge`06e`030=OG08cG
001ge`802ML400;G1005e`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG
002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG
000Ae`D0>]L503[G1@0je`D0>]L500kG000Ae`D0>]L503?G1003e`D0>]L503[G1@0>e`004=L603WG
1P0ee`040=OGe`H0>ML603WG1P0>e`004ML503[G1@0ee`030=OG00;G1@0je`D0>]L500kG000Ae`D0
>]L503GG00<0emL00]L503[G1@0je`D03]L001?G00<0emL0?=L00`3Ge`0ee`030=OG00CG00<0emL0
?=L00`3Ge`0le`030=OG00kG0028e`<01]L00`3Ge`2<e`00R]L00`3Ge`04e`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`03
0=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG002Ae`030=OG08cG001fe`@00mL00`3Ge`02e`@0
0]L300KG00<0emL0S=L007SG00<0emL01mL00`3Ge`06e`030=OG00?G00<0emL0S=L007SG00<0emL0
2=L00`3Ge`05e`030=OG00?G0P2=e`00N=L00`3Ge`09e`040=OGe`<01]L00`3Ge`2<e`00N=L00`3G
e`0:e`040=OG00SG00<0emL0S=L007KG0`09e`040=OG00;G00<0emL01]L00`3Ge`2<e`00N=L00`3G
e`08e`800mL400GG00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G
00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L007cG
1003e`030=OG00;G0`06e`030=OG08cG001ne`030=OG00[G00<0emL00mL00`3Ge`2<e`00O]L00`3G
e`0:e`030=OG00?G0P2=e`00O]L00`3Ge`07e`<01]L00`3Ge`2<e`00O]L00`3Ge`07e`030=OG00KG
00<0emL0S=L007cG0`09e`030=OG00KG00<0emL0S=L007kG00<0emL01mL400GG00<0emL0S=L0097G
00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G
00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L007KG1003e`030=OG00?G
00<0emL00]L300KG00<0emL0S=L007SG00<0emL02=L00`3Ge`05e`030=OG00?G00<0emL0S=L007SG
00<0emL02ML00`3Ge`04e`030=OG00?G0P2=e`00N=L00`3Ge`09e`040=OGe`<01]L00`3Ge`2<e`00
N=L00`3Ge`0:e`040=OG00SG00<0emL0S=L007KG0`09e`040=OG00;G00<0emL01]L00`3Ge`2<e`00
N=L00`3Ge`07e`@00]L400GG00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0
S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0S=L0097G00<0emL0
S=L0097G00<0emL0S=L008SG1005e`030=OG08cG0028e`030=OG00KG00<0emL0S=L008WG00<0emL0
1ML208gG002:e`030=OG09?G002;e`030=OG09;G0028e`040=OG09CG0029e`80UML00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-2.29539, -0.192483, 0.0158303, \
0.0158303}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clear[p3];p3=Plot3D[g[x,y],{x,-2.,2.},{y,-1.,1.},PlotPoints->60,
PlotRange->{0,1.2},ViewPoint->{0.,0.,2.},
ClipFill->None, AspectRatio->0.5,Shading->True] 
\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.5 [
[0 -0.00625 -6 -9 ]
[0 -0.00625 6 0 ]
[.25 -0.00625 -6 -9 ]
[.25 -0.00625 6 0 ]
[.5 -0.00625 -3 -9 ]
[.5 -0.00625 3 0 ]
[.75 -0.00625 -3 -9 ]
[.75 -0.00625 3 0 ]
[1 -0.00625 -3 -9 ]
[1 -0.00625 3 0 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -6 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -18 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[.92159 .45455 0 -4.5 ]
[.92159 .45455 6 4.5 ]
[.9377 .4626 0 -4.5 ]
[.9377 .4626 24 4.5 ]
[.95512 .47131 0 -4.5 ]
[.95512 .47131 18 4.5 ]
[.97404 .48077 0 -4.5 ]
[.97404 .48077 24 4.5 ]
[.99464 .49107 0 -4.5 ]
[.99464 .49107 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .00313 L
s
[(-2)] 0 -0.00625 0 1 Mshowa
.25 0 m
.25 .00313 L
s
[(-1)] .25 -0.00625 0 1 Mshowa
.5 0 m
.5 .00313 L
s
[(0)] .5 -0.00625 0 1 Mshowa
.75 0 m
.75 .00313 L
s
[(1)] .75 -0.00625 0 1 Mshowa
1 0 m
1 .00313 L
s
[(2)] 1 -0.00625 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00188 L
s
.1 0 m
.1 .00188 L
s
.15 0 m
.15 .00188 L
s
.2 0 m
.2 .00188 L
s
.3 0 m
.3 .00188 L
s
.35 0 m
.35 .00188 L
s
.4 0 m
.4 .00188 L
s
.45 0 m
.45 .00188 L
s
.55 0 m
.55 .00188 L
s
.6 0 m
.6 .00188 L
s
.65 0 m
.65 .00188 L
s
.7 0 m
.7 .00188 L
s
.8 0 m
.8 .00188 L
s
.85 0 m
.85 .00188 L
s
.9 0 m
.9 .00188 L
s
.95 0 m
.95 .00188 L
s
.25 Mabswid
0 0 m
0 .5 L
s
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .125 m
.00625 .125 L
s
[(-0.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1)] -0.0125 .5 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
.25 Mabswid
.90909 .45455 m
1 .5 L
s
.90909 .45455 m
.90284 .45455 L
s
[(0)] .92159 .45455 -1 0 Mshowa
.9252 .4626 m
.91895 .4626 L
s
[(0.25)] .9377 .4626 -1 0 Mshowa
.94262 .47131 m
.93637 .47131 L
s
[(0.5)] .95512 .47131 -1 0 Mshowa
.96154 .48077 m
.95529 .48077 L
s
[(0.75)] .97404 .48077 -1 0 Mshowa
.98214 .49107 m
.97589 .49107 L
s
[(1)] .99464 .49107 -1 0 Mshowa
.125 Mabswid
.91221 .45611 m
.90846 .45611 L
s
.91538 .45769 m
.91163 .45769 L
s
.9186 .4593 m
.91485 .4593 L
s
.92188 .46094 m
.91813 .46094 L
s
.92857 .46429 m
.92482 .46429 L
s
.932 .466 m
.92825 .466 L
s
.93548 .46774 m
.93173 .46774 L
s
.93902 .46951 m
.93527 .46951 L
s
.94628 .47314 m
.94253 .47314 L
s
.95 .475 m
.94625 .475 L
s
.95378 .47689 m
.95003 .47689 L
s
.95763 .47881 m
.95388 .47881 L
s
.96552 .48276 m
.96177 .48276 L
s
.96957 .48478 m
.96582 .48478 L
s
.97368 .48684 m
.96993 .48684 L
s
.97788 .48894 m
.97413 .48894 L
s
.98649 .49324 m
.98274 .49324 L
s
.99091 .49545 m
.98716 .49545 L
s
.99541 .49771 m
.99166 .49771 L
s
.25 Mabswid
.09091 .04545 m
0 0 L
s
0 0 m
0 .5 L
s
0 .5 m
.09091 .45455 L
s
.09091 .45455 m
.09091 .04545 L
s
.90909 .04545 m
.90909 .45455 L
s
.90909 .45455 m
1 .5 L
s
1 .5 m
1 0 L
s
1 0 m
.90909 .04545 L
s
.09091 .04545 m
0 0 L
s
0 0 m
1 0 L
s
1 0 m
.90909 .04545 L
s
.90909 .04545 m
.09091 .04545 L
s
.09091 .45455 m
.90909 .45455 L
s
.90909 .45455 m
1 .5 L
s
1 .5 m
0 .5 L
s
0 .5 m
.09091 .45455 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.706 .571 .7 r
.01786 .00893 .01778 .01706 .0339 .01695 .03419 .00892 Metetra
.721 .567 .681 r
.03419 .00892 .0339 .01695 .05023 .01694 .05068 .009 Metetra
.729 .56 .663 r
.05068 .009 .05023 .01694 .06669 .01699 .06726 .00914 Metetra
.732 .551 .648 r
.06726 .00914 .06669 .01699 .08321 .01709 .08386 .00929 Metetra
.73 .541 .636 r
.08386 .00929 .08321 .01709 .09974 .01719 .10043 .00944 Metetra
.726 .532 .628 r
.10043 .00944 .09974 .01719 .11625 .0173 .11694 .00957 Metetra
.719 .523 .624 r
.11694 .00957 .11625 .0173 .13271 .01739 .13337 .00966 Metetra
.711 .516 .624 r
.13337 .00966 .13271 .01739 .14914 .01745 .14973 .0097 Metetra
.702 .513 .629 r
.14973 .0097 .14914 .01745 .16551 .01749 .16602 .0097 Metetra
.694 .512 .637 r
.16602 .0097 .16551 .01749 .18183 .01749 .18224 .00964 Metetra
.687 .515 .649 r
.18224 .00964 .18183 .01749 .19813 .01748 .19841 .00955 Metetra
.681 .523 .664 r
.19841 .00955 .19813 .01748 .2144 .01744 .21456 .00941 Metetra
.677 .534 .683 r
.21456 .00941 .2144 .01744 .23066 .01739 .23068 .00925 Metetra
.675 .548 .703 r
.23068 .00925 .23066 .01739 .24693 .01734 .24682 .00907 Metetra
.674 .566 .725 r
.24682 .00907 .24693 .01734 .26322 .0173 .26297 .00888 Metetra
.675 .586 .748 r
.26297 .00888 .26322 .0173 .27953 .01728 .27915 .0087 Metetra
.677 .608 .771 r
.27915 .0087 .27953 .01728 .29586 .01728 .29538 .00854 Metetra
.68 .63 .793 r
.29538 .00854 .29586 .01728 .31222 .01732 .31164 .00841 Metetra
.683 .653 .814 r
.31164 .00841 .31222 .01732 .32861 .0174 .32796 .00832 Metetra
.685 .674 .833 r
.32796 .00832 .32861 .0174 .34502 .01752 .34431 .00827 Metetra
.687 .694 .851 r
.34431 .00827 .34502 .01752 .36143 .01769 .36069 .00826 Metetra
.688 .712 .867 r
.36069 .00826 .36143 .01769 .37784 .01789 .3771 .0083 Metetra
.687 .728 .881 r
.3771 .0083 .37784 .01789 .39423 .01812 .39352 .00837 Metetra
.685 .74 .893 r
.39352 .00837 .39423 .01812 .4106 .01836 .40994 .00847 Metetra
.681 .75 .903 r
.40994 .00847 .4106 .01836 .42693 .0186 .42635 .00859 Metetra
.676 .756 .911 r
.42635 .00859 .42693 .0186 .44322 .01883 .44274 .0087 Metetra
.67 .76 .918 r
.44274 .0087 .44322 .01883 .45948 .01901 .45912 .00881 Metetra
.664 .761 .923 r
.45912 .00881 .45948 .01901 .4757 .01914 .47548 .00888 Metetra
.657 .76 .926 r
.47548 .00888 .4757 .01914 .4919 .01921 .49183 .00892 Metetra
.65 .758 .928 r
.49183 .00892 .4919 .01921 .5081 .01921 .50817 .00892 Metetra
.708 .557 .68 r
.96581 .00892 .9661 .01695 .98222 .01706 .98214 .00893 Metetra
.691 .53 .663 r
.94932 .009 .94977 .01694 .9661 .01695 .96581 .00892 Metetra
.681 .51 .648 r
.93274 .00914 .93331 .01699 .94977 .01694 .94932 .009 Metetra
.676 .497 .636 r
.91614 .00929 .91679 .01709 .93331 .01699 .93274 .00914 Metetra
.676 .491 .629 r
.89957 .00944 .90026 .01719 .91679 .01709 .91614 .00929 Metetra
.68 .491 .625 r
.88306 .00957 .88375 .0173 .90026 .01719 .89957 .00944 Metetra
.686 .497 .625 r
.86663 .00966 .86729 .01739 .88375 .0173 .88306 .00957 Metetra
.695 .507 .629 r
.85027 .0097 .85086 .01745 .86729 .01739 .86663 .00966 Metetra
.705 .521 .637 r
.83398 .0097 .83449 .01749 .85086 .01745 .85027 .0097 Metetra
.714 .538 .649 r
.81776 .00964 .81817 .01749 .83449 .01749 .83398 .0097 Metetra
.723 .557 .665 r
.80159 .00955 .80187 .01748 .81817 .01749 .81776 .00964 Metetra
.73 .577 .683 r
.78544 .00941 .7856 .01744 .80187 .01748 .80159 .00955 Metetra
.735 .598 .703 r
.76932 .00925 .76934 .01739 .7856 .01744 .78544 .00941 Metetra
.737 .618 .725 r
.75318 .00907 .75307 .01734 .76934 .01739 .76932 .00925 Metetra
.737 .636 .748 r
.73703 .00888 .73678 .0173 .75307 .01734 .75318 .00907 Metetra
.733 .653 .771 r
.72085 .0087 .72047 .01728 .73678 .0173 .73703 .00888 Metetra
.726 .668 .793 r
.70462 .00854 .70414 .01728 .72047 .01728 .72085 .0087 Metetra
.718 .681 .814 r
.68836 .00841 .68778 .01732 .70414 .01728 .70462 .00854 Metetra
.707 .692 .834 r
.67204 .00832 .67139 .0174 .68778 .01732 .68836 .00841 Metetra
.695 .701 .851 r
.65569 .00827 .65498 .01752 .67139 .0174 .67204 .00832 Metetra
.683 .709 .867 r
.63931 .00826 .63857 .01769 .65498 .01752 .65569 .00827 Metetra
.672 .715 .881 r
.6229 .0083 .62216 .01789 .63857 .01769 .63931 .00826 Metetra
.662 .721 .893 r
.60648 .00837 .60577 .01812 .62216 .01789 .6229 .0083 Metetra
.653 .726 .903 r
.59006 .00847 .5894 .01836 .60577 .01812 .60648 .00837 Metetra
.646 .732 .911 r
.57365 .00859 .57307 .0186 .5894 .01836 .59006 .00847 Metetra
.642 .737 .918 r
.55726 .0087 .55678 .01883 .57307 .0186 .57365 .00859 Metetra
.641 .743 .923 r
.54088 .00881 .54052 .01901 .55678 .01883 .55726 .0087 Metetra
.642 .748 .926 r
.52452 .00888 .5243 .01914 .54052 .01901 .54088 .00881 Metetra
.645 .753 .928 r
.50817 .00892 .5081 .01921 .5243 .01914 .52452 .00888 Metetra
.687 .557 .702 r
.01778 .01706 .01772 .02521 .03366 .02501 .0339 .01695 Metetra
.705 .557 .685 r
.0339 .01695 .03366 .02501 .04984 .02492 .05023 .01694 Metetra
.716 .554 .669 r
.05023 .01694 .04984 .02492 .06619 .02491 .06669 .01699 Metetra
.722 .549 .656 r
.06669 .01699 .06619 .02491 .08263 .02495 .08321 .01709 Metetra
.724 .543 .646 r
.08321 .01709 .08263 .02495 .09913 .02502 .09974 .01719 Metetra
.723 .537 .639 r
.09974 .01719 .09913 .02502 .11564 .02511 .11625 .0173 Metetra
.72 .532 .635 r
.11625 .0173 .11564 .02511 .13214 .02519 .13271 .01739 Metetra
.716 .529 .636 r
.13271 .01739 .13214 .02519 .14862 .02528 .14914 .01745 Metetra
.711 .528 .64 r
.14914 .01745 .14862 .02528 .16507 .02535 .16551 .01749 Metetra
.706 .531 .649 r
.16551 .01749 .16507 .02535 .1815 .02542 .18183 .01749 Metetra
.702 .537 .66 r
.18183 .01749 .1815 .02542 .19791 .02547 .19813 .01748 Metetra
.7 .546 .675 r
.19813 .01748 .19791 .02547 .21431 .02553 .2144 .01744 Metetra
.698 .559 .693 r
.2144 .01744 .21431 .02553 .2307 .02558 .23066 .01739 Metetra
.698 .574 .713 r
.23066 .01739 .2307 .02558 .2471 .02565 .24693 .01734 Metetra
.699 .593 .733 r
.24693 .01734 .2471 .02565 .26351 .02574 .26322 .0173 Metetra
.701 .613 .755 r
.26322 .0173 .26351 .02574 .27994 .02586 .27953 .01728 Metetra
.704 .635 .777 r
.27953 .01728 .27994 .02586 .29638 .02601 .29586 .01728 Metetra
.707 .657 .798 r
.29586 .01728 .29638 .02601 .31283 .02621 .31222 .01732 Metetra
.709 .678 .818 r
.31222 .01732 .31283 .02621 .32929 .02645 .32861 .0174 Metetra
.711 .699 .836 r
.32861 .0174 .32929 .02645 .34574 .02673 .34502 .01752 Metetra
.712 .717 .853 r
.34502 .01752 .34574 .02673 .36218 .02705 .36143 .01769 Metetra
.711 .734 .869 r
.36143 .01769 .36218 .02705 .37858 .02741 .37784 .01789 Metetra
.708 .748 .883 r
.37784 .01789 .37858 .02741 .39495 .02778 .39423 .01812 Metetra
.704 .758 .894 r
.39423 .01812 .39495 .02778 .41126 .02815 .4106 .01836 Metetra
.697 .766 .905 r
.4106 .01836 .41126 .02815 .42751 .02851 .42693 .0186 Metetra
.689 .77 .913 r
.42693 .0186 .42751 .02851 .4437 .02883 .44322 .01883 Metetra
.68 .772 .92 r
.44322 .01883 .4437 .02883 .45984 .02909 .45948 .01901 Metetra
.669 .77 .926 r
.45948 .01901 .45984 .02909 .47592 .02928 .4757 .01914 Metetra
.659 .766 .929 r
.4757 .01914 .47592 .02928 .49198 .02938 .4919 .01921 Metetra
.648 .76 .931 r
.4919 .01921 .49198 .02938 .50802 .02938 .5081 .01921 Metetra
.727 .575 .684 r
.9661 .01695 .96634 .02501 .98228 .02521 .98222 .01706 Metetra
.708 .548 .669 r
.94977 .01694 .95016 .02492 .96634 .02501 .9661 .01695 Metetra
.695 .527 .656 r
.93331 .01699 .93381 .02491 .95016 .02492 .94977 .01694 Metetra
.687 .513 .646 r
.91679 .01709 .91737 .02495 .93381 .02491 .93331 .01699 Metetra
.684 .505 .639 r
.90026 .01719 .90087 .02502 .91737 .02495 .91679 .01709 Metetra
.684 .503 .635 r
.88375 .0173 .88436 .02511 .90087 .02502 .90026 .01719 Metetra
.687 .506 .636 r
.86729 .01739 .86786 .02519 .88436 .02511 .88375 .0173 Metetra
.692 .513 .641 r
.85086 .01745 .85138 .02528 .86786 .02519 .86729 .01739 Metetra
.698 .524 .649 r
.83449 .01749 .83493 .02535 .85138 .02528 .85086 .01745 Metetra
.704 .538 .661 r
.81817 .01749 .8185 .02542 .83493 .02535 .83449 .01749 Metetra
.71 .554 .675 r
.80187 .01748 .80209 .02547 .8185 .02542 .81817 .01749 Metetra
.714 .571 .693 r
.7856 .01744 .78569 .02553 .80209 .02547 .80187 .01748 Metetra
.716 .589 .713 r
.76934 .01739 .7693 .02558 .78569 .02553 .7856 .01744 Metetra
.715 .606 .733 r
.75307 .01734 .7529 .02565 .7693 .02558 .76934 .01739 Metetra
.713 .622 .755 r
.73678 .0173 .73649 .02574 .7529 .02565 .75307 .01734 Metetra
.707 .637 .777 r
.72047 .01728 .72006 .02586 .73649 .02574 .73678 .0173 Metetra
.7 .651 .798 r
.70414 .01728 .70362 .02601 .72006 .02586 .72047 .01728 Metetra
.69 .663 .818 r
.68778 .01732 .68717 .02621 .70362 .02601 .70414 .01728 Metetra
.679 .673 .837 r
.67139 .0174 .67071 .02645 .68717 .02621 .68778 .01732 Metetra
.668 .682 .854 r
.65498 .01752 .65426 .02673 .67071 .02645 .67139 .0174 Metetra
.657 .69 .869 r
.63857 .01769 .63782 .02705 .65426 .02673 .65498 .01752 Metetra
.646 .697 .883 r
.62216 .01789 .62142 .02741 .63782 .02705 .63857 .01769 Metetra
.637 .704 .895 r
.60577 .01812 .60505 .02778 .62142 .02741 .62216 .01789 Metetra
.63 .711 .905 r
.5894 .01836 .58874 .02815 .60505 .02778 .60577 .01812 Metetra
.626 .719 .913 r
.57307 .0186 .57249 .02851 .58874 .02815 .5894 .01836 Metetra
.625 .727 .92 r
.55678 .01883 .5563 .02883 .57249 .02851 .57307 .0186 Metetra
.627 .735 .925 r
.54052 .01901 .54016 .02909 .5563 .02883 .55678 .01883 Metetra
.632 .744 .929 r
.5243 .01914 .52408 .02928 .54016 .02909 .54052 .01901 Metetra
.639 .752 .931 r
.5081 .01921 .50802 .02938 .52408 .02928 .5243 .01914 Metetra
.668 .543 .703 r
.01772 .02521 .01769 .03337 .03346 .0331 .03366 .02501 Metetra
.69 .548 .688 r
.03366 .02501 .03346 .0331 .0495 .03294 .04984 .02492 Metetra
.704 .549 .674 r
.04984 .02492 .0495 .03294 .06575 .03287 .06619 .02491 Metetra
.713 .547 .663 r
.06619 .02491 .06575 .03287 .08213 .03287 .08263 .02495 Metetra
.719 .545 .654 r
.08263 .02495 .08213 .03287 .09859 .03291 .09913 .02502 Metetra
.721 .542 .648 r
.09913 .02502 .09859 .03291 .1151 .03298 .11564 .02511 Metetra
.721 .541 .645 r
.11564 .02511 .1151 .03298 .13164 .03307 .13214 .02519 Metetra
.72 .541 .646 r
.13214 .02519 .13164 .03307 .14817 .03318 .14862 .02528 Metetra
.719 .543 .651 r
.14862 .02528 .14817 .03318 .16471 .03329 .16507 .02535 Metetra
.718 .548 .659 r
.16507 .02535 .16471 .03329 .18123 .0334 .1815 .02542 Metetra
.717 .556 .67 r
.1815 .02542 .18123 .0334 .19775 .03352 .19791 .02547 Metetra
.717 .567 .685 r
.19791 .02547 .19775 .03352 .21427 .03366 .21431 .02553 Metetra
.718 .582 .702 r
.21431 .02553 .21427 .03366 .23079 .03381 .2307 .02558 Metetra
.72 .598 .72 r
.2307 .02558 .23079 .03381 .24731 .03399 .2471 .02565 Metetra
.722 .617 .74 r
.2471 .02565 .24731 .03399 .26384 .0342 .26351 .02574 Metetra
.726 .638 .76 r
.26351 .02574 .26384 .0342 .28038 .03445 .27994 .02586 Metetra
.729 .659 .781 r
.27994 .02586 .28038 .03445 .29692 .03474 .29638 .02601 Metetra
.732 .681 .801 r
.29638 .02601 .29692 .03474 .31346 .03507 .31283 .02621 Metetra
.734 .702 .82 r
.31283 .02621 .31346 .03507 .32998 .03545 .32929 .02645 Metetra
.736 .721 .838 r
.32929 .02645 .32998 .03545 .34648 .03588 .34574 .02673 Metetra
.735 .739 .854 r
.34574 .02673 .34648 .03588 .36294 .03635 .36218 .02705 Metetra
.733 .754 .87 r
.36218 .02705 .36294 .03635 .37934 .03684 .37858 .02741 Metetra
.729 .767 .883 r
.37858 .02741 .37934 .03684 .39568 .03734 .39495 .02778 Metetra
.722 .776 .895 r
.39495 .02778 .39568 .03734 .41193 .03784 .41126 .02815 Metetra
.713 .782 .906 r
.41126 .02815 .41193 .03784 .4281 .03831 .42751 .02851 Metetra
.702 .784 .915 r
.42751 .02851 .4281 .03831 .44419 .03872 .4437 .02883 Metetra
.689 .783 .923 r
.4437 .02883 .44419 .03872 .4602 .03906 .45984 .02909 Metetra
.675 .779 .928 r
.45984 .02909 .4602 .03906 .47615 .03929 .47592 .02928 Metetra
.66 .772 .932 r
.47592 .02928 .47615 .03929 .49205 .03942 .49198 .02938 Metetra
.646 .763 .934 r
.49198 .02938 .49205 .03942 .50795 .03942 .50802 .02938 Metetra
.744 .592 .687 r
.96634 .02501 .96654 .0331 .98231 .03337 .98228 .02521 Metetra
.723 .564 .674 r
.95016 .02492 .9505 .03294 .96654 .0331 .96634 .02501 Metetra
.708 .543 .662 r
.93381 .02491 .93425 .03287 .9505 .03294 .95016 .02492 Metetra
.697 .527 .654 r
.91737 .02495 .91787 .03287 .93425 .03287 .93381 .02491 Metetra
.691 .518 .648 r
.90087 .02502 .90141 .03291 .91787 .03287 .91737 .02495 Metetra
.688 .513 .645 r
.88436 .02511 .8849 .03298 .90141 .03291 .90087 .02502 Metetra
.688 .514 .646 r
.86786 .02519 .86836 .03307 .8849 .03298 .88436 .02511 Metetra
.689 .519 .651 r
.85138 .02528 .85183 .03318 .86836 .03307 .86786 .02519 Metetra
.691 .527 .659 r
.83493 .02535 .83529 .03329 .85183 .03318 .85138 .02528 Metetra
.694 .538 .67 r
.8185 .02542 .81877 .0334 .83529 .03329 .83493 .02535 Metetra
.696 .551 .685 r
.80209 .02547 .80225 .03352 .81877 .0334 .8185 .02542 Metetra
.697 .565 .702 r
.78569 .02553 .78573 .03366 .80225 .03352 .80209 .02547 Metetra
.696 .579 .72 r
.7693 .02558 .76921 .03381 .78573 .03366 .78569 .02553 Metetra
.694 .594 .74 r
.7529 .02565 .75269 .03399 .76921 .03381 .7693 .02558 Metetra
.689 .608 .761 r
.73649 .02574 .73616 .0342 .75269 .03399 .7529 .02565 Metetra
.682 .621 .781 r
.72006 .02586 .71962 .03445 .73616 .0342 .73649 .02574 Metetra
.673 .633 .801 r
.70362 .02601 .70308 .03474 .71962 .03445 .72006 .02586 Metetra
.663 .644 .821 r
.68717 .02621 .68654 .03507 .70308 .03474 .70362 .02601 Metetra
.652 .653 .839 r
.67071 .02645 .67002 .03545 .68654 .03507 .68717 .02621 Metetra
.64 .662 .855 r
.65426 .02673 .65352 .03588 .67002 .03545 .67071 .02645 Metetra
.629 .67 .87 r
.63782 .02705 .63706 .03635 .65352 .03588 .65426 .02673 Metetra
.62 .678 .884 r
.62142 .02741 .62066 .03684 .63706 .03635 .63782 .02705 Metetra
.612 .686 .895 r
.60505 .02778 .60432 .03734 .62066 .03684 .62142 .02741 Metetra
.607 .696 .906 r
.58874 .02815 .58807 .03784 .60432 .03734 .60505 .02778 Metetra
.606 .705 .915 r
.57249 .02851 .5719 .03831 .58807 .03784 .58874 .02815 Metetra
.607 .716 .922 r
.5563 .02883 .55581 .03872 .5719 .03831 .57249 .02851 Metetra
.612 .728 .928 r
.54016 .02909 .5398 .03906 .55581 .03872 .5563 .02883 Metetra
.621 .74 .932 r
.52408 .02928 .52385 .03929 .5398 .03906 .54016 .02909 Metetra
.632 .752 .934 r
.50802 .02938 .50795 .03942 .52385 .03929 .52408 .02928 Metetra
.651 .53 .704 r
.01769 .03337 .01768 .04154 .03329 .04121 .03346 .0331 Metetra
.675 .539 .691 r
.03346 .0331 .03329 .04121 .04921 .041 .0495 .03294 Metetra
.693 .543 .679 r
.0495 .03294 .04921 .041 .06537 .04088 .06575 .03287 Metetra
.705 .545 .669 r
.06575 .03287 .06537 .04088 .08169 .04084 .08213 .03287 Metetra
.714 .546 .661 r
.08213 .03287 .08169 .04084 .09813 .04086 .09859 .03291 Metetra
.719 .547 .656 r
.09859 .03291 .09813 .04086 .11464 .04092 .1151 .03298 Metetra
.723 .549 .654 r
.1151 .03298 .11464 .04092 .13121 .04102 .13164 .03307 Metetra
.725 .551 .655 r
.13164 .03307 .13121 .04102 .1478 .04114 .14817 .03318 Metetra
.727 .556 .66 r
.14817 .03318 .1478 .04114 .16441 .04128 .16471 .03329 Metetra
.728 .564 .668 r
.16471 .03329 .16441 .04128 .18103 .04144 .18123 .0334 Metetra
.73 .574 .679 r
.18123 .0334 .18103 .04144 .19765 .04162 .19775 .03352 Metetra
.733 .587 .693 r
.19775 .03352 .19765 .04162 .21428 .04183 .21427 .03366 Metetra
.736 .602 .709 r
.21427 .03366 .21428 .04183 .23092 .04207 .23079 .03381 Metetra
.739 .62 .726 r
.23079 .03381 .23092 .04207 .24756 .04235 .24731 .03399 Metetra
.744 .64 .745 r
.24731 .03399 .24756 .04235 .26421 .04267 .26384 .0342 Metetra
.748 .661 .764 r
.26384 .0342 .26421 .04267 .28085 .04303 .28038 .03445 Metetra
.752 .682 .783 r
.28038 .03445 .28085 .04303 .29749 .04344 .29692 .03474 Metetra
.755 .703 .802 r
.29692 .03474 .29749 .04344 .31411 .0439 .31346 .03507 Metetra
.758 .724 .821 r
.31346 .03507 .31411 .0439 .3307 .04442 .32998 .03545 Metetra
.759 .743 .838 r
.32998 .03545 .3307 .04442 .34724 .04498 .34648 .03588 Metetra
.758 .759 .854 r
.34648 .03588 .34724 .04498 .36371 .04557 .36294 .03635 Metetra
.754 .774 .869 r
.36294 .03635 .36371 .04557 .38011 .04619 .37934 .03684 Metetra
.748 .785 .883 r
.37934 .03684 .38011 .04619 .39642 .04682 .39568 .03734 Metetra
.74 .793 .895 r
.39568 .03734 .39642 .04682 .41261 .04743 .41193 .03784 Metetra
.729 .798 .907 r
.41193 .03784 .41261 .04743 .4287 .04799 .4281 .03831 Metetra
.715 .798 .917 r
.4281 .03831 .4287 .04799 .44468 .04849 .44419 .03872 Metetra
.699 .795 .925 r
.44419 .03872 .44468 .04849 .46057 .0489 .4602 .03906 Metetra
.681 .788 .931 r
.4602 .03906 .46057 .0489 .47637 .04918 .47615 .03929 Metetra
.662 .778 .936 r
.47615 .03929 .47637 .04918 .49213 .04933 .49205 .03942 Metetra
.643 .766 .938 r
.49205 .03942 .49213 .04933 .50787 .04933 .50795 .03942 Metetra
.759 .607 .689 r
.96654 .0331 .96671 .04121 .98232 .04154 .98231 .03337 Metetra
.737 .579 .678 r
.9505 .03294 .95079 .041 .96671 .04121 .96654 .0331 Metetra
.719 .557 .668 r
.93425 .03287 .93463 .04088 .95079 .041 .9505 .03294 Metetra
.706 .54 .661 r
.91787 .03287 .91831 .04084 .93463 .04088 .93425 .03287 Metetra
.697 .529 .656 r
.90141 .03291 .90187 .04086 .91831 .04084 .91787 .03287 Metetra
.691 .522 .654 r
.8849 .03298 .88536 .04092 .90187 .04086 .90141 .03291 Metetra
.687 .521 .655 r
.86836 .03307 .86879 .04102 .88536 .04092 .8849 .03298 Metetra
.685 .523 .66 r
.85183 .03318 .8522 .04114 .86879 .04102 .86836 .03307 Metetra
.685 .528 .668 r
.83529 .03329 .83559 .04128 .8522 .04114 .85183 .03318 Metetra
.684 .536 .679 r
.81877 .0334 .81897 .04144 .83559 .04128 .83529 .03329 Metetra
.683 .546 .693 r
.80225 .03352 .80235 .04162 .81897 .04144 .81877 .0334 Metetra
.681 .558 .709 r
.78573 .03366 .78572 .04183 .80235 .04162 .80225 .03352 Metetra
.677 .57 .726 r
.76921 .03381 .76908 .04207 .78572 .04183 .78573 .03366 Metetra
.672 .582 .745 r
.75269 .03399 .75244 .04235 .76908 .04207 .76921 .03381 Metetra
.665 .593 .765 r
.73616 .0342 .73579 .04267 .75244 .04235 .75269 .03399 Metetra
.657 .604 .784 r
.71962 .03445 .71915 .04303 .73579 .04267 .73616 .0342 Metetra
.647 .615 .803 r
.70308 .03474 .70251 .04344 .71915 .04303 .71962 .03445 Metetra
.635 .624 .822 r
.68654 .03507 .68589 .0439 .70251 .04344 .70308 .03474 Metetra
.624 .633 .839 r
.67002 .03545 .6693 .04442 .68589 .0439 .68654 .03507 Metetra
.612 .641 .855 r
.65352 .03588 .65276 .04498 .6693 .04442 .67002 .03545 Metetra
.602 .65 .87 r
.63706 .03635 .63629 .04557 .65276 .04498 .65352 .03588 Metetra
.593 .659 .883 r
.62066 .03684 .61989 .04619 .63629 .04557 .63706 .03635 Metetra
.587 .668 .895 r
.60432 .03734 .60358 .04682 .61989 .04619 .62066 .03684 Metetra
.584 .679 .906 r
.58807 .03784 .58739 .04743 .60358 .04682 .60432 .03734 Metetra
.584 .691 .916 r
.5719 .03831 .5713 .04799 .58739 .04743 .58807 .03784 Metetra
.589 .705 .924 r
.55581 .03872 .55532 .04849 .5713 .04799 .5719 .03831 Metetra
.597 .72 .93 r
.5398 .03906 .53943 .0489 .55532 .04849 .55581 .03872 Metetra
.61 .735 .935 r
.52385 .03929 .52363 .04918 .53943 .0489 .5398 .03906 Metetra
.625 .751 .937 r
.50795 .03942 .50787 .04933 .52363 .04918 .52385 .03929 Metetra
.635 .518 .704 r
.01768 .04154 .01768 .04971 .03315 .04934 .03329 .04121 Metetra
.662 .53 .693 r
.03329 .04121 .03315 .04934 .04896 .04908 .04921 .041 Metetra
.683 .538 .683 r
.04921 .041 .04896 .04908 .06504 .04893 .06537 .04088 Metetra
.698 .544 .674 r
.06537 .04088 .06504 .04893 .08131 .04886 .08169 .04084 Metetra
.71 .548 .667 r
.08169 .04084 .08131 .04886 .09772 .04886 .09813 .04086 Metetra
.718 .552 .663 r
.09813 .04086 .09772 .04886 .11424 .04891 .11464 .04092 Metetra
.724 .556 .662 r
.11464 .04092 .11424 .04891 .13084 .04901 .13121 .04102 Metetra
.73 .562 .664 r
.13121 .04102 .13084 .04901 .14749 .04915 .1478 .04114 Metetra
.734 .569 .668 r
.1478 .04114 .14749 .04915 .16417 .04932 .16441 .04128 Metetra
.738 .579 .676 r
.16441 .04128 .16417 .04932 .18088 .04953 .18103 .04144 Metetra
.743 .591 .687 r
.18103 .04144 .18088 .04953 .1976 .04977 .19765 .04162 Metetra
.747 .605 .699 r
.19765 .04162 .1976 .04977 .21435 .05004 .21428 .04183 Metetra
.752 .622 .714 r
.21428 .04183 .21435 .05004 .2311 .05036 .23092 .04207 Metetra
.758 .64 .731 r
.23092 .04207 .2311 .05036 .24785 .05072 .24756 .04235 Metetra
.763 .66 .748 r
.24756 .04235 .24785 .05072 .26461 .05113 .26421 .04267 Metetra
.768 .681 .766 r
.26421 .04267 .26461 .05113 .28136 .0516 .28085 .04303 Metetra
.773 .702 .785 r
.28085 .04303 .28136 .0516 .29808 .05212 .29749 .04344 Metetra
.777 .723 .803 r
.29749 .04344 .29808 .05212 .31478 .0527 .31411 .0439 Metetra
.779 .743 .82 r
.31411 .0439 .31478 .0527 .33143 .05333 .3307 .04442 Metetra
.78 .762 .837 r
.3307 .04442 .33143 .05333 .348 .05401 .34724 .04498 Metetra
.778 .778 .852 r
.34724 .04498 .348 .05401 .3645 .05472 .36371 .04557 Metetra
.774 .792 .867 r
.36371 .04557 .3645 .05472 .38089 .05545 .38011 .04619 Metetra
.767 .803 .881 r
.38011 .04619 .38089 .05545 .39716 .05619 .39642 .04682 Metetra
.757 .81 .895 r
.39642 .04682 .39716 .05619 .4133 .0569 .41261 .04743 Metetra
.744 .813 .907 r
.41261 .04743 .4133 .0569 .42931 .05757 .4287 .04799 Metetra
.727 .812 .917 r
.4287 .04799 .42931 .05757 .44518 .05815 .44468 .04849 Metetra
.708 .807 .927 r
.44468 .04849 .44518 .05815 .46094 .05861 .46057 .0489 Metetra
.686 .798 .934 r
.46057 .0489 .46094 .05861 .47661 .05894 .47637 .04918 Metetra
.663 .785 .939 r
.47637 .04918 .47661 .05894 .49221 .05911 .49213 .04933 Metetra
.64 .768 .941 r
.49213 .04933 .49221 .05911 .50779 .05911 .50787 .04933 Metetra
.773 .621 .691 r
.96671 .04121 .96685 .04934 .98232 .04971 .98232 .04154 Metetra
.749 .592 .681 r
.95079 .041 .95104 .04908 .96685 .04934 .96671 .04121 Metetra
.73 .569 .673 r
.93463 .04088 .93496 .04893 .95104 .04908 .95079 .041 Metetra
.714 .551 .667 r
.91831 .04084 .91869 .04886 .93496 .04893 .93463 .04088 Metetra
.702 .539 .663 r
.90187 .04086 .90228 .04886 .91869 .04886 .91831 .04084 Metetra
.693 .53 .662 r
.88536 .04092 .88576 .04891 .90228 .04886 .90187 .04086 Metetra
.687 .526 .664 r
.86879 .04102 .86916 .04901 .88576 .04891 .88536 .04092 Metetra
.682 .526 .669 r
.8522 .04114 .85251 .04915 .86916 .04901 .86879 .04102 Metetra
.678 .529 .676 r
.83559 .04128 .83583 .04932 .85251 .04915 .8522 .04114 Metetra
.674 .534 .687 r
.81897 .04144 .81912 .04953 .83583 .04932 .83559 .04128 Metetra
.67 .542 .7 r
.80235 .04162 .8024 .04977 .81912 .04953 .81897 .04144 Metetra
.665 .55 .715 r
.78572 .04183 .78565 .05004 .8024 .04977 .80235 .04162 Metetra
.659 .559 .731 r
.76908 .04207 .7689 .05036 .78565 .05004 .78572 .04183 Metetra
.651 .569 .749 r
.75244 .04235 .75215 .05072 .7689 .05036 .76908 .04207 Metetra
.642 .578 .767 r
.73579 .04267 .73539 .05113 .75215 .05072 .75244 .04235 Metetra
.632 .587 .786 r
.71915 .04303 .71864 .0516 .73539 .05113 .73579 .04267 Metetra
.62 .596 .804 r
.70251 .04344 .70192 .05212 .71864 .0516 .71915 .04303 Metetra
.608 .604 .822 r
.68589 .0439 .68522 .0527 .70192 .05212 .70251 .04344 Metetra
.596 .612 .838 r
.6693 .04442 .66857 .05333 .68522 .0527 .68589 .0439 Metetra
.584 .62 .854 r
.65276 .04498 .652 .05401 .66857 .05333 .6693 .04442 Metetra
.574 .629 .868 r
.63629 .04557 .6355 .05472 .652 .05401 .65276 .04498 Metetra
.566 .638 .882 r
.61989 .04619 .61911 .05545 .6355 .05472 .63629 .04557 Metetra
.561 .649 .894 r
.60358 .04682 .60284 .05619 .61911 .05545 .61989 .04619 Metetra
.559 .662 .906 r
.58739 .04743 .5867 .0569 .60284 .05619 .60358 .04682 Metetra
.562 .677 .916 r
.5713 .04799 .57069 .05757 .5867 .0569 .58739 .04743 Metetra
.569 .693 .925 r
.55532 .04849 .55482 .05815 .57069 .05757 .5713 .04799 Metetra
.581 .711 .932 r
.53943 .0489 .53906 .05861 .55482 .05815 .55532 .04849 Metetra
.597 .731 .938 r
.52363 .04918 .52339 .05894 .53906 .05861 .53943 .0489 Metetra
.617 .75 .941 r
.50787 .04933 .50779 .05911 .52339 .05894 .52363 .04918 Metetra
.62 .507 .703 r
.01768 .04971 .01769 .05789 .03304 .05748 .03315 .04934 Metetra
.65 .522 .694 r
.03315 .04934 .03304 .05748 .04875 .05719 .04896 .04908 Metetra
.674 .534 .686 r
.04896 .04908 .04875 .05719 .06476 .05701 .06504 .04893 Metetra
.692 .542 .679 r
.06504 .04893 .06476 .05701 .08098 .05692 .08131 .04886 Metetra
.706 .549 .673 r
.08131 .04886 .08098 .05692 .09738 .05691 .09772 .04886 Metetra
.717 .556 .67 r
.09772 .04886 .09738 .05691 .11391 .05695 .11424 .04891 Metetra
.726 .563 .669 r
.11424 .04891 .11391 .05695 .13053 .05706 .13084 .04901 Metetra
.734 .571 .671 r
.13084 .04901 .13053 .05706 .14723 .05721 .14749 .04915 Metetra
.741 .581 .676 r
.14749 .04915 .14723 .05721 .16399 .05741 .16417 .04932 Metetra
.748 .592 .683 r
.16417 .04932 .16399 .05741 .18078 .05765 .18088 .04953 Metetra
.754 .606 .693 r
.18088 .04953 .18078 .05765 .19761 .05794 .1976 .04977 Metetra
.761 .621 .705 r
.1976 .04977 .19761 .05794 .21445 .05827 .21435 .05004 Metetra
.768 .639 .719 r
.21435 .05004 .21445 .05827 .23131 .05866 .2311 .05036 Metetra
.775 .658 .734 r
.2311 .05036 .23131 .05866 .24818 .0591 .24785 .05072 Metetra
.781 .679 .751 r
.24785 .05072 .24818 .0591 .26504 .0596 .26461 .05113 Metetra
.788 .7 .767 r
.26461 .05113 .26504 .0596 .28188 .06016 .28136 .0516 Metetra
.793 .721 .785 r
.28136 .0516 .28188 .06016 .2987 .06077 .29808 .05212 Metetra
.797 .742 .801 r
.29808 .05212 .2987 .06077 .31546 .06145 .31478 .0527 Metetra
.8 .762 .818 r
.31478 .0527 .31546 .06145 .33217 .06219 .33143 .05333 Metetra
.8 .78 .834 r
.33143 .05333 .33217 .06219 .34878 .06297 .348 .05401 Metetra
.798 .796 .85 r
.348 .05401 .34878 .06297 .36529 .06379 .3645 .05472 Metetra
.794 .809 .864 r
.3645 .05472 .36529 .06379 .38168 .06463 .38089 .05545 Metetra
.786 .819 .879 r
.38089 .05545 .38168 .06463 .39792 .06547 .39716 .05619 Metetra
.774 .826 .893 r
.39716 .05619 .39792 .06547 .414 .06627 .4133 .0569 Metetra
.759 .828 .906 r
.4133 .0569 .414 .06627 .42992 .06702 .42931 .05757 Metetra
.74 .826 .918 r
.42931 .05757 .42992 .06702 .44569 .06768 .44518 .05815 Metetra
.717 .819 .928 r
.44518 .05815 .44569 .06768 .46132 .06821 .46094 .05861 Metetra
.692 .808 .937 r
.46094 .05861 .46132 .06821 .47684 .06858 .47661 .05894 Metetra
.664 .791 .942 r
.47661 .05894 .47684 .06858 .49229 .06877 .49221 .05911 Metetra
.636 .772 .945 r
.49221 .05911 .49229 .06877 .50771 .06877 .50779 .05911 Metetra
.785 .632 .692 r
.96685 .04934 .96696 .05748 .98231 .05789 .98232 .04971 Metetra
.76 .604 .684 r
.95104 .04908 .95125 .05719 .96696 .05748 .96685 .04934 Metetra
.738 .58 .678 r
.93496 .04893 .93524 .05701 .95125 .05719 .95104 .04908 Metetra
.721 .561 .673 r
.91869 .04886 .91902 .05692 .93524 .05701 .93496 .04893 Metetra
.707 .547 .67 r
.90228 .04886 .90262 .05691 .91902 .05692 .91869 .04886 Metetra
.695 .537 .669 r
.88576 .04891 .88609 .05695 .90262 .05691 .90228 .04886 Metetra
.685 .531 .671 r
.86916 .04901 .86947 .05706 .88609 .05695 .88576 .04891 Metetra
.678 .529 .676 r
.85251 .04915 .85277 .05721 .86947 .05706 .86916 .04901 Metetra
.67 .529 .683 r
.83583 .04932 .83601 .05741 .85277 .05721 .85251 .04915 Metetra
.664 .532 .693 r
.81912 .04953 .81922 .05765 .83601 .05741 .83583 .04932 Metetra
.657 .536 .706 r
.8024 .04977 .80239 .05794 .81922 .05765 .81912 .04953 Metetra
.649 .542 .72 r
.78565 .05004 .78555 .05827 .80239 .05794 .8024 .04977 Metetra
.641 .549 .735 r
.7689 .05036 .76869 .05866 .78555 .05827 .78565 .05004 Metetra
.631 .556 .752 r
.75215 .05072 .75182 .0591 .76869 .05866 .7689 .05036 Metetra
.62 .563 .769 r
.73539 .05113 .73496 .0596 .75182 .0591 .75215 .05072 Metetra
.608 .57 .786 r
.71864 .0516 .71812 .06016 .73496 .0596 .73539 .05113 Metetra
.595 .577 .803 r
.70192 .05212 .7013 .06077 .71812 .06016 .71864 .0516 Metetra
.581 .584 .82 r
.68522 .0527 .68454 .06145 .7013 .06077 .70192 .05212 Metetra
.568 .591 .836 r
.66857 .05333 .66783 .06219 .68454 .06145 .68522 .0527 Metetra
.556 .599 .851 r
.652 .05401 .65122 .06297 .66783 .06219 .66857 .05333 Metetra
.546 .607 .866 r
.6355 .05472 .63471 .06379 .65122 .06297 .652 .05401 Metetra
.538 .617 .879 r
.61911 .05545 .61832 .06463 .63471 .06379 .6355 .05472 Metetra
.534 .629 .892 r
.60284 .05619 .60208 .06547 .61832 .06463 .61911 .05545 Metetra
.534 .644 .904 r
.5867 .0569 .586 .06627 .60208 .06547 .60284 .05619 Metetra
.539 .661 .915 r
.57069 .05757 .57008 .06702 .586 .06627 .5867 .0569 Metetra
.549 .681 .925 r
.55482 .05815 .55431 .06768 .57008 .06702 .57069 .05757 Metetra
.564 .702 .934 r
.53906 .05861 .53868 .06821 .55431 .06768 .55482 .05815 Metetra
.585 .726 .94 r
.52339 .05894 .52316 .06858 .53868 .06821 .53906 .05861 Metetra
.609 .749 .944 r
.50779 .05911 .50771 .06877 .52316 .06858 .52339 .05894 Metetra
.607 .497 .702 r
.01769 .05789 .0177 .06607 .03295 .06564 .03304 .05748 Metetra
.639 .515 .696 r
.03304 .05748 .03295 .06564 .04858 .06533 .04875 .05719 Metetra
.665 .529 .689 r
.04875 .05719 .04858 .06533 .06451 .06512 .06476 .05701 Metetra
.686 .541 .683 r
.06476 .05701 .06451 .06512 .0807 .06502 .08098 .05692 Metetra
.703 .551 .678 r
.08098 .05692 .0807 .06502 .09708 .06499 .09738 .05691 Metetra
.717 .56 .676 r
.09738 .05691 .09708 .06499 .11362 .06503 .11391 .05695 Metetra
.728 .57 .675 r
.11391 .05695 .11362 .06503 .13028 .06514 .13053 .05706 Metetra
.739 .58 .677 r
.13053 .05706 .13028 .06514 .14703 .06531 .14723 .05721 Metetra
.748 .592 .682 r
.14723 .05721 .14703 .06531 .16385 .06553 .16399 .05741 Metetra
.757 .605 .689 r
.16399 .05741 .16385 .06553 .18073 .06581 .18078 .05765 Metetra
.765 .62 .698 r
.18078 .05765 .18073 .06581 .19765 .06614 .19761 .05794 Metetra
.774 .637 .709 r
.19761 .05794 .19765 .06614 .2146 .06653 .21445 .05827 Metetra
.782 .655 .722 r
.21445 .05827 .2146 .06653 .23156 .06697 .23131 .05866 Metetra
.79 .675 .736 r
.23131 .05866 .23156 .06697 .24853 .06748 .24818 .0591 Metetra
.798 .696 .752 r
.24818 .0591 .24853 .06748 .26549 .06805 .26504 .0596 Metetra
.805 .717 .767 r
.26504 .0596 .26549 .06805 .28243 .06869 .28188 .06016 Metetra
.811 .738 .783 r
.28188 .06016 .28243 .06869 .29932 .06939 .2987 .06077 Metetra
.816 .759 .799 r
.2987 .06077 .29932 .06939 .31616 .07016 .31546 .06145 Metetra
.819 .778 .815 r
.31546 .06145 .31616 .07016 .33292 .07098 .33217 .06219 Metetra
.819 .796 .83 r
.33217 .06219 .33292 .07098 .34957 .07186 .34878 .06297 Metetra
.817 .812 .845 r
.34878 .06297 .34957 .07186 .3661 .07277 .36529 .06379 Metetra
.812 .825 .86 r
.36529 .06379 .3661 .07277 .38247 .07371 .38168 .06463 Metetra
.803 .835 .875 r
.38168 .06463 .38247 .07371 .39868 .07464 .39792 .06547 Metetra
.791 .841 .89 r
.39792 .06547 .39868 .07464 .4147 .07553 .414 .06627 Metetra
.774 .843 .904 r
.414 .06627 .4147 .07553 .43054 .07636 .42992 .06702 Metetra
.753 .84 .917 r
.42992 .06702 .43054 .07636 .44621 .07709 .44569 .06768 Metetra
.727 .831 .929 r
.44569 .06768 .44621 .07709 .46171 .07768 .46132 .06821 Metetra
.698 .818 .939 r
.46132 .06821 .46171 .07768 .47708 .07809 .47684 .06858 Metetra
.665 .798 .946 r
.47684 .06858 .47708 .07809 .49237 .07831 .49229 .06877 Metetra
.632 .775 .949 r
.49229 .06877 .49237 .07831 .50763 .07831 .50771 .06877 Metetra
.795 .642 .692 r
.96696 .05748 .96705 .06564 .9823 .06607 .98231 .05789 Metetra
.769 .614 .687 r
.95125 .05719 .95142 .06533 .96705 .06564 .96696 .05748 Metetra
.746 .59 .682 r
.93524 .05701 .93549 .06512 .95142 .06533 .95125 .05719 Metetra
.727 .57 .678 r
.91902 .05692 .9193 .06502 .93549 .06512 .93524 .05701 Metetra
.71 .554 .675 r
.90262 .05691 .90292 .06499 .9193 .06502 .91902 .05692 Metetra
.696 .543 .675 r
.88609 .05695 .88638 .06503 .90292 .06499 .90262 .05691 Metetra
.684 .535 .678 r
.86947 .05706 .86972 .06514 .88638 .06503 .88609 .05695 Metetra
.673 .53 .682 r
.85277 .05721 .85297 .06531 .86972 .06514 .86947 .05706 Metetra
.663 .528 .69 r
.83601 .05741 .83615 .06553 .85297 .06531 .85277 .05721 Metetra
.654 .529 .699 r
.81922 .05765 .81927 .06581 .83615 .06553 .83601 .05741 Metetra
.644 .531 .71 r
.80239 .05794 .80235 .06614 .81927 .06581 .81922 .05765 Metetra
.634 .534 .724 r
.78555 .05827 .7854 .06653 .80235 .06614 .80239 .05794 Metetra
.623 .538 .738 r
.76869 .05866 .76844 .06697 .7854 .06653 .78555 .05827 Metetra
.611 .543 .753 r
.75182 .0591 .75147 .06748 .76844 .06697 .76869 .05866 Metetra
.597 .548 .769 r
.73496 .0596 .73451 .06805 .75147 .06748 .75182 .0591 Metetra
.584 .553 .786 r
.71812 .06016 .71757 .06869 .73451 .06805 .73496 .0596 Metetra
.569 .558 .802 r
.7013 .06077 .70068 .06939 .71757 .06869 .71812 .06016 Metetra
.555 .563 .817 r
.68454 .06145 .68384 .07016 .70068 .06939 .7013 .06077 Metetra
.541 .569 .833 r
.66783 .06219 .66708 .07098 .68384 .07016 .68454 .06145 Metetra
.528 .576 .847 r
.65122 .06297 .65043 .07186 .66708 .07098 .66783 .06219 Metetra
.517 .585 .862 r
.63471 .06379 .6339 .07277 .65043 .07186 .65122 .06297 Metetra
.51 .595 .875 r
.61832 .06463 .61753 .07371 .6339 .07277 .63471 .06379 Metetra
.506 .608 .889 r
.60208 .06547 .60132 .07464 .61753 .07371 .61832 .06463 Metetra
.507 .625 .902 r
.586 .06627 .5853 .07553 .60132 .07464 .60208 .06547 Metetra
.514 .644 .914 r
.57008 .06702 .56946 .07636 .5853 .07553 .586 .06627 Metetra
.527 .667 .926 r
.55431 .06768 .55379 .07709 .56946 .07636 .57008 .06702 Metetra
.546 .693 .935 r
.53868 .06821 .53829 .07768 .55379 .07709 .55431 .06768 Metetra
.571 .72 .943 r
.52316 .06858 .52292 .07809 .53829 .07768 .53868 .06821 Metetra
.6 .748 .948 r
.50771 .06877 .50763 .07831 .52292 .07809 .52316 .06858 Metetra
.595 .487 .701 r
.0177 .06607 .01772 .07425 .03288 .0738 .03295 .06564 Metetra
.63 .508 .696 r
.03295 .06564 .03288 .0738 .04843 .07348 .04858 .06533 Metetra
.658 .526 .691 r
.04858 .06533 .04843 .07348 .06431 .07326 .06451 .06512 Metetra
.681 .54 .686 r
.06451 .06512 .06431 .07326 .08046 .07314 .0807 .06502 Metetra
.7 .552 .683 r
.0807 .06502 .08046 .07314 .09684 .0731 .09708 .06499 Metetra
.717 .564 .681 r
.09708 .06499 .09684 .0731 .11339 .07315 .11362 .06503 Metetra
.731 .576 .681 r
.11362 .06503 .11339 .07315 .13008 .07326 .13028 .06514 Metetra
.743 .588 .683 r
.13028 .06514 .13008 .07326 .14688 .07344 .14703 .06531 Metetra
.755 .602 .687 r
.14703 .06531 .14688 .07344 .16377 .07368 .16385 .06553 Metetra
.765 .616 .694 r
.16385 .06553 .16377 .07368 .18072 .07399 .18073 .06581 Metetra
.776 .633 .703 r
.18073 .06581 .18072 .07399 .19773 .07436 .19765 .06614 Metetra
.786 .65 .713 r
.19765 .06614 .19773 .07436 .21477 .07479 .2146 .06653 Metetra
.796 .67 .725 r
.2146 .06653 .21477 .07479 .23184 .07529 .23156 .06697 Metetra
.805 .69 .738 r
.23156 .06697 .23184 .07529 .2489 .07585 .24853 .06748 Metetra
.814 .711 .752 r
.24853 .06748 .2489 .07585 .26596 .07649 .26549 .06805 Metetra
.822 .732 .766 r
.26549 .06805 .26596 .07649 .28299 .07719 .28243 .06869 Metetra
.828 .753 .781 r
.28243 .06869 .28299 .07719 .29997 .07797 .29932 .06939 Metetra
.833 .774 .795 r
.29932 .06939 .29997 .07797 .31687 .07881 .31616 .07016 Metetra
.836 .793 .81 r
.31616 .07016 .31687 .07881 .33368 .07972 .33292 .07098 Metetra
.837 .811 .825 r
.33292 .07098 .33368 .07972 .35037 .08068 .34957 .07186 Metetra
.835 .827 .84 r
.34957 .07186 .35037 .08068 .3669 .08167 .3661 .07277 Metetra
.829 .84 .855 r
.3661 .07277 .3669 .08167 .38327 .08269 .38247 .07371 Metetra
.82 .849 .87 r
.38247 .07371 .38327 .08269 .39945 .0837 .39868 .07464 Metetra
.807 .856 .886 r
.39868 .07464 .39945 .0837 .41542 .08468 .4147 .07553 Metetra
.789 .857 .901 r
.4147 .07553 .41542 .08468 .43117 .08558 .43054 .07636 Metetra
.765 .854 .916 r
.43054 .07636 .43117 .08558 .44673 .08638 .44621 .07709 Metetra
.737 .844 .93 r
.44621 .07709 .44673 .08638 .4621 .08702 .46171 .07768 Metetra
.704 .828 .942 r
.46171 .07768 .4621 .08702 .47732 .08747 .47708 .07809 Metetra
.667 .806 .949 r
.47708 .07809 .47732 .08747 .49245 .08771 .49237 .07831 Metetra
.628 .778 .953 r
.49237 .07831 .49245 .08771 .50755 .08771 .50763 .07831 Metetra
.804 .651 .692 r
.96705 .06564 .96712 .0738 .98228 .07425 .9823 .06607 Metetra
.777 .623 .689 r
.95142 .06533 .95157 .07348 .96712 .0738 .96705 .06564 Metetra
.753 .598 .685 r
.93549 .06512 .93569 .07326 .95157 .07348 .95142 .06533 Metetra
.731 .578 .682 r
.9193 .06502 .91954 .07314 .93569 .07326 .93549 .06512 Metetra
.713 .561 .681 r
.90292 .06499 .90316 .0731 .91954 .07314 .9193 .06502 Metetra
.697 .548 .681 r
.88638 .06503 .88661 .07315 .90316 .0731 .90292 .06499 Metetra
.682 .538 .683 r
.86972 .06514 .86992 .07326 .88661 .07315 .88638 .06503 Metetra
.669 .531 .688 r
.85297 .06531 .85312 .07344 .86992 .07326 .86972 .06514 Metetra
.656 .527 .695 r
.83615 .06553 .83623 .07368 .85312 .07344 .85297 .06531 Metetra
.644 .525 .704 r
.81927 .06581 .81928 .07399 .83623 .07368 .83615 .06553 Metetra
.632 .525 .714 r
.80235 .06614 .80227 .07436 .81928 .07399 .81927 .06581 Metetra
.619 .525 .726 r
.7854 .06653 .78523 .07479 .80227 .07436 .80235 .06614 Metetra
.605 .527 .74 r
.76844 .06697 .76816 .07529 .78523 .07479 .7854 .06653 Metetra
.591 .529 .754 r
.75147 .06748 .7511 .07585 .76816 .07529 .76844 .06697 Metetra
.576 .532 .769 r
.73451 .06805 .73404 .07649 .7511 .07585 .75147 .06748 Metetra
.56 .535 .784 r
.71757 .06869 .71701 .07719 .73404 .07649 .73451 .06805 Metetra
.544 .538 .799 r
.70068 .06939 .70003 .07797 .71701 .07719 .71757 .06869 Metetra
.528 .542 .814 r
.68384 .07016 .68313 .07881 .70003 .07797 .70068 .06939 Metetra
.513 .547 .828 r
.66708 .07098 .66632 .07972 .68313 .07881 .68384 .07016 Metetra
.5 .554 .843 r
.65043 .07186 .64963 .08068 .66632 .07972 .66708 .07098 Metetra
.489 .562 .857 r
.6339 .07277 .6331 .08167 .64963 .08068 .65043 .07186 Metetra
.481 .573 .871 r
.61753 .07371 .61673 .08269 .6331 .08167 .6339 .07277 Metetra
.478 .587 .884 r
.60132 .07464 .60055 .0837 .61673 .08269 .61753 .07371 Metetra
.48 .604 .898 r
.5853 .07553 .58458 .08468 .60055 .0837 .60132 .07464 Metetra
.489 .626 .912 r
.56946 .07636 .56883 .08558 .58458 .08468 .5853 .07553 Metetra
.504 .652 .925 r
.55379 .07709 .55327 .08638 .56883 .08558 .56946 .07636 Metetra
.527 .682 .937 r
.53829 .07768 .5379 .08702 .55327 .08638 .55379 .07709 Metetra
.556 .714 .946 r
.52292 .07809 .52268 .08747 .5379 .08702 .53829 .07768 Metetra
.59 .747 .952 r
.50763 .07831 .50755 .08771 .52268 .08747 .52292 .07809 Metetra
.584 .479 .7 r
.01772 .07425 .01775 .08244 .03282 .08198 .03288 .0738 Metetra
.621 .503 .697 r
.03288 .0738 .03282 .08198 .0483 .08164 .04843 .07348 Metetra
.651 .522 .693 r
.04843 .07348 .0483 .08164 .06414 .08141 .06431 .07326 Metetra
.677 .539 .69 r
.06431 .07326 .06414 .08141 .08027 .08128 .08046 .07314 Metetra
.698 .554 .687 r
.08046 .07314 .08027 .08128 .09663 .08124 .09684 .0731 Metetra
.717 .568 .685 r
.09684 .0731 .09663 .08124 .1132 .08129 .11339 .07315 Metetra
.733 .582 .686 r
.11339 .07315 .1132 .08129 .12992 .08141 .13008 .07326 Metetra
.748 .596 .688 r
.13008 .07326 .12992 .08141 .14677 .0816 .14688 .07344 Metetra
.761 .611 .692 r
.14688 .07344 .14677 .0816 .16372 .08186 .16377 .07368 Metetra
.774 .627 .698 r
.16377 .07368 .16372 .08186 .18076 .08219 .18072 .07399 Metetra
.785 .644 .706 r
.18072 .07399 .18076 .08219 .19785 .08259 .19773 .07436 Metetra
.797 .663 .715 r
.19773 .07436 .19785 .08259 .21498 .08306 .21477 .07479 Metetra
.808 .683 .726 r
.21477 .07479 .21498 .08306 .23214 .0836 .23184 .07529 Metetra
.818 .703 .738 r
.23184 .07529 .23214 .0836 .2493 .08422 .2489 .07585 Metetra
.828 .725 .75 r
.2489 .07585 .2493 .08422 .26645 .0849 .26596 .07649 Metetra
.837 .746 .764 r
.26596 .07649 .26645 .0849 .28356 .08567 .28299 .07719 Metetra
.844 .767 .777 r
.28299 .07719 .28356 .08567 .30062 .08651 .29997 .07797 Metetra
.849 .787 .791 r
.29997 .07797 .30062 .08651 .31759 .08741 .31687 .07881 Metetra
.853 .807 .805 r
.31687 .07881 .31759 .08741 .33444 .08839 .33368 .07972 Metetra
.854 .824 .819 r
.33368 .07972 .33444 .08839 .35116 .08941 .35037 .08068 Metetra
.852 .84 .833 r
.35037 .08068 .35116 .08941 .36772 .09048 .3669 .08167 Metetra
.846 .853 .848 r
.3669 .08167 .36772 .09048 .38408 .09157 .38327 .08269 Metetra
.837 .863 .864 r
.38327 .08269 .38408 .09157 .40022 .09265 .39945 .0837 Metetra
.823 .869 .88 r
.39945 .0837 .40022 .09265 .41613 .0937 .41542 .08468 Metetra
.803 .871 .897 r
.41542 .08468 .41613 .0937 .43181 .09468 .43117 .08558 Metetra
.778 .867 .914 r
.43117 .08558 .43181 .09468 .44726 .09553 .44673 .08638 Metetra
.747 .857 .93 r
.44673 .08638 .44726 .09553 .4625 .09623 .4621 .08702 Metetra
.71 .839 .944 r
.4621 .08702 .4625 .09623 .47757 .09672 .47732 .08747 Metetra
.668 .813 .953 r
.47732 .08747 .47757 .09672 .49254 .09698 .49245 .08771 Metetra
.623 .781 .957 r
.49245 .08771 .49254 .09698 .50746 .09698 .50755 .08771 Metetra
.812 .659 .692 r
.96712 .0738 .96718 .08198 .98225 .08244 .98228 .07425 Metetra
.784 .63 .69 r
.95157 .07348 .9517 .08164 .96718 .08198 .96712 .0738 Metetra
.758 .605 .688 r
.93569 .07326 .93586 .08141 .9517 .08164 .95157 .07348 Metetra
.736 .584 .686 r
.91954 .07314 .91973 .08128 .93586 .08141 .93569 .07326 Metetra
.715 .566 .685 r
.90316 .0731 .90337 .08124 .91973 .08128 .91954 .07314 Metetra
.697 .552 .686 r
.88661 .07315 .8868 .08129 .90337 .08124 .90316 .0731 Metetra
.68 .54 .689 r
.86992 .07326 .87008 .08141 .8868 .08129 .88661 .07315 Metetra
.664 .532 .693 r
.85312 .07344 .85323 .0816 .87008 .08141 .86992 .07326 Metetra
.649 .525 .699 r
.83623 .07368 .83628 .08186 .85323 .0816 .85312 .07344 Metetra
.634 .521 .707 r
.81928 .07399 .81924 .08219 .83628 .08186 .83623 .07368 Metetra
.619 .518 .717 r
.80227 .07436 .80215 .08259 .81924 .08219 .81928 .07399 Metetra
.604 .516 .728 r
.78523 .07479 .78502 .08306 .80215 .08259 .80227 .07436 Metetra
.588 .516 .741 r
.76816 .07529 .76786 .0836 .78502 .08306 .78523 .07479 Metetra
.572 .516 .754 r
.7511 .07585 .7507 .08422 .76786 .0836 .76816 .07529 Metetra
.554 .516 .767 r
.73404 .07649 .73355 .0849 .7507 .08422 .7511 .07585 Metetra
.537 .517 .781 r
.71701 .07719 .71644 .08567 .73355 .0849 .73404 .07649 Metetra
.519 .519 .795 r
.70003 .07797 .69938 .08651 .71644 .08567 .71701 .07719 Metetra
.502 .521 .809 r
.68313 .07881 .68241 .08741 .69938 .08651 .70003 .07797 Metetra
.486 .525 .823 r
.66632 .07972 .66556 .08839 .68241 .08741 .68313 .07881 Metetra
.471 .53 .836 r
.64963 .08068 .64884 .08941 .66556 .08839 .66632 .07972 Metetra
.46 .538 .85 r
.6331 .08167 .63228 .09048 .64884 .08941 .64963 .08068 Metetra
.452 .549 .864 r
.61673 .08269 .61592 .09157 .63228 .09048 .6331 .08167 Metetra
.449 .564 .879 r
.60055 .0837 .59978 .09265 .61592 .09157 .61673 .08269 Metetra
.452 .583 .894 r
.58458 .08468 .58387 .0937 .59978 .09265 .60055 .0837 Metetra
.462 .607 .909 r
.56883 .08558 .56819 .09468 .58387 .0937 .58458 .08468 Metetra
.48 .636 .924 r
.55327 .08638 .55274 .09553 .56819 .09468 .56883 .08558 Metetra
.506 .67 .937 r
.5379 .08702 .5375 .09623 .55274 .09553 .55327 .08638 Metetra
.54 .707 .948 r
.52268 .08747 .52243 .09672 .5375 .09623 .5379 .08702 Metetra
.58 .745 .955 r
.50755 .08771 .50746 .09698 .52243 .09672 .52268 .08747 Metetra
.575 .471 .699 r
.01775 .08244 .01777 .09062 .03277 .09016 .03282 .08198 Metetra
.613 .497 .697 r
.03282 .08198 .03277 .09016 .0482 .08982 .0483 .08164 Metetra
.646 .519 .695 r
.0483 .08164 .0482 .08982 .064 .08958 .06414 .08141 Metetra
.673 .539 .692 r
.06414 .08141 .064 .08958 .0801 .08945 .08027 .08128 Metetra
.697 .556 .69 r
.08027 .08128 .0801 .08945 .09647 .08941 .09663 .08124 Metetra
.717 .572 .689 r
.09663 .08124 .09647 .08941 .11304 .08945 .1132 .08129 Metetra
.736 .587 .69 r
.1132 .08129 .11304 .08945 .1298 .08958 .12992 .08141 Metetra
.752 .603 .692 r
.12992 .08141 .1298 .08958 .1467 .08978 .14677 .0816 Metetra
.767 .62 .696 r
.14677 .0816 .1467 .08978 .16371 .09006 .16372 .08186 Metetra
.781 .637 .702 r
.16372 .08186 .16371 .09006 .18082 .09041 .18076 .08219 Metetra
.795 .655 .709 r
.18076 .08219 .18082 .09041 .19799 .09083 .19785 .08259 Metetra
.808 .675 .717 r
.19785 .08259 .19799 .09083 .21521 .09133 .21498 .08306 Metetra
.82 .695 .727 r
.21498 .08306 .21521 .09133 .23246 .09191 .23214 .0836 Metetra
.831 .716 .737 r
.23214 .0836 .23246 .09191 .24972 .09256 .2493 .08422 Metetra
.841 .737 .749 r
.2493 .08422 .24972 .09256 .26695 .0933 .26645 .0849 Metetra
.851 .758 .76 r
.26645 .0849 .26695 .0933 .28415 .09411 .28356 .08567 Metetra
.858 .779 .772 r
.28356 .08567 .28415 .09411 .30127 .09499 .30062 .08651 Metetra
.864 .799 .785 r
.30062 .08651 .30127 .09499 .3183 .09595 .31759 .08741 Metetra
.868 .819 .798 r
.31759 .08741 .3183 .09595 .33521 .09698 .33444 .08839 Metetra
.869 .836 .811 r
.33444 .08839 .33521 .09698 .35196 .09807 .35116 .08941 Metetra
.867 .852 .825 r
.35116 .08941 .35196 .09807 .36853 .09919 .36772 .09048 Metetra
.862 .865 .84 r
.36772 .09048 .36853 .09919 .38488 .10035 .38408 .09157 Metetra
.853 .876 .856 r
.38408 .09157 .38488 .10035 .401 .10149 .40022 .09265 Metetra
.838 .882 .873 r
.40022 .09265 .401 .10149 .41686 .10261 .41613 .0937 Metetra
.818 .885 .892 r
.41613 .0937 .41686 .10261 .43245 .10364 .43181 .09468 Metetra
.792 .881 .911 r
.43181 .09468 .43245 .10364 .44779 .10456 .44726 .09553 Metetra
.758 .87 .93 r
.44726 .09553 .44779 .10456 .4629 .10531 .4625 .09623 Metetra
.717 .85 .945 r
.4625 .09623 .4629 .10531 .47782 .10584 .47757 .09672 Metetra
.669 .822 .957 r
.47757 .09672 .47782 .10584 .49262 .10612 .49254 .09698 Metetra
.618 .785 .961 r
.49254 .09698 .49262 .10612 .50738 .10612 .50746 .09698 Metetra
.819 .665 .692 r
.96718 .08198 .96723 .09016 .98223 .09062 .98225 .08244 Metetra
.79 .637 .692 r
.9517 .08164 .9518 .08982 .96723 .09016 .96718 .08198 Metetra
.763 .612 .69 r
.93586 .08141 .936 .08958 .9518 .08982 .9517 .08164 Metetra
.739 .59 .689 r
.91973 .08128 .9199 .08945 .936 .08958 .93586 .08141 Metetra
.717 .571 .689 r
.90337 .08124 .90353 .08941 .9199 .08945 .91973 .08128 Metetra
.696 .555 .69 r
.8868 .08129 .88696 .08945 .90353 .08941 .90337 .08124 Metetra
.677 .542 .693 r
.87008 .08141 .8702 .08958 .88696 .08945 .8868 .08129 Metetra
.659 .531 .697 r
.85323 .0816 .8533 .08978 .8702 .08958 .87008 .08141 Metetra
.642 .523 .703 r
.83628 .08186 .83629 .09006 .8533 .08978 .85323 .0816 Metetra
.624 .516 .711 r
.81924 .08219 .81918 .09041 .83629 .09006 .83628 .08186 Metetra
.607 .511 .72 r
.80215 .08259 .80201 .09083 .81918 .09041 .81924 .08219 Metetra
.59 .507 .73 r
.78502 .08306 .78479 .09133 .80201 .09083 .80215 .08259 Metetra
.572 .504 .741 r
.76786 .0836 .76754 .09191 .78479 .09133 .78502 .08306 Metetra
.553 .502 .753 r
.7507 .08422 .75028 .09256 .76754 .09191 .76786 .0836 Metetra
.534 .5 .765 r
.73355 .0849 .73305 .0933 .75028 .09256 .7507 .08422 Metetra
.514 .499 .777 r
.71644 .08567 .71585 .09411 .73305 .0933 .73355 .0849 Metetra
.495 .499 .79 r
.69938 .08651 .69873 .09499 .71585 .09411 .71644 .08567 Metetra
.476 .5 .803 r
.68241 .08741 .6817 .09595 .69873 .09499 .69938 .08651 Metetra
.459 .502 .816 r
.66556 .08839 .66479 .09698 .6817 .09595 .68241 .08741 Metetra
.443 .507 .829 r
.64884 .08941 .64804 .09807 .66479 .09698 .66556 .08839 Metetra
.431 .514 .843 r
.63228 .09048 .63147 .09919 .64804 .09807 .64884 .08941 Metetra
.422 .524 .857 r
.61592 .09157 .61512 .10035 .63147 .09919 .63228 .09048 Metetra
.419 .54 .872 r
.59978 .09265 .599 .10149 .61512 .10035 .61592 .09157 Metetra
.422 .56 .888 r
.58387 .0937 .58314 .10261 .599 .10149 .59978 .09265 Metetra
.434 .586 .904 r
.56819 .09468 .56755 .10364 .58314 .10261 .58387 .0937 Metetra
.454 .619 .921 r
.55274 .09553 .55221 .10456 .56755 .10364 .56819 .09468 Metetra
.483 .657 .937 r
.5375 .09623 .5371 .10531 .55221 .10456 .55274 .09553 Metetra
.522 .699 .95 r
.52243 .09672 .52218 .10584 .5371 .10531 .5375 .09623 Metetra
.568 .743 .959 r
.50746 .09698 .50738 .10612 .52218 .10584 .52243 .09672 Metetra
.567 .464 .697 r
.01777 .09062 .01779 .0988 .03274 .09834 .03277 .09016 Metetra
.607 .493 .697 r
.03277 .09016 .03274 .09834 .04812 .098 .0482 .08982 Metetra
.641 .517 .696 r
.0482 .08982 .04812 .098 .06388 .09777 .064 .08958 Metetra
.671 .538 .695 r
.064 .08958 .06388 .09777 .07997 .09764 .0801 .08945 Metetra
.696 .557 .693 r
.0801 .08945 .07997 .09764 .09633 .09759 .09647 .08941 Metetra
.718 .575 .693 r
.09647 .08941 .09633 .09759 .11293 .09764 .11304 .08945 Metetra
.738 .593 .694 r
.11304 .08945 .11293 .09764 .12971 .09777 .1298 .08958 Metetra
.756 .61 .696 r
.1298 .08958 .12971 .09777 .14666 .09798 .1467 .08978 Metetra
.773 .628 .699 r
.1467 .08978 .14666 .09798 .16373 .09827 .16371 .09006 Metetra
.789 .646 .704 r
.16371 .09006 .16373 .09827 .18091 .09864 .18082 .09041 Metetra
.803 .665 .71 r
.18082 .09041 .18091 .09864 .19816 .09908 .19799 .09083 Metetra
.817 .685 .718 r
.19799 .09083 .19816 .09908 .21547 .0996 .21521 .09133 Metetra
.83 .706 .726 r
.21521 .09133 .21547 .0996 .2328 .10021 .23246 .09191 Metetra
.843 .727 .736 r
.23246 .09191 .2328 .10021 .25014 .10089 .24972 .09256 Metetra
.854 .748 .746 r
.24972 .09256 .25014 .10089 .26746 .10166 .26695 .0933 Metetra
.864 .769 .756 r
.26695 .0933 .26746 .10166 .28473 .1025 .28415 .09411 Metetra
.872 .79 .767 r
.28415 .09411 .28473 .1025 .30193 .10343 .30127 .09499 Metetra
.878 .81 .778 r
.30127 .09499 .30193 .10343 .31902 .10443 .3183 .09595 Metetra
.882 .829 .79 r
.3183 .09595 .31902 .10443 .33598 .1055 .33521 .09698 Metetra
.884 .847 .802 r
.33521 .09698 .33598 .1055 .35276 .10663 .35196 .09807 Metetra
.882 .863 .816 r
.35196 .09807 .35276 .10663 .36934 .10781 .36853 .09919 Metetra
.877 .876 .83 r
.36853 .09919 .36934 .10781 .38569 .10901 .38488 .10035 Metetra
.868 .887 .847 r
.38488 .10035 .38569 .10901 .40177 .11022 .401 .10149 Metetra
.854 .895 .865 r
.401 .10149 .40177 .11022 .41758 .11139 .41686 .10261 Metetra
.833 .898 .885 r
.41686 .10261 .41758 .11139 .4331 .11248 .43245 .10364 Metetra
.805 .894 .907 r
.43245 .10364 .4331 .11248 .44834 .11346 .44779 .10456 Metetra
.769 .883 .928 r
.44779 .10456 .44834 .11346 .46331 .11426 .4629 .10531 Metetra
.724 .862 .947 r
.4629 .10531 .46331 .11426 .47808 .11483 .47782 .10584 Metetra
.67 .83 .96 r
.47782 .10584 .47808 .11483 .49271 .11513 .49262 .10612 Metetra
.613 .789 .966 r
.49262 .10612 .49271 .11513 .50729 .11513 .50738 .10612 Metetra
.824 .67 .692 r
.96723 .09016 .96726 .09834 .98221 .0988 .98223 .09062 Metetra
.795 .642 .693 r
.9518 .08982 .95188 .098 .96726 .09834 .96723 .09016 Metetra
.767 .617 .693 r
.936 .08958 .93612 .09777 .95188 .098 .9518 .08982 Metetra
.742 .594 .692 r
.9199 .08945 .92003 .09764 .93612 .09777 .936 .08958 Metetra
.718 .575 .693 r
.90353 .08941 .90367 .09759 .92003 .09764 .9199 .08945 Metetra
.695 .557 .694 r
.88696 .08945 .88707 .09764 .90367 .09759 .90353 .08941 Metetra
.674 .543 .697 r
.8702 .08958 .87029 .09777 .88707 .09764 .88696 .08945 Metetra
.654 .53 .701 r
.8533 .08978 .85334 .09798 .87029 .09777 .8702 .08958 Metetra
.634 .52 .706 r
.83629 .09006 .83627 .09827 .85334 .09798 .8533 .08978 Metetra
.615 .511 .713 r
.81918 .09041 .81909 .09864 .83627 .09827 .83629 .09006 Metetra
.596 .504 .721 r
.80201 .09083 .80184 .09908 .81909 .09864 .81918 .09041 Metetra
.576 .498 .73 r
.78479 .09133 .78453 .0996 .80184 .09908 .80201 .09083 Metetra
.555 .493 .74 r
.76754 .09191 .7672 .10021 .78453 .0996 .78479 .09133 Metetra
.535 .488 .751 r
.75028 .09256 .74986 .10089 .7672 .10021 .76754 .09191 Metetra
.514 .484 .762 r
.73305 .0933 .73254 .10166 .74986 .10089 .75028 .09256 Metetra
.492 .481 .773 r
.71585 .09411 .71527 .1025 .73254 .10166 .73305 .0933 Metetra
.471 .479 .784 r
.69873 .09499 .69807 .10343 .71527 .1025 .71585 .09411 Metetra
.451 .478 .796 r
.6817 .09595 .68098 .10443 .69807 .10343 .69873 .09499 Metetra
.432 .479 .808 r
.66479 .09698 .66402 .1055 .68098 .10443 .6817 .09595 Metetra
.415 .482 .821 r
.64804 .09807 .64724 .10663 .66402 .1055 .66479 .09698 Metetra
.401 .489 .834 r
.63147 .09919 .63066 .10781 .64724 .10663 .64804 .09807 Metetra
.392 .499 .848 r
.61512 .10035 .61431 .10901 .63066 .10781 .63147 .09919 Metetra
.388 .514 .864 r
.599 .10149 .59823 .11022 .61431 .10901 .61512 .10035 Metetra
.392 .535 .88 r
.58314 .10261 .58242 .11139 .59823 .11022 .599 .10149 Metetra
.404 .564 .899 r
.56755 .10364 .5669 .11248 .58242 .11139 .58314 .10261 Metetra
.426 .599 .918 r
.55221 .10456 .55166 .11346 .5669 .11248 .56755 .10364 Metetra
.458 .642 .936 r
.5371 .10531 .53669 .11426 .55166 .11346 .55221 .10456 Metetra
.502 .69 .952 r
.52218 .10584 .52192 .11483 .53669 .11426 .5371 .10531 Metetra
.555 .74 .963 r
.50738 .10612 .50729 .11513 .52192 .11483 .52218 .10584 Metetra
.56 .458 .696 r
.01779 .0988 .01781 .10698 .03271 .10653 .03274 .09834 Metetra
.601 .489 .698 r
.03274 .09834 .03271 .10653 .04805 .1062 .04812 .098 Metetra
.637 .515 .697 r
.04812 .098 .04805 .1062 .06379 .10597 .06388 .09777 Metetra
.668 .538 .697 r
.06388 .09777 .06379 .10597 .07986 .10584 .07997 .09764 Metetra
.695 .559 .696 r
.07997 .09764 .07986 .10584 .09623 .1058 .09633 .09759 Metetra
.72 .579 .696 r
.09633 .09759 .09623 .1058 .11284 .10584 .11293 .09764 Metetra
.741 .598 .697 r
.11293 .09764 .11284 .10584 .12966 .10598 .12971 .09777 Metetra
.761 .616 .699 r
.12971 .09777 .12966 .10598 .14665 .10619 .14666 .09798 Metetra
.779 .635 .702 r
.14666 .09798 .14665 .10619 .16378 .10649 .16373 .09827 Metetra
.796 .654 .706 r
.16373 .09827 .16378 .10649 .18102 .10687 .18091 .09864 Metetra
.812 .674 .712 r
.18091 .09864 .18102 .10687 .19835 .10733 .19816 .09908 Metetra
.827 .695 .718 r
.19816 .09908 .19835 .10733 .21574 .10787 .21547 .0996 Metetra
.841 .715 .725 r
.21547 .0996 .21574 .10787 .23316 .10849 .2328 .10021 Metetra
.854 .736 .733 r
.2328 .10021 .23316 .10849 .25058 .1092 .25014 .10089 Metetra
.865 .758 .742 r
.25014 .10089 .25058 .1092 .26798 .10999 .26746 .10166 Metetra
.876 .779 .751 r
.26746 .10166 .26798 .10999 .28532 .11086 .28473 .1025 Metetra
.884 .799 .761 r
.28473 .1025 .28532 .11086 .30259 .11181 .30193 .10343 Metetra
.891 .819 .771 r
.30193 .10343 .30259 .11181 .31974 .11284 .31902 .10443 Metetra
.896 .838 .781 r
.31902 .10443 .31974 .11284 .33674 .11395 .33598 .1055 Metetra
.897 .856 .793 r
.33598 .1055 .33674 .11395 .35355 .11511 .35276 .10663 Metetra
.896 .872 .805 r
.35276 .10663 .35355 .11511 .37015 .11633 .36934 .10781 Metetra
.892 .886 .819 r
.36934 .10781 .37015 .11633 .38649 .11757 .38569 .10901 Metetra
.883 .897 .836 r
.38569 .10901 .38649 .11757 .40255 .11882 .40177 .11022 Metetra
.869 .906 .855 r
.40177 .11022 .40255 .11882 .41831 .12004 .41758 .11139 Metetra
.848 .91 .877 r
.41758 .11139 .41831 .12004 .43375 .12119 .4331 .11248 Metetra
.819 .907 .9 r
.4331 .11248 .43375 .12119 .44889 .12222 .44834 .11346 Metetra
.781 .897 .925 r
.44834 .11346 .44889 .12222 .46373 .12307 .46331 .11426 Metetra
.731 .874 .947 r
.46331 .11426 .46373 .12307 .47834 .12368 .47808 .11483 Metetra
.672 .839 .964 r
.47808 .11483 .47834 .12368 .4928 .124 .49271 .11513 Metetra
.606 .792 .97 r
.49271 .11513 .4928 .124 .5072 .124 .50729 .11513 Metetra
.829 .675 .691 r
.96726 .09834 .96729 .10653 .98219 .10698 .98221 .0988 Metetra
.799 .647 .694 r
.95188 .098 .95195 .1062 .96729 .10653 .96726 .09834 Metetra
.771 .622 .694 r
.93612 .09777 .93621 .10597 .95195 .1062 .95188 .098 Metetra
.744 .598 .695 r
.92003 .09764 .92014 .10584 .93621 .10597 .93612 .09777 Metetra
.718 .578 .696 r
.90367 .09759 .90377 .1058 .92014 .10584 .92003 .09764 Metetra
.694 .559 .698 r
.88707 .09764 .88716 .10584 .90377 .1058 .90367 .09759 Metetra
.671 .543 .7 r
.87029 .09777 .87034 .10598 .88716 .10584 .88707 .09764 Metetra
.649 .529 .704 r
.85334 .09798 .85335 .10619 .87034 .10598 .87029 .09777 Metetra
.627 .517 .709 r
.83627 .09827 .83622 .10649 .85335 .10619 .85334 .09798 Metetra
.606 .506 .715 r
.81909 .09864 .81898 .10687 .83622 .10649 .83627 .09827 Metetra
.584 .497 .722 r
.80184 .09908 .80165 .10733 .81898 .10687 .81909 .09864 Metetra
.562 .488 .73 r
.78453 .0996 .78426 .10787 .80165 .10733 .80184 .09908 Metetra
.54 .481 .739 r
.7672 .10021 .76684 .10849 .78426 .10787 .78453 .0996 Metetra
.517 .474 .748 r
.74986 .10089 .74942 .1092 .76684 .10849 .7672 .10021 Metetra
.494 .468 .758 r
.73254 .10166 .73202 .10999 .74942 .1092 .74986 .10089 Metetra
.471 .463 .768 r
.71527 .1025 .71468 .11086 .73202 .10999 .73254 .10166 Metetra
.448 .459 .778 r
.69807 .10343 .69741 .11181 .71468 .11086 .71527 .1025 Metetra
.426 .456 .788 r
.68098 .10443 .68026 .11284 .69741 .11181 .69807 .10343 Metetra
.405 .456 .799 r
.66402 .1055 .66326 .11395 .68026 .11284 .68098 .10443 Metetra
.387 .457 .811 r
.64724 .10663 .64645 .11511 .66326 .11395 .66402 .1055 Metetra
.372 .463 .824 r
.63066 .10781 .62985 .11633 .64645 .11511 .64724 .10663 Metetra
.361 .472 .838 r
.61431 .10901 .61351 .11757 .62985 .11633 .63066 .10781 Metetra
.357 .487 .854 r
.59823 .11022 .59745 .11882 .61351 .11757 .61431 .10901 Metetra
.36 .509 .871 r
.58242 .11139 .58169 .12004 .59745 .11882 .59823 .11022 Metetra
.372 .539 .891 r
.5669 .11248 .56625 .12119 .58169 .12004 .58242 .11139 Metetra
.395 .578 .913 r
.55166 .11346 .55111 .12222 .56625 .12119 .5669 .11248 Metetra
.431 .625 .934 r
.53669 .11426 .53627 .12307 .55111 .12222 .55166 .11346 Metetra
.48 .679 .953 r
.52192 .11483 .52166 .12368 .53627 .12307 .53669 .11426 Metetra
.54 .737 .966 r
.50729 .11513 .5072 .124 .52166 .12368 .52192 .11483 Metetra
.554 .454 .695 r
.01781 .10698 .01783 .11516 .03269 .11473 .03271 .10653 Metetra
.597 .485 .698 r
.03271 .10653 .03269 .11473 .048 .1144 .04805 .1062 Metetra
.634 .513 .698 r
.04805 .1062 .048 .1144 .06371 .11417 .06379 .10597 Metetra
.667 .538 .699 r
.06379 .10597 .06371 .11417 .07978 .11405 .07986 .10584 Metetra
.695 .561 .699 r
.07986 .10584 .07978 .11405 .09615 .11401 .09623 .1058 Metetra
.721 .582 .699 r
.09623 .1058 .09615 .11401 .11278 .11406 .11284 .10584 Metetra
.744 .602 .7 r
.11284 .10584 .11278 .11406 .12963 .1142 .12966 .10598 Metetra
.765 .622 .701 r
.12966 .10598 .12963 .1142 .14666 .11442 .14665 .10619 Metetra
.785 .642 .704 r
.14665 .10619 .14666 .11442 .16385 .11472 .16378 .10649 Metetra
.803 .662 .708 r
.16378 .10649 .16385 .11472 .18116 .11511 .18102 .10687 Metetra
.819 .682 .712 r
.18102 .10687 .18116 .11511 .19856 .11557 .19835 .10733 Metetra
.835 .703 .718 r
.19835 .10733 .19856 .11557 .21602 .11612 .21574 .10787 Metetra
.85 .724 .724 r
.21574 .10787 .21602 .11612 .23352 .11676 .23316 .10849 Metetra
.864 .745 .731 r
.23316 .10849 .23352 .11676 .25102 .11748 .25058 .1092 Metetra
.876 .766 .738 r
.25058 .1092 .25102 .11748 .26849 .11828 .26798 .10999 Metetra
.887 .787 .745 r
.26798 .10999 .26849 .11828 .28591 .11917 .28532 .11086 Metetra
.896 .808 .754 r
.28532 .11086 .28591 .11917 .30324 .12014 .30259 .11181 Metetra
.903 .827 .762 r
.30259 .11181 .30324 .12014 .32044 .12119 .31974 .11284 Metetra
.908 .846 .771 r
.31974 .11284 .32044 .12119 .33749 .12231 .33674 .11395 Metetra
.91 .864 .782 r
.33674 .11395 .33749 .12231 .35433 .1235 .35355 .11511 Metetra
.909 .88 .793 r
.35355 .11511 .35433 .1235 .37094 .12474 .37015 .11633 Metetra
.905 .894 .807 r
.37015 .11633 .37094 .12474 .38729 .12602 .38649 .11757 Metetra
.897 .906 .823 r
.38649 .11757 .38729 .12602 .40333 .1273 .40255 .11882 Metetra
.883 .916 .843 r
.40255 .11882 .40333 .1273 .41904 .12856 .41831 .12004 Metetra
.863 .921 .866 r
.41831 .12004 .41904 .12856 .43441 .12976 .43375 .12119 Metetra
.834 .92 .892 r
.43375 .12119 .43441 .12976 .44945 .13084 .44889 .12222 Metetra
.794 .91 .92 r
.44889 .12222 .44945 .13084 .46416 .13174 .46373 .12307 Metetra
.74 .888 .947 r
.46373 .12307 .46416 .13174 .47862 .13239 .47834 .12368 Metetra
.674 .849 .967 r
.47834 .12368 .47862 .13239 .49289 .13273 .4928 .124 Metetra
.599 .796 .975 r
.4928 .124 .49289 .13273 .50711 .13273 .5072 .124 Metetra
.833 .678 .691 r
.96729 .10653 .96731 .11473 .98217 .11516 .98219 .10698 Metetra
.803 .651 .694 r
.95195 .1062 .952 .1144 .96731 .11473 .96729 .10653 Metetra
.773 .625 .696 r
.93621 .10597 .93629 .11417 .952 .1144 .95195 .1062 Metetra
.745 .602 .697 r
.92014 .10584 .92022 .11405 .93629 .11417 .93621 .10597 Metetra
.719 .58 .699 r
.90377 .1058 .90385 .11401 .92022 .11405 .92014 .10584 Metetra
.693 .56 .7 r
.88716 .10584 .88722 .11406 .90385 .11401 .90377 .1058 Metetra
.668 .543 .703 r
.87034 .10598 .87037 .1142 .88722 .11406 .88716 .10584 Metetra
.644 .527 .706 r
.85335 .10619 .85334 .11442 .87037 .1142 .87034 .10598 Metetra
.62 .513 .711 r
.83622 .10649 .83615 .11472 .85334 .11442 .85335 .10619 Metetra
.597 .501 .716 r
.81898 .10687 .81884 .11511 .83615 .11472 .83622 .10649 Metetra
.573 .489 .722 r
.80165 .10733 .80144 .11557 .81884 .11511 .81898 .10687 Metetra
.549 .479 .729 r
.78426 .10787 .78398 .11612 .80144 .11557 .80165 .10733 Metetra
.525 .469 .736 r
.76684 .10849 .76648 .11676 .78398 .11612 .78426 .10787 Metetra
.5 .46 .744 r
.74942 .1092 .74898 .11748 .76648 .11676 .76684 .10849 Metetra
.475 .452 .753 r
.73202 .10999 .73151 .11828 .74898 .11748 .74942 .1092 Metetra
.45 .445 .762 r
.71468 .11086 .71409 .11917 .73151 .11828 .73202 .10999 Metetra
.425 .439 .77 r
.69741 .11181 .69676 .12014 .71409 .11917 .71468 .11086 Metetra
.402 .435 .78 r
.68026 .11284 .67956 .12119 .69676 .12014 .69741 .11181 Metetra
.379 .432 .79 r
.66326 .11395 .66251 .12231 .67956 .12119 .68026 .11284 Metetra
.359 .432 .801 r
.64645 .11511 .64567 .1235 .66251 .12231 .66326 .11395 Metetra
.343 .436 .813 r
.62985 .11633 .62906 .12474 .64567 .1235 .64645 .11511 Metetra
.331 .445 .826 r
.61351 .11757 .61271 .12602 .62906 .12474 .62985 .11633 Metetra
.324 .459 .842 r
.59745 .11882 .59667 .1273 .61271 .12602 .61351 .11757 Metetra
.326 .481 .861 r
.58169 .12004 .58096 .12856 .59667 .1273 .59745 .11882 Metetra
.338 .512 .882 r
.56625 .12119 .56559 .12976 .58096 .12856 .58169 .12004 Metetra
.363 .554 .906 r
.55111 .12222 .55055 .13084 .56559 .12976 .56625 .12119 Metetra
.402 .606 .931 r
.53627 .12307 .53584 .13174 .55055 .13084 .55111 .12222 Metetra
.456 .667 .953 r
.52166 .12368 .52138 .13239 .53584 .13174 .53627 .12307 Metetra
.523 .732 .97 r
.5072 .124 .50711 .13273 .52138 .13239 .52166 .12368 Metetra
.549 .449 .694 r
.01783 .11516 .01785 .12333 .03267 .12292 .03269 .11473 Metetra
.593 .483 .698 r
.03269 .11473 .03267 .12292 .04796 .12261 .048 .1144 Metetra
.631 .512 .699 r
.048 .1144 .04796 .12261 .06365 .12239 .06371 .11417 Metetra
.665 .539 .7 r
.06371 .11417 .06365 .12239 .07971 .12227 .07978 .11405 Metetra
.695 .563 .701 r
.07978 .11405 .07971 .12227 .09609 .12223 .09615 .11401 Metetra
.723 .585 .701 r
.09615 .11401 .09609 .12223 .11274 .12229 .11278 .11406 Metetra
.747 .607 .702 r
.11278 .11406 .11274 .12229 .12962 .12243 .12963 .1142 Metetra
.769 .628 .703 r
.12963 .1142 .12962 .12243 .1467 .12265 .14666 .11442 Metetra
.79 .648 .706 r
.14666 .11442 .1467 .12265 .16394 .12295 .16385 .11472 Metetra
.809 .669 .709 r
.16385 .11472 .16394 .12295 .18131 .12334 .18116 .11511 Metetra
.827 .69 .712 r
.18116 .11511 .18131 .12334 .19878 .12381 .19856 .11557 Metetra
.843 .711 .717 r
.19856 .11557 .19878 .12381 .21631 .12437 .21602 .11612 Metetra
.859 .732 .722 r
.21602 .11612 .21631 .12437 .23388 .125 .23352 .11676 Metetra
.873 .753 .727 r
.23352 .11676 .23388 .125 .25145 .12573 .25102 .11748 Metetra
.886 .774 .733 r
.25102 .11748 .25145 .12573 .269 .12654 .26849 .11828 Metetra
.897 .794 .739 r
.26849 .11828 .269 .12654 .28649 .12743 .28591 .11917 Metetra
.906 .815 .746 r
.28591 .11917 .28649 .12743 .30388 .1284 .30324 .12014 Metetra
.914 .834 .753 r
.30324 .12014 .30388 .1284 .32114 .12946 .32044 .12119 Metetra
.919 .852 .761 r
.32044 .12119 .32114 .12946 .33822 .13059 .33749 .12231 Metetra
.922 .87 .77 r
.33749 .12231 .33822 .13059 .3551 .13179 .35433 .1235 Metetra
.922 .886 .78 r
.35433 .1235 .3551 .13179 .37173 .13305 .37094 .12474 Metetra
.918 .901 .793 r
.37094 .12474 .37173 .13305 .38808 .13434 .38729 .12602 Metetra
.91 .914 .809 r
.38729 .12602 .38808 .13434 .4041 .13565 .40333 .1273 Metetra
.898 .924 .829 r
.40333 .1273 .4041 .13565 .41977 .13695 .41904 .12856 Metetra
.878 .931 .853 r
.41904 .12856 .41977 .13695 .43508 .13819 .43441 .12976 Metetra
.849 .932 .882 r
.43441 .12976 .43508 .13819 .45001 .13931 .44945 .13084 Metetra
.807 .924 .914 r
.44945 .13084 .45001 .13931 .4646 .14026 .46416 .13174 Metetra
.75 .901 .945 r
.46416 .13174 .4646 .14026 .47889 .14096 .47862 .13239 Metetra
.676 .86 .969 r
.47862 .13239 .47889 .14096 .49299 .14133 .49289 .13273 Metetra
.591 .8 .979 r
.49289 .13273 .49299 .14133 .50701 .14133 .50711 .13273 Metetra
.836 .681 .691 r
.96731 .11473 .96733 .12292 .98215 .12333 .98217 .11516 Metetra
.805 .654 .695 r
.952 .1144 .95204 .12261 .96733 .12292 .96731 .11473 Metetra
.776 .628 .698 r
.93629 .11417 .93635 .12239 .95204 .12261 .952 .1144 Metetra
.747 .604 .699 r
.92022 .11405 .92029 .12227 .93635 .12239 .93629 .11417 Metetra
.718 .582 .701 r
.90385 .11401 .90391 .12223 .92029 .12227 .92022 .11405 Metetra
.691 .561 .703 r
.88722 .11406 .88726 .12229 .90391 .12223 .90385 .11401 Metetra
.665 .542 .705 r
.87037 .1142 .87038 .12243 .88726 .12229 .88722 .11406 Metetra
.639 .525 .708 r
.85334 .11442 .8533 .12265 .87038 .12243 .87037 .1142 Metetra
.613 .509 .712 r
.83615 .11472 .83606 .12295 .8533 .12265 .85334 .11442 Metetra
.588 .495 .716 r
.81884 .11511 .81869 .12334 .83606 .12295 .83615 .11472 Metetra
.562 .482 .722 r
.80144 .11557 .80122 .12381 .81869 .12334 .81884 .11511 Metetra
.536 .469 .727 r
.78398 .11612 .78369 .12437 .80122 .12381 .80144 .11557 Metetra
.51 .457 .734 r
.76648 .11676 .76612 .125 .78369 .12437 .78398 .11612 Metetra
.484 .446 .74 r
.74898 .11748 .74855 .12573 .76612 .125 .76648 .11676 Metetra
.457 .436 .747 r
.73151 .11828 .731 .12654 .74855 .12573 .74898 .11748 Metetra
.43 .427 .755 r
.71409 .11917 .71351 .12743 .731 .12654 .73151 .11828 Metetra
.404 .419 .762 r
.69676 .12014 .69612 .1284 .71351 .12743 .71409 .11917 Metetra
.378 .413 .77 r
.67956 .12119 .67886 .12946 .69612 .1284 .69676 .12014 Metetra
.354 .408 .779 r
.66251 .12231 .66178 .13059 .67886 .12946 .67956 .12119 Metetra
.332 .407 .789 r
.64567 .1235 .6449 .13179 .66178 .13059 .66251 .12231 Metetra
.313 .409 .8 r
.62906 .12474 .62827 .13305 .6449 .13179 .64567 .1235 Metetra
.299 .416 .813 r
.61271 .12602 .61192 .13434 .62827 .13305 .62906 .12474 Metetra
.292 .43 .829 r
.59667 .1273 .5959 .13565 .61192 .13434 .61271 .12602 Metetra
.292 .451 .848 r
.58096 .12856 .58023 .13695 .5959 .13565 .59667 .1273 Metetra
.303 .483 .871 r
.56559 .12976 .56492 .13819 .58023 .13695 .58096 .12856 Metetra
.328 .527 .897 r
.55055 .13084 .54999 .13931 .56492 .13819 .56559 .12976 Metetra
.369 .583 .925 r
.53584 .13174 .5354 .14026 .54999 .13931 .55055 .13084 Metetra
.428 .652 .953 r
.52138 .13239 .52111 .14096 .5354 .14026 .53584 .13174 Metetra
.504 .727 .973 r
.50711 .13273 .50701 .14133 .52111 .14096 .52138 .13239 Metetra
.545 .446 .693 r
.01785 .12333 .01786 .13151 .03266 .13111 .03267 .12292 Metetra
.59 .48 .697 r
.03267 .12292 .03266 .13111 .04793 .13082 .04796 .12261 Metetra
.629 .511 .7 r
.04796 .12261 .04793 .13082 .06361 .13061 .06365 .12239 Metetra
.665 .539 .702 r
.06365 .12239 .06361 .13061 .07967 .13049 .07971 .12227 Metetra
.696 .564 .702 r
.07971 .12227 .07967 .13049 .09605 .13046 .09609 .12223 Metetra
.724 .588 .703 r
.09609 .12223 .09605 .13046 .11272 .13052 .11274 .12229 Metetra
.75 .611 .704 r
.11274 .12229 .11272 .13052 .12963 .13066 .12962 .12243 Metetra
.773 .633 .705 r
.12962 .12243 .12963 .13066 .14675 .13088 .1467 .12265 Metetra
.795 .654 .707 r
.1467 .12265 .14675 .13088 .16404 .13119 .16394 .12295 Metetra
.815 .675 .709 r
.16394 .12295 .16404 .13119 .18147 .13157 .18131 .12334 Metetra
.834 .696 .712 r
.18131 .12334 .18147 .13157 .199 .13204 .19878 .12381 Metetra
.851 .717 .715 r
.19878 .12381 .199 .13204 .2166 .13259 .21631 .12437 Metetra
.867 .739 .719 r
.21631 .12437 .2166 .13259 .23424 .13323 .23388 .125 Metetra
.882 .76 .723 r
.23388 .125 .23424 .13323 .25189 .13395 .25145 .12573 Metetra
.895 .78 .727 r
.25145 .12573 .25189 .13395 .2695 .13475 .269 .12654 Metetra
.906 .801 .732 r
.269 .12654 .2695 .13475 .28706 .13564 .28649 .12743 Metetra
.916 .82 .737 r
.28649 .12743 .28706 .13564 .30451 .13661 .30388 .1284 Metetra
.924 .839 .743 r
.30388 .1284 .30451 .13661 .32182 .13767 .32114 .12946 Metetra
.929 .858 .749 r
.32114 .12946 .32182 .13767 .33895 .1388 .33822 .13059 Metetra
.932 .875 .757 r
.33822 .13059 .33895 .1388 .35586 .14 .3551 .13179 Metetra
.933 .891 .766 r
.3551 .13179 .35586 .14 .3725 .14125 .37173 .13305 Metetra
.93 .906 .778 r
.37173 .13305 .3725 .14125 .38885 .14256 .38808 .13434 Metetra
.923 .92 .793 r
.38808 .13434 .38885 .14256 .40486 .14388 .4041 .13565 Metetra
.911 .931 .812 r
.4041 .13565 .40486 .14388 .4205 .1452 .41977 .13695 Metetra
.892 .94 .837 r
.41977 .13695 .4205 .1452 .43574 .14647 .43508 .13819 Metetra
.864 .943 .868 r
.43508 .13819 .43574 .14647 .45059 .14764 .45001 .13931 Metetra
.821 .937 .905 r
.45001 .13931 .45059 .14764 .46505 .14864 .4646 .14026 Metetra
.76 .916 .942 r
.4646 .14026 .46505 .14864 .47918 .14938 .47889 .14096 Metetra
.679 .872 .972 r
.47889 .14096 .47918 .14938 .49307 .14946 .49299 .14133 Metetra
.616 .786 .963 r
.49299 .14133 .49307 .14946 .50693 .14946 .50701 .14133 Metetra
.839 .684 .691 r
.96733 .12292 .96734 .13111 .98214 .13151 .98215 .12333 Metetra
.808 .657 .695 r
.95204 .12261 .95207 .13082 .96734 .13111 .96733 .12292 Metetra
.777 .631 .699 r
.93635 .12239 .93639 .13061 .95207 .13082 .95204 .12261 Metetra
.747 .606 .701 r
.92029 .12227 .92033 .13049 .93639 .13061 .93635 .12239 Metetra
.718 .583 .703 r
.90391 .12223 .90395 .13046 .92033 .13049 .92029 .12227 Metetra
.69 .561 .705 r
.88726 .12229 .88728 .13052 .90395 .13046 .90391 .12223 Metetra
.662 .541 .707 r
.87038 .12243 .87037 .13066 .88728 .13052 .88726 .12229 Metetra
.634 .523 .71 r
.8533 .12265 .85325 .13088 .87037 .13066 .87038 .12243 Metetra
.607 .505 .713 r
.83606 .12295 .83596 .13119 .85325 .13088 .8533 .12265 Metetra
.579 .489 .716 r
.81869 .12334 .81853 .13157 .83596 .13119 .83606 .12295 Metetra
.552 .474 .721 r
.80122 .12381 .801 .13204 .81853 .13157 .81869 .12334 Metetra
.524 .459 .725 r
.78369 .12437 .7834 .13259 .801 .13204 .80122 .12381 Metetra
.496 .446 .73 r
.76612 .125 .76576 .13323 .7834 .13259 .78369 .12437 Metetra
.468 .433 .736 r
.74855 .12573 .74811 .13395 .76576 .13323 .76612 .125 Metetra
.439 .421 .741 r
.731 .12654 .7305 .13475 .74811 .13395 .74855 .12573 Metetra
.411 .409 .747 r
.71351 .12743 .71294 .13564 .7305 .13475 .731 .12654 Metetra
.382 .399 .753 r
.69612 .1284 .69549 .13661 .71294 .13564 .71351 .12743 Metetra
.355 .391 .76 r
.67886 .12946 .67818 .13767 .69549 .13661 .69612 .1284 Metetra
.329 .384 .768 r
.66178 .13059 .66105 .1388 .67818 .13767 .67886 .12946 Metetra
.305 .381 .776 r
.6449 .13179 .64414 .14 .66105 .1388 .66178 .13059 Metetra
.284 .381 .786 r
.62827 .13305 .6275 .14125 .64414 .14 .6449 .13179 Metetra
.268 .386 .799 r
.61192 .13434 .61115 .14256 .6275 .14125 .62827 .13305 Metetra
.258 .399 .814 r
.5959 .13565 .59514 .14388 .61115 .14256 .61192 .13434 Metetra
.256 .42 .833 r
.58023 .13695 .5795 .1452 .59514 .14388 .5959 .13565 Metetra
.266 .451 .857 r
.56492 .13819 .56426 .14647 .5795 .1452 .58023 .13695 Metetra
.29 .497 .886 r
.54999 .13931 .54941 .14764 .56426 .14647 .56492 .13819 Metetra
.332 .558 .918 r
.5354 .14026 .53495 .14864 .54941 .14764 .54999 .13931 Metetra
.397 .634 .95 r
.52111 .14096 .52082 .14938 .53495 .14864 .5354 .14026 Metetra
.506 .693 .952 r
.50701 .14133 .50693 .14946 .52082 .14938 .52111 .14096 Metetra
.542 .443 .692 r
.01786 .13151 .01787 .13968 .03265 .13931 .03266 .13111 Metetra
.587 .479 .697 r
.03266 .13111 .03265 .13931 .0479 .13903 .04793 .13082 Metetra
.628 .511 .701 r
.04793 .13082 .0479 .13903 .06358 .13884 .06361 .13061 Metetra
.664 .54 .703 r
.06361 .13061 .06358 .13884 .07963 .13873 .07967 .13049 Metetra
.697 .566 .704 r
.07967 .13049 .07963 .13873 .09603 .1387 .09605 .13046 Metetra
.726 .591 .705 r
.09605 .13046 .09603 .1387 .11272 .13876 .11272 .13052 Metetra
.753 .614 .705 r
.11272 .13052 .11272 .13876 .12966 .1389 .12963 .13066 Metetra
.777 .637 .706 r
.12963 .13066 .12966 .1389 .14682 .13912 .14675 .13088 Metetra
.8 .659 .707 r
.14675 .13088 .14682 .13912 .16416 .13942 .16404 .13119 Metetra
.821 .681 .709 r
.16404 .13119 .16416 .13942 .18164 .1398 .18147 .13157 Metetra
.84 .702 .711 r
.18147 .13157 .18164 .1398 .19923 .14026 .199 .13204 Metetra
.858 .723 .713 r
.199 .13204 .19923 .14026 .2169 .1408 .2166 .13259 Metetra
.874 .744 .716 r
.2166 .13259 .2169 .1408 .2346 .14143 .23424 .13323 Metetra
.889 .765 .718 r
.23424 .13323 .2346 .14143 .25231 .14214 .25189 .13395 Metetra
.903 .786 .721 r
.25189 .13395 .25231 .14214 .26999 .14293 .2695 .13475 Metetra
.915 .806 .725 r
.2695 .13475 .26999 .14293 .28761 .1438 .28706 .13564 Metetra
.925 .825 .728 r
.28706 .13564 .28761 .1438 .30511 .14476 .30451 .13661 Metetra
.933 .843 .732 r
.30451 .13661 .30511 .14476 .32248 .1458 .32182 .13767 Metetra
.939 .861 .737 r
.32182 .13767 .32248 .1458 .33965 .14692 .33895 .1388 Metetra
.942 .878 .743 r
.33895 .1388 .33965 .14692 .35659 .1481 .35586 .14 Metetra
.943 .894 .751 r
.35586 .14 .35659 .1481 .37326 .14935 .3725 .14125 Metetra
.941 .91 .761 r
.3725 .14125 .37326 .14935 .38961 .15065 .38885 .14256 Metetra
.935 .924 .775 r
.38885 .14256 .38961 .15065 .40561 .15198 .40486 .14388 Metetra
.924 .937 .793 r
.40486 .14388 .40561 .15198 .42122 .15331 .4205 .1452 Metetra
.906 .947 .819 r
.4205 .1452 .42122 .15331 .4364 .15461 .43574 .14647 Metetra
.879 .953 .851 r
.43574 .14647 .4364 .15461 .45116 .15582 .45059 .14764 Metetra
.837 .95 .892 r
.45059 .14764 .45116 .15582 .46533 .15639 .46505 .14864 Metetra
.848 .906 .875 r
.46505 .14864 .46533 .15639 .4792 .15639 .47918 .14938 Metetra
.739 .631 .739 r
.47918 .14938 .4792 .15639 .49307 .15639 .49307 .14946 Metetra
.841 .686 .69 r
.96734 .13111 .96735 .13931 .98213 .13968 .98214 .13151 Metetra
.809 .659 .696 r
.95207 .13082 .9521 .13903 .96735 .13931 .96734 .13111 Metetra
.778 .633 .7 r
.93639 .13061 .93642 .13884 .9521 .13903 .95207 .13082 Metetra
.748 .608 .703 r
.92033 .13049 .92037 .13873 .93642 .13884 .93639 .13061 Metetra
.717 .584 .705 r
.90395 .13046 .90397 .1387 .92037 .13873 .92033 .13049 Metetra
.688 .561 .707 r
.88728 .13052 .88728 .13876 .90397 .1387 .90395 .13046 Metetra
.658 .54 .708 r
.87037 .13066 .87034 .1389 .88728 .13876 .88728 .13052 Metetra
.629 .52 .711 r
.85325 .13088 .85318 .13912 .87034 .1389 .87037 .13066 Metetra
.6 .501 .713 r
.83596 .13119 .83584 .13942 .85318 .13912 .85325 .13088 Metetra
.571 .483 .716 r
.81853 .13157 .81836 .1398 .83584 .13942 .83596 .13119 Metetra
.542 .466 .719 r
.801 .13204 .80077 .14026 .81836 .1398 .81853 .13157 Metetra
.513 .45 .723 r
.7834 .13259 .7831 .1408 .80077 .14026 .801 .13204 Metetra
.483 .434 .727 r
.76576 .13323 .7654 .14143 .7831 .1408 .7834 .13259 Metetra
.453 .419 .731 r
.74811 .13395 .74769 .14214 .7654 .14143 .76576 .13323 Metetra
.422 .405 .735 r
.7305 .13475 .73001 .14293 .74769 .14214 .74811 .13395 Metetra
.392 .392 .739 r
.71294 .13564 .71239 .1438 .73001 .14293 .7305 .13475 Metetra
.362 .379 .744 r
.69549 .13661 .69489 .14476 .71239 .1438 .71294 .13564 Metetra
.333 .369 .749 r
.67818 .13767 .67752 .1458 .69489 .14476 .69549 .13661 Metetra
.305 .36 .755 r
.66105 .1388 .66035 .14692 .67752 .1458 .67818 .13767 Metetra
.279 .354 .762 r
.64414 .14 .64341 .1481 .66035 .14692 .66105 .1388 Metetra
.256 .353 .771 r
.6275 .14125 .62674 .14935 .64341 .1481 .64414 .14 Metetra
.237 .356 .783 r
.61115 .14256 .61039 .15065 .62674 .14935 .6275 .14125 Metetra
.224 .366 .797 r
.59514 .14388 .59439 .15198 .61039 .15065 .61115 .14256 Metetra
.22 .386 .816 r
.5795 .1452 .57878 .15331 .59439 .15198 .59514 .14388 Metetra
.226 .417 .841 r
.56426 .14647 .5636 .15461 .57878 .15331 .5795 .1452 Metetra
.249 .463 .872 r
.54941 .14764 .54884 .15582 .5636 .15461 .56426 .14647 Metetra
.294 .444 .841 r
.53495 .14864 .53467 .15639 .54884 .15582 .54941 .14764 Metetra
.377 .333 .682 r
.52082 .14938 .5208 .15639 .53467 .15639 .53495 .14864 Metetra
.672 .549 .706 r
.50693 .14946 .50693 .15639 .5208 .15639 .52082 .14938 Metetra
.539 .441 .691 r
.01787 .13968 .01788 .14786 .03264 .14751 .03265 .13931 Metetra
.585 .477 .697 r
.03265 .13931 .03264 .14751 .04788 .14725 .0479 .13903 Metetra
.627 .51 .701 r
.0479 .13903 .04788 .14725 .06355 .14706 .06358 .13884 Metetra
.664 .54 .704 r
.06358 .13884 .06355 .14706 .07961 .14696 .07963 .13873 Metetra
.698 .568 .705 r
.07963 .13873 .07961 .14696 .09602 .14694 .09603 .1387 Metetra
.728 .594 .706 r
.09603 .1387 .09602 .14694 .11273 .147 .11272 .13876 Metetra
.756 .618 .706 r
.11272 .13876 .11273 .147 .1297 .14714 .12966 .1389 Metetra
.781 .641 .707 r
.12966 .1389 .1297 .14714 .1469 .14735 .14682 .13912 Metetra
.805 .664 .708 r
.14682 .13912 .1469 .14735 .16428 .14765 .16416 .13942 Metetra
.826 .686 .708 r
.16416 .13942 .16428 .14765 .18181 .14802 .18164 .1398 Metetra
.846 .707 .709 r
.18164 .1398 .18181 .14802 .19946 .14847 .19923 .14026 Metetra
.865 .729 .711 r
.19923 .14026 .19946 .14847 .21718 .14899 .2169 .1408 Metetra
.881 .75 .712 r
.2169 .1408 .21718 .14899 .23495 .1496 .2346 .14143 Metetra
.897 .77 .714 r
.2346 .14143 .23495 .1496 .25273 .15029 .25231 .14214 Metetra
.911 .79 .715 r
.25231 .14214 .25273 .15029 .27047 .15106 .26999 .14293 Metetra
.923 .81 .717 r
.26999 .14293 .27047 .15106 .28814 .15192 .28761 .1438 Metetra
.933 .828 .719 r
.28761 .1438 .28814 .15192 .3057 .15285 .30511 .14476 Metetra
.941 .847 .721 r
.30511 .14476 .3057 .15285 .32311 .15386 .32248 .1458 Metetra
.947 .864 .724 r
.32248 .1458 .32311 .15386 .34032 .15495 .33965 .14692 Metetra
.951 .881 .728 r
.33965 .14692 .34032 .15495 .3573 .15612 .35659 .1481 Metetra
.952 .896 .734 r
.35659 .1481 .3573 .15612 .37399 .15734 .37326 .14935 Metetra
.951 .912 .743 r
.37326 .14935 .37399 .15734 .39035 .15863 .38961 .15065 Metetra
.945 .926 .755 r
.38961 .15065 .39035 .15863 .40634 .15994 .40561 .15198 Metetra
.936 .94 .772 r
.40561 .15198 .40634 .15994 .42192 .16128 .42122 .15331 Metetra
.92 .952 .797 r
.42122 .15331 .42192 .16128 .43706 .16259 .4364 .15461 Metetra
.894 .961 .831 r
.4364 .15461 .43706 .16259 .45146 .16333 .45116 .15582 Metetra
.852 .869 .852 r
.45116 .15582 .45146 .16333 .46533 .16333 .46533 .15639 Metetra
.842 .687 .69 r
.96735 .13931 .96736 .14751 .98212 .14786 .98213 .13968 Metetra
.811 .661 .696 r
.9521 .13903 .95212 .14725 .96736 .14751 .96735 .13931 Metetra
.779 .634 .701 r
.93642 .13884 .93645 .14706 .95212 .14725 .9521 .13903 Metetra
.748 .609 .704 r
.92037 .13873 .92039 .14696 .93645 .14706 .93642 .13884 Metetra
.716 .584 .706 r
.90397 .1387 .90398 .14694 .92039 .14696 .92037 .13873 Metetra
.686 .561 .708 r
.88728 .13876 .88727 .147 .90398 .14694 .90397 .1387 Metetra
.655 .538 .71 r
.87034 .1389 .8703 .14714 .88727 .147 .88728 .13876 Metetra
.624 .517 .711 r
.85318 .13912 .8531 .14735 .8703 .14714 .87034 .1389 Metetra
.594 .496 .713 r
.83584 .13942 .83572 .14765 .8531 .14735 .85318 .13912 Metetra
.563 .477 .715 r
.81836 .1398 .81819 .14802 .83572 .14765 .83584 .13942 Metetra
.533 .458 .717 r
.80077 .14026 .80054 .14847 .81819 .14802 .81836 .1398 Metetra
.501 .44 .72 r
.7831 .1408 .78282 .14899 .80054 .14847 .80077 .14026 Metetra
.47 .423 .723 r
.7654 .14143 .76505 .1496 .78282 .14899 .7831 .1408 Metetra
.438 .406 .725 r
.74769 .14214 .74727 .15029 .76505 .1496 .7654 .14143 Metetra
.406 .389 .728 r
.73001 .14293 .72953 .15106 .74727 .15029 .74769 .14214 Metetra
.374 .374 .731 r
.71239 .1438 .71186 .15192 .72953 .15106 .73001 .14293 Metetra
.342 .36 .734 r
.69489 .14476 .6943 .15285 .71186 .15192 .71239 .1438 Metetra
.311 .347 .738 r
.67752 .1458 .67689 .15386 .6943 .15285 .69489 .14476 Metetra
.281 .336 .742 r
.66035 .14692 .65968 .15495 .67689 .15386 .67752 .1458 Metetra
.253 .328 .748 r
.64341 .1481 .6427 .15612 .65968 .15495 .66035 .14692 Metetra
.227 .324 .755 r
.62674 .14935 .62601 .15734 .6427 .15612 .64341 .1481 Metetra
.206 .325 .765 r
.61039 .15065 .60965 .15863 .62601 .15734 .62674 .14935 Metetra
.19 .333 .779 r
.59439 .15198 .59366 .15994 .60965 .15863 .61039 .15065 Metetra
.182 .35 .797 r
.57878 .15331 .57808 .16128 .59366 .15994 .59439 .15198 Metetra
.185 .379 .822 r
.5636 .15461 .56294 .16259 .57808 .16128 .57878 .15331 Metetra
.192 .307 .753 r
.54884 .15582 .54854 .16333 .56294 .16259 .5636 .15461 Metetra
.428 .349 .666 r
.53467 .15639 .53467 .16333 .54854 .16333 .54884 .15582 Metetra
.538 .439 .691 r
.01788 .14786 .01788 .15603 .03264 .15571 .03264 .14751 Metetra
.584 .476 .697 r
.03264 .14751 .03264 .15571 .04787 .15546 .04788 .14725 Metetra
.626 .51 .702 r
.04788 .14725 .04787 .15546 .06354 .1553 .06355 .14706 Metetra
.664 .541 .704 r
.06355 .14706 .06354 .1553 .0796 .1552 .07961 .14696 Metetra
.699 .57 .706 r
.07961 .14696 .0796 .1552 .09602 .15519 .09602 .14694 Metetra
.73 .596 .707 r
.09602 .14694 .09602 .15519 .11275 .15525 .11273 .147 Metetra
.759 .621 .707 r
.11273 .147 .11275 .15525 .12975 .15538 .1297 .14714 Metetra
.785 .645 .707 r
.1297 .14714 .12975 .15538 .14698 .15559 .1469 .14735 Metetra
.809 .668 .707 r
.1469 .14735 .14698 .15559 .1644 .15587 .16428 .14765 Metetra
.831 .69 .708 r
.16428 .14765 .1644 .15587 .18198 .15623 .18181 .14802 Metetra
.852 .712 .708 r
.18181 .14802 .18198 .15623 .19968 .15666 .19946 .14847 Metetra
.871 .733 .708 r
.19946 .14847 .19968 .15666 .21747 .15717 .21718 .14899 Metetra
.888 .754 .708 r
.21718 .14899 .21747 .15717 .23529 .15775 .23495 .1496 Metetra
.903 .774 .708 r
.23495 .1496 .23529 .15775 .25312 .15842 .25273 .15029 Metetra
.917 .794 .708 r
.25273 .15029 .25312 .15842 .27092 .15916 .27047 .15106 Metetra
.93 .813 .709 r
.27047 .15106 .27092 .15916 .28865 .15998 .28814 .15192 Metetra
.94 .831 .709 r
.28814 .15192 .28865 .15998 .30626 .16088 .3057 .15285 Metetra
.949 .848 .709 r
.3057 .15285 .30626 .16088 .32372 .16186 .32311 .15386 Metetra
.955 .865 .711 r
.32311 .15386 .32372 .16186 .34097 .16291 .34032 .15495 Metetra
.959 .881 .713 r
.34032 .15495 .34097 .16291 .35798 .16404 .3573 .15612 Metetra
.961 .897 .717 r
.3573 .15612 .35798 .16404 .37469 .16523 .37399 .15734 Metetra
.96 .912 .723 r
.37399 .15734 .37469 .16523 .39106 .16648 .39035 .15863 Metetra
.955 .927 .733 r
.39035 .15863 .39106 .16648 .40705 .16778 .40634 .15994 Metetra
.946 .941 .749 r
.40634 .15994 .40705 .16778 .42262 .1691 .42192 .16128 Metetra
.932 .954 .772 r
.42192 .16128 .42262 .1691 .4376 .17026 .43706 .16259 Metetra
.864 .921 .864 r
.43706 .16259 .4376 .17026 .45146 .17026 .45146 .16333 Metetra
.843 .688 .69 r
.96736 .14751 .96736 .15571 .98212 .15603 .98212 .14786 Metetra
.812 .662 .697 r
.95212 .14725 .95213 .15546 .96736 .15571 .96736 .14751 Metetra
.78 .635 .701 r
.93645 .14706 .93646 .1553 .95213 .15546 .95212 .14725 Metetra
.748 .609 .705 r
.92039 .14696 .9204 .1552 .93646 .1553 .93645 .14706 Metetra
.715 .584 .707 r
.90398 .14694 .90398 .15519 .9204 .1552 .92039 .14696 Metetra
.683 .56 .709 r
.88727 .147 .88725 .15525 .90398 .15519 .90398 .14694 Metetra
.652 .536 .71 r
.8703 .14714 .87025 .15538 .88725 .15525 .88727 .147 Metetra
.62 .514 .712 r
.8531 .14735 .85302 .15559 .87025 .15538 .8703 .14714 Metetra
.588 .492 .713 r
.83572 .14765 .8356 .15587 .85302 .15559 .8531 .14735 Metetra
.556 .471 .714 r
.81819 .14802 .81802 .15623 .8356 .15587 .83572 .14765 Metetra
.524 .45 .715 r
.80054 .14847 .80032 .15666 .81802 .15623 .81819 .14802 Metetra
.491 .43 .717 r
.78282 .14899 .78253 .15717 .80032 .15666 .80054 .14847 Metetra
.458 .411 .718 r
.76505 .1496 .76471 .15775 .78253 .15717 .78282 .14899 Metetra
.425 .392 .719 r
.74727 .15029 .74688 .15842 .76471 .15775 .76505 .1496 Metetra
.391 .374 .721 r
.72953 .15106 .72908 .15916 .74688 .15842 .74727 .15029 Metetra
.357 .357 .722 r
.71186 .15192 .71135 .15998 .72908 .15916 .72953 .15106 Metetra
.324 .341 .724 r
.6943 .15285 .69374 .16088 .71135 .15998 .71186 .15192 Metetra
.291 .325 .726 r
.67689 .15386 .67628 .16186 .69374 .16088 .6943 .15285 Metetra
.259 .312 .728 r
.65968 .15495 .65903 .16291 .67628 .16186 .67689 .15386 Metetra
.228 .302 .732 r
.6427 .15612 .64202 .16404 .65903 .16291 .65968 .15495 Metetra
.2 .295 .738 r
.62601 .15734 .62531 .16523 .64202 .16404 .6427 .15612 Metetra
.175 .293 .746 r
.60965 .15863 .60894 .16648 .62531 .16523 .62601 .15734 Metetra
.156 .298 .758 r
.59366 .15994 .59295 .16778 .60894 .16648 .60965 .15863 Metetra
.144 .312 .775 r
.57808 .16128 .57738 .1691 .59295 .16778 .59366 .15994 Metetra
.137 .3 .766 r
.56294 .16259 .5624 .17026 .57738 .1691 .57808 .16128 Metetra
.328 .268 .636 r
.54854 .16333 .54854 .17026 .5624 .17026 .56294 .16259 Metetra
.537 .438 .69 r
.01788 .15603 .01788 .1642 .03263 .16391 .03264 .15571 Metetra
.583 .476 .697 r
.03264 .15571 .03263 .16391 .04786 .16368 .04787 .15546 Metetra
.626 .51 .702 r
.04787 .15546 .04786 .16368 .06353 .16353 .06354 .1553 Metetra
.665 .542 .705 r
.06354 .1553 .06353 .16353 .0796 .16345 .0796 .1552 Metetra
.7 .571 .707 r
.0796 .1552 .0796 .16345 .09603 .16343 .09602 .15519 Metetra
.732 .598 .708 r
.09602 .15519 .09603 .16343 .11277 .16349 .11275 .15525 Metetra
.761 .624 .708 r
.11275 .15525 .11277 .16349 .1298 .16362 .12975 .15538 Metetra
.788 .648 .707 r
.12975 .15538 .1298 .16362 .14707 .16382 .14698 .15559 Metetra
.813 .672 .707 r
.14698 .15559 .14707 .16382 .16453 .16409 .1644 .15587 Metetra
.836 .694 .706 r
.1644 .15587 .16453 .16409 .18216 .16443 .18198 .15623 Metetra
.857 .716 .706 r
.18198 .15623 .18216 .16443 .1999 .16484 .19968 .15666 Metetra
.876 .737 .705 r
.19968 .15666 .1999 .16484 .21774 .16532 .21747 .15717 Metetra
.894 .757 .704 r
.21747 .15717 .21774 .16532 .23562 .16588 .23529 .15775 Metetra
.91 .777 .703 r
.23529 .15775 .23562 .16588 .2535 .16651 .25312 .15842 Metetra
.924 .796 .701 r
.25312 .15842 .2535 .16651 .27136 .16721 .27092 .15916 Metetra
.936 .815 .7 r
.27092 .15916 .27136 .16721 .28913 .168 .28865 .15998 Metetra
.947 .832 .699 r
.28865 .15998 .28913 .168 .30679 .16885 .30626 .16088 Metetra
.955 .849 .698 r
.30626 .16088 .30679 .16885 .32429 .16979 .32372 .16186 Metetra
.962 .866 .697 r
.32372 .16186 .32429 .16979 .34158 .17079 .34097 .16291 Metetra
.966 .881 .697 r
.34097 .16291 .34158 .17079 .35862 .17187 .35798 .16404 Metetra
.968 .896 .699 r
.35798 .16404 .35862 .17187 .37536 .17302 .37469 .16523 Metetra
.968 .911 .703 r
.37469 .16523 .37536 .17302 .39175 .17422 .39106 .16648 Metetra
.964 .925 .71 r
.39106 .16648 .39175 .17422 .40774 .17548 .40705 .16778 Metetra
.956 .939 .723 r
.40705 .16778 .40774 .17548 .42329 .17678 .42262 .1691 Metetra
.931 .953 .775 r
.42262 .1691 .42329 .17678 .4376 .1772 .4376 .17026 Metetra
.844 .689 .69 r
.96736 .15571 .96737 .16391 .98212 .1642 .98212 .15603 Metetra
.812 .663 .697 r
.95213 .15546 .95214 .16368 .96737 .16391 .96736 .15571 Metetra
.78 .636 .702 r
.93646 .1553 .93647 .16353 .95214 .16368 .95213 .15546 Metetra
.747 .61 .706 r
.9204 .1552 .9204 .16345 .93647 .16353 .93646 .1553 Metetra
.714 .584 .708 r
.90398 .15519 .90397 .16343 .9204 .16345 .9204 .1552 Metetra
.681 .559 .71 r
.88725 .15525 .88723 .16349 .90397 .16343 .90398 .15519 Metetra
.648 .534 .711 r
.87025 .15538 .8702 .16362 .88723 .16349 .88725 .15525 Metetra
.615 .51 .711 r
.85302 .15559 .85293 .16382 .8702 .16362 .87025 .15538 Metetra
.582 .487 .712 r
.8356 .15587 .83547 .16409 .85293 .16382 .85302 .15559 Metetra
.549 .465 .712 r
.81802 .15623 .81784 .16443 .83547 .16409 .8356 .15587 Metetra
.515 .443 .713 r
.80032 .15666 .8001 .16484 .81784 .16443 .81802 .15623 Metetra
.481 .421 .713 r
.78253 .15717 .78226 .16532 .8001 .16484 .80032 .15666 Metetra
.447 .4 .713 r
.76471 .15775 .76438 .16588 .78226 .16532 .78253 .15717 Metetra
.412 .38 .713 r
.74688 .15842 .7465 .16651 .76438 .16588 .76471 .15775 Metetra
.377 .359 .713 r
.72908 .15916 .72864 .16721 .7465 .16651 .74688 .15842 Metetra
.342 .34 .713 r
.71135 .15998 .71087 .168 .72864 .16721 .72908 .15916 Metetra
.306 .322 .713 r
.69374 .16088 .69321 .16885 .71087 .168 .71135 .15998 Metetra
.271 .304 .713 r
.67628 .16186 .67571 .16979 .69321 .16885 .69374 .16088 Metetra
.237 .289 .714 r
.65903 .16291 .65842 .17079 .67571 .16979 .67628 .16186 Metetra
.204 .276 .716 r
.64202 .16404 .64138 .17187 .65842 .17079 .65903 .16291 Metetra
.174 .266 .719 r
.62531 .16523 .62464 .17302 .64138 .17187 .64202 .16404 Metetra
.146 .261 .726 r
.60894 .16648 .60825 .17422 .62464 .17302 .62531 .16523 Metetra
.123 .262 .736 r
.59295 .16778 .59226 .17548 .60825 .17422 .60894 .16648 Metetra
.106 .273 .751 r
.57738 .1691 .57671 .17678 .59226 .17548 .59295 .16778 Metetra
.113 .092 .553 r
.5624 .17026 .5624 .1772 .57671 .17678 .57738 .1691 Metetra
.536 .437 .69 r
.01788 .1642 .01788 .17237 .03263 .17211 .03263 .16391 Metetra
.583 .476 .697 r
.03263 .16391 .03263 .17211 .04786 .1719 .04786 .16368 Metetra
.626 .51 .702 r
.04786 .16368 .04786 .1719 .06353 .17176 .06353 .16353 Metetra
.665 .543 .706 r
.06353 .16353 .06353 .17176 .0796 .17169 .0796 .16345 Metetra
.701 .573 .707 r
.0796 .16345 .0796 .17169 .09604 .17168 .09603 .16343 Metetra
.734 .6 .708 r
.09603 .16343 .09604 .17168 .11281 .17174 .11277 .16349 Metetra
.764 .627 .708 r
.11277 .16349 .11281 .17174 .12986 .17186 .1298 .16362 Metetra
.792 .651 .707 r
.1298 .16362 .12986 .17186 .14715 .17205 .14707 .16382 Metetra
.817 .675 .706 r
.14707 .16382 .14715 .17205 .16465 .1723 .16453 .16409 Metetra
.84 .697 .705 r
.16453 .16409 .16465 .1723 .18232 .17262 .18216 .16443 Metetra
.862 .719 .703 r
.18216 .16443 .18232 .17262 .20011 .173 .1999 .16484 Metetra
.881 .74 .701 r
.1999 .16484 .20011 .173 .21799 .17346 .21774 .16532 Metetra
.899 .76 .699 r
.21774 .16532 .21799 .17346 .23592 .17398 .23562 .16588 Metetra
.915 .779 .697 r
.23562 .16588 .23592 .17398 .25386 .17457 .2535 .16651 Metetra
.929 .798 .694 r
.2535 .16651 .25386 .17457 .27176 .17523 .27136 .16721 Metetra
.942 .816 .691 r
.27136 .16721 .27176 .17523 .28959 .17597 .28913 .168 Metetra
.953 .833 .688 r
.28913 .168 .28959 .17597 .30729 .17677 .30679 .16885 Metetra
.961 .849 .685 r
.30679 .16885 .30729 .17677 .32483 .17765 .32429 .16979 Metetra
.968 .865 .683 r
.32429 .16979 .32483 .17765 .34216 .1786 .34158 .17079 Metetra
.973 .879 .681 r
.34158 .17079 .34216 .1786 .35923 .17961 .35862 .17187 Metetra
.975 .894 .68 r
.35862 .17187 .35923 .17961 .37599 .1807 .37536 .17302 Metetra
.974 .908 .681 r
.37536 .17302 .37599 .1807 .39239 .18185 .39175 .17422 Metetra
.971 .922 .686 r
.39175 .17422 .39239 .18185 .40839 .18306 .40774 .17548 Metetra
.964 .936 .696 r
.40774 .17548 .40839 .18306 .42373 .18413 .42329 .17678 Metetra
.849 .857 .849 r
.42329 .17678 .42373 .18413 .4376 .18413 .4376 .1772 Metetra
.844 .689 .69 r
.96737 .16391 .96737 .17211 .98212 .17237 .98212 .1642 Metetra
.813 .663 .697 r
.95214 .16368 .95214 .1719 .96737 .17211 .96737 .16391 Metetra
.78 .637 .703 r
.93647 .16353 .93647 .17176 .95214 .1719 .95214 .16368 Metetra
.747 .61 .706 r
.9204 .16345 .9204 .17169 .93647 .17176 .93647 .16353 Metetra
.713 .583 .709 r
.90397 .16343 .90396 .17168 .9204 .17169 .9204 .16345 Metetra
.679 .557 .71 r
.88723 .16349 .88719 .17174 .90396 .17168 .90397 .16343 Metetra
.645 .532 .711 r
.8702 .16362 .87014 .17186 .88719 .17174 .88723 .16349 Metetra
.611 .507 .711 r
.85293 .16382 .85285 .17205 .87014 .17186 .8702 .16362 Metetra
.577 .482 .711 r
.83547 .16409 .83535 .1723 .85285 .17205 .85293 .16382 Metetra
.542 .459 .711 r
.81784 .16443 .81768 .17262 .83535 .1723 .83547 .16409 Metetra
.507 .435 .71 r
.8001 .16484 .79989 .173 .81768 .17262 .81784 .16443 Metetra
.472 .412 .709 r
.78226 .16532 .78201 .17346 .79989 .173 .8001 .16484 Metetra
.436 .389 .708 r
.76438 .16588 .76408 .17398 .78201 .17346 .78226 .16532 Metetra
.4 .367 .706 r
.7465 .16651 .74614 .17457 .76408 .17398 .76438 .16588 Metetra
.363 .345 .705 r
.72864 .16721 .72824 .17523 .74614 .17457 .7465 .16651 Metetra
.327 .324 .703 r
.71087 .168 .71041 .17597 .72824 .17523 .72864 .16721 Metetra
.29 .303 .701 r
.69321 .16885 .69271 .17677 .71041 .17597 .71087 .168 Metetra
.253 .284 .7 r
.67571 .16979 .67517 .17765 .69271 .17677 .69321 .16885 Metetra
.217 .266 .699 r
.65842 .17079 .65784 .1786 .67517 .17765 .67571 .16979 Metetra
.182 .25 .699 r
.64138 .17187 .64077 .17961 .65784 .1786 .65842 .17079 Metetra
.148 .237 .7 r
.62464 .17302 .62401 .1807 .64077 .17961 .64138 .17187 Metetra
.117 .228 .704 r
.60825 .17422 .60761 .18185 .62401 .1807 .62464 .17302 Metetra
.09 .226 .712 r
.59226 .17548 .59161 .18306 .60761 .18185 .60825 .17422 Metetra
.058 .172 .668 r
.57671 .17678 .57627 .18413 .59161 .18306 .59226 .17548 Metetra
.451 .368 .672 r
.5624 .1772 .5624 .18413 .57627 .18413 .57671 .17678 Metetra
.535 .437 .69 r
.01788 .17237 .01788 .18054 .03263 .1803 .03263 .17211 Metetra
.582 .475 .697 r
.03263 .17211 .03263 .1803 .04785 .18012 .04786 .1719 Metetra
.626 .511 .703 r
.04786 .1719 .04785 .18012 .06353 .18 .06353 .17176 Metetra
.666 .544 .706 r
.06353 .17176 .06353 .18 .07961 .17993 .0796 .17169 Metetra
.702 .574 .708 r
.0796 .17169 .07961 .17993 .09606 .17993 .09604 .17168 Metetra
.736 .602 .708 r
.09604 .17168 .09606 .17993 .11284 .17998 .11281 .17174 Metetra
.766 .629 .708 r
.11281 .17174 .11284 .17998 .12992 .1801 .12986 .17186 Metetra
.795 .654 .707 r
.12986 .17186 .12992 .1801 .14724 .18027 .14715 .17205 Metetra
.82 .678 .705 r
.14715 .17205 .14724 .18027 .16477 .1805 .16465 .1723 Metetra
.844 .7 .703 r
.16465 .1723 .16477 .1805 .18248 .1808 .18232 .17262 Metetra
.866 .722 .701 r
.18232 .17262 .18248 .1808 .20031 .18115 .20011 .173 Metetra
.886 .742 .698 r
.20011 .173 .20031 .18115 .21824 .18157 .21799 .17346 Metetra
.904 .762 .695 r
.21799 .17346 .21824 .18157 .23621 .18205 .23592 .17398 Metetra
.92 .781 .691 r
.23592 .17398 .23621 .18205 .25419 .1826 .25386 .17457 Metetra
.934 .799 .687 r
.25386 .17457 .25419 .1826 .27214 .18321 .27176 .17523 Metetra
.947 .816 .682 r
.27176 .17523 .27214 .18321 .29 .18389 .28959 .17597 Metetra
.958 .833 .678 r
.28959 .17597 .29 .18389 .30775 .18463 .30729 .17677 Metetra
.967 .848 .673 r
.30729 .17677 .30775 .18463 .32533 .18545 .32483 .17765 Metetra
.973 .863 .668 r
.32483 .17765 .32533 .18545 .34269 .18633 .34216 .1786 Metetra
.978 .877 .664 r
.34216 .1786 .34269 .18633 .35979 .18727 .35923 .17961 Metetra
.98 .89 .661 r
.35923 .17961 .35979 .18727 .37658 .18829 .37599 .1807 Metetra
.98 .903 .659 r
.37599 .1807 .37658 .18829 .393 .18937 .39239 .18185 Metetra
.977 .916 .661 r
.39239 .18185 .393 .18937 .40901 .19051 .40839 .18306 Metetra
.962 .933 .709 r
.40839 .18306 .40901 .19051 .42373 .19106 .42373 .18413 Metetra
.845 .689 .69 r
.96737 .17211 .96737 .1803 .98212 .18054 .98212 .17237 Metetra
.813 .664 .697 r
.95214 .1719 .95215 .18012 .96737 .1803 .96737 .17211 Metetra
.78 .637 .703 r
.93647 .17176 .93647 .18 .95215 .18012 .95214 .1719 Metetra
.746 .61 .707 r
.9204 .17169 .92039 .17993 .93647 .18 .93647 .17176 Metetra
.712 .583 .709 r
.90396 .17168 .90394 .17993 .92039 .17993 .9204 .17169 Metetra
.677 .556 .71 r
.88719 .17174 .88716 .17998 .90394 .17993 .90396 .17168 Metetra
.642 .53 .711 r
.87014 .17186 .87008 .1801 .88716 .17998 .88719 .17174 Metetra
.607 .504 .71 r
.85285 .17205 .85276 .18027 .87008 .1801 .87014 .17186 Metetra
.572 .478 .71 r
.83535 .1723 .83523 .1805 .85276 .18027 .85285 .17205 Metetra
.536 .453 .708 r
.81768 .17262 .81752 .1808 .83523 .1805 .83535 .1723 Metetra
.5 .428 .707 r
.79989 .173 .79969 .18115 .81752 .1808 .81768 .17262 Metetra
.463 .403 .705 r
.78201 .17346 .78176 .18157 .79969 .18115 .79989 .173 Metetra
.426 .379 .702 r
.76408 .17398 .76379 .18205 .78176 .18157 .78201 .17346 Metetra
.389 .355 .7 r
.74614 .17457 .74581 .1826 .76379 .18205 .76408 .17398 Metetra
.351 .331 .697 r
.72824 .17523 .72786 .18321 .74581 .1826 .74614 .17457 Metetra
.313 .308 .693 r
.71041 .17597 .71 .18389 .72786 .18321 .72824 .17523 Metetra
.275 .285 .69 r
.69271 .17677 .69225 .18463 .71 .18389 .71041 .17597 Metetra
.236 .264 .687 r
.67517 .17765 .67467 .18545 .69225 .18463 .69271 .17677 Metetra
.198 .243 .684 r
.65784 .1786 .65731 .18633 .67467 .18545 .67517 .17765 Metetra
.16 .224 .681 r
.64077 .17961 .64021 .18727 .65731 .18633 .65784 .1786 Metetra
.124 .208 .681 r
.62401 .1807 .62342 .18829 .64021 .18727 .64077 .17961 Metetra
.09 .196 .682 r
.60761 .18185 .607 .18937 .62342 .18829 .62401 .1807 Metetra
.059 .189 .687 r
.59161 .18306 .59099 .19051 .607 .18937 .60761 .18185 Metetra
.07 .057 .534 r
.57627 .18413 .57627 .19106 .59099 .19051 .59161 .18306 Metetra
.535 .437 .69 r
.01788 .18054 .01788 .18871 .03263 .1885 .03263 .1803 Metetra
.582 .475 .697 r
.03263 .1803 .03263 .1885 .04785 .18834 .04785 .18012 Metetra
.626 .511 .703 r
.04785 .18012 .04785 .18834 .06353 .18824 .06353 .18 Metetra
.666 .544 .706 r
.06353 .18 .06353 .18824 .07962 .18818 .07961 .17993 Metetra
.704 .575 .708 r
.07961 .17993 .07962 .18818 .09608 .18818 .09606 .17993 Metetra
.738 .604 .708 r
.09606 .17993 .09608 .18818 .11288 .18823 .11284 .17998 Metetra
.769 .631 .708 r
.11284 .17998 .11288 .18823 .12997 .18833 .12992 .1801 Metetra
.797 .656 .706 r
.12992 .1801 .12997 .18833 .14732 .18849 .14724 .18027 Metetra
.824 .68 .704 r
.14724 .18027 .14732 .18849 .16488 .1887 .16477 .1805 Metetra
.848 .702 .701 r
.16477 .1805 .16488 .1887 .18262 .18897 .18248 .1808 Metetra
.87 .724 .698 r
.18248 .1808 .18262 .18897 .20049 .18929 .20031 .18115 Metetra
.89 .744 .694 r
.20031 .18115 .20049 .18929 .21846 .18967 .21824 .18157 Metetra
.908 .763 .69 r
.21824 .18157 .21846 .18967 .23647 .19011 .23621 .18205 Metetra
.924 .782 .685 r
.23621 .18205 .23647 .19011 .25449 .1906 .25419 .1826 Metetra
.939 .799 .679 r
.25419 .1826 .25449 .1906 .27248 .19116 .27214 .18321 Metetra
.952 .816 .673 r
.27214 .18321 .27248 .19116 .29038 .19177 .29 .18389 Metetra
.962 .832 .667 r
.29 .18389 .29038 .19177 .30817 .19245 .30775 .18463 Metetra
.971 .846 .661 r
.30775 .18463 .30817 .19245 .32578 .19319 .32533 .18545 Metetra
.978 .86 .654 r
.32533 .18545 .32578 .19319 .34317 .19399 .34269 .18633 Metetra
.983 .873 .647 r
.34269 .18633 .34317 .19399 .3603 .19486 .35979 .18727 Metetra
.985 .885 .641 r
.35979 .18727 .3603 .19486 .37711 .19579 .37658 .18829 Metetra
.985 .897 .637 r
.37658 .18829 .37711 .19579 .39356 .19678 .393 .18937 Metetra
.982 .909 .635 r
.393 .18937 .39356 .19678 .40958 .19783 .40901 .19051 Metetra
.909 .907 .808 r
.40901 .19051 .40958 .19783 .42373 .198 .42373 .19106 Metetra
.845 .689 .69 r
.96737 .1803 .96737 .1885 .98212 .18871 .98212 .18054 Metetra
.813 .664 .698 r
.95215 .18012 .95215 .18834 .96737 .1885 .96737 .1803 Metetra
.78 .637 .703 r
.93647 .18 .93647 .18824 .95215 .18834 .95215 .18012 Metetra
.746 .61 .707 r
.92039 .17993 .92038 .18818 .93647 .18824 .93647 .18 Metetra
.711 .582 .709 r
.90394 .17993 .90392 .18818 .92038 .18818 .92039 .17993 Metetra
.675 .554 .71 r
.88716 .17998 .88712 .18823 .90392 .18818 .90394 .17993 Metetra
.64 .527 .71 r
.87008 .1801 .87003 .18833 .88712 .18823 .88716 .17998 Metetra
.603 .5 .71 r
.85276 .18027 .85268 .18849 .87003 .18833 .87008 .1801 Metetra
.567 .473 .708 r
.83523 .1805 .83512 .1887 .85268 .18849 .85276 .18027 Metetra
.53 .447 .706 r
.81752 .1808 .81738 .18897 .83512 .1887 .83523 .1805 Metetra
.493 .421 .703 r
.79969 .18115 .79951 .18929 .81738 .18897 .81752 .1808 Metetra
.456 .395 .7 r
.78176 .18157 .78154 .18967 .79951 .18929 .79969 .18115 Metetra
.418 .369 .697 r
.76379 .18205 .76353 .19011 .78154 .18967 .78176 .18157 Metetra
.379 .343 .693 r
.74581 .1826 .74551 .1906 .76353 .19011 .76379 .18205 Metetra
.34 .318 .688 r
.72786 .18321 .72752 .19116 .74551 .1906 .74581 .1826 Metetra
.3 .293 .683 r
.71 .18389 .70962 .19177 .72752 .19116 .72786 .18321 Metetra
.261 .268 .678 r
.69225 .18463 .69183 .19245 .70962 .19177 .71 .18389 Metetra
.221 .244 .673 r
.67467 .18545 .67422 .19319 .69183 .19245 .69225 .18463 Metetra
.18 .221 .668 r
.65731 .18633 .65683 .19399 .67422 .19319 .67467 .18545 Metetra
.141 .2 .664 r
.64021 .18727 .6397 .19486 .65683 .19399 .65731 .18633 Metetra
.102 .18 .66 r
.62342 .18829 .62289 .19579 .6397 .19486 .64021 .18727 Metetra
.064 .164 .659 r
.607 .18937 .60644 .19678 .62289 .19579 .62342 .18829 Metetra
.029 .153 .66 r
.59099 .19051 .59042 .19783 .60644 .19678 .607 .18937 Metetra
.297 .242 .626 r
.57627 .19106 .57627 .198 .59042 .19783 .59099 .19051 Metetra
.535 .437 .69 r
.01788 .18871 .01788 .19688 .03262 .1967 .03263 .1885 Metetra
.583 .476 .698 r
.03263 .1885 .03262 .1967 .04785 .19656 .04785 .18834 Metetra
.627 .512 .703 r
.04785 .18834 .04785 .19656 .06353 .19647 .06353 .18824 Metetra
.667 .545 .706 r
.06353 .18824 .06353 .19647 .07963 .19642 .07962 .18818 Metetra
.705 .576 .708 r
.07962 .18818 .07963 .19642 .0961 .19642 .09608 .18818 Metetra
.739 .605 .708 r
.09608 .18818 .0961 .19642 .11291 .19647 .11288 .18823 Metetra
.771 .632 .708 r
.11288 .18823 .11291 .19647 .13003 .19656 .12997 .18833 Metetra
.8 .658 .706 r
.12997 .18833 .13003 .19656 .1474 .1967 .14732 .18849 Metetra
.826 .682 .703 r
.14732 .18849 .1474 .1967 .16499 .19689 .16488 .1887 Metetra
.851 .704 .699 r
.16488 .1887 .16499 .19689 .18275 .19713 .18262 .18897 Metetra
.873 .725 .695 r
.18262 .18897 .18275 .19713 .20066 .19741 .20049 .18929 Metetra
.893 .745 .69 r
.20049 .18929 .20066 .19741 .21865 .19775 .21846 .18967 Metetra
.912 .764 .685 r
.21846 .18967 .21865 .19775 .2367 .19814 .23647 .19011 Metetra
.928 .782 .679 r
.23647 .19011 .2367 .19814 .25476 .19858 .25449 .1906 Metetra
.943 .799 .672 r
.25449 .1906 .25476 .19858 .27278 .19907 .27248 .19116 Metetra
.956 .815 .664 r
.27248 .19116 .27278 .19907 .29072 .19962 .29038 .19177 Metetra
.966 .83 .657 r
.29038 .19177 .29072 .19962 .30854 .20022 .30817 .19245 Metetra
.975 .843 .648 r
.30817 .19245 .30854 .20022 .32619 .20088 .32578 .19319 Metetra
.982 .856 .639 r
.32578 .19319 .32619 .20088 .34361 .20159 .34317 .19399 Metetra
.987 .868 .631 r
.34317 .19399 .34361 .20159 .36076 .20237 .3603 .19486 Metetra
.989 .879 .622 r
.3603 .19486 .36076 .20237 .3776 .2032 .37711 .19579 Metetra
.989 .89 .614 r
.37711 .19579 .3776 .2032 .39406 .20409 .39356 .19678 Metetra
.986 .9 .608 r
.39356 .19678 .39406 .20409 .40986 .20493 .40958 .19783 Metetra
.807 .758 .807 r
.40958 .19783 .40986 .20493 .42373 .20493 .42373 .198 Metetra
.845 .689 .69 r
.96737 .1885 .96738 .1967 .98212 .19688 .98212 .18871 Metetra
.813 .664 .698 r
.95215 .18834 .95215 .19656 .96738 .1967 .96737 .1885 Metetra
.779 .637 .703 r
.93647 .18824 .93647 .19647 .95215 .19656 .95215 .18834 Metetra
.745 .609 .707 r
.92038 .18818 .92037 .19642 .93647 .19647 .93647 .18824 Metetra
.709 .581 .709 r
.90392 .18818 .9039 .19642 .92037 .19642 .92038 .18818 Metetra
.673 .553 .71 r
.88712 .18823 .88709 .19647 .9039 .19642 .90392 .18818 Metetra
.637 .525 .71 r
.87003 .18833 .86997 .19656 .88709 .19647 .88712 .18823 Metetra
.6 .497 .708 r
.85268 .18849 .8526 .1967 .86997 .19656 .87003 .18833 Metetra
.563 .469 .706 r
.83512 .1887 .83501 .19689 .8526 .1967 .85268 .18849 Metetra
.525 .442 .704 r
.81738 .18897 .81725 .19713 .83501 .19689 .83512 .1887 Metetra
.487 .414 .7 r
.79951 .18929 .79934 .19741 .81725 .19713 .81738 .18897 Metetra
.449 .387 .696 r
.78154 .18967 .78135 .19775 .79934 .19741 .79951 .18929 Metetra
.41 .359 .691 r
.76353 .19011 .7633 .19814 .78135 .19775 .78154 .18967 Metetra
.37 .332 .686 r
.74551 .1906 .74524 .19858 .7633 .19814 .76353 .19011 Metetra
.33 .305 .68 r
.72752 .19116 .72722 .19907 .74524 .19858 .74551 .1906 Metetra
.289 .278 .674 r
.70962 .19177 .70928 .19962 .72722 .19907 .72752 .19116 Metetra
.248 .252 .667 r
.69183 .19245 .69146 .20022 .70928 .19962 .70962 .19177 Metetra
.206 .225 .66 r
.67422 .19319 .67381 .20088 .69146 .20022 .69183 .19245 Metetra
.165 .2 .652 r
.65683 .19399 .65639 .20159 .67381 .20088 .67422 .19319 Metetra
.123 .176 .646 r
.6397 .19486 .63924 .20237 .65639 .20159 .65683 .19399 Metetra
.081 .153 .64 r
.62289 .19579 .6224 .2032 .63924 .20237 .6397 .19486 Metetra
.04 .133 .635 r
.60644 .19678 .60594 .20409 .6224 .2032 .62289 .19579 Metetra
0 .059 .572 r
.59042 .19783 .59014 .20493 .60594 .20409 .60644 .19678 Metetra
.57 .465 .696 r
.57627 .198 .57627 .20493 .59014 .20493 .59042 .19783 Metetra
.536 .437 .69 r
.01788 .19688 .01787 .20506 .03262 .2049 .03262 .1967 Metetra
.583 .476 .698 r
.03262 .1967 .03262 .2049 .04786 .20479 .04785 .19656 Metetra
.627 .512 .703 r
.04785 .19656 .04786 .20479 .06354 .20471 .06353 .19647 Metetra
.668 .546 .707 r
.06353 .19647 .06354 .20471 .07964 .20467 .07963 .19642 Metetra
.706 .577 .708 r
.07963 .19642 .07964 .20467 .09612 .20467 .0961 .19642 Metetra
.741 .606 .708 r
.0961 .19642 .09612 .20467 .11295 .20471 .11291 .19647 Metetra
.773 .634 .707 r
.11291 .19647 .11295 .20471 .13008 .20479 .13003 .19656 Metetra
.802 .659 .705 r
.13003 .19656 .13008 .20479 .14747 .20491 .1474 .1967 Metetra
.829 .683 .702 r
.1474 .1967 .14747 .20491 .16508 .20507 .16499 .19689 Metetra
.854 .705 .697 r
.16499 .19689 .16508 .20507 .18287 .20528 .18275 .19713 Metetra
.876 .726 .692 r
.18275 .19713 .18287 .20528 .2008 .20552 .20066 .19741 Metetra
.897 .746 .686 r
.20066 .19741 .2008 .20552 .21883 .20582 .21865 .19775 Metetra
.915 .764 .68 r
.21865 .19775 .21883 .20582 .23691 .20615 .2367 .19814 Metetra
.932 .782 .673 r
.2367 .19814 .23691 .20615 .255 .20653 .25476 .19858 Metetra
.946 .798 .664 r
.25476 .19858 .255 .20653 .27305 .20696 .27278 .19907 Metetra
.959 .813 .656 r
.27278 .19907 .27305 .20696 .29102 .20743 .29072 .19962 Metetra
.97 .827 .646 r
.29072 .19962 .29102 .20743 .30887 .20795 .30854 .20022 Metetra
.979 .84 .636 r
.30854 .20022 .30887 .20795 .32654 .20852 .32619 .20088 Metetra
.985 .852 .625 r
.32619 .20088 .32654 .20852 .34399 .20914 .34361 .20159 Metetra
.99 .863 .614 r
.34361 .20159 .34399 .20914 .36117 .20981 .36076 .20237 Metetra
.992 .872 .603 r
.36076 .20237 .36117 .20981 .37803 .21054 .3776 .2032 Metetra
.992 .882 .592 r
.3776 .2032 .37803 .21054 .39451 .21132 .39406 .20409 Metetra
.988 .895 .618 r
.39406 .20409 .39451 .21132 .40986 .21186 .40986 .20493 Metetra
.844 .689 .69 r
.96738 .1967 .96738 .2049 .98213 .20506 .98212 .19688 Metetra
.813 .664 .698 r
.95215 .19656 .95214 .20479 .96738 .2049 .96738 .1967 Metetra
.779 .637 .704 r
.93647 .19647 .93646 .20471 .95214 .20479 .95215 .19656 Metetra
.744 .609 .707 r
.92037 .19642 .92036 .20467 .93646 .20471 .93647 .19647 Metetra
.708 .58 .709 r
.9039 .19642 .90388 .20467 .92036 .20467 .92037 .19642 Metetra
.672 .551 .71 r
.88709 .19647 .88705 .20471 .90388 .20467 .9039 .19642 Metetra
.635 .523 .709 r
.86997 .19656 .86992 .20479 .88705 .20471 .88709 .19647 Metetra
.597 .494 .707 r
.8526 .1967 .85253 .20491 .86992 .20479 .86997 .19656 Metetra
.559 .465 .704 r
.83501 .19689 .83492 .20507 .85253 .20491 .8526 .1967 Metetra
.521 .436 .701 r
.81725 .19713 .81713 .20528 .83492 .20507 .83501 .19689 Metetra
.482 .408 .696 r
.79934 .19741 .7992 .20552 .81713 .20528 .81725 .19713 Metetra
.442 .379 .691 r
.78135 .19775 .78117 .20582 .7992 .20552 .79934 .19741 Metetra
.402 .351 .685 r
.7633 .19814 .76309 .20615 .78117 .20582 .78135 .19775 Metetra
.362 .322 .679 r
.74524 .19858 .745 .20653 .76309 .20615 .7633 .19814 Metetra
.321 .293 .671 r
.72722 .19907 .72695 .20696 .745 .20653 .74524 .19858 Metetra
.279 .265 .664 r
.70928 .19962 .70898 .20743 .72695 .20696 .72722 .19907 Metetra
.237 .236 .655 r
.69146 .20022 .69113 .20795 .70898 .20743 .70928 .19962 Metetra
.194 .208 .646 r
.67381 .20088 .67346 .20852 .69113 .20795 .69146 .20022 Metetra
.15 .18 .637 r
.65639 .20159 .65601 .20914 .67346 .20852 .67381 .20088 Metetra
.107 .153 .628 r
.63924 .20237 .63883 .20981 .65601 .20914 .65639 .20159 Metetra
.063 .127 .619 r
.6224 .2032 .62197 .21054 .63883 .20981 .63924 .20237 Metetra
.019 .103 .611 r
.60594 .20409 .60549 .21132 .62197 .21054 .6224 .2032 Metetra
.019 .016 .51 r
.59014 .20493 .59014 .21186 .60549 .21132 .60594 .20409 Metetra
.536 .437 .69 r
.01787 .20506 .01787 .21323 .03262 .2131 .03262 .2049 Metetra
.583 .476 .698 r
.03262 .2049 .03262 .2131 .04786 .21301 .04786 .20479 Metetra
.627 .512 .703 r
.04786 .20479 .04786 .21301 .06354 .21294 .06354 .20471 Metetra
.669 .546 .707 r
.06354 .20471 .06354 .21294 .07965 .21291 .07964 .20467 Metetra
.707 .578 .708 r
.07964 .20467 .07965 .21291 .09614 .21291 .09612 .20467 Metetra
.742 .607 .708 r
.09612 .20467 .09614 .21291 .11298 .21294 .11295 .20471 Metetra
.774 .635 .707 r
.11295 .20471 .11298 .21294 .13012 .21301 .13008 .20479 Metetra
.804 .66 .704 r
.13008 .20479 .13012 .21301 .14753 .21311 .14747 .20491 Metetra
.831 .684 .7 r
.14747 .20491 .14753 .21311 .16516 .21325 .16508 .20507 Metetra
.856 .706 .695 r
.16508 .20507 .16516 .21325 .18297 .21342 .18287 .20528 Metetra
.879 .727 .689 r
.18287 .20528 .18297 .21342 .20093 .21363 .2008 .20552 Metetra
.899 .746 .683 r
.2008 .20552 .20093 .21363 .21898 .21387 .21883 .20582 Metetra
.918 .764 .675 r
.21883 .20582 .21898 .21387 .23708 .21415 .23691 .20615 Metetra
.934 .781 .667 r
.23691 .20615 .23708 .21415 .2552 .21446 .255 .20653 Metetra
.949 .796 .657 r
.255 .20653 .2552 .21446 .27328 .21482 .27305 .20696 Metetra
.962 .811 .647 r
.27305 .20696 .27328 .21482 .29127 .21521 .29102 .20743 Metetra
.973 .824 .636 r
.29102 .20743 .29127 .21521 .30914 .21565 .30887 .20795 Metetra
.981 .836 .624 r
.30887 .20795 .30914 .21565 .32684 .21612 .32654 .20852 Metetra
.988 .846 .611 r
.32654 .20852 .32684 .21612 .34431 .21664 .34399 .20914 Metetra
.993 .856 .598 r
.34399 .20914 .34431 .21664 .36151 .2172 .36117 .20981 Metetra
.995 .865 .584 r
.36117 .20981 .36151 .2172 .37839 .21781 .37803 .21054 Metetra
.995 .872 .57 r
.37803 .21054 .37839 .21781 .39489 .21847 .39451 .21132 Metetra
.979 .886 .666 r
.39451 .21132 .39489 .21847 .40986 .2188 .40986 .21186 Metetra
.844 .689 .69 r
.96738 .2049 .96738 .2131 .98213 .21323 .98213 .20506 Metetra
.812 .663 .698 r
.95214 .20479 .95214 .21301 .96738 .2131 .96738 .2049 Metetra
.779 .636 .704 r
.93646 .20471 .93646 .21294 .95214 .21301 .95214 .20479 Metetra
.744 .608 .707 r
.92036 .20467 .92035 .21291 .93646 .21294 .93646 .20471 Metetra
.707 .579 .709 r
.90388 .20467 .90386 .21291 .92035 .21291 .92036 .20467 Metetra
.67 .55 .709 r
.88705 .20471 .88702 .21294 .90386 .21291 .90388 .20467 Metetra
.633 .52 .708 r
.86992 .20479 .86988 .21301 .88702 .21294 .88705 .20471 Metetra
.595 .491 .706 r
.85253 .20491 .85247 .21311 .86988 .21301 .86992 .20479 Metetra
.556 .461 .703 r
.83492 .20507 .83484 .21325 .85247 .21311 .85253 .20491 Metetra
.517 .432 .698 r
.81713 .20528 .81703 .21342 .83484 .21325 .83492 .20507 Metetra
.477 .402 .693 r
.7992 .20552 .79907 .21363 .81703 .21342 .81713 .20528 Metetra
.437 .372 .687 r
.78117 .20582 .78102 .21387 .79907 .21363 .7992 .20552 Metetra
.396 .342 .68 r
.76309 .20615 .76292 .21415 .78102 .21387 .78117 .20582 Metetra
.355 .312 .672 r
.745 .20653 .7448 .21446 .76292 .21415 .76309 .20615 Metetra
.313 .282 .663 r
.72695 .20696 .72672 .21482 .7448 .21446 .745 .20653 Metetra
.27 .252 .654 r
.70898 .20743 .70873 .21521 .72672 .21482 .72695 .20696 Metetra
.227 .221 .644 r
.69113 .20795 .69086 .21565 .70873 .21521 .70898 .20743 Metetra
.183 .191 .633 r
.67346 .20852 .67316 .21612 .69086 .21565 .69113 .20795 Metetra
.138 .161 .621 r
.65601 .20914 .65569 .21664 .67316 .21612 .67346 .20852 Metetra
.093 .131 .61 r
.63883 .20981 .63849 .2172 .65569 .21664 .65601 .20914 Metetra
.046 .102 .598 r
.62197 .21054 .62161 .21781 .63849 .2172 .63883 .20981 Metetra
0 .074 .587 r
.60549 .21132 .60511 .21847 .62161 .21781 .62197 .21054 Metetra
.134 .109 .563 r
.59014 .21186 .59014 .2188 .60511 .21847 .60549 .21132 Metetra
.536 .438 .69 r
.01787 .21323 .01786 .2214 .03262 .2213 .03262 .2131 Metetra
.583 .476 .698 r
.03262 .2131 .03262 .2213 .04786 .22123 .04786 .21301 Metetra
.628 .513 .703 r
.04786 .21301 .04786 .22123 .06355 .22118 .06354 .21294 Metetra
.669 .547 .707 r
.06354 .21294 .06355 .22118 .07966 .22115 .07965 .21291 Metetra
.708 .579 .708 r
.07965 .21291 .07966 .22115 .09616 .22115 .09614 .21291 Metetra
.743 .608 .708 r
.09614 .21291 .09616 .22115 .113 .22118 .11298 .21294 Metetra
.776 .636 .706 r
.11298 .21294 .113 .22118 .13016 .22123 .13012 .21301 Metetra
.806 .661 .703 r
.13012 .21301 .13016 .22123 .14758 .22131 .14753 .21311 Metetra
.833 .685 .698 r
.14753 .21311 .14758 .22131 .16522 .22142 .16516 .21325 Metetra
.858 .706 .693 r
.16516 .21325 .16522 .22142 .18305 .22156 .18297 .21342 Metetra
.881 .727 .686 r
.18297 .21342 .18305 .22156 .20103 .22172 .20093 .21363 Metetra
.901 .746 .679 r
.20093 .21363 .20103 .22172 .2191 .22191 .21898 .21387 Metetra
.92 .763 .67 r
.21898 .21387 .2191 .22191 .23722 .22213 .23708 .21415 Metetra
.937 .779 .661 r
.23708 .21415 .23722 .22213 .25536 .22238 .2552 .21446 Metetra
.951 .794 .65 r
.2552 .21446 .25536 .22238 .27346 .22266 .27328 .21482 Metetra
.964 .808 .639 r
.27328 .21482 .27346 .22266 .29148 .22297 .29127 .21521 Metetra
.975 .82 .626 r
.29127 .21521 .29148 .22297 .30937 .22331 .30914 .21565 Metetra
.984 .831 .612 r
.30914 .21565 .30937 .22331 .32708 .22369 .32684 .21612 Metetra
.99 .841 .598 r
.32684 .21612 .32708 .22369 .34457 .2241 .34431 .21664 Metetra
.995 .849 .582 r
.34431 .21664 .34457 .2241 .36179 .22454 .36151 .2172 Metetra
.997 .856 .566 r
.36151 .2172 .36179 .22454 .37868 .22502 .37839 .21781 Metetra
.996 .862 .549 r
.37839 .21781 .37868 .22502 .3952 .22555 .39489 .21847 Metetra
.956 .86 .705 r
.39489 .21847 .3952 .22555 .40986 .22573 .40986 .2188 Metetra
.844 .689 .69 r
.96738 .2131 .96738 .2213 .98214 .2214 .98213 .21323 Metetra
.812 .663 .698 r
.95214 .21301 .95214 .22123 .96738 .2213 .96738 .2131 Metetra
.778 .636 .704 r
.93646 .21294 .93645 .22118 .95214 .22123 .95214 .21301 Metetra
.743 .607 .707 r
.92035 .21291 .92034 .22115 .93645 .22118 .93646 .21294 Metetra
.706 .578 .709 r
.90386 .21291 .90384 .22115 .92034 .22115 .92035 .21291 Metetra
.669 .548 .709 r
.88702 .21294 .887 .22118 .90384 .22115 .90386 .21291 Metetra
.631 .518 .707 r
.86988 .21301 .86984 .22123 .887 .22118 .88702 .21294 Metetra
.592 .488 .704 r
.85247 .21311 .85242 .22131 .86984 .22123 .86988 .21301 Metetra
.553 .458 .7 r
.83484 .21325 .83478 .22142 .85242 .22131 .85247 .21311 Metetra
.514 .427 .695 r
.81703 .21342 .81695 .22156 .83478 .22142 .83484 .21325 Metetra
.473 .396 .689 r
.79907 .21363 .79897 .22172 .81695 .22156 .81703 .21342 Metetra
.433 .366 .682 r
.78102 .21387 .7809 .22191 .79897 .22172 .79907 .21363 Metetra
.391 .334 .674 r
.76292 .21415 .76278 .22213 .7809 .22191 .78102 .21387 Metetra
.349 .303 .665 r
.7448 .21446 .74464 .22238 .76278 .22213 .76292 .21415 Metetra
.306 .272 .655 r
.72672 .21482 .72654 .22266 .74464 .22238 .7448 .21446 Metetra
.263 .24 .644 r
.70873 .21521 .70852 .22297 .72654 .22266 .72672 .21482 Metetra
.219 .208 .632 r
.69086 .21565 .69063 .22331 .70852 .22297 .70873 .21521 Metetra
.174 .175 .62 r
.67316 .21612 .67292 .22369 .69063 .22331 .69086 .21565 Metetra
.128 .143 .606 r
.65569 .21664 .65543 .2241 .67292 .22369 .67316 .21612 Metetra
.081 .111 .592 r
.63849 .2172 .63821 .22454 .65543 .2241 .65569 .21664 Metetra
.033 .078 .577 r
.62161 .21781 .62132 .22502 .63821 .22454 .63849 .2172 Metetra
0 .047 .563 r
.60511 .21847 .6048 .22555 .62132 .22502 .62161 .21781 Metetra
.256 .209 .611 r
.59014 .2188 .59014 .22573 .6048 .22555 .60511 .21847 Metetra
.537 .438 .69 r
.01786 .2214 .01786 .22957 .03262 .2295 .03262 .2213 Metetra
.584 .477 .698 r
.03262 .2213 .03262 .2295 .04786 .22945 .04786 .22123 Metetra
.628 .513 .703 r
.04786 .22123 .04786 .22945 .06355 .22941 .06355 .22118 Metetra
.67 .547 .707 r
.06355 .22118 .06355 .22941 .07967 .2294 .07966 .22115 Metetra
.708 .579 .708 r
.07966 .22115 .07967 .2294 .09617 .2294 .09616 .22115 Metetra
.744 .609 .707 r
.09616 .22115 .09617 .2294 .11302 .22942 .113 .22118 Metetra
.777 .636 .705 r
.113 .22118 .11302 .22942 .13018 .22945 .13016 .22123 Metetra
.807 .661 .702 r
.13016 .22123 .13018 .22945 .14761 .22951 .14758 .22131 Metetra
.835 .685 .697 r
.14758 .22131 .14761 .22951 .16527 .22959 .16522 .22142 Metetra
.86 .706 .691 r
.16522 .22142 .16527 .22959 .18312 .22969 .18305 .22156 Metetra
.883 .726 .683 r
.18305 .22156 .18312 .22969 .2011 .2298 .20103 .22172 Metetra
.903 .745 .675 r
.20103 .22172 .2011 .2298 .21919 .22994 .2191 .22191 Metetra
.922 .762 .666 r
.2191 .22191 .21919 .22994 .23733 .2301 .23722 .22213 Metetra
.939 .777 .655 r
.23722 .22213 .23733 .2301 .25548 .23028 .25536 .22238 Metetra
.953 .791 .643 r
.25536 .22238 .25548 .23028 .2736 .23048 .27346 .22266 Metetra
.966 .804 .63 r
.27346 .22266 .2736 .23048 .29163 .23071 .29148 .22297 Metetra
.977 .816 .616 r
.29148 .22297 .29163 .23071 .30954 .23095 .30937 .22331 Metetra
.985 .826 .601 r
.30937 .22331 .30954 .23095 .32727 .23122 .32708 .22369 Metetra
.992 .834 .585 r
.32708 .22369 .32727 .23122 .34477 .23152 .34457 .2241 Metetra
.996 .841 .567 r
.34457 .2241 .34477 .23152 .362 .23184 .36179 .22454 Metetra
.998 .847 .548 r
.36179 .22454 .362 .23184 .37891 .23219 .37868 .22502 Metetra
.998 .851 .528 r
.37868 .22502 .37891 .23219 .39544 .23257 .3952 .22555 Metetra
.921 .818 .728 r
.3952 .22555 .39544 .23257 .40986 .23267 .40986 .22573 Metetra
.844 .689 .69 r
.96738 .2213 .96738 .2295 .98214 .22957 .98214 .2214 Metetra
.812 .663 .698 r
.95214 .22123 .95214 .22945 .96738 .2295 .96738 .2213 Metetra
.778 .636 .704 r
.93645 .22118 .93645 .22941 .95214 .22945 .95214 .22123 Metetra
.743 .607 .707 r
.92034 .22115 .92033 .2294 .93645 .22941 .93645 .22118 Metetra
.706 .577 .708 r
.90384 .22115 .90383 .2294 .92033 .2294 .92034 .22115 Metetra
.668 .547 .708 r
.887 .22118 .88698 .22942 .90383 .2294 .90384 .22115 Metetra
.63 .517 .706 r
.86984 .22123 .86982 .22945 .88698 .22942 .887 .22118 Metetra
.591 .486 .703 r
.85242 .22131 .85239 .22951 .86982 .22945 .86984 .22123 Metetra
.551 .454 .698 r
.83478 .22142 .83473 .22959 .85239 .22951 .85242 .22131 Metetra
.511 .423 .693 r
.81695 .22156 .81688 .22969 .83473 .22959 .83478 .22142 Metetra
.47 .391 .686 r
.79897 .22172 .7989 .2298 .81688 .22969 .81695 .22156 Metetra
.429 .36 .678 r
.7809 .22191 .78081 .22994 .7989 .2298 .79897 .22172 Metetra
.387 .327 .668 r
.76278 .22213 .76267 .2301 .78081 .22994 .7809 .22191 Metetra
.344 .295 .658 r
.74464 .22238 .74452 .23028 .76267 .2301 .76278 .22213 Metetra
.301 .262 .647 r
.72654 .22266 .7264 .23048 .74452 .23028 .74464 .22238 Metetra
.257 .229 .635 r
.70852 .22297 .70837 .23071 .7264 .23048 .72654 .22266 Metetra
.212 .195 .621 r
.69063 .22331 .69046 .23095 .70837 .23071 .70852 .22297 Metetra
.166 .161 .607 r
.67292 .22369 .67273 .23122 .69046 .23095 .69063 .22331 Metetra
.119 .127 .591 r
.65543 .2241 .65523 .23152 .67273 .23122 .67292 .22369 Metetra
.071 .092 .575 r
.63821 .22454 .638 .23184 .65523 .23152 .65543 .2241 Metetra
.021 .057 .557 r
.62132 .22502 .62109 .23219 .638 .23184 .63821 .22454 Metetra
0 .021 .539 r
.6048 .22555 .60456 .23257 .62109 .23219 .62132 .22502 Metetra
.373 .305 .651 r
.59014 .22573 .59014 .23267 .60456 .23257 .6048 .22555 Metetra
.537 .438 .69 r
.01786 .22957 .01786 .23774 .03262 .2377 .03262 .2295 Metetra
.584 .477 .698 r
.03262 .2295 .03262 .2377 .04786 .23767 .04786 .22945 Metetra
.629 .513 .703 r
.04786 .22945 .04786 .23767 .06356 .23765 .06355 .22941 Metetra
.67 .547 .706 r
.06355 .22941 .06356 .23765 .07967 .23764 .07967 .2294 Metetra
.709 .579 .708 r
.07967 .2294 .07967 .23764 .09618 .23764 .09617 .2294 Metetra
.745 .609 .707 r
.09617 .2294 .09618 .23764 .11304 .23765 .11302 .22942 Metetra
.778 .636 .705 r
.11302 .22942 .11304 .23765 .1302 .23767 .13018 .22945 Metetra
.808 .661 .701 r
.13018 .22945 .1302 .23767 .14764 .23771 .14761 .22951 Metetra
.836 .685 .695 r
.14761 .22951 .14764 .23771 .16531 .23776 .16527 .22959 Metetra
.861 .706 .689 r
.16527 .22959 .16531 .23776 .18316 .23781 .18312 .22969 Metetra
.884 .726 .681 r
.18312 .22969 .18316 .23781 .20116 .23788 .2011 .2298 Metetra
.905 .744 .671 r
.2011 .2298 .20116 .23788 .21925 .23797 .21919 .22994 Metetra
.923 .76 .661 r
.21919 .22994 .21925 .23797 .2374 .23806 .23733 .2301 Metetra
.94 .775 .649 r
.23733 .2301 .2374 .23806 .25556 .23817 .25548 .23028 Metetra
.955 .788 .637 r
.25548 .23028 .25556 .23817 .27369 .23829 .2736 .23048 Metetra
.967 .8 .623 r
.2736 .23048 .27369 .23829 .29174 .23843 .29163 .23071 Metetra
.978 .811 .607 r
.29163 .23071 .29174 .23843 .30965 .23858 .30954 .23095 Metetra
.987 .82 .591 r
.30954 .23095 .30965 .23858 .32739 .23874 .32727 .23122 Metetra
.993 .827 .573 r
.32727 .23122 .32739 .23874 .34491 .23892 .34477 .23152 Metetra
.997 .833 .553 r
.34477 .23152 .34491 .23892 .36215 .23912 .362 .23184 Metetra
.999 .837 .532 r
.362 .23184 .36215 .23912 .37906 .23933 .37891 .23219 Metetra
.998 .839 .509 r
.37891 .23219 .37906 .23933 .3956 .23956 .39544 .23257 Metetra
.878 .765 .733 r
.39544 .23257 .3956 .23956 .40986 .2396 .40986 .23267 Metetra
.707 .577 .707 r
.4792 .23267 .4792 .2396 .49153 .23729 .49307 .23267 Metetra
.036 0 0 r
.49307 .23267 .49153 .23729 .50847 .23729 .50693 .23267 Metetra
.844 .689 .69 r
.96738 .2295 .96738 .2377 .98214 .23774 .98214 .22957 Metetra
.812 .663 .698 r
.95214 .22945 .95214 .23767 .96738 .2377 .96738 .2295 Metetra
.778 .635 .703 r
.93645 .22941 .93644 .23765 .95214 .23767 .95214 .22945 Metetra
.742 .606 .707 r
.92033 .2294 .92033 .23764 .93644 .23765 .93645 .22941 Metetra
.705 .577 .708 r
.90383 .2294 .90382 .23764 .92033 .23764 .92033 .2294 Metetra
.667 .546 .707 r
.88698 .22942 .88696 .23765 .90382 .23764 .90383 .2294 Metetra
.629 .515 .705 r
.86982 .22945 .8698 .23767 .88696 .23765 .88698 .22942 Metetra
.589 .483 .701 r
.85239 .22951 .85236 .23771 .8698 .23767 .86982 .22945 Metetra
.549 .452 .696 r
.83473 .22959 .83469 .23776 .85236 .23771 .85239 .22951 Metetra
.509 .419 .69 r
.81688 .22969 .81684 .23781 .83469 .23776 .83473 .22959 Metetra
.468 .387 .682 r
.7989 .2298 .79884 .23788 .81684 .23781 .81688 .22969 Metetra
.426 .354 .673 r
.78081 .22994 .78075 .23797 .79884 .23788 .7989 .2298 Metetra
.384 .321 .663 r
.76267 .2301 .7626 .23806 .78075 .23797 .78081 .22994 Metetra
.341 .288 .652 r
.74452 .23028 .74444 .23817 .7626 .23806 .76267 .2301 Metetra
.297 .253 .639 r
.7264 .23048 .72631 .23829 .74444 .23817 .74452 .23028 Metetra
.253 .219 .625 r
.70837 .23071 .70826 .23843 .72631 .23829 .7264 .23048 Metetra
.207 .184 .611 r
.69046 .23095 .69035 .23858 .70826 .23843 .70837 .23071 Metetra
.16 .148 .594 r
.67273 .23122 .67261 .23874 .69035 .23858 .69046 .23095 Metetra
.113 .112 .577 r
.65523 .23152 .65509 .23892 .67261 .23874 .67273 .23122 Metetra
.064 .075 .558 r
.638 .23184 .63785 .23912 .65509 .23892 .65523 .23152 Metetra
.013 .037 .538 r
.62109 .23219 .62094 .23933 .63785 .23912 .638 .23184 Metetra
0 0 .517 r
.60456 .23257 .6044 .23956 .62094 .23933 .62109 .23219 Metetra
.471 .385 .677 r
.59014 .23267 .59014 .2396 .6044 .23956 .60456 .23257 Metetra
.036 0 0 r
.50693 .23267 .50847 .23729 .5208 .2396 .5208 .23267 Metetra
.537 .438 .69 r
.01786 .23774 .01786 .24591 .03262 .2459 .03262 .2377 Metetra
.584 .477 .698 r
.03262 .2377 .03262 .2459 .04786 .24589 .04786 .23767 Metetra
.629 .513 .703 r
.04786 .23767 .04786 .24589 .06356 .24588 .06356 .23765 Metetra
.671 .548 .706 r
.06356 .23765 .06356 .24588 .07968 .24588 .07967 .23764 Metetra
.709 .579 .707 r
.07967 .23764 .07968 .24588 .09618 .24588 .09618 .23764 Metetra
.745 .609 .706 r
.09618 .23764 .09618 .24588 .11304 .24588 .11304 .23765 Metetra
.778 .636 .704 r
.11304 .23765 .11304 .24588 .13021 .24589 .1302 .23767 Metetra
.809 .661 .699 r
.1302 .23767 .13021 .24589 .14765 .2459 .14764 .23771 Metetra
.836 .684 .694 r
.14764 .23771 .14765 .2459 .16532 .24592 .16531 .23776 Metetra
.862 .705 .686 r
.16531 .23776 .16532 .24592 .18318 .24594 .18316 .23781 Metetra
.885 .724 .678 r
.18316 .23781 .18318 .24594 .20118 .24596 .20116 .23788 Metetra
.905 .742 .668 r
.20116 .23788 .20118 .24596 .21928 .24599 .21925 .23797 Metetra
.924 .758 .657 r
.21925 .23797 .21928 .24599 .23744 .24602 .2374 .23806 Metetra
.941 .772 .644 r
.2374 .23806 .23744 .24602 .25561 .24606 .25556 .23817 Metetra
.956 .785 .63 r
.25556 .23817 .25561 .24606 .27374 .2461 .27369 .23829 Metetra
.968 .796 .615 r
.27369 .23829 .27374 .2461 .29179 .24614 .29174 .23843 Metetra
.979 .805 .599 r
.29174 .23843 .29179 .24614 .30971 .24619 .30965 .23858 Metetra
.988 .813 .581 r
.30965 .23858 .30971 .24619 .32745 .24625 .32739 .23874 Metetra
.994 .82 .561 r
.32739 .23874 .32745 .24625 .34497 .24631 .34491 .23892 Metetra
.998 .824 .54 r
.34491 .23892 .34497 .24631 .36222 .24637 .36215 .23912 Metetra
1 .827 .516 r
.36215 .23912 .36222 .24637 .37914 .24645 .37906 .23933 Metetra
.999 .828 .491 r
.37906 .23933 .37914 .24645 .39568 .24652 .3956 .23956 Metetra
.841 .712 .721 r
.3956 .23956 .39568 .24652 .40986 .24653 .40986 .2396 Metetra
0 0 .048 r
.4792 .2396 .4792 .24653 .49153 .24576 .49153 .23729 Metetra
.844 .689 .69 r
.96738 .2377 .96738 .2459 .98214 .24591 .98214 .23774 Metetra
.812 .663 .698 r
.95214 .23767 .95214 .24589 .96738 .2459 .96738 .2377 Metetra
.778 .635 .703 r
.93644 .23765 .93644 .24588 .95214 .24589 .95214 .23767 Metetra
.742 .606 .706 r
.92033 .23764 .92032 .24588 .93644 .24588 .93644 .23765 Metetra
.705 .576 .708 r
.90382 .23764 .90382 .24588 .92032 .24588 .92033 .23764 Metetra
.667 .545 .707 r
.88696 .23765 .88696 .24588 .90382 .24588 .90382 .23764 Metetra
.628 .514 .704 r
.8698 .23767 .86979 .24589 .88696 .24588 .88696 .23765 Metetra
.588 .482 .7 r
.85236 .23771 .85235 .2459 .86979 .24589 .8698 .23767 Metetra
.548 .449 .694 r
.83469 .23776 .83468 .24592 .85235 .2459 .85236 .23771 Metetra
.508 .416 .687 r
.81684 .23781 .81682 .24594 .83468 .24592 .83469 .23776 Metetra
.466 .383 .679 r
.79884 .23788 .79882 .24596 .81682 .24594 .81684 .23781 Metetra
.424 .35 .669 r
.78075 .23797 .78072 .24599 .79882 .24596 .79884 .23788 Metetra
.382 .316 .658 r
.7626 .23806 .76256 .24602 .78072 .24599 .78075 .23797 Metetra
.339 .281 .645 r
.74444 .23817 .74439 .24606 .76256 .24602 .7626 .23806 Metetra
.295 .246 .632 r
.72631 .23829 .72626 .2461 .74439 .24606 .74444 .23817 Metetra
.25 .21 .617 r
.70826 .23843 .70821 .24614 .72626 .2461 .72631 .23829 Metetra
.204 .174 .6 r
.69035 .23858 .69029 .24619 .70821 .24614 .70826 .23843 Metetra
.157 .136 .583 r
.67261 .23874 .67255 .24625 .69029 .24619 .69035 .23858 Metetra
.108 .098 .563 r
.65509 .23892 .65503 .24631 .67255 .24625 .67261 .23874 Metetra
.059 .059 .542 r
.63785 .23912 .63778 .24637 .65503 .24631 .65509 .23892 Metetra
.007 .019 .52 r
.62094 .23933 .62086 .24645 .63778 .24637 .63785 .23912 Metetra
0 0 .495 r
.6044 .23956 .60432 .24652 .62086 .24645 .62094 .23933 Metetra
.54 .441 .691 r
.59014 .2396 .59014 .24653 .60432 .24652 .6044 .23956 Metetra
.753 .615 .048 r
.50847 .23729 .50847 .24576 .5208 .24653 .5208 .2396 Metetra
.537 .439 .69 r
.01786 .24591 .01786 .25409 .03262 .2541 .03262 .2459 Metetra
.584 .477 .698 r
.03262 .2459 .03262 .2541 .04786 .25411 .04786 .24589 Metetra
.629 .513 .703 r
.04786 .24589 .04786 .25411 .06356 .25412 .06356 .24588 Metetra
.671 .548 .706 r
.06356 .24588 .06356 .25412 .07968 .25412 .07968 .24588 Metetra
.71 .579 .707 r
.07968 .24588 .07968 .25412 .09618 .25412 .09618 .24588 Metetra
.746 .609 .706 r
.09618 .24588 .09618 .25412 .11304 .25412 .11304 .24588 Metetra
.779 .636 .703 r
.11304 .24588 .11304 .25412 .13021 .25411 .13021 .24589 Metetra
.809 .661 .698 r
.13021 .24589 .13021 .25411 .14765 .2541 .14765 .2459 Metetra
.837 .683 .692 r
.14765 .2459 .14765 .2541 .16532 .25408 .16532 .24592 Metetra
.862 .704 .684 r
.16532 .24592 .16532 .25408 .18318 .25406 .18318 .24594 Metetra
.885 .723 .675 r
.18318 .24594 .18318 .25406 .20118 .25404 .20118 .24596 Metetra
.906 .74 .665 r
.20118 .24596 .20118 .25404 .21928 .25401 .21928 .24599 Metetra
.925 .755 .653 r
.21928 .24599 .21928 .25401 .23744 .25398 .23744 .24602 Metetra
.941 .769 .639 r
.23744 .24602 .23744 .25398 .25561 .25394 .25561 .24606 Metetra
.956 .781 .625 r
.25561 .24606 .25561 .25394 .27374 .2539 .27374 .2461 Metetra
.969 .791 .608 r
.27374 .2461 .27374 .2539 .29179 .25386 .29179 .24614 Metetra
.979 .8 .591 r
.29179 .24614 .29179 .25386 .30971 .25381 .30971 .24619 Metetra
.988 .807 .571 r
.30971 .24619 .30971 .25381 .32745 .25375 .32745 .24625 Metetra
.994 .812 .55 r
.32745 .24625 .32745 .25375 .34497 .25369 .34497 .24631 Metetra
.998 .815 .527 r
.34497 .24631 .34497 .25369 .36222 .25363 .36222 .24637 Metetra
1 .816 .502 r
.36222 .24637 .36222 .25363 .37914 .25355 .37914 .24645 Metetra
.999 .815 .475 r
.37914 .24645 .37914 .25355 .39568 .25348 .39568 .24652 Metetra
.818 .668 .697 r
.39568 .24652 .39568 .25348 .40986 .25347 .40986 .24653 Metetra
0 0 .048 r
.4792 .24653 .4792 .25347 .49153 .25424 .49153 .24576 Metetra
.843 .689 .69 r
.96738 .2459 .96738 .2541 .98214 .25409 .98214 .24591 Metetra
.812 .663 .698 r
.95214 .24589 .95214 .25411 .96738 .2541 .96738 .2459 Metetra
.778 .635 .703 r
.93644 .24588 .93644 .25412 .95214 .25411 .95214 .24589 Metetra
.742 .606 .706 r
.92032 .24588 .92032 .25412 .93644 .25412 .93644 .24588 Metetra
.705 .575 .707 r
.90382 .24588 .90382 .25412 .92032 .25412 .92032 .24588 Metetra
.666 .544 .706 r
.88696 .24588 .88696 .25412 .90382 .25412 .90382 .24588 Metetra
.628 .512 .703 r
.86979 .24589 .86979 .25411 .88696 .25412 .88696 .24588 Metetra
.588 .48 .698 r
.85235 .2459 .85235 .2541 .86979 .25411 .86979 .24589 Metetra
.548 .447 .692 r
.83468 .24592 .83468 .25408 .85235 .2541 .85235 .2459 Metetra
.507 .414 .684 r
.81682 .24594 .81682 .25406 .83468 .25408 .83468 .24592 Metetra
.465 .38 .675 r
.79882 .24596 .79882 .25404 .81682 .25406 .81682 .24594 Metetra
.423 .346 .665 r
.78072 .24599 .78072 .25401 .79882 .25404 .79882 .24596 Metetra
.381 .311 .653 r
.76256 .24602 .76256 .25398 .78072 .25401 .78072 .24599 Metetra
.337 .276 .639 r
.74439 .24606 .74439 .25394 .76256 .25398 .76256 .24602 Metetra
.293 .239 .625 r
.72626 .2461 .72626 .2539 .74439 .25394 .74439 .24606 Metetra
.248 .203 .608 r
.70821 .24614 .70821 .25386 .72626 .2539 .72626 .2461 Metetra
.202 .165 .591 r
.69029 .24619 .69029 .25381 .70821 .25386 .70821 .24614 Metetra
.155 .126 .571 r
.67255 .24625 .67255 .25375 .69029 .25381 .69029 .24619 Metetra
.106 .087 .55 r
.65503 .24631 .65503 .25369 .67255 .25375 .67255 .24625 Metetra
.056 .046 .527 r
.63778 .24637 .63778 .25363 .65503 .25369 .65503 .24631 Metetra
.004 .004 .502 r
.62086 .24645 .62086 .25355 .63778 .25363 .63778 .24637 Metetra
0 0 .475 r
.60432 .24652 .60432 .25348 .62086 .25355 .62086 .24645 Metetra
.575 .469 .697 r
.59014 .24653 .59014 .25347 .60432 .25348 .60432 .24652 Metetra
.753 .615 .048 r
.50847 .24576 .50847 .25424 .5208 .25347 .5208 .24653 Metetra
.686 .566 .714 r
.01778 .48294 .01786 .49107 .03419 .49108 .0339 .48305 Metetra
.705 .597 .733 r
.0339 .48305 .03419 .49108 .05068 .491 .05023 .48306 Metetra
.716 .619 .749 r
.05023 .48306 .05068 .491 .06726 .49086 .06669 .48301 Metetra
.722 .635 .761 r
.06669 .48301 .06726 .49086 .08386 .49071 .08321 .48291 Metetra
.723 .646 .771 r
.08321 .48291 .08386 .49071 .10043 .49056 .09974 .48281 Metetra
.722 .651 .777 r
.09974 .48281 .10043 .49056 .11694 .49043 .11625 .4827 Metetra
.719 .651 .781 r
.11625 .4827 .11694 .49043 .13337 .49034 .13271 .48261 Metetra
.715 .647 .781 r
.13271 .48261 .13337 .49034 .14973 .4903 .14914 .48255 Metetra
.71 .64 .777 r
.14914 .48255 .14973 .4903 .16602 .4903 .16551 .48251 Metetra
.705 .63 .771 r
.16551 .48251 .16602 .4903 .18224 .49036 .18183 .48251 Metetra
.702 .618 .76 r
.18183 .48251 .18224 .49036 .19841 .49045 .19813 .48252 Metetra
.699 .604 .747 r
.19813 .48252 .19841 .49045 .21456 .49059 .2144 .48256 Metetra
.698 .589 .73 r
.2144 .48256 .21456 .49059 .23068 .49075 .23066 .48261 Metetra
.698 .572 .71 r
.23066 .48261 .23068 .49075 .24682 .49093 .24693 .48266 Metetra
.699 .556 .688 r
.24693 .48266 .24682 .49093 .26297 .49112 .26322 .4827 Metetra
.702 .538 .663 r
.26322 .4827 .26297 .49112 .27915 .4913 .27953 .48272 Metetra
.705 .521 .637 r
.27953 .48272 .27915 .4913 .29538 .49146 .29586 .48272 Metetra
.708 .503 .61 r
.29586 .48272 .29538 .49146 .31164 .49159 .31222 .48268 Metetra
.71 .485 .582 r
.31222 .48268 .31164 .49159 .32796 .49168 .32861 .4826 Metetra
.712 .468 .553 r
.32861 .4826 .32796 .49168 .34431 .49173 .34502 .48248 Metetra
.713 .45 .526 r
.34502 .48248 .34431 .49173 .36069 .49174 .36143 .48231 Metetra
.712 .432 .499 r
.36143 .48231 .36069 .49174 .3771 .4917 .37784 .48211 Metetra
.71 .414 .474 r
.37784 .48211 .3771 .4917 .39352 .49163 .39423 .48188 Metetra
.706 .396 .451 r
.39423 .48188 .39352 .49163 .40994 .49153 .4106 .48164 Metetra
.699 .378 .43 r
.4106 .48164 .40994 .49153 .42635 .49141 .42693 .4814 Metetra
.691 .361 .412 r
.42693 .4814 .42635 .49141 .44274 .4913 .44322 .48117 Metetra
.682 .344 .397 r
.44322 .48117 .44274 .4913 .45912 .49119 .45948 .48099 Metetra
.672 .329 .385 r
.45948 .48099 .45912 .49119 .47548 .49112 .4757 .48086 Metetra
.661 .316 .377 r
.4757 .48086 .47548 .49112 .49183 .49108 .4919 .48079 Metetra
.65 .305 .373 r
.4919 .48079 .49183 .49108 .50817 .49108 .5081 .48079 Metetra
.727 .615 .733 r
.9661 .48305 .96581 .49108 .98214 .49107 .98222 .48294 Metetra
.708 .613 .749 r
.94977 .48306 .94932 .491 .96581 .49108 .9661 .48305 Metetra
.695 .614 .762 r
.93331 .48301 .93274 .49086 .94932 .491 .94977 .48306 Metetra
.687 .616 .771 r
.91679 .48291 .91614 .49071 .93274 .49086 .93331 .48301 Metetra
.683 .619 .777 r
.90026 .48281 .89957 .49056 .91614 .49071 .91679 .48291 Metetra
.683 .622 .781 r
.88375 .4827 .88306 .49043 .89957 .49056 .90026 .48281 Metetra
.686 .624 .781 r
.86729 .48261 .86663 .49034 .88306 .49043 .88375 .4827 Metetra
.691 .625 .777 r
.85086 .48255 .85027 .4903 .86663 .49034 .86729 .48261 Metetra
.697 .624 .77 r
.83449 .48251 .83398 .4903 .85027 .4903 .85086 .48255 Metetra
.703 .62 .76 r
.81817 .48251 .81776 .49036 .83398 .4903 .83449 .48251 Metetra
.709 .612 .747 r
.80187 .48252 .80159 .49045 .81776 .49036 .81817 .48251 Metetra
.713 .601 .73 r
.7856 .48256 .78544 .49059 .80159 .49045 .80187 .48252 Metetra
.716 .587 .71 r
.76934 .48261 .76932 .49075 .78544 .49059 .7856 .48256 Metetra
.716 .569 .688 r
.75307 .48266 .75318 .49093 .76932 .49075 .76934 .48261 Metetra
.713 .547 .663 r
.73678 .4827 .73703 .49112 .75318 .49093 .75307 .48266 Metetra
.708 .523 .637 r
.72047 .48272 .72085 .4913 .73703 .49112 .73678 .4827 Metetra
.7 .497 .609 r
.70414 .48272 .70462 .49146 .72085 .4913 .72047 .48272 Metetra
.691 .469 .581 r
.68778 .48268 .68836 .49159 .70462 .49146 .70414 .48272 Metetra
.68 .441 .553 r
.67139 .4826 .67204 .49168 .68836 .49159 .68778 .48268 Metetra
.669 .414 .526 r
.65498 .48248 .65569 .49173 .67204 .49168 .67139 .4826 Metetra
.658 .387 .499 r
.63857 .48231 .63931 .49174 .65569 .49173 .65498 .48248 Metetra
.647 .363 .474 r
.62216 .48211 .6229 .4917 .63931 .49174 .63857 .48231 Metetra
.638 .341 .45 r
.60577 .48188 .60648 .49163 .6229 .4917 .62216 .48211 Metetra
.632 .323 .43 r
.5894 .48164 .59006 .49153 .60648 .49163 .60577 .48188 Metetra
.628 .309 .412 r
.57307 .4814 .57365 .49141 .59006 .49153 .5894 .48164 Metetra
.627 .299 .397 r
.55678 .48117 .55726 .4913 .57365 .49141 .57307 .4814 Metetra
.629 .294 .385 r
.54052 .48099 .54088 .49119 .55726 .4913 .55678 .48117 Metetra
.634 .294 .377 r
.5243 .48086 .52452 .49112 .54088 .49119 .54052 .48099 Metetra
.641 .297 .373 r
.5081 .48079 .50817 .49108 .52452 .49112 .5243 .48086 Metetra
.668 .549 .711 r
.01772 .47479 .01778 .48294 .0339 .48305 .03366 .47499 Metetra
.689 .581 .729 r
.03366 .47499 .0339 .48305 .05023 .48306 .04984 .47508 Metetra
.704 .605 .743 r
.04984 .47508 .05023 .48306 .06669 .48301 .06619 .47509 Metetra
.713 .623 .755 r
.06619 .47509 .06669 .48301 .08321 .48291 .08263 .47505 Metetra
.718 .635 .764 r
.08263 .47505 .08321 .48291 .09974 .48281 .09913 .47498 Metetra
.72 .642 .769 r
.09913 .47498 .09974 .48281 .11625 .4827 .11564 .47489 Metetra
.721 .644 .772 r
.11564 .47489 .11625 .4827 .13271 .48261 .13214 .47481 Metetra
.72 .643 .771 r
.13214 .47481 .13271 .48261 .14914 .48255 .14862 .47472 Metetra
.718 .638 .768 r
.14862 .47472 .14914 .48255 .16551 .48251 .16507 .47465 Metetra
.717 .631 .761 r
.16507 .47465 .16551 .48251 .18183 .48251 .1815 .47458 Metetra
.716 .622 .751 r
.1815 .47458 .18183 .48251 .19813 .48252 .19791 .47453 Metetra
.716 .61 .737 r
.19791 .47453 .19813 .48252 .2144 .48256 .21431 .47447 Metetra
.718 .597 .721 r
.21431 .47447 .2144 .48256 .23066 .48261 .2307 .47442 Metetra
.72 .583 .702 r
.2307 .47442 .23066 .48261 .24693 .48266 .2471 .47435 Metetra
.723 .568 .68 r
.2471 .47435 .24693 .48266 .26322 .4827 .26351 .47426 Metetra
.726 .553 .656 r
.26351 .47426 .26322 .4827 .27953 .48272 .27994 .47414 Metetra
.73 .536 .63 r
.27994 .47414 .27953 .48272 .29586 .48272 .29638 .47399 Metetra
.733 .52 .603 r
.29638 .47399 .29586 .48272 .31222 .48268 .31283 .47379 Metetra
.735 .502 .575 r
.31283 .47379 .31222 .48268 .32861 .4826 .32929 .47355 Metetra
.737 .485 .548 r
.32929 .47355 .32861 .4826 .34502 .48248 .34574 .47327 Metetra
.737 .466 .52 r
.34574 .47327 .34502 .48248 .36143 .48231 .36218 .47295 Metetra
.735 .448 .493 r
.36218 .47295 .36143 .48231 .37784 .48211 .37858 .47259 Metetra
.73 .428 .468 r
.37858 .47259 .37784 .48211 .39423 .48188 .39495 .47222 Metetra
.724 .408 .445 r
.39495 .47222 .39423 .48188 .4106 .48164 .41126 .47185 Metetra
.715 .388 .423 r
.41126 .47185 .4106 .48164 .42693 .4814 .42751 .47149 Metetra
.704 .368 .405 r
.42751 .47149 .42693 .4814 .44322 .48117 .4437 .47117 Metetra
.692 .348 .39 r
.4437 .47117 .44322 .48117 .45948 .48099 .45984 .47091 Metetra
.678 .33 .378 r
.45984 .47091 .45948 .48099 .4757 .48086 .47592 .47072 Metetra
.663 .313 .37 r
.47592 .47072 .4757 .48086 .4919 .48079 .49198 .47062 Metetra
.648 .298 .365 r
.49198 .47062 .4919 .48079 .5081 .48079 .50802 .47062 Metetra
.744 .626 .728 r
.96634 .47499 .9661 .48305 .98222 .48294 .98228 .47479 Metetra
.723 .621 .743 r
.95016 .47508 .94977 .48306 .9661 .48305 .96634 .47499 Metetra
.708 .619 .755 r
.93381 .47509 .93331 .48301 .94977 .48306 .95016 .47508 Metetra
.697 .617 .764 r
.91737 .47505 .91679 .48291 .93331 .48301 .93381 .47509 Metetra
.69 .617 .769 r
.90087 .47498 .90026 .48281 .91679 .48291 .91737 .47505 Metetra
.687 .617 .772 r
.88436 .47489 .88375 .4827 .90026 .48281 .90087 .47498 Metetra
.687 .616 .771 r
.86786 .47481 .86729 .48261 .88375 .4827 .88436 .47489 Metetra
.688 .614 .768 r
.85138 .47472 .85086 .48255 .86729 .48261 .86786 .47481 Metetra
.691 .61 .761 r
.83493 .47465 .83449 .48251 .85086 .48255 .85138 .47472 Metetra
.693 .603 .75 r
.8185 .47458 .81817 .48251 .83449 .48251 .83493 .47465 Metetra
.696 .593 .737 r
.80209 .47453 .80187 .48252 .81817 .48251 .8185 .47458 Metetra
.697 .58 .721 r
.78569 .47447 .7856 .48256 .80187 .48252 .80209 .47453 Metetra
.696 .564 .702 r
.7693 .47442 .76934 .48261 .7856 .48256 .78569 .47447 Metetra
.694 .545 .68 r
.7529 .47435 .75307 .48266 .76934 .48261 .7693 .47442 Metetra
.689 .522 .656 r
.73649 .47426 .73678 .4827 .75307 .48266 .7529 .47435 Metetra
.682 .498 .63 r
.72006 .47414 .72047 .48272 .73678 .4827 .73649 .47426 Metetra
.674 .471 .603 r
.70362 .47399 .70414 .48272 .72047 .48272 .72006 .47414 Metetra
.664 .443 .576 r
.68717 .47379 .68778 .48268 .70414 .48272 .70362 .47399 Metetra
.652 .415 .548 r
.67071 .47355 .67139 .4826 .68778 .48268 .68717 .47379 Metetra
.641 .388 .52 r
.65426 .47327 .65498 .48248 .67139 .4826 .67071 .47355 Metetra
.63 .362 .493 r
.63782 .47295 .63857 .48231 .65498 .48248 .65426 .47327 Metetra
.621 .339 .468 r
.62142 .47259 .62216 .48211 .63857 .48231 .63782 .47295 Metetra
.613 .318 .445 r
.60505 .47222 .60577 .48188 .62216 .48211 .62142 .47259 Metetra
.609 .301 .423 r
.58874 .47185 .5894 .48164 .60577 .48188 .60505 .47222 Metetra
.607 .289 .405 r
.57249 .47149 .57307 .4814 .5894 .48164 .58874 .47185 Metetra
.609 .281 .389 r
.5563 .47117 .55678 .48117 .57307 .4814 .57249 .47149 Metetra
.614 .278 .378 r
.54016 .47091 .54052 .48099 .55678 .48117 .5563 .47117 Metetra
.623 .281 .37 r
.52408 .47072 .5243 .48086 .54052 .48099 .54016 .47091 Metetra
.635 .287 .365 r
.50802 .47062 .5081 .48079 .5243 .48086 .52408 .47072 Metetra
.651 .534 .708 r
.01769 .46663 .01772 .47479 .03366 .47499 .03346 .4669 Metetra
.675 .566 .725 r
.03346 .4669 .03366 .47499 .04984 .47508 .0495 .46706 Metetra
.693 .592 .738 r
.0495 .46706 .04984 .47508 .06619 .47509 .06575 .46713 Metetra
.705 .611 .749 r
.06575 .46713 .06619 .47509 .08263 .47505 .08213 .46713 Metetra
.713 .625 .757 r
.08213 .46713 .08263 .47505 .09913 .47498 .09859 .46709 Metetra
.719 .633 .762 r
.09859 .46709 .09913 .47498 .11564 .47489 .1151 .46702 Metetra
.722 .638 .764 r
.1151 .46702 .11564 .47489 .13214 .47481 .13164 .46693 Metetra
.724 .639 .763 r
.13164 .46693 .13214 .47481 .14862 .47472 .14817 .46682 Metetra
.726 .637 .758 r
.14817 .46682 .14862 .47472 .16507 .47465 .16471 .46671 Metetra
.728 .632 .751 r
.16471 .46671 .16507 .47465 .1815 .47458 .18123 .4666 Metetra
.73 .625 .741 r
.18123 .4666 .1815 .47458 .19791 .47453 .19775 .46648 Metetra
.732 .616 .728 r
.19775 .46648 .19791 .47453 .21431 .47447 .21427 .46634 Metetra
.736 .605 .712 r
.21427 .46634 .21431 .47447 .2307 .47442 .23079 .46619 Metetra
.74 .593 .693 r
.23079 .46619 .2307 .47442 .2471 .47435 .24731 .46601 Metetra
.744 .58 .672 r
.24731 .46601 .2471 .47435 .26351 .47426 .26384 .4658 Metetra
.749 .566 .648 r
.26384 .4658 .26351 .47426 .27994 .47414 .28038 .46555 Metetra
.753 .551 .623 r
.28038 .46555 .27994 .47414 .29638 .47399 .29692 .46526 Metetra
.756 .535 .597 r
.29692 .46526 .29638 .47399 .31283 .47379 .31346 .46493 Metetra
.759 .518 .569 r
.31346 .46493 .31283 .47379 .32929 .47355 .32998 .46455 Metetra
.76 .501 .542 r
.32998 .46455 .32929 .47355 .34574 .47327 .34648 .46412 Metetra
.759 .482 .514 r
.34648 .46412 .34574 .47327 .36218 .47295 .36294 .46365 Metetra
.756 .462 .487 r
.36294 .46365 .36218 .47295 .37858 .47259 .37934 .46316 Metetra
.75 .442 .462 r
.37934 .46316 .37858 .47259 .39495 .47222 .39568 .46266 Metetra
.742 .42 .438 r
.39568 .46266 .39495 .47222 .41126 .47185 .41193 .46216 Metetra
.731 .398 .417 r
.41193 .46216 .41126 .47185 .42751 .47149 .4281 .46169 Metetra
.717 .375 .398 r
.4281 .46169 .42751 .47149 .4437 .47117 .44419 .46128 Metetra
.701 .352 .382 r
.44419 .46128 .4437 .47117 .45984 .47091 .4602 .46094 Metetra
.683 .33 .37 r
.4602 .46094 .45984 .47091 .47592 .47072 .47615 .46071 Metetra
.665 .31 .361 r
.47615 .46071 .47592 .47072 .49198 .47062 .49205 .46058 Metetra
.646 .291 .357 r
.49205 .46058 .49198 .47062 .50802 .47062 .50795 .46058 Metetra
.759 .636 .724 r
.96654 .4669 .96634 .47499 .98228 .47479 .98231 .46663 Metetra
.737 .628 .738 r
.9505 .46706 .95016 .47508 .96634 .47499 .96654 .4669 Metetra
.719 .623 .749 r
.93425 .46713 .93381 .47509 .95016 .47508 .9505 .46706 Metetra
.706 .619 .757 r
.91787 .46713 .91737 .47505 .93381 .47509 .93425 .46713 Metetra
.696 .615 .762 r
.90141 .46709 .90087 .47498 .91737 .47505 .91787 .46713 Metetra
.69 .612 .764 r
.8849 .46702 .88436 .47489 .90087 .47498 .90141 .46709 Metetra
.687 .608 .763 r
.86836 .46693 .86786 .47481 .88436 .47489 .8849 .46702 Metetra
.685 .603 .759 r
.85183 .46682 .85138 .47472 .86786 .47481 .86836 .46693 Metetra
.684 .596 .751 r
.83529 .46671 .83493 .47465 .85138 .47472 .85183 .46682 Metetra
.683 .587 .741 r
.81877 .4666 .8185 .47458 .83493 .47465 .83529 .46671 Metetra
.683 .575 .728 r
.80225 .46648 .80209 .47453 .8185 .47458 .81877 .4666 Metetra
.681 .56 .712 r
.78573 .46634 .78569 .47447 .80209 .47453 .80225 .46648 Metetra
.677 .542 .693 r
.76921 .46619 .7693 .47442 .78569 .47447 .78573 .46634 Metetra
.672 .522 .672 r
.75269 .46601 .7529 .47435 .7693 .47442 .76921 .46619 Metetra
.666 .498 .649 r
.73616 .4658 .73649 .47426 .7529 .47435 .75269 .46601 Metetra
.657 .473 .623 r
.71962 .46555 .72006 .47414 .73649 .47426 .73616 .4658 Metetra
.647 .446 .597 r
.70308 .46526 .70362 .47399 .72006 .47414 .71962 .46555 Metetra
.636 .418 .569 r
.68654 .46493 .68717 .47379 .70362 .47399 .70308 .46526 Metetra
.624 .39 .542 r
.67002 .46455 .67071 .47355 .68717 .47379 .68654 .46493 Metetra
.613 .363 .514 r
.65352 .46412 .65426 .47327 .67071 .47355 .67002 .46455 Metetra
.603 .337 .487 r
.63706 .46365 .63782 .47295 .65426 .47327 .65352 .46412 Metetra
.594 .314 .462 r
.62066 .46316 .62142 .47259 .63782 .47295 .63706 .46365 Metetra
.588 .295 .438 r
.60432 .46266 .60505 .47222 .62142 .47259 .62066 .46316 Metetra
.585 .279 .417 r
.58807 .46216 .58874 .47185 .60505 .47222 .60432 .46266 Metetra
.586 .268 .398 r
.5719 .46169 .57249 .47149 .58874 .47185 .58807 .46216 Metetra
.59 .262 .382 r
.55581 .46128 .5563 .47117 .57249 .47149 .5719 .46169 Metetra
.599 .262 .37 r
.5398 .46094 .54016 .47091 .5563 .47117 .55581 .46128 Metetra
.612 .267 .361 r
.52385 .46071 .52408 .47072 .54016 .47091 .5398 .46094 Metetra
.628 .277 .357 r
.50795 .46058 .50802 .47062 .52408 .47072 .52385 .46071 Metetra
.635 .519 .705 r
.01768 .45846 .01769 .46663 .03346 .4669 .03329 .45879 Metetra
.662 .553 .721 r
.03329 .45879 .03346 .4669 .0495 .46706 .04921 .459 Metetra
.683 .58 .734 r
.04921 .459 .0495 .46706 .06575 .46713 .06537 .45912 Metetra
.698 .601 .744 r
.06537 .45912 .06575 .46713 .08213 .46713 .08169 .45916 Metetra
.709 .616 .751 r
.08169 .45916 .08213 .46713 .09859 .46709 .09813 .45914 Metetra
.718 .626 .755 r
.09813 .45914 .09859 .46709 .1151 .46702 .11464 .45908 Metetra
.724 .633 .756 r
.11464 .45908 .1151 .46702 .13164 .46693 .13121 .45898 Metetra
.729 .636 .754 r
.13121 .45898 .13164 .46693 .14817 .46682 .1478 .45886 Metetra
.734 .636 .75 r
.1478 .45886 .14817 .46682 .16471 .46671 .16441 .45872 Metetra
.738 .633 .743 r
.16441 .45872 .16471 .46671 .18123 .4666 .18103 .45856 Metetra
.743 .628 .732 r
.18103 .45856 .18123 .4666 .19775 .46648 .19765 .45838 Metetra
.747 .621 .719 r
.19765 .45838 .19775 .46648 .21427 .46634 .21428 .45817 Metetra
.753 .613 .703 r
.21428 .45817 .21427 .46634 .23079 .46619 .23092 .45793 Metetra
.758 .603 .685 r
.23092 .45793 .23079 .46619 .24731 .46601 .24756 .45765 Metetra
.764 .591 .664 r
.24756 .45765 .24731 .46601 .26384 .4658 .26421 .45733 Metetra
.769 .579 .641 r
.26421 .45733 .26384 .4658 .28038 .46555 .28085 .45697 Metetra
.774 .565 .616 r
.28085 .45697 .28038 .46555 .29692 .46526 .29749 .45656 Metetra
.778 .55 .59 r
.29749 .45656 .29692 .46526 .31346 .46493 .31411 .4561 Metetra
.781 .534 .563 r
.31411 .4561 .31346 .46493 .32998 .46455 .3307 .45558 Metetra
.781 .516 .535 r
.3307 .45558 .32998 .46455 .34648 .46412 .34724 .45502 Metetra
.78 .497 .508 r
.34724 .45502 .34648 .46412 .36294 .46365 .36371 .45443 Metetra
.776 .477 .481 r
.36371 .45443 .36294 .46365 .37934 .46316 .38011 .45381 Metetra
.769 .455 .455 r
.38011 .45381 .37934 .46316 .39568 .46266 .39642 .45318 Metetra
.759 .432 .431 r
.39642 .45318 .39568 .46266 .41193 .46216 .41261 .45257 Metetra
.746 .408 .409 r
.41261 .45257 .41193 .46216 .4281 .46169 .4287 .45201 Metetra
.73 .382 .39 r
.4287 .45201 .4281 .46169 .44419 .46128 .44468 .45151 Metetra
.711 .356 .374 r
.44468 .45151 .44419 .46128 .4602 .46094 .46057 .4511 Metetra
.689 .33 .361 r
.46057 .4511 .4602 .46094 .47615 .46071 .47637 .45082 Metetra
.666 .306 .352 r
.47637 .45082 .47615 .46071 .49205 .46058 .49213 .45067 Metetra
.643 .284 .348 r
.49213 .45067 .49205 .46058 .50795 .46058 .50787 .45067 Metetra
.773 .644 .719 r
.96671 .45879 .96654 .4669 .98231 .46663 .98232 .45846 Metetra
.749 .634 .733 r
.95079 .459 .9505 .46706 .96654 .4669 .96671 .45879 Metetra
.729 .626 .744 r
.93463 .45912 .93425 .46713 .9505 .46706 .95079 .459 Metetra
.714 .62 .751 r
.91831 .45916 .91787 .46713 .93425 .46713 .93463 .45912 Metetra
.702 .614 .755 r
.90187 .45914 .90141 .46709 .91787 .46713 .91831 .45916 Metetra
.693 .607 .756 r
.88536 .45908 .8849 .46702 .90141 .46709 .90187 .45914 Metetra
.686 .601 .755 r
.86879 .45898 .86836 .46693 .8849 .46702 .88536 .45908 Metetra
.681 .593 .75 r
.8522 .45886 .85183 .46682 .86836 .46693 .86879 .45898 Metetra
.677 .583 .743 r
.83559 .45872 .83529 .46671 .85183 .46682 .8522 .45886 Metetra
.673 .572 .733 r
.81897 .45856 .81877 .4666 .83529 .46671 .83559 .45872 Metetra
.669 .558 .72 r
.80235 .45838 .80225 .46648 .81877 .4666 .81897 .45856 Metetra
.665 .541 .704 r
.78572 .45817 .78573 .46634 .80225 .46648 .80235 .45838 Metetra
.659 .522 .685 r
.76908 .45793 .76921 .46619 .78573 .46634 .78572 .45817 Metetra
.651 .5 .664 r
.75244 .45765 .75269 .46601 .76921 .46619 .76908 .45793 Metetra
.643 .475 .641 r
.73579 .45733 .73616 .4658 .75269 .46601 .75244 .45765 Metetra
.632 .449 .616 r
.71915 .45697 .71962 .46555 .73616 .4658 .73579 .45733 Metetra
.621 .421 .59 r
.70251 .45656 .70308 .46526 .71962 .46555 .71915 .45697 Metetra
.609 .393 .563 r
.68589 .4561 .68654 .46493 .70308 .46526 .70251 .45656 Metetra
.596 .365 .536 r
.6693 .45558 .67002 .46455 .68654 .46493 .68589 .4561 Metetra
.585 .338 .508 r
.65276 .45502 .65352 .46412 .67002 .46455 .6693 .45558 Metetra
.575 .312 .481 r
.63629 .45443 .63706 .46365 .65352 .46412 .65276 .45502 Metetra
.567 .29 .455 r
.61989 .45381 .62066 .46316 .63706 .46365 .63629 .45443 Metetra
.561 .271 .431 r
.60358 .45318 .60432 .46266 .62066 .46316 .61989 .45381 Metetra
.56 .256 .409 r
.58739 .45257 .58807 .46216 .60432 .46266 .60358 .45318 Metetra
.563 .246 .39 r
.5713 .45201 .5719 .46169 .58807 .46216 .58739 .45257 Metetra
.571 .243 .374 r
.55532 .45151 .55581 .46128 .5719 .46169 .5713 .45201 Metetra
.583 .244 .361 r
.53943 .4511 .5398 .46094 .55581 .46128 .55532 .45151 Metetra
.6 .252 .352 r
.52363 .45082 .52385 .46071 .5398 .46094 .53943 .4511 Metetra
.62 .266 .348 r
.50787 .45067 .50795 .46058 .52385 .46071 .52363 .45082 Metetra
.62 .506 .702 r
.01768 .45029 .01768 .45846 .03329 .45879 .03315 .45066 Metetra
.65 .541 .718 r
.03315 .45066 .03329 .45879 .04921 .459 .04896 .45092 Metetra
.673 .569 .73 r
.04896 .45092 .04921 .459 .06537 .45912 .06504 .45107 Metetra
.692 .591 .739 r
.06504 .45107 .06537 .45912 .08169 .45916 .08131 .45114 Metetra
.706 .608 .745 r
.08131 .45114 .08169 .45916 .09813 .45914 .09772 .45114 Metetra
.717 .62 .748 r
.09772 .45114 .09813 .45914 .11464 .45908 .11424 .45109 Metetra
.726 .628 .749 r
.11424 .45109 .11464 .45908 .13121 .45898 .13084 .45099 Metetra
.734 .633 .747 r
.13084 .45099 .13121 .45898 .1478 .45886 .14749 .45085 Metetra
.741 .635 .742 r
.14749 .45085 .1478 .45886 .16441 .45872 .16417 .45068 Metetra
.748 .634 .735 r
.16417 .45068 .16441 .45872 .18103 .45856 .18088 .45047 Metetra
.754 .632 .724 r
.18088 .45047 .18103 .45856 .19765 .45838 .1976 .45023 Metetra
.761 .627 .711 r
.1976 .45023 .19765 .45838 .21428 .45817 .21435 .44996 Metetra
.768 .62 .695 r
.21435 .44996 .21428 .45817 .23092 .45793 .2311 .44964 Metetra
.775 .612 .677 r
.2311 .44964 .23092 .45793 .24756 .45765 .24785 .44928 Metetra
.782 .602 .656 r
.24785 .44928 .24756 .45765 .26421 .45733 .26461 .44887 Metetra
.788 .591 .633 r
.26461 .44887 .26421 .45733 .28085 .45697 .28136 .4484 Metetra
.794 .578 .609 r
.28136 .4484 .28085 .45697 .29749 .45656 .29808 .44788 Metetra
.798 .564 .583 r
.29808 .44788 .29749 .45656 .31411 .4561 .31478 .4473 Metetra
.801 .548 .556 r
.31478 .4473 .31411 .4561 .3307 .45558 .33143 .44667 Metetra
.801 .531 .529 r
.33143 .44667 .3307 .45558 .34724 .45502 .348 .44599 Metetra
.8 .512 .501 r
.348 .44599 .34724 .45502 .36371 .45443 .3645 .44528 Metetra
.795 .491 .475 r
.3645 .44528 .36371 .45443 .38011 .45381 .38089 .44455 Metetra
.787 .468 .449 r
.38089 .44455 .38011 .45381 .39642 .45318 .39716 .44381 Metetra
.776 .444 .424 r
.39716 .44381 .39642 .45318 .41261 .45257 .4133 .4431 Metetra
.761 .417 .402 r
.4133 .4431 .41261 .45257 .4287 .45201 .42931 .44243 Metetra
.743 .389 .382 r
.42931 .44243 .4287 .45201 .44468 .45151 .44518 .44185 Metetra
.721 .36 .365 r
.44518 .44185 .44468 .45151 .46057 .4511 .46094 .44139 Metetra
.695 .331 .352 r
.46094 .44139 .46057 .4511 .47637 .45082 .47661 .44106 Metetra
.668 .302 .343 r
.47661 .44106 .47637 .45082 .49213 .45067 .49221 .44089 Metetra
.64 .276 .338 r
.49221 .44089 .49213 .45067 .50787 .45067 .50779 .44089 Metetra
.785 .652 .715 r
.96685 .45066 .96671 .45879 .98232 .45846 .98232 .45029 Metetra
.76 .64 .729 r
.95104 .45092 .95079 .459 .96671 .45879 .96685 .45066 Metetra
.738 .63 .738 r
.93496 .45107 .93463 .45912 .95079 .459 .95104 .45092 Metetra
.721 .62 .745 r
.91869 .45114 .91831 .45916 .93463 .45912 .93496 .45107 Metetra
.706 .612 .749 r
.90228 .45114 .90187 .45914 .91831 .45916 .91869 .45114 Metetra
.695 .603 .749 r
.88576 .45109 .88536 .45908 .90187 .45914 .90228 .45114 Metetra
.685 .593 .747 r
.86916 .45099 .86879 .45898 .88536 .45908 .88576 .45109 Metetra
.677 .583 .743 r
.85251 .45085 .8522 .45886 .86879 .45898 .86916 .45099 Metetra
.67 .571 .735 r
.83583 .45068 .83559 .45872 .8522 .45886 .85251 .45085 Metetra
.663 .557 .725 r
.81912 .45047 .81897 .45856 .83559 .45872 .83583 .45068 Metetra
.657 .541 .712 r
.8024 .45023 .80235 .45838 .81897 .45856 .81912 .45047 Metetra
.649 .523 .696 r
.78565 .44996 .78572 .45817 .80235 .45838 .8024 .45023 Metetra
.641 .502 .678 r
.7689 .44964 .76908 .45793 .78572 .45817 .78565 .44996 Metetra
.631 .478 .657 r
.75215 .44928 .75244 .45765 .76908 .45793 .7689 .44964 Metetra
.62 .453 .634 r
.73539 .44887 .73579 .45733 .75244 .45765 .75215 .44928 Metetra
.608 .426 .61 r
.71864 .4484 .71915 .45697 .73579 .45733 .73539 .44887 Metetra
.595 .397 .584 r
.70192 .44788 .70251 .45656 .71915 .45697 .71864 .4484 Metetra
.582 .369 .557 r
.68522 .4473 .68589 .4561 .70251 .45656 .70192 .44788 Metetra
.569 .34 .529 r
.66857 .44667 .6693 .45558 .68589 .4561 .68522 .4473 Metetra
.557 .313 .502 r
.652 .44599 .65276 .45502 .6693 .45558 .66857 .44667 Metetra
.546 .288 .475 r
.6355 .44528 .63629 .45443 .65276 .45502 .652 .44599 Metetra
.539 .265 .449 r
.61911 .44455 .61989 .45381 .63629 .45443 .6355 .44528 Metetra
.535 .247 .424 r
.60284 .44381 .60358 .45318 .61989 .45381 .61911 .44455 Metetra
.535 .233 .402 r
.5867 .4431 .58739 .45257 .60358 .45318 .60284 .44381 Metetra
.54 .224 .382 r
.57069 .44243 .5713 .45201 .58739 .45257 .5867 .4431 Metetra
.55 .222 .365 r
.55482 .44185 .55532 .45151 .5713 .45201 .57069 .44243 Metetra
.566 .226 .351 r
.53906 .44139 .53943 .4511 .55532 .45151 .55482 .44185 Metetra
.587 .237 .342 r
.52339 .44106 .52363 .45082 .53943 .4511 .53906 .44139 Metetra
.612 .254 .338 r
.50779 .44089 .50787 .45067 .52363 .45082 .52339 .44106 Metetra
.607 .495 .7 r
.01769 .44211 .01768 .45029 .03315 .45066 .03304 .44252 Metetra
.639 .531 .715 r
.03304 .44252 .03315 .45066 .04896 .45092 .04875 .44281 Metetra
.665 .56 .726 r
.04875 .44281 .04896 .45092 .06504 .45107 .06476 .44299 Metetra
.686 .583 .734 r
.06476 .44299 .06504 .45107 .08131 .45114 .08098 .44308 Metetra
.703 .601 .74 r
.08098 .44308 .08131 .45114 .09772 .45114 .09738 .44309 Metetra
.716 .615 .742 r
.09738 .44309 .09772 .45114 .11424 .45109 .11391 .44305 Metetra
.728 .625 .743 r
.11391 .44305 .11424 .45109 .13084 .45099 .13053 .44294 Metetra
.738 .631 .74 r
.13053 .44294 .13084 .45099 .14749 .45085 .14723 .44279 Metetra
.748 .635 .735 r
.14723 .44279 .14749 .45085 .16417 .45068 .16399 .44259 Metetra
.757 .636 .727 r
.16399 .44259 .16417 .45068 .18088 .45047 .18078 .44235 Metetra
.765 .635 .717 r
.18078 .44235 .18088 .45047 .1976 .45023 .19761 .44206 Metetra
.774 .632 .703 r
.19761 .44206 .1976 .45023 .21435 .44996 .21445 .44173 Metetra
.783 .627 .688 r
.21445 .44173 .21435 .44996 .2311 .44964 .23131 .44134 Metetra
.791 .62 .669 r
.23131 .44134 .2311 .44964 .24785 .44928 .24818 .4409 Metetra
.799 .612 .649 r
.24818 .4409 .24785 .44928 .26461 .44887 .26504 .4404 Metetra
.806 .602 .626 r
.26504 .4404 .26461 .44887 .28136 .4484 .28188 .43984 Metetra
.812 .59 .602 r
.28188 .43984 .28136 .4484 .29808 .44788 .2987 .43923 Metetra
.817 .577 .576 r
.2987 .43923 .29808 .44788 .31478 .4473 .31546 .43855 Metetra
.82 .562 .549 r
.31546 .43855 .31478 .4473 .33143 .44667 .33217 .43781 Metetra
.82 .545 .522 r
.33217 .43781 .33143 .44667 .348 .44599 .34878 .43703 Metetra
.818 .526 .495 r
.34878 .43703 .348 .44599 .3645 .44528 .36529 .43621 Metetra
.813 .505 .468 r
.36529 .43621 .3645 .44528 .38089 .44455 .38168 .43537 Metetra
.805 .481 .442 r
.38168 .43537 .38089 .44455 .39716 .44381 .39792 .43453 Metetra
.793 .455 .417 r
.39792 .43453 .39716 .44381 .4133 .4431 .414 .43373 Metetra
.776 .427 .394 r
.414 .43373 .4133 .4431 .42931 .44243 .42992 .43298 Metetra
.756 .396 .373 r
.42992 .43298 .42931 .44243 .44518 .44185 .44569 .43232 Metetra
.731 .364 .356 r
.44569 .43232 .44518 .44185 .46094 .44139 .46132 .43179 Metetra
.702 .331 .342 r
.46132 .43179 .46094 .44139 .47661 .44106 .47684 .43142 Metetra
.669 .298 .332 r
.47684 .43142 .47661 .44106 .49221 .44089 .49229 .43123 Metetra
.636 .267 .327 r
.49229 .43123 .49221 .44089 .50779 .44089 .50771 .43123 Metetra
.795 .658 .711 r
.96696 .44252 .96685 .45066 .98232 .45029 .98231 .44211 Metetra
.769 .645 .724 r
.95125 .44281 .95104 .45092 .96685 .45066 .96696 .44252 Metetra
.746 .632 .734 r
.93524 .44299 .93496 .45107 .95104 .45092 .95125 .44281 Metetra
.726 .621 .74 r
.91902 .44308 .91869 .45114 .93496 .45107 .93524 .44299 Metetra
.71 .609 .743 r
.90262 .44309 .90228 .45114 .91869 .45114 .91902 .44308 Metetra
.696 .598 .743 r
.88609 .44305 .88576 .45109 .90228 .45114 .90262 .44309 Metetra
.684 .587 .741 r
.86947 .44294 .86916 .45099 .88576 .45109 .88609 .44305 Metetra
.673 .574 .736 r
.85277 .44279 .85251 .45085 .86916 .45099 .86947 .44294 Metetra
.663 .56 .728 r
.83601 .44259 .83583 .45068 .85251 .45085 .85277 .44279 Metetra
.653 .544 .717 r
.81922 .44235 .81912 .45047 .83583 .45068 .83601 .44259 Metetra
.644 .526 .704 r
.80239 .44206 .8024 .45023 .81912 .45047 .81922 .44235 Metetra
.634 .505 .689 r
.78555 .44173 .78565 .44996 .8024 .45023 .80239 .44206 Metetra
.623 .483 .671 r
.76869 .44134 .7689 .44964 .78565 .44996 .78555 .44173 Metetra
.611 .458 .65 r
.75182 .4409 .75215 .44928 .7689 .44964 .76869 .44134 Metetra
.598 .431 .628 r
.73496 .4404 .73539 .44887 .75215 .44928 .75182 .4409 Metetra
.584 .403 .603 r
.71812 .43984 .71864 .4484 .73539 .44887 .73496 .4404 Metetra
.569 .374 .577 r
.7013 .43923 .70192 .44788 .71864 .4484 .71812 .43984 Metetra
.555 .345 .551 r
.68454 .43855 .68522 .4473 .70192 .44788 .7013 .43923 Metetra
.541 .316 .523 r
.66783 .43781 .66857 .44667 .68522 .4473 .68454 .43855 Metetra
.528 .289 .496 r
.65122 .43703 .652 .44599 .66857 .44667 .66783 .43781 Metetra
.518 .263 .468 r
.63471 .43621 .6355 .44528 .652 .44599 .65122 .43703 Metetra
.51 .241 .442 r
.61832 .43537 .61911 .44455 .6355 .44528 .63471 .43621 Metetra
.507 .222 .417 r
.60208 .43453 .60284 .44381 .61911 .44455 .61832 .43537 Metetra
.508 .209 .393 r
.586 .43373 .5867 .4431 .60284 .44381 .60208 .43453 Metetra
.515 .201 .373 r
.57008 .43298 .57069 .44243 .5867 .4431 .586 .43373 Metetra
.529 .2 .355 r
.55431 .43232 .55482 .44185 .57069 .44243 .57008 .43298 Metetra
.548 .207 .341 r
.53868 .43179 .53906 .44139 .55482 .44185 .55431 .43232 Metetra
.574 .22 .332 r
.52316 .43142 .52339 .44106 .53906 .44139 .53868 .43179 Metetra
.603 .241 .327 r
.50771 .43123 .50779 .44089 .52339 .44106 .52316 .43142 Metetra
.595 .484 .698 r
.0177 .43393 .01769 .44211 .03304 .44252 .03295 .43436 Metetra
.629 .521 .712 r
.03295 .43436 .03304 .44252 .04875 .44281 .04858 .43467 Metetra
.658 .551 .722 r
.04858 .43467 .04875 .44281 .06476 .44299 .06451 .43488 Metetra
.681 .575 .73 r
.06451 .43488 .06476 .44299 .08098 .44308 .0807 .43498 Metetra
.7 .595 .735 r
.0807 .43498 .08098 .44308 .09738 .44309 .09708 .43501 Metetra
.716 .61 .737 r
.09708 .43501 .09738 .44309 .11391 .44305 .11362 .43497 Metetra
.73 .622 .737 r
.11362 .43497 .11391 .44305 .13053 .44294 .13028 .43486 Metetra
.743 .63 .734 r
.13028 .43486 .13053 .44294 .14723 .44279 .14703 .43469 Metetra
.755 .635 .728 r
.14703 .43469 .14723 .44279 .16399 .44259 .16385 .43447 Metetra
.765 .638 .72 r
.16385 .43447 .16399 .44259 .18078 .44235 .18073 .43419 Metetra
.776 .639 .71 r
.18073 .43419 .18078 .44235 .19761 .44206 .19765 .43386 Metetra
.786 .637 .696 r
.19765 .43386 .19761 .44206 .21445 .44173 .2146 .43347 Metetra
.796 .634 .681 r
.2146 .43347 .21445 .44173 .23131 .44134 .23156 .43303 Metetra
.805 .628 .662 r
.23156 .43303 .23131 .44134 .24818 .4409 .24853 .43252 Metetra
.814 .621 .642 r
.24853 .43252 .24818 .4409 .26504 .4404 .26549 .43195 Metetra
.822 .613 .619 r
.26549 .43195 .26504 .4404 .28188 .43984 .28243 .43131 Metetra
.829 .602 .595 r
.28243 .43131 .28188 .43984 .2987 .43923 .29932 .43061 Metetra
.834 .59 .57 r
.29932 .43061 .2987 .43923 .31546 .43855 .31616 .42984 Metetra
.837 .575 .543 r
.31616 .42984 .31546 .43855 .33217 .43781 .33292 .42902 Metetra
.838 .559 .516 r
.33292 .42902 .33217 .43781 .34878 .43703 .34957 .42814 Metetra
.836 .54 .488 r
.34957 .42814 .34878 .43703 .36529 .43621 .3661 .42723 Metetra
.831 .518 .461 r
.3661 .42723 .36529 .43621 .38168 .43537 .38247 .42629 Metetra
.822 .494 .435 r
.38247 .42629 .38168 .43537 .39792 .43453 .39868 .42536 Metetra
.809 .467 .409 r
.39868 .42536 .39792 .43453 .414 .43373 .4147 .42447 Metetra
.791 .437 .386 r
.4147 .42447 .414 .43373 .42992 .43298 .43054 .42364 Metetra
.769 .404 .365 r
.43054 .42364 .42992 .43298 .44569 .43232 .44621 .42291 Metetra
.741 .368 .346 r
.44621 .42291 .44569 .43232 .46132 .43179 .46171 .42232 Metetra
.708 .331 .332 r
.46171 .42232 .46132 .43179 .47684 .43142 .47708 .42191 Metetra
.671 .293 .321 r
.47708 .42191 .47684 .43142 .49229 .43123 .49237 .42169 Metetra
.632 .258 .316 r
.49237 .42169 .49229 .43123 .50771 .43123 .50763 .42169 Metetra
.804 .664 .708 r
.96705 .43436 .96696 .44252 .98231 .44211 .9823 .43393 Metetra
.777 .649 .72 r
.95142 .43467 .95125 .44281 .96696 .44252 .96705 .43436 Metetra
.753 .634 .729 r
.93549 .43488 .93524 .44299 .95125 .44281 .95142 .43467 Metetra
.731 .621 .735 r
.9193 .43498 .91902 .44308 .93524 .44299 .93549 .43488 Metetra
.713 .607 .737 r
.90292 .43501 .90262 .44309 .91902 .44308 .9193 .43498 Metetra
.696 .594 .737 r
.88638 .43497 .88609 .44305 .90262 .44309 .90292 .43501 Metetra
.682 .58 .735 r
.86972 .43486 .86947 .44294 .88609 .44305 .88638 .43497 Metetra
.668 .565 .729 r
.85297 .43469 .85277 .44279 .86947 .44294 .86972 .43486 Metetra
.656 .549 .721 r
.83615 .43447 .83601 .44259 .85277 .44279 .85297 .43469 Metetra
.644 .531 .711 r
.81927 .43419 .81922 .44235 .83601 .44259 .83615 .43447 Metetra
.631 .511 .698 r
.80235 .43386 .80239 .44206 .81922 .44235 .81927 .43419 Metetra
.619 .489 .682 r
.7854 .43347 .78555 .44173 .80239 .44206 .80235 .43386 Metetra
.605 .465 .664 r
.76844 .43303 .76869 .44134 .78555 .44173 .7854 .43347 Metetra
.591 .439 .644 r
.75147 .43252 .75182 .4409 .76869 .44134 .76844 .43303 Metetra
.576 .411 .621 r
.73451 .43195 .73496 .4404 .75182 .4409 .75147 .43252 Metetra
.56 .382 .597 r
.71757 .43131 .71812 .43984 .73496 .4404 .73451 .43195 Metetra
.544 .352 .571 r
.70068 .43061 .7013 .43923 .71812 .43984 .71757 .43131 Metetra
.528 .322 .545 r
.68384 .42984 .68454 .43855 .7013 .43923 .70068 .43061 Metetra
.513 .293 .517 r
.66708 .42902 .66783 .43781 .68454 .43855 .68384 .42984 Metetra
.5 .265 .489 r
.65043 .42814 .65122 .43703 .66783 .43781 .66708 .42902 Metetra
.489 .239 .462 r
.6339 .42723 .63471 .43621 .65122 .43703 .65043 .42814 Metetra
.481 .216 .435 r
.61753 .42629 .61832 .43537 .63471 .43621 .6339 .42723 Metetra
.478 .198 .409 r
.60132 .42536 .60208 .43453 .61832 .43537 .61753 .42629 Metetra
.481 .184 .385 r
.5853 .42447 .586 .43373 .60208 .43453 .60132 .42536 Metetra
.49 .177 .364 r
.56946 .42364 .57008 .43298 .586 .43373 .5853 .42447 Metetra
.506 .178 .345 r
.55379 .42291 .55431 .43232 .57008 .43298 .56946 .42364 Metetra
.529 .186 .331 r
.53829 .42232 .53868 .43179 .55431 .43232 .55379 .42291 Metetra
.559 .203 .321 r
.52292 .42191 .52316 .43142 .53868 .43179 .53829 .42232 Metetra
.594 .227 .316 r
.50763 .42169 .50771 .43123 .52316 .43142 .52292 .42191 Metetra
.584 .475 .696 r
.01772 .42575 .0177 .43393 .03295 .43436 .03288 .4262 Metetra
.621 .513 .709 r
.03288 .4262 .03295 .43436 .04858 .43467 .04843 .42652 Metetra
.651 .544 .719 r
.04843 .42652 .04858 .43467 .06451 .43488 .06431 .42674 Metetra
.677 .569 .726 r
.06431 .42674 .06451 .43488 .0807 .43498 .08046 .42686 Metetra
.698 .59 .731 r
.08046 .42686 .0807 .43498 .09708 .43501 .09684 .4269 Metetra
.717 .606 .732 r
.09684 .4269 .09708 .43501 .11362 .43497 .11339 .42685 Metetra
.733 .619 .731 r
.11339 .42685 .11362 .43497 .13028 .43486 .13008 .42674 Metetra
.748 .629 .728 r
.13008 .42674 .13028 .43486 .14703 .43469 .14688 .42656 Metetra
.761 .636 .722 r
.14688 .42656 .14703 .43469 .16385 .43447 .16377 .42632 Metetra
.774 .64 .714 r
.16377 .42632 .16385 .43447 .18073 .43419 .18072 .42601 Metetra
.786 .642 .703 r
.18072 .42601 .18073 .43419 .19765 .43386 .19773 .42564 Metetra
.797 .642 .69 r
.19773 .42564 .19765 .43386 .2146 .43347 .21477 .42521 Metetra
.808 .64 .674 r
.21477 .42521 .2146 .43347 .23156 .43303 .23184 .42471 Metetra
.819 .636 .656 r
.23184 .42471 .23156 .43303 .24853 .43252 .2489 .42415 Metetra
.829 .631 .635 r
.2489 .42415 .24853 .43252 .26549 .43195 .26596 .42351 Metetra
.837 .623 .613 r
.26596 .42351 .26549 .43195 .28243 .43131 .28299 .42281 Metetra
.844 .613 .589 r
.28299 .42281 .28243 .43131 .29932 .43061 .29997 .42203 Metetra
.85 .602 .563 r
.29997 .42203 .29932 .43061 .31616 .42984 .31687 .42119 Metetra
.853 .588 .537 r
.31687 .42119 .31616 .42984 .33292 .42902 .33368 .42028 Metetra
.854 .572 .509 r
.33368 .42028 .33292 .42902 .34957 .42814 .35037 .41932 Metetra
.853 .553 .482 r
.35037 .41932 .34957 .42814 .3661 .42723 .3669 .41833 Metetra
.847 .532 .454 r
.3669 .41833 .3661 .42723 .38247 .42629 .38327 .41731 Metetra
.838 .507 .427 r
.38327 .41731 .38247 .42629 .39868 .42536 .39945 .4163 Metetra
.825 .479 .401 r
.39945 .4163 .39868 .42536 .4147 .42447 .41542 .41532 Metetra
.806 .447 .377 r
.41542 .41532 .4147 .42447 .43054 .42364 .43117 .41442 Metetra
.782 .412 .355 r
.43117 .41442 .43054 .42364 .44621 .42291 .44673 .41362 Metetra
.751 .372 .336 r
.44673 .41362 .44621 .42291 .46171 .42232 .4621 .41298 Metetra
.715 .331 .32 r
.4621 .41298 .46171 .42232 .47708 .42191 .47732 .41253 Metetra
.673 .288 .309 r
.47732 .41253 .47708 .42191 .49237 .42169 .49245 .41229 Metetra
.628 .248 .303 r
.49245 .41229 .49237 .42169 .50763 .42169 .50755 .41229 Metetra
.812 .669 .705 r
.96712 .4262 .96705 .43436 .9823 .43393 .98228 .42575 Metetra
.784 .652 .717 r
.95157 .42652 .95142 .43467 .96705 .43436 .96712 .4262 Metetra
.758 .636 .725 r
.93569 .42674 .93549 .43488 .95142 .43467 .95157 .42652 Metetra
.736 .62 .73 r
.91954 .42686 .9193 .43498 .93549 .43488 .93569 .42674 Metetra
.715 .605 .733 r
.90316 .4269 .90292 .43501 .9193 .43498 .91954 .42686 Metetra
.696 .589 .732 r
.88661 .42685 .88638 .43497 .90292 .43501 .90316 .4269 Metetra
.679 .573 .729 r
.86992 .42674 .86972 .43486 .88638 .43497 .88661 .42685 Metetra
.664 .556 .723 r
.85312 .42656 .85297 .43469 .86972 .43486 .86992 .42674 Metetra
.649 .538 .715 r
.83623 .42632 .83615 .43447 .85297 .43469 .85312 .42656 Metetra
.634 .518 .705 r
.81928 .42601 .81927 .43419 .83615 .43447 .83623 .42632 Metetra
.619 .497 .691 r
.80227 .42564 .80235 .43386 .81927 .43419 .81928 .42601 Metetra
.604 .473 .676 r
.78523 .42521 .7854 .43347 .80235 .43386 .80227 .42564 Metetra
.588 .448 .658 r
.76816 .42471 .76844 .43303 .7854 .43347 .78523 .42521 Metetra
.572 .42 .637 r
.7511 .42415 .75147 .43252 .76844 .43303 .76816 .42471 Metetra
.554 .392 .615 r
.73404 .42351 .73451 .43195 .75147 .43252 .7511 .42415 Metetra
.537 .362 .591 r
.71701 .42281 .71757 .43131 .73451 .43195 .73404 .42351 Metetra
.519 .331 .565 r
.70003 .42203 .70068 .43061 .71757 .43131 .71701 .42281 Metetra
.502 .3 .539 r
.68313 .42119 .68384 .42984 .70068 .43061 .70003 .42203 Metetra
.486 .27 .511 r
.66632 .42028 .66708 .42902 .68384 .42984 .68313 .42119 Metetra
.471 .241 .483 r
.64963 .41932 .65043 .42814 .66708 .42902 .66632 .42028 Metetra
.46 .215 .455 r
.6331 .41833 .6339 .42723 .65043 .42814 .64963 .41932 Metetra
.452 .192 .427 r
.61673 .41731 .61753 .42629 .6339 .42723 .6331 .41833 Metetra
.449 .173 .401 r
.60055 .4163 .60132 .42536 .61753 .42629 .61673 .41731 Metetra
.452 .159 .376 r
.58458 .41532 .5853 .42447 .60132 .42536 .60055 .4163 Metetra
.463 .153 .354 r
.56883 .41442 .56946 .42364 .5853 .42447 .58458 .41532 Metetra
.481 .154 .334 r
.55327 .41362 .55379 .42291 .56946 .42364 .56883 .41442 Metetra
.508 .164 .319 r
.5379 .41298 .53829 .42232 .55379 .42291 .55327 .41362 Metetra
.543 .184 .308 r
.52268 .41253 .52292 .42191 .53829 .42232 .5379 .41298 Metetra
.584 .212 .303 r
.50755 .41229 .50763 .42169 .52292 .42191 .52268 .41253 Metetra
.575 .467 .694 r
.01775 .41756 .01772 .42575 .03288 .4262 .03282 .41802 Metetra
.613 .505 .707 r
.03282 .41802 .03288 .4262 .04843 .42652 .0483 .41836 Metetra
.646 .537 .716 r
.0483 .41836 .04843 .42652 .06431 .42674 .06414 .41859 Metetra
.673 .563 .723 r
.06414 .41859 .06431 .42674 .08046 .42686 .08027 .41872 Metetra
.697 .585 .727 r
.08027 .41872 .08046 .42686 .09684 .4269 .09663 .41876 Metetra
.717 .603 .728 r
.09663 .41876 .09684 .4269 .11339 .42685 .1132 .41871 Metetra
.736 .617 .727 r
.1132 .41871 .11339 .42685 .13008 .42674 .12992 .41859 Metetra
.752 .628 .723 r
.12992 .41859 .13008 .42674 .14688 .42656 .14677 .4184 Metetra
.767 .637 .717 r
.14677 .4184 .14688 .42656 .16377 .42632 .16372 .41814 Metetra
.781 .642 .708 r
.16372 .41814 .16377 .42632 .18072 .42601 .18076 .41781 Metetra
.795 .646 .697 r
.18076 .41781 .18072 .42601 .19773 .42564 .19785 .41741 Metetra
.808 .647 .684 r
.19785 .41741 .19773 .42564 .21477 .42521 .21498 .41694 Metetra
.82 .647 .668 r
.21498 .41694 .21477 .42521 .23184 .42471 .23214 .4164 Metetra
.831 .644 .649 r
.23214 .4164 .23184 .42471 .2489 .42415 .2493 .41578 Metetra
.842 .64 .629 r
.2493 .41578 .2489 .42415 .26596 .42351 .26645 .4151 Metetra
.851 .633 .607 r
.26645 .4151 .26596 .42351 .28299 .42281 .28356 .41433 Metetra
.859 .624 .583 r
.28356 .41433 .28299 .42281 .29997 .42203 .30062 .41349 Metetra
.865 .614 .557 r
.30062 .41349 .29997 .42203 .31687 .42119 .31759 .41259 Metetra
.869 .601 .531 r
.31759 .41259 .31687 .42119 .33368 .42028 .33444 .41161 Metetra
.87 .585 .503 r
.33444 .41161 .33368 .42028 .35037 .41932 .35116 .41059 Metetra
.868 .567 .475 r
.35116 .41059 .35037 .41932 .3669 .41833 .36772 .40952 Metetra
.863 .545 .447 r
.36772 .40952 .3669 .41833 .38327 .41731 .38408 .40843 Metetra
.854 .52 .42 r
.38408 .40843 .38327 .41731 .39945 .4163 .40022 .40735 Metetra
.84 .491 .394 r
.40022 .40735 .39945 .4163 .41542 .41532 .41613 .4063 Metetra
.821 .458 .368 r
.41613 .4063 .41542 .41532 .43117 .41442 .43181 .40532 Metetra
.795 .42 .345 r
.43181 .40532 .43117 .41442 .44673 .41362 .44726 .40447 Metetra
.762 .377 .325 r
.44726 .40447 .44673 .41362 .4621 .41298 .4625 .40377 Metetra
.722 .331 .308 r
.4625 .40377 .4621 .41298 .47732 .41253 .47757 .40328 Metetra
.675 .283 .296 r
.47757 .40328 .47732 .41253 .49245 .41229 .49254 .40302 Metetra
.623 .237 .29 r
.49254 .40302 .49245 .41229 .50755 .41229 .50746 .40302 Metetra
.819 .673 .702 r
.96718 .41802 .96712 .4262 .98228 .42575 .98225 .41756 Metetra
.79 .655 .713 r
.9517 .41836 .95157 .42652 .96712 .4262 .96718 .41802 Metetra
.763 .637 .721 r
.93586 .41859 .93569 .42674 .95157 .42652 .9517 .41836 Metetra
.739 .62 .726 r
.91973 .41872 .91954 .42686 .93569 .42674 .93586 .41859 Metetra
.717 .603 .728 r
.90337 .41876 .90316 .4269 .91954 .42686 .91973 .41872 Metetra
.696 .585 .727 r
.8868 .41871 .88661 .42685 .90316 .4269 .90337 .41876 Metetra
.677 .567 .724 r
.87008 .41859 .86992 .42674 .88661 .42685 .8868 .41871 Metetra
.659 .548 .718 r
.85323 .4184 .85312 .42656 .86992 .42674 .87008 .41859 Metetra
.641 .528 .71 r
.83628 .41814 .83623 .42632 .85312 .42656 .85323 .4184 Metetra
.624 .507 .699 r
.81924 .41781 .81928 .42601 .83623 .42632 .83628 .41814 Metetra
.607 .483 .686 r
.80215 .41741 .80227 .42564 .81928 .42601 .81924 .41781 Metetra
.59 .458 .67 r
.78502 .41694 .78523 .42521 .80227 .42564 .80215 .41741 Metetra
.572 .432 .652 r
.76786 .4164 .76816 .42471 .78523 .42521 .78502 .41694 Metetra
.553 .403 .632 r
.7507 .41578 .7511 .42415 .76816 .42471 .76786 .4164 Metetra
.534 .373 .609 r
.73355 .4151 .73404 .42351 .7511 .42415 .7507 .41578 Metetra
.514 .342 .585 r
.71644 .41433 .71701 .42281 .73404 .42351 .73355 .4151 Metetra
.495 .311 .56 r
.69938 .41349 .70003 .42203 .71701 .42281 .71644 .41433 Metetra
.476 .279 .533 r
.68241 .41259 .68313 .42119 .70003 .42203 .69938 .41349 Metetra
.459 .248 .505 r
.66556 .41161 .66632 .42028 .68313 .42119 .68241 .41259 Metetra
.443 .219 .477 r
.64884 .41059 .64963 .41932 .66632 .42028 .66556 .41161 Metetra
.431 .191 .448 r
.63228 .40952 .6331 .41833 .64963 .41932 .64884 .41059 Metetra
.422 .167 .42 r
.61592 .40843 .61673 .41731 .6331 .41833 .63228 .40952 Metetra
.419 .148 .393 r
.59978 .40735 .60055 .4163 .61673 .41731 .61592 .40843 Metetra
.423 .134 .367 r
.58387 .4063 .58458 .41532 .60055 .4163 .59978 .40735 Metetra
.434 .127 .344 r
.56819 .40532 .56883 .41442 .58458 .41532 .58387 .4063 Metetra
.455 .129 .323 r
.55274 .40447 .55327 .41362 .56883 .41442 .56819 .40532 Metetra
.485 .141 .307 r
.5375 .40377 .5379 .41298 .55327 .41362 .55274 .40447 Metetra
.525 .163 .295 r
.52243 .40328 .52268 .41253 .5379 .41298 .5375 .40377 Metetra
.572 .196 .289 r
.50746 .40302 .50755 .41229 .52268 .41253 .52243 .40328 Metetra
.567 .461 .693 r
.01777 .40938 .01775 .41756 .03282 .41802 .03277 .40984 Metetra
.607 .499 .705 r
.03277 .40984 .03282 .41802 .0483 .41836 .0482 .41018 Metetra
.641 .531 .714 r
.0482 .41018 .0483 .41836 .06414 .41859 .064 .41042 Metetra
.67 .559 .72 r
.064 .41042 .06414 .41859 .08027 .41872 .0801 .41055 Metetra
.696 .582 .723 r
.0801 .41055 .08027 .41872 .09663 .41876 .09647 .41059 Metetra
.718 .601 .724 r
.09647 .41059 .09663 .41876 .1132 .41871 .11304 .41055 Metetra
.738 .616 .722 r
.11304 .41055 .1132 .41871 .12992 .41859 .1298 .41042 Metetra
.756 .628 .718 r
.1298 .41042 .12992 .41859 .14677 .4184 .1467 .41022 Metetra
.773 .638 .712 r
.1467 .41022 .14677 .4184 .16372 .41814 .16371 .40994 Metetra
.789 .645 .703 r
.16371 .40994 .16372 .41814 .18076 .41781 .18082 .40959 Metetra
.804 .65 .692 r
.18082 .40959 .18076 .41781 .19785 .41741 .19799 .40917 Metetra
.818 .653 .678 r
.19799 .40917 .19785 .41741 .21498 .41694 .21521 .40867 Metetra
.831 .653 .662 r
.21521 .40867 .21498 .41694 .23214 .4164 .23246 .40809 Metetra
.843 .652 .644 r
.23246 .40809 .23214 .4164 .2493 .41578 .24972 .40744 Metetra
.854 .648 .623 r
.24972 .40744 .2493 .41578 .26645 .4151 .26695 .4067 Metetra
.864 .643 .601 r
.26695 .4067 .26645 .4151 .28356 .41433 .28415 .40589 Metetra
.872 .635 .577 r
.28415 .40589 .28356 .41433 .30062 .41349 .30127 .40501 Metetra
.878 .625 .551 r
.30127 .40501 .30062 .41349 .31759 .41259 .3183 .40405 Metetra
.883 .613 .525 r
.3183 .40405 .31759 .41259 .33444 .41161 .33521 .40302 Metetra
.884 .598 .497 r
.33521 .40302 .33444 .41161 .35116 .41059 .35196 .40193 Metetra
.883 .58 .469 r
.35196 .40193 .35116 .41059 .36772 .40952 .36853 .40081 Metetra
.878 .558 .441 r
.36853 .40081 .36772 .40952 .38408 .40843 .38488 .39965 Metetra
.869 .533 .413 r
.38488 .39965 .38408 .40843 .40022 .40735 .401 .39851 Metetra
.856 .504 .386 r
.401 .39851 .40022 .40735 .41613 .4063 .41686 .39739 Metetra
.836 .469 .359 r
.41686 .39739 .41613 .4063 .43181 .40532 .43245 .39636 Metetra
.809 .429 .335 r
.43245 .39636 .43181 .40532 .44726 .40447 .44779 .39544 Metetra
.774 .383 .314 r
.44779 .39544 .44726 .40447 .4625 .40377 .4629 .39469 Metetra
.73 .332 .296 r
.4629 .39469 .4625 .40377 .47757 .40328 .47782 .39416 Metetra
.677 .278 .283 r
.47782 .39416 .47757 .40328 .49254 .40302 .49262 .39388 Metetra
.618 .225 .275 r
.49262 .39388 .49254 .40302 .50746 .40302 .50738 .39388 Metetra
.824 .677 .7 r
.96723 .40984 .96718 .41802 .98225 .41756 .98223 .40938 Metetra
.795 .657 .711 r
.9518 .41018 .9517 .41836 .96718 .41802 .96723 .40984 Metetra
.767 .638 .718 r
.936 .41042 .93586 .41859 .9517 .41836 .9518 .41018 Metetra
.742 .619 .723 r
.9199 .41055 .91973 .41872 .93586 .41859 .936 .41042 Metetra
.718 .6 .724 r
.90353 .41059 .90337 .41876 .91973 .41872 .9199 .41055 Metetra
.695 .581 .723 r
.88696 .41055 .8868 .41871 .90337 .41876 .90353 .41059 Metetra
.674 .561 .72 r
.8702 .41042 .87008 .41859 .8868 .41871 .88696 .41055 Metetra
.654 .541 .713 r
.8533 .41022 .85323 .4184 .87008 .41859 .8702 .41042 Metetra
.634 .519 .705 r
.83629 .40994 .83628 .41814 .85323 .4184 .8533 .41022 Metetra
.615 .496 .694 r
.81918 .40959 .81924 .41781 .83628 .41814 .83629 .40994 Metetra
.595 .471 .68 r
.80201 .40917 .80215 .41741 .81924 .41781 .81918 .40959 Metetra
.576 .444 .665 r
.78479 .40867 .78502 .41694 .80215 .41741 .80201 .40917 Metetra
.555 .416 .647 r
.76754 .40809 .76786 .4164 .78502 .41694 .78479 .40867 Metetra
.535 .387 .627 r
.75028 .40744 .7507 .41578 .76786 .4164 .76754 .40809 Metetra
.514 .356 .604 r
.73305 .4067 .73355 .4151 .7507 .41578 .75028 .40744 Metetra
.492 .324 .58 r
.71585 .40589 .71644 .41433 .73355 .4151 .73305 .4067 Metetra
.471 .291 .555 r
.69873 .40501 .69938 .41349 .71644 .41433 .71585 .40589 Metetra
.451 .259 .528 r
.6817 .40405 .68241 .41259 .69938 .41349 .69873 .40501 Metetra
.432 .227 .5 r
.66479 .40302 .66556 .41161 .68241 .41259 .6817 .40405 Metetra
.415 .196 .471 r
.64804 .40193 .64884 .41059 .66556 .41161 .66479 .40302 Metetra
.401 .168 .442 r
.63147 .40081 .63228 .40952 .64884 .41059 .64804 .40193 Metetra
.392 .143 .413 r
.61512 .39965 .61592 .40843 .63228 .40952 .63147 .40081 Metetra
.388 .123 .385 r
.599 .39851 .59978 .40735 .61592 .40843 .61512 .39965 Metetra
.392 .108 .358 r
.58314 .39739 .58387 .4063 .59978 .40735 .599 .39851 Metetra
.404 .101 .333 r
.56755 .39636 .56819 .40532 .58387 .4063 .58314 .39739 Metetra
.427 .103 .311 r
.55221 .39544 .55274 .40447 .56819 .40532 .56755 .39636 Metetra
.46 .115 .293 r
.5371 .39469 .5375 .40377 .55274 .40447 .55221 .39544 Metetra
.505 .141 .281 r
.52218 .39416 .52243 .40328 .5375 .40377 .5371 .39469 Metetra
.559 .178 .275 r
.50738 .39388 .50746 .40302 .52243 .40328 .52218 .39416 Metetra
.56 .455 .692 r
.01779 .4012 .01777 .40938 .03277 .40984 .03274 .40166 Metetra
.601 .494 .704 r
.03274 .40166 .03277 .40984 .0482 .41018 .04812 .402 Metetra
.637 .527 .712 r
.04812 .402 .0482 .41018 .064 .41042 .06388 .40223 Metetra
.668 .555 .717 r
.06388 .40223 .064 .41042 .0801 .41055 .07997 .40236 Metetra
.695 .579 .72 r
.07997 .40236 .0801 .41055 .09647 .41059 .09633 .40241 Metetra
.72 .599 .721 r
.09633 .40241 .09647 .41059 .11304 .41055 .11293 .40236 Metetra
.741 .615 .719 r
.11293 .40236 .11304 .41055 .1298 .41042 .12971 .40223 Metetra
.761 .629 .714 r
.12971 .40223 .1298 .41042 .1467 .41022 .14666 .40202 Metetra
.779 .64 .707 r
.14666 .40202 .1467 .41022 .16371 .40994 .16373 .40173 Metetra
.796 .648 .698 r
.16373 .40173 .16371 .40994 .18082 .40959 .18091 .40136 Metetra
.812 .654 .687 r
.18091 .40136 .18082 .40959 .19799 .40917 .19816 .40092 Metetra
.827 .658 .673 r
.19816 .40092 .19799 .40917 .21521 .40867 .21547 .4004 Metetra
.841 .659 .657 r
.21547 .4004 .21521 .40867 .23246 .40809 .2328 .39979 Metetra
.854 .659 .638 r
.2328 .39979 .23246 .40809 .24972 .40744 .25014 .39911 Metetra
.865 .656 .618 r
.25014 .39911 .24972 .40744 .26695 .4067 .26746 .39834 Metetra
.876 .652 .596 r
.26746 .39834 .26695 .4067 .28415 .40589 .28473 .3975 Metetra
.884 .645 .572 r
.28473 .3975 .28415 .40589 .30127 .40501 .30193 .39657 Metetra
.891 .636 .546 r
.30193 .39657 .30127 .40501 .3183 .40405 .31902 .39557 Metetra
.896 .624 .519 r
.31902 .39557 .3183 .40405 .33521 .40302 .33598 .3945 Metetra
.898 .61 .491 r
.33598 .3945 .33521 .40302 .35196 .40193 .35276 .39337 Metetra
.897 .593 .463 r
.35276 .39337 .35196 .40193 .36853 .40081 .36934 .39219 Metetra
.892 .572 .434 r
.36934 .39219 .36853 .40081 .38488 .39965 .38569 .39099 Metetra
.884 .547 .406 r
.38569 .39099 .38488 .39965 .401 .39851 .40177 .38978 Metetra
.87 .517 .377 r
.40177 .38978 .401 .39851 .41686 .39739 .41758 .38861 Metetra
.851 .481 .35 r
.41758 .38861 .41686 .39739 .43245 .39636 .4331 .38752 Metetra
.823 .439 .325 r
.4331 .38752 .43245 .39636 .44779 .39544 .44834 .38654 Metetra
.786 .389 .302 r
.44834 .38654 .44779 .39544 .4629 .39469 .46331 .38574 Metetra
.738 .333 .282 r
.46331 .38574 .4629 .39469 .47782 .39416 .47808 .38517 Metetra
.679 .272 .268 r
.47808 .38517 .47782 .39416 .49262 .39388 .49271 .38487 Metetra
.613 .212 .259 r
.49271 .38487 .49262 .39388 .50738 .39388 .50729 .38487 Metetra
.829 .68 .698 r
.96726 .40166 .96723 .40984 .98223 .40938 .98221 .4012 Metetra
.799 .659 .708 r
.95188 .402 .9518 .41018 .96723 .40984 .96726 .40166 Metetra
.771 .639 .715 r
.93612 .40223 .936 .41042 .9518 .41018 .95188 .402 Metetra
.744 .618 .72 r
.92003 .40236 .9199 .41055 .936 .41042 .93612 .40223 Metetra
.718 .598 .721 r
.90367 .40241 .90353 .41059 .9199 .41055 .92003 .40236 Metetra
.694 .577 .72 r
.88707 .40236 .88696 .41055 .90353 .41059 .90367 .40241 Metetra
.671 .556 .716 r
.87029 .40223 .8702 .41042 .88696 .41055 .88707 .40236 Metetra
.649 .534 .709 r
.85334 .40202 .8533 .41022 .8702 .41042 .87029 .40223 Metetra
.627 .51 .701 r
.83627 .40173 .83629 .40994 .8533 .41022 .85334 .40202 Metetra
.606 .485 .689 r
.81909 .40136 .81918 .40959 .83629 .40994 .83627 .40173 Metetra
.584 .459 .676 r
.80184 .40092 .80201 .40917 .81918 .40959 .81909 .40136 Metetra
.562 .431 .66 r
.78453 .4004 .78479 .40867 .80201 .40917 .80184 .40092 Metetra
.54 .402 .642 r
.7672 .39979 .76754 .40809 .78479 .40867 .78453 .4004 Metetra
.517 .371 .622 r
.74986 .39911 .75028 .40744 .76754 .40809 .7672 .39979 Metetra
.494 .339 .6 r
.73254 .39834 .73305 .4067 .75028 .40744 .74986 .39911 Metetra
.471 .306 .576 r
.71527 .3975 .71585 .40589 .73305 .4067 .73254 .39834 Metetra
.448 .273 .55 r
.69807 .39657 .69873 .40501 .71585 .40589 .71527 .3975 Metetra
.426 .239 .523 r
.68098 .39557 .6817 .40405 .69873 .40501 .69807 .39657 Metetra
.405 .207 .495 r
.66402 .3945 .66479 .40302 .6817 .40405 .68098 .39557 Metetra
.387 .175 .466 r
.64724 .39337 .64804 .40193 .66479 .40302 .66402 .3945 Metetra
.372 .146 .436 r
.63066 .39219 .63147 .40081 .64804 .40193 .64724 .39337 Metetra
.361 .119 .406 r
.61431 .39099 .61512 .39965 .63147 .40081 .63066 .39219 Metetra
.357 .098 .377 r
.59823 .38978 .599 .39851 .61512 .39965 .61431 .39099 Metetra
.36 .082 .349 r
.58242 .38861 .58314 .39739 .599 .39851 .59823 .38978 Metetra
.372 .073 .322 r
.5669 .38752 .56755 .39636 .58314 .39739 .58242 .38861 Metetra
.396 .075 .299 r
.55166 .38654 .55221 .39544 .56755 .39636 .5669 .38752 Metetra
.433 .088 .279 r
.53669 .38574 .5371 .39469 .55221 .39544 .55166 .38654 Metetra
.484 .116 .266 r
.52192 .38517 .52218 .39416 .5371 .39469 .53669 .38574 Metetra
.545 .158 .259 r
.50729 .38487 .50738 .39388 .52218 .39416 .52192 .38517 Metetra
.554 .45 .691 r
.01781 .39302 .01779 .4012 .03274 .40166 .03271 .39347 Metetra
.597 .489 .702 r
.03271 .39347 .03274 .40166 .04812 .402 .04805 .3938 Metetra
.634 .523 .71 r
.04805 .3938 .04812 .402 .06388 .40223 .06379 .39403 Metetra
.666 .552 .715 r
.06379 .39403 .06388 .40223 .07997 .40236 .07986 .39416 Metetra
.695 .576 .718 r
.07986 .39416 .07997 .40236 .09633 .40241 .09623 .3942 Metetra
.721 .597 .718 r
.09623 .3942 .09633 .40241 .11293 .40236 .11284 .39416 Metetra
.744 .615 .715 r
.11284 .39416 .11293 .40236 .12971 .40223 .12966 .39402 Metetra
.765 .63 .71 r
.12966 .39402 .12971 .40223 .14666 .40202 .14665 .39381 Metetra
.785 .642 .703 r
.14665 .39381 .14666 .40202 .16373 .40173 .16378 .39351 Metetra
.803 .651 .694 r
.16378 .39351 .16373 .40173 .18091 .40136 .18102 .39313 Metetra
.82 .658 .682 r
.18102 .39313 .18091 .40136 .19816 .40092 .19835 .39267 Metetra
.835 .663 .668 r
.19835 .39267 .19816 .40092 .21547 .4004 .21574 .39213 Metetra
.85 .665 .652 r
.21574 .39213 .21547 .4004 .2328 .39979 .23316 .39151 Metetra
.864 .666 .634 r
.23316 .39151 .2328 .39979 .25014 .39911 .25058 .3908 Metetra
.876 .665 .613 r
.25058 .3908 .25014 .39911 .26746 .39834 .26798 .39001 Metetra
.887 .661 .591 r
.26798 .39001 .26746 .39834 .28473 .3975 .28532 .38914 Metetra
.896 .655 .567 r
.28532 .38914 .28473 .3975 .30193 .39657 .30259 .38819 Metetra
.903 .647 .541 r
.30259 .38819 .30193 .39657 .31902 .39557 .31974 .38716 Metetra
.908 .636 .514 r
.31974 .38716 .31902 .39557 .33598 .3945 .33674 .38605 Metetra
.91 .622 .486 r
.33674 .38605 .33598 .3945 .35276 .39337 .35355 .38489 Metetra
.909 .605 .457 r
.35355 .38489 .35276 .39337 .36934 .39219 .37015 .38367 Metetra
.906 .585 .428 r
.37015 .38367 .36934 .39219 .38569 .39099 .38649 .38243 Metetra
.898 .56 .399 r
.38649 .38243 .38569 .39099 .40177 .38978 .40255 .38118 Metetra
.885 .53 .369 r
.40255 .38118 .40177 .38978 .41758 .38861 .41831 .37996 Metetra
.865 .493 .341 r
.41831 .37996 .41758 .38861 .4331 .38752 .43375 .37881 Metetra
.838 .449 .314 r
.43375 .37881 .4331 .38752 .44834 .38654 .44889 .37778 Metetra
.799 .396 .289 r
.44889 .37778 .44834 .38654 .46331 .38574 .46373 .37693 Metetra
.747 .335 .268 r
.46373 .37693 .46331 .38574 .47808 .38517 .47834 .37632 Metetra
.682 .266 .251 r
.47834 .37632 .47808 .38517 .49271 .38487 .4928 .376 Metetra
.606 .198 .242 r
.4928 .376 .49271 .38487 .50729 .38487 .5072 .376 Metetra
.833 .682 .696 r
.96729 .39347 .96726 .40166 .98221 .4012 .98219 .39302 Metetra
.803 .661 .706 r
.95195 .3938 .95188 .402 .96726 .40166 .96729 .39347 Metetra
.773 .639 .713 r
.93621 .39403 .93612 .40223 .95188 .402 .95195 .3938 Metetra
.745 .618 .717 r
.92014 .39416 .92003 .40236 .93612 .40223 .93621 .39403 Metetra
.719 .596 .718 r
.90377 .3942 .90367 .40241 .92003 .40236 .92014 .39416 Metetra
.693 .573 .716 r
.88716 .39416 .88707 .40236 .90367 .40241 .90377 .3942 Metetra
.668 .55 .712 r
.87034 .39402 .87029 .40223 .88707 .40236 .88716 .39416 Metetra
.644 .527 .706 r
.85335 .39381 .85334 .40202 .87029 .40223 .87034 .39402 Metetra
.62 .502 .697 r
.83622 .39351 .83627 .40173 .85334 .40202 .85335 .39381 Metetra
.597 .476 .685 r
.81898 .39313 .81909 .40136 .83627 .40173 .83622 .39351 Metetra
.573 .448 .672 r
.80165 .39267 .80184 .40092 .81909 .40136 .81898 .39313 Metetra
.549 .419 .656 r
.78426 .39213 .78453 .4004 .80184 .40092 .80165 .39267 Metetra
.525 .389 .638 r
.76684 .39151 .7672 .39979 .78453 .4004 .78426 .39213 Metetra
.5 .357 .618 r
.74942 .3908 .74986 .39911 .7672 .39979 .76684 .39151 Metetra
.475 .324 .595 r
.73202 .39001 .73254 .39834 .74986 .39911 .74942 .3908 Metetra
.45 .29 .571 r
.71468 .38914 .71527 .3975 .73254 .39834 .73202 .39001 Metetra
.425 .256 .546 r
.69741 .38819 .69807 .39657 .71527 .3975 .71468 .38914 Metetra
.402 .221 .518 r
.68026 .38716 .68098 .39557 .69807 .39657 .69741 .38819 Metetra
.379 .187 .49 r
.66326 .38605 .66402 .3945 .68098 .39557 .68026 .38716 Metetra
.359 .155 .46 r
.64645 .38489 .64724 .39337 .66402 .3945 .66326 .38605 Metetra
.343 .124 .43 r
.62985 .38367 .63066 .39219 .64724 .39337 .64645 .38489 Metetra
.33 .096 .4 r
.61351 .38243 .61431 .39099 .63066 .39219 .62985 .38367 Metetra
.324 .073 .369 r
.59745 .38118 .59823 .38978 .61431 .39099 .61351 .38243 Metetra
.326 .055 .34 r
.58169 .37996 .58242 .38861 .59823 .38978 .59745 .38118 Metetra
.338 .045 .311 r
.56625 .37881 .5669 .38752 .58242 .38861 .58169 .37996 Metetra
.363 .045 .286 r
.55111 .37778 .55166 .38654 .5669 .38752 .56625 .37881 Metetra
.403 .059 .264 r
.53627 .37693 .53669 .38574 .55166 .38654 .55111 .37778 Metetra
.459 .089 .249 r
.52166 .37632 .52192 .38517 .53669 .38574 .53627 .37693 Metetra
.529 .136 .241 r
.5072 .376 .50729 .38487 .52192 .38517 .52166 .37632 Metetra
.549 .447 .691 r
.01783 .38484 .01781 .39302 .03271 .39347 .03269 .38527 Metetra
.593 .486 .701 r
.03269 .38527 .03271 .39347 .04805 .3938 .048 .3856 Metetra
.631 .52 .709 r
.048 .3856 .04805 .3938 .06379 .39403 .06371 .38583 Metetra
.665 .549 .713 r
.06371 .38583 .06379 .39403 .07986 .39416 .07978 .38595 Metetra
.695 .575 .715 r
.07978 .38595 .07986 .39416 .09623 .3942 .09615 .38599 Metetra
.723 .597 .715 r
.09615 .38599 .09623 .3942 .11284 .39416 .11278 .38594 Metetra
.747 .615 .712 r
.11278 .38594 .11284 .39416 .12966 .39402 .12963 .3858 Metetra
.769 .631 .707 r
.12963 .3858 .12966 .39402 .14665 .39381 .14666 .38558 Metetra
.79 .644 .7 r
.14666 .38558 .14665 .39381 .16378 .39351 .16385 .38528 Metetra
.809 .654 .69 r
.16385 .38528 .16378 .39351 .18102 .39313 .18116 .38489 Metetra
.827 .662 .678 r
.18116 .38489 .18102 .39313 .19835 .39267 .19856 .38443 Metetra
.844 .668 .664 r
.19856 .38443 .19835 .39267 .21574 .39213 .21602 .38388 Metetra
.859 .672 .648 r
.21602 .38388 .21574 .39213 .23316 .39151 .23352 .38324 Metetra
.873 .673 .629 r
.23352 .38324 .23316 .39151 .25058 .3908 .25102 .38252 Metetra
.886 .673 .609 r
.25102 .38252 .25058 .3908 .26798 .39001 .26849 .38172 Metetra
.897 .67 .587 r
.26849 .38172 .26798 .39001 .28532 .38914 .28591 .38083 Metetra
.906 .665 .562 r
.28591 .38083 .28532 .38914 .30259 .38819 .30324 .37986 Metetra
.913 .657 .537 r
.30324 .37986 .30259 .38819 .31974 .38716 .32044 .37881 Metetra
.919 .647 .51 r
.32044 .37881 .31974 .38716 .33674 .38605 .33749 .37769 Metetra
.921 .634 .481 r
.33749 .37769 .33674 .38605 .35355 .38489 .35433 .3765 Metetra
.921 .618 .452 r
.35433 .3765 .35355 .38489 .37015 .38367 .37094 .37526 Metetra
.918 .598 .422 r
.37094 .37526 .37015 .38367 .38649 .38243 .38729 .37398 Metetra
.911 .573 .392 r
.38729 .37398 .38649 .38243 .40255 .38118 .40333 .3727 Metetra
.898 .543 .362 r
.40333 .3727 .40255 .38118 .41831 .37996 .41904 .37144 Metetra
.88 .507 .332 r
.41904 .37144 .41831 .37996 .43375 .37881 .43441 .37024 Metetra
.852 .461 .303 r
.43441 .37024 .43375 .37881 .44889 .37778 .44945 .36916 Metetra
.813 .405 .276 r
.44945 .36916 .44889 .37778 .46373 .37693 .46416 .36826 Metetra
.757 .337 .252 r
.46416 .36826 .46373 .37693 .47834 .37632 .47862 .36761 Metetra
.685 .261 .234 r
.47862 .36761 .47834 .37632 .4928 .376 .49289 .36727 Metetra
.599 .182 .223 r
.49289 .36727 .4928 .376 .5072 .376 .50711 .36727 Metetra
.836 .684 .694 r
.96731 .38527 .96729 .39347 .98219 .39302 .98217 .38484 Metetra
.806 .662 .704 r
.952 .3856 .95195 .3938 .96729 .39347 .96731 .38527 Metetra
.776 .639 .711 r
.93629 .38583 .93621 .39403 .95195 .3938 .952 .3856 Metetra
.747 .617 .714 r
.92022 .38595 .92014 .39416 .93621 .39403 .93629 .38583 Metetra
.718 .593 .715 r
.90385 .38599 .90377 .3942 .92014 .39416 .92022 .38595 Metetra
.691 .57 .713 r
.88722 .38594 .88716 .39416 .90377 .3942 .90385 .38599 Metetra
.665 .545 .709 r
.87037 .3858 .87034 .39402 .88716 .39416 .88722 .38594 Metetra
.639 .52 .702 r
.85334 .38558 .85335 .39381 .87034 .39402 .87037 .3858 Metetra
.613 .494 .693 r
.83615 .38528 .83622 .39351 .85335 .39381 .85334 .38558 Metetra
.588 .467 .682 r
.81884 .38489 .81898 .39313 .83622 .39351 .83615 .38528 Metetra
.562 .438 .668 r
.80144 .38443 .80165 .39267 .81898 .39313 .81884 .38489 Metetra
.536 .408 .652 r
.78398 .38388 .78426 .39213 .80165 .39267 .80144 .38443 Metetra
.51 .376 .634 r
.76648 .38324 .76684 .39151 .78426 .39213 .78398 .38388 Metetra
.484 .343 .614 r
.74898 .38252 .74942 .3908 .76684 .39151 .76648 .38324 Metetra
.457 .309 .592 r
.73151 .38172 .73202 .39001 .74942 .3908 .74898 .38252 Metetra
.43 .275 .568 r
.71409 .38083 .71468 .38914 .73202 .39001 .73151 .38172 Metetra
.404 .239 .542 r
.69676 .37986 .69741 .38819 .71468 .38914 .71409 .38083 Metetra
.378 .204 .515 r
.67956 .37881 .68026 .38716 .69741 .38819 .69676 .37986 Metetra
.354 .169 .486 r
.66251 .37769 .66326 .38605 .68026 .38716 .67956 .37881 Metetra
.332 .135 .456 r
.64567 .3765 .64645 .38489 .66326 .38605 .66251 .37769 Metetra
.313 .103 .425 r
.62906 .37526 .62985 .38367 .64645 .38489 .64567 .3765 Metetra
.299 .073 .393 r
.61271 .37398 .61351 .38243 .62985 .38367 .62906 .37526 Metetra
.291 .048 .362 r
.59667 .3727 .59745 .38118 .61351 .38243 .61271 .37398 Metetra
.292 .028 .33 r
.58096 .37144 .58169 .37996 .59745 .38118 .59667 .3727 Metetra
.303 .016 .3 r
.56559 .37024 .56625 .37881 .58169 .37996 .58096 .37144 Metetra
.328 .015 .272 r
.55055 .36916 .55111 .37778 .56625 .37881 .56559 .37024 Metetra
.37 .028 .248 r
.53584 .36826 .53627 .37693 .55111 .37778 .55055 .36916 Metetra
.431 .06 .231 r
.52138 .36761 .52166 .37632 .53627 .37693 .53584 .36826 Metetra
.51 .112 .222 r
.50711 .36727 .5072 .376 .52166 .37632 .52138 .36761 Metetra
.545 .444 .69 r
.01785 .37667 .01783 .38484 .03269 .38527 .03267 .37708 Metetra
.59 .483 .7 r
.03267 .37708 .03269 .38527 .048 .3856 .04796 .37739 Metetra
.629 .517 .707 r
.04796 .37739 .048 .3856 .06371 .38583 .06365 .37761 Metetra
.664 .547 .712 r
.06365 .37761 .06371 .38583 .07978 .38595 .07971 .37773 Metetra
.696 .573 .713 r
.07971 .37773 .07978 .38595 .09615 .38599 .09609 .37777 Metetra
.724 .596 .713 r
.09609 .37777 .09615 .38599 .11278 .38594 .11274 .37771 Metetra
.75 .616 .71 r
.11274 .37771 .11278 .38594 .12963 .3858 .12962 .37757 Metetra
.773 .632 .704 r
.12962 .37757 .12963 .3858 .14666 .38558 .1467 .37735 Metetra
.795 .646 .697 r
.1467 .37735 .14666 .38558 .16385 .38528 .16394 .37705 Metetra
.815 .657 .687 r
.16394 .37705 .16385 .38528 .18116 .38489 .18131 .37666 Metetra
.834 .666 .675 r
.18131 .37666 .18116 .38489 .19856 .38443 .19878 .37619 Metetra
.851 .673 .661 r
.19878 .37619 .19856 .38443 .21602 .38388 .21631 .37563 Metetra
.867 .678 .644 r
.21631 .37563 .21602 .38388 .23352 .38324 .23388 .375 Metetra
.882 .68 .626 r
.23388 .375 .23352 .38324 .25102 .38252 .25145 .37427 Metetra
.895 .68 .605 r
.25145 .37427 .25102 .38252 .26849 .38172 .269 .37346 Metetra
.906 .678 .583 r
.269 .37346 .26849 .38172 .28591 .38083 .28649 .37257 Metetra
.916 .674 .559 r
.28649 .37257 .28591 .38083 .30324 .37986 .30388 .3716 Metetra
.923 .668 .533 r
.30388 .3716 .30324 .37986 .32044 .37881 .32114 .37054 Metetra
.929 .658 .506 r
.32114 .37054 .32044 .37881 .33749 .37769 .33822 .36941 Metetra
.932 .646 .477 r
.33822 .36941 .33749 .37769 .35433 .3765 .3551 .36821 Metetra
.932 .631 .447 r
.3551 .36821 .35433 .3765 .37094 .37526 .37173 .36695 Metetra
.929 .611 .417 r
.37173 .36695 .37094 .37526 .38729 .37398 .38808 .36566 Metetra
.923 .587 .386 r
.38808 .36566 .38729 .37398 .40333 .3727 .4041 .36435 Metetra
.912 .558 .354 r
.4041 .36435 .40333 .3727 .41904 .37144 .41977 .36305 Metetra
.894 .521 .323 r
.41977 .36305 .41904 .37144 .43441 .37024 .43508 .36181 Metetra
.867 .474 .292 r
.43508 .36181 .43441 .37024 .44945 .36916 .45001 .36069 Metetra
.827 .415 .262 r
.45001 .36069 .44945 .36916 .46416 .36826 .4646 .35974 Metetra
.769 .341 .236 r
.4646 .35974 .46416 .36826 .47862 .36761 .47889 .35904 Metetra
.689 .255 .214 r
.47889 .35904 .47862 .36761 .49289 .36727 .49299 .35867 Metetra
.591 .165 .202 r
.49299 .35867 .49289 .36727 .50711 .36727 .50701 .35867 Metetra
.839 .686 .693 r
.96733 .37708 .96731 .38527 .98217 .38484 .98215 .37667 Metetra
.808 .663 .703 r
.95204 .37739 .952 .3856 .96731 .38527 .96733 .37708 Metetra
.777 .639 .709 r
.93635 .37761 .93629 .38583 .952 .3856 .95204 .37739 Metetra
.747 .615 .712 r
.92029 .37773 .92022 .38595 .93629 .38583 .93635 .37761 Metetra
.718 .591 .713 r
.90391 .37777 .90385 .38599 .92022 .38595 .92029 .37773 Metetra
.689 .566 .711 r
.88726 .37771 .88722 .38594 .90385 .38599 .90391 .37777 Metetra
.662 .541 .706 r
.87038 .37757 .87037 .3858 .88722 .38594 .88726 .37771 Metetra
.634 .514 .7 r
.8533 .37735 .85334 .38558 .87037 .3858 .87038 .37757 Metetra
.607 .487 .69 r
.83606 .37705 .83615 .38528 .85334 .38558 .8533 .37735 Metetra
.579 .458 .679 r
.81869 .37666 .81884 .38489 .83615 .38528 .83606 .37705 Metetra
.552 .428 .665 r
.80122 .37619 .80144 .38443 .81884 .38489 .81869 .37666 Metetra
.524 .397 .649 r
.78369 .37563 .78398 .38388 .80144 .38443 .80122 .37619 Metetra
.496 .365 .631 r
.76612 .375 .76648 .38324 .78398 .38388 .78369 .37563 Metetra
.468 .331 .611 r
.74855 .37427 .74898 .38252 .76648 .38324 .76612 .375 Metetra
.439 .296 .589 r
.731 .37346 .73151 .38172 .74898 .38252 .74855 .37427 Metetra
.411 .26 .565 r
.71351 .37257 .71409 .38083 .73151 .38172 .731 .37346 Metetra
.382 .224 .539 r
.69612 .3716 .69676 .37986 .71409 .38083 .71351 .37257 Metetra
.355 .188 .511 r
.67886 .37054 .67956 .37881 .69676 .37986 .69612 .3716 Metetra
.329 .151 .482 r
.66178 .36941 .66251 .37769 .67956 .37881 .67886 .37054 Metetra
.305 .116 .452 r
.6449 .36821 .64567 .3765 .66251 .37769 .66178 .36941 Metetra
.284 .082 .42 r
.62827 .36695 .62906 .37526 .64567 .3765 .6449 .36821 Metetra
.268 .051 .388 r
.61192 .36566 .61271 .37398 .62906 .37526 .62827 .36695 Metetra
.258 .023 .355 r
.5959 .36435 .59667 .3727 .61271 .37398 .61192 .36566 Metetra
.256 .001 .322 r
.58023 .36305 .58096 .37144 .59667 .3727 .5959 .36435 Metetra
.265 0 .289 r
.56492 .36181 .56559 .37024 .58096 .37144 .58023 .36305 Metetra
.29 0 .258 r
.54999 .36069 .55055 .36916 .56559 .37024 .56492 .36181 Metetra
.333 0 .231 r
.5354 .35974 .53584 .36826 .55055 .36916 .54999 .36069 Metetra
.4 .027 .211 r
.52111 .35904 .52138 .36761 .53584 .36826 .5354 .35974 Metetra
.489 .085 .201 r
.50701 .35867 .50711 .36727 .52138 .36761 .52111 .35904 Metetra
.542 .441 .69 r
.01786 .36849 .01785 .37667 .03267 .37708 .03266 .36889 Metetra
.587 .48 .699 r
.03266 .36889 .03267 .37708 .04796 .37739 .04793 .36918 Metetra
.628 .515 .706 r
.04793 .36918 .04796 .37739 .06365 .37761 .06361 .36939 Metetra
.664 .546 .71 r
.06361 .36939 .06365 .37761 .07971 .37773 .07967 .36951 Metetra
.697 .573 .712 r
.07967 .36951 .07971 .37773 .09609 .37777 .09605 .36954 Metetra
.726 .596 .711 r
.09605 .36954 .09609 .37777 .11274 .37771 .11272 .36948 Metetra
.753 .616 .707 r
.11272 .36948 .11274 .37771 .12962 .37757 .12963 .36934 Metetra
.777 .634 .702 r
.12963 .36934 .12962 .37757 .1467 .37735 .14675 .36912 Metetra
.8 .648 .694 r
.14675 .36912 .1467 .37735 .16394 .37705 .16404 .36881 Metetra
.821 .661 .684 r
.16404 .36881 .16394 .37705 .18131 .37666 .18147 .36843 Metetra
.84 .67 .672 r
.18147 .36843 .18131 .37666 .19878 .37619 .199 .36796 Metetra
.858 .678 .658 r
.199 .36796 .19878 .37619 .21631 .37563 .2166 .36741 Metetra
.874 .684 .641 r
.2166 .36741 .21631 .37563 .23388 .375 .23424 .36677 Metetra
.889 .687 .623 r
.23424 .36677 .23388 .375 .25145 .37427 .25189 .36605 Metetra
.903 .688 .602 r
.25189 .36605 .25145 .37427 .269 .37346 .2695 .36525 Metetra
.914 .687 .58 r
.2695 .36525 .269 .37346 .28649 .37257 .28706 .36436 Metetra
.924 .683 .555 r
.28706 .36436 .28649 .37257 .30388 .3716 .30451 .36339 Metetra
.932 .678 .529 r
.30451 .36339 .30388 .3716 .32114 .37054 .32182 .36233 Metetra
.938 .669 .502 r
.32182 .36233 .32114 .37054 .33822 .36941 .33895 .3612 Metetra
.941 .658 .473 r
.33895 .3612 .33822 .36941 .3551 .36821 .35586 .36 Metetra
.942 .643 .443 r
.35586 .36 .3551 .36821 .37173 .36695 .3725 .35875 Metetra
.94 .624 .412 r
.3725 .35875 .37173 .36695 .38808 .36566 .38885 .35744 Metetra
.934 .601 .38 r
.38885 .35744 .38808 .36566 .4041 .36435 .40486 .35612 Metetra
.924 .572 .347 r
.40486 .35612 .4041 .36435 .41977 .36305 .4205 .3548 Metetra
.907 .535 .314 r
.4205 .3548 .41977 .36305 .43508 .36181 .43574 .35353 Metetra
.882 .488 .28 r
.43574 .35353 .43508 .36181 .45001 .36069 .45059 .35236 Metetra
.842 .427 .248 r
.45059 .35236 .45001 .36069 .4646 .35974 .46505 .35136 Metetra
.782 .347 .218 r
.46505 .35136 .4646 .35974 .47889 .35904 .47918 .35062 Metetra
.611 .178 .194 r
.47918 .35062 .47889 .35904 .49299 .35867 .49307 .35054 Metetra
.616 .22 .27 r
.49307 .35054 .49299 .35867 .50701 .35867 .50693 .35054 Metetra
.841 .687 .692 r
.96734 .36889 .96733 .37708 .98215 .37667 .98214 .36849 Metetra
.809 .664 .701 r
.95207 .36918 .95204 .37739 .96733 .37708 .96734 .36889 Metetra
.778 .639 .708 r
.93639 .36939 .93635 .37761 .95204 .37739 .95207 .36918 Metetra
.748 .614 .711 r
.92033 .36951 .92029 .37773 .93635 .37761 .93639 .36939 Metetra
.717 .589 .711 r
.90395 .36954 .90391 .37777 .92029 .37773 .92033 .36951 Metetra
.688 .563 .709 r
.88728 .36948 .88726 .37771 .90391 .37777 .90395 .36954 Metetra
.658 .536 .704 r
.87037 .36934 .87038 .37757 .88726 .37771 .88728 .36948 Metetra
.629 .509 .697 r
.85325 .36912 .8533 .37735 .87038 .37757 .87037 .36934 Metetra
.6 .48 .688 r
.83596 .36881 .83606 .37705 .8533 .37735 .85325 .36912 Metetra
.571 .45 .676 r
.81853 .36843 .81869 .37666 .83606 .37705 .83596 .36881 Metetra
.542 .42 .663 r
.801 .36796 .80122 .37619 .81869 .37666 .81853 .36843 Metetra
.513 .387 .647 r
.7834 .36741 .78369 .37563 .80122 .37619 .801 .36796 Metetra
.483 .354 .629 r
.76576 .36677 .76612 .375 .78369 .37563 .7834 .36741 Metetra
.453 .319 .608 r
.74811 .36605 .74855 .37427 .76612 .375 .76576 .36677 Metetra
.422 .284 .586 r
.7305 .36525 .731 .37346 .74855 .37427 .74811 .36605 Metetra
.392 .247 .562 r
.71294 .36436 .71351 .37257 .731 .37346 .7305 .36525 Metetra
.362 .21 .536 r
.69549 .36339 .69612 .3716 .71351 .37257 .71294 .36436 Metetra
.333 .173 .509 r
.67818 .36233 .67886 .37054 .69612 .3716 .69549 .36339 Metetra
.305 .135 .479 r
.66105 .3612 .66178 .36941 .67886 .37054 .67818 .36233 Metetra
.279 .099 .448 r
.64414 .36 .6449 .36821 .66178 .36941 .66105 .3612 Metetra
.256 .063 .416 r
.6275 .35875 .62827 .36695 .6449 .36821 .64414 .36 Metetra
.237 .03 .383 r
.61115 .35744 .61192 .36566 .62827 .36695 .6275 .35875 Metetra
.224 0 .348 r
.59514 .35612 .5959 .36435 .61192 .36566 .61115 .35744 Metetra
.219 0 .313 r
.5795 .3548 .58023 .36305 .5959 .36435 .59514 .35612 Metetra
.226 0 .278 r
.56426 .35353 .56492 .36181 .58023 .36305 .5795 .3548 Metetra
.248 0 .244 r
.54941 .35236 .54999 .36069 .56492 .36181 .56426 .35353 Metetra
.292 0 .213 r
.53495 .35136 .5354 .35974 .54999 .36069 .54941 .35236 Metetra
.363 0 .19 r
.52082 .35062 .52111 .35904 .5354 .35974 .53495 .35136 Metetra
.59 .199 .27 r
.50693 .35054 .50701 .35867 .52111 .35904 .52082 .35062 Metetra
.539 .44 .69 r
.01787 .36032 .01786 .36849 .03266 .36889 .03265 .36069 Metetra
.585 .479 .699 r
.03265 .36069 .03266 .36889 .04793 .36918 .0479 .36097 Metetra
.627 .514 .705 r
.0479 .36097 .04793 .36918 .06361 .36939 .06358 .36116 Metetra
.664 .545 .709 r
.06358 .36116 .06361 .36939 .07967 .36951 .07963 .36127 Metetra
.698 .572 .71 r
.07963 .36127 .07967 .36951 .09605 .36954 .09603 .3613 Metetra
.728 .596 .709 r
.09603 .3613 .09605 .36954 .11272 .36948 .11272 .36124 Metetra
.756 .617 .706 r
.11272 .36124 .11272 .36948 .12963 .36934 .12966 .3611 Metetra
.781 .636 .7 r
.12966 .3611 .12963 .36934 .14675 .36912 .14682 .36088 Metetra
.805 .651 .692 r
.14682 .36088 .14675 .36912 .16404 .36881 .16416 .36058 Metetra
.826 .664 .682 r
.16416 .36058 .16404 .36881 .18147 .36843 .18164 .3602 Metetra
.846 .675 .669 r
.18164 .3602 .18147 .36843 .199 .36796 .19923 .35974 Metetra
.865 .683 .655 r
.19923 .35974 .199 .36796 .2166 .36741 .2169 .3592 Metetra
.881 .689 .638 r
.2169 .3592 .2166 .36741 .23424 .36677 .2346 .35857 Metetra
.897 .694 .62 r
.2346 .35857 .23424 .36677 .25189 .36605 .25231 .35786 Metetra
.91 .695 .599 r
.25231 .35786 .25189 .36605 .2695 .36525 .26999 .35707 Metetra
.922 .695 .577 r
.26999 .35707 .2695 .36525 .28706 .36436 .28761 .3562 Metetra
.932 .693 .553 r
.28761 .3562 .28706 .36436 .30451 .36339 .30511 .35524 Metetra
.94 .687 .527 r
.30511 .35524 .30451 .36339 .32182 .36233 .32248 .3542 Metetra
.946 .68 .499 r
.32248 .3542 .32182 .36233 .33895 .3612 .33965 .35308 Metetra
.95 .669 .47 r
.33965 .35308 .33895 .3612 .35586 .36 .35659 .3519 Metetra
.951 .655 .44 r
.35659 .3519 .35586 .36 .3725 .35875 .37326 .35065 Metetra
.95 .638 .408 r
.37326 .35065 .3725 .35875 .38885 .35744 .38961 .34935 Metetra
.944 .615 .375 r
.38961 .34935 .38885 .35744 .40486 .35612 .40561 .34802 Metetra
.935 .587 .34 r
.40561 .34802 .40486 .35612 .4205 .3548 .42122 .34669 Metetra
.92 .551 .305 r
.42122 .34669 .4205 .3548 .43574 .35353 .4364 .34539 Metetra
.896 .504 .27 r
.4364 .34539 .43574 .35353 .45059 .35236 .45116 .34418 Metetra
.772 .349 .245 r
.45116 .34418 .45059 .35236 .46505 .35136 .46533 .34361 Metetra
.649 .301 .369 r
.46533 .34361 .46505 .35136 .47918 .35062 .4792 .34361 Metetra
.706 .549 .673 r
.4792 .34361 .47918 .35062 .49307 .35054 .49307 .34361 Metetra
.842 .688 .692 r
.96735 .36069 .96734 .36889 .98214 .36849 .98213 .36032 Metetra
.811 .664 .7 r
.9521 .36097 .95207 .36918 .96734 .36889 .96735 .36069 Metetra
.779 .639 .706 r
.93642 .36116 .93639 .36939 .95207 .36918 .9521 .36097 Metetra
.748 .613 .709 r
.92037 .36127 .92033 .36951 .93639 .36939 .93642 .36116 Metetra
.716 .587 .709 r
.90397 .3613 .90395 .36954 .92033 .36951 .92037 .36127 Metetra
.686 .56 .707 r
.88728 .36124 .88728 .36948 .90395 .36954 .90397 .3613 Metetra
.655 .532 .702 r
.87034 .3611 .87037 .36934 .88728 .36948 .88728 .36124 Metetra
.624 .504 .695 r
.85318 .36088 .85325 .36912 .87037 .36934 .87034 .3611 Metetra
.594 .474 .686 r
.83584 .36058 .83596 .36881 .85325 .36912 .85318 .36088 Metetra
.563 .443 .674 r
.81836 .3602 .81853 .36843 .83596 .36881 .83584 .36058 Metetra
.533 .412 .661 r
.80077 .35974 .801 .36796 .81853 .36843 .81836 .3602 Metetra
.501 .379 .645 r
.7831 .3592 .7834 .36741 .801 .36796 .80077 .35974 Metetra
.47 .344 .627 r
.7654 .35857 .76576 .36677 .7834 .36741 .7831 .3592 Metetra
.438 .309 .607 r
.74769 .35786 .74811 .36605 .76576 .36677 .7654 .35857 Metetra
.406 .272 .584 r
.73001 .35707 .7305 .36525 .74811 .36605 .74769 .35786 Metetra
.374 .235 .56 r
.71239 .3562 .71294 .36436 .7305 .36525 .73001 .35707 Metetra
.343 .197 .534 r
.69489 .35524 .69549 .36339 .71294 .36436 .71239 .3562 Metetra
.311 .159 .507 r
.67752 .3542 .67818 .36233 .69549 .36339 .69489 .35524 Metetra
.281 .12 .477 r
.66035 .35308 .66105 .3612 .67818 .36233 .67752 .3542 Metetra
.253 .082 .446 r
.64341 .3519 .64414 .36 .66105 .3612 .66035 .35308 Metetra
.228 .045 .413 r
.62674 .35065 .6275 .35875 .64414 .36 .64341 .3519 Metetra
.206 .01 .378 r
.61039 .34935 .61115 .35744 .6275 .35875 .62674 .35065 Metetra
.19 0 .342 r
.59439 .34802 .59514 .35612 .61115 .35744 .61039 .34935 Metetra
.182 0 .305 r
.57878 .34669 .5795 .3548 .59514 .35612 .59439 .34802 Metetra
.185 0 .267 r
.5636 .34539 .56426 .35353 .5795 .3548 .57878 .34669 Metetra
.204 0 .23 r
.54884 .34418 .54941 .35236 .56426 .35353 .5636 .34539 Metetra
.423 .128 .358 r
.53467 .34361 .53495 .35136 .54941 .35236 .54884 .34418 Metetra
.706 .549 .673 r
.5208 .34361 .52082 .35062 .53495 .35136 .53467 .34361 Metetra
.707 .577 .707 r
.50693 .34361 .50693 .35054 .52082 .35062 .5208 .34361 Metetra
.538 .439 .69 r
.01788 .35214 .01787 .36032 .03265 .36069 .03264 .35249 Metetra
.584 .477 .699 r
.03264 .35249 .03265 .36069 .0479 .36097 .04788 .35275 Metetra
.626 .513 .705 r
.04788 .35275 .0479 .36097 .06358 .36116 .06355 .35294 Metetra
.664 .544 .708 r
.06355 .35294 .06358 .36116 .07963 .36127 .07961 .35304 Metetra
.699 .572 .709 r
.07961 .35304 .07963 .36127 .09603 .3613 .09602 .35306 Metetra
.73 .597 .708 r
.09602 .35306 .09603 .3613 .11272 .36124 .11273 .353 Metetra
.759 .619 .704 r
.11273 .353 .11272 .36124 .12966 .3611 .1297 .35286 Metetra
.785 .637 .698 r
.1297 .35286 .12966 .3611 .14682 .36088 .1469 .35265 Metetra
.809 .654 .69 r
.1469 .35265 .14682 .36088 .16416 .36058 .16428 .35235 Metetra
.831 .668 .68 r
.16428 .35235 .16416 .36058 .18164 .3602 .18181 .35198 Metetra
.852 .679 .667 r
.18181 .35198 .18164 .3602 .19923 .35974 .19946 .35153 Metetra
.871 .688 .653 r
.19946 .35153 .19923 .35974 .2169 .3592 .21718 .35101 Metetra
.888 .695 .636 r
.21718 .35101 .2169 .3592 .2346 .35857 .23495 .3504 Metetra
.903 .7 .618 r
.23495 .3504 .2346 .35857 .25231 .35786 .25273 .34971 Metetra
.917 .703 .597 r
.25273 .34971 .25231 .35786 .26999 .35707 .27047 .34894 Metetra
.929 .703 .575 r
.27047 .34894 .26999 .35707 .28761 .3562 .28814 .34808 Metetra
.94 .701 .551 r
.28814 .34808 .28761 .3562 .30511 .35524 .3057 .34715 Metetra
.948 .697 .525 r
.3057 .34715 .30511 .35524 .32248 .3542 .32311 .34614 Metetra
.954 .69 .497 r
.32311 .34614 .32248 .3542 .33965 .35308 .34032 .34505 Metetra
.958 .681 .468 r
.34032 .34505 .33965 .35308 .35659 .3519 .3573 .34388 Metetra
.959 .667 .437 r
.3573 .34388 .35659 .3519 .37326 .35065 .37399 .34266 Metetra
.958 .651 .404 r
.37399 .34266 .37326 .35065 .38961 .34935 .39035 .34137 Metetra
.954 .629 .37 r
.39035 .34137 .38961 .34935 .40561 .34802 .40634 .34006 Metetra
.945 .602 .335 r
.40634 .34006 .40561 .34802 .42122 .34669 .42192 .33872 Metetra
.932 .567 .298 r
.42192 .33872 .42122 .34669 .4364 .34539 .43706 .33741 Metetra
.837 .433 .278 r
.43706 .33741 .4364 .34539 .45116 .34418 .45146 .33667 Metetra
.67 .363 .444 r
.45146 .33667 .45116 .34418 .46533 .34361 .46533 .33667 Metetra
.843 .689 .691 r
.96736 .35249 .96735 .36069 .98213 .36032 .98212 .35214 Metetra
.812 .664 .7 r
.95212 .35275 .9521 .36097 .96735 .36069 .96736 .35249 Metetra
.78 .639 .705 r
.93645 .35294 .93642 .36116 .9521 .36097 .95212 .35275 Metetra
.748 .612 .708 r
.92039 .35304 .92037 .36127 .93642 .36116 .93645 .35294 Metetra
.715 .585 .708 r
.90398 .35306 .90397 .3613 .92037 .36127 .92039 .35304 Metetra
.683 .557 .706 r
.88727 .353 .88728 .36124 .90397 .3613 .90398 .35306 Metetra
.652 .529 .701 r
.8703 .35286 .87034 .3611 .88728 .36124 .88727 .353 Metetra
.62 .499 .694 r
.8531 .35265 .85318 .36088 .87034 .3611 .8703 .35286 Metetra
.588 .469 .684 r
.83572 .35235 .83584 .36058 .85318 .36088 .8531 .35265 Metetra
.556 .437 .673 r
.81819 .35198 .81836 .3602 .83584 .36058 .83572 .35235 Metetra
.524 .404 .659 r
.80054 .35153 .80077 .35974 .81836 .3602 .81819 .35198 Metetra
.491 .371 .643 r
.78282 .35101 .7831 .3592 .80077 .35974 .80054 .35153 Metetra
.458 .336 .625 r
.76505 .3504 .7654 .35857 .7831 .3592 .78282 .35101 Metetra
.425 .299 .605 r
.74727 .34971 .74769 .35786 .7654 .35857 .76505 .3504 Metetra
.391 .262 .583 r
.72953 .34894 .73001 .35707 .74769 .35786 .74727 .34971 Metetra
.358 .224 .559 r
.71186 .34808 .71239 .3562 .73001 .35707 .72953 .34894 Metetra
.324 .186 .533 r
.6943 .34715 .69489 .35524 .71239 .3562 .71186 .34808 Metetra
.291 .146 .505 r
.67689 .34614 .67752 .3542 .69489 .35524 .6943 .34715 Metetra
.259 .107 .476 r
.65968 .34505 .66035 .35308 .67752 .3542 .67689 .34614 Metetra
.229 .067 .444 r
.6427 .34388 .64341 .3519 .66035 .35308 .65968 .34505 Metetra
.2 .029 .411 r
.62601 .34266 .62674 .35065 .64341 .3519 .6427 .34388 Metetra
.176 0 .375 r
.60965 .34137 .61039 .34935 .62674 .35065 .62601 .34266 Metetra
.156 0 .338 r
.59366 .34006 .59439 .34802 .61039 .34935 .60965 .34137 Metetra
.144 0 .298 r
.57808 .33872 .57878 .34669 .59439 .34802 .59366 .34006 Metetra
.143 0 .258 r
.56294 .33741 .5636 .34539 .57878 .34669 .57808 .33872 Metetra
.339 .112 .415 r
.54854 .33667 .54884 .34418 .5636 .34539 .56294 .33741 Metetra
.707 .577 .707 r
.53467 .33667 .53467 .34361 .54884 .34418 .54854 .33667 Metetra
.537 .438 .69 r
.01788 .34397 .01788 .35214 .03264 .35249 .03264 .34429 Metetra
.583 .477 .698 r
.03264 .34429 .03264 .35249 .04788 .35275 .04787 .34454 Metetra
.626 .512 .704 r
.04787 .34454 .04788 .35275 .06355 .35294 .06354 .3447 Metetra
.665 .544 .707 r
.06354 .3447 .06355 .35294 .07961 .35304 .0796 .3448 Metetra
.7 .572 .708 r
.0796 .3448 .07961 .35304 .09602 .35306 .09602 .34481 Metetra
.732 .598 .707 r
.09602 .34481 .09602 .35306 .11273 .353 .11275 .34475 Metetra
.761 .62 .703 r
.11275 .34475 .11273 .353 .1297 .35286 .12975 .34462 Metetra
.788 .64 .697 r
.12975 .34462 .1297 .35286 .1469 .35265 .14698 .34441 Metetra
.813 .657 .688 r
.14698 .34441 .1469 .35265 .16428 .35235 .1644 .34413 Metetra
.836 .671 .678 r
.1644 .34413 .16428 .35235 .18181 .35198 .18198 .34377 Metetra
.857 .683 .666 r
.18198 .34377 .18181 .35198 .19946 .35153 .19968 .34334 Metetra
.876 .693 .651 r
.19968 .34334 .19946 .35153 .21718 .35101 .21747 .34283 Metetra
.894 .701 .635 r
.21747 .34283 .21718 .35101 .23495 .3504 .23529 .34225 Metetra
.909 .707 .616 r
.23529 .34225 .23495 .3504 .25273 .34971 .25312 .34158 Metetra
.923 .71 .596 r
.25312 .34158 .25273 .34971 .27047 .34894 .27092 .34084 Metetra
.936 .711 .574 r
.27092 .34084 .27047 .34894 .28814 .34808 .28865 .34002 Metetra
.946 .71 .549 r
.28865 .34002 .28814 .34808 .3057 .34715 .30626 .33912 Metetra
.954 .707 .523 r
.30626 .33912 .3057 .34715 .32311 .34614 .32372 .33814 Metetra
.961 .701 .496 r
.32372 .33814 .32311 .34614 .34032 .34505 .34097 .33709 Metetra
.965 .692 .466 r
.34097 .33709 .34032 .34505 .3573 .34388 .35798 .33596 Metetra
.967 .68 .435 r
.35798 .33596 .3573 .34388 .37399 .34266 .37469 .33477 Metetra
.966 .664 .402 r
.37469 .33477 .37399 .34266 .39035 .34137 .39106 .33352 Metetra
.962 .643 .367 r
.39106 .33352 .39035 .34137 .40634 .34006 .40705 .33222 Metetra
.954 .617 .33 r
.40705 .33222 .40634 .34006 .42192 .33872 .42262 .3309 Metetra
.93 .564 .3 r
.42262 .3309 .42192 .33872 .43706 .33741 .4376 .32974 Metetra
.644 .287 .351 r
.4376 .32974 .43706 .33741 .45146 .33667 .45146 .32974 Metetra
.844 .689 .691 r
.96736 .34429 .96736 .35249 .98212 .35214 .98212 .34397 Metetra
.812 .664 .699 r
.95213 .34454 .95212 .35275 .96736 .35249 .96736 .34429 Metetra
.78 .638 .704 r
.93646 .3447 .93645 .35294 .95212 .35275 .95213 .34454 Metetra
.747 .611 .707 r
.9204 .3448 .92039 .35304 .93645 .35294 .93646 .3447 Metetra
.714 .583 .707 r
.90398 .34481 .90398 .35306 .92039 .35304 .9204 .3448 Metetra
.681 .555 .705 r
.88725 .34475 .88727 .353 .90398 .35306 .90398 .34481 Metetra
.648 .525 .7 r
.87025 .34462 .8703 .35286 .88727 .353 .88725 .34475 Metetra
.615 .495 .692 r
.85302 .34441 .8531 .35265 .8703 .35286 .87025 .34462 Metetra
.582 .464 .683 r
.8356 .34413 .83572 .35235 .8531 .35265 .85302 .34441 Metetra
.549 .431 .672 r
.81802 .34377 .81819 .35198 .83572 .35235 .8356 .34413 Metetra
.515 .398 .658 r
.80032 .34334 .80054 .35153 .81819 .35198 .81802 .34377 Metetra
.481 .363 .642 r
.78253 .34283 .78282 .35101 .80054 .35153 .80032 .34334 Metetra
.447 .328 .624 r
.76471 .34225 .76505 .3504 .78282 .35101 .78253 .34283 Metetra
.412 .291 .604 r
.74688 .34158 .74727 .34971 .76505 .3504 .76471 .34225 Metetra
.377 .253 .583 r
.72908 .34084 .72953 .34894 .74727 .34971 .74688 .34158 Metetra
.342 .215 .559 r
.71135 .34002 .71186 .34808 .72953 .34894 .72908 .34084 Metetra
.307 .175 .533 r
.69374 .33912 .6943 .34715 .71186 .34808 .71135 .34002 Metetra
.272 .135 .505 r
.67628 .33814 .67689 .34614 .6943 .34715 .69374 .33912 Metetra
.238 .095 .475 r
.65903 .33709 .65968 .34505 .67689 .34614 .67628 .33814 Metetra
.205 .054 .443 r
.64202 .33596 .6427 .34388 .65968 .34505 .65903 .33709 Metetra
.174 .014 .409 r
.62531 .33477 .62601 .34266 .6427 .34388 .64202 .33596 Metetra
.146 0 .373 r
.60894 .33352 .60965 .34137 .62601 .34266 .62531 .33477 Metetra
.123 0 .334 r
.59295 .33222 .59366 .34006 .60965 .34137 .60894 .33352 Metetra
.107 0 .293 r
.57738 .3309 .57808 .33872 .59366 .34006 .59295 .33222 Metetra
.146 0 .308 r
.5624 .32974 .56294 .33741 .57808 .33872 .57738 .3309 Metetra
.707 .577 .707 r
.54854 .32974 .54854 .33667 .56294 .33741 .5624 .32974 Metetra
.536 .437 .69 r
.01788 .3358 .01788 .34397 .03264 .34429 .03263 .33609 Metetra
.583 .476 .698 r
.03263 .33609 .03264 .34429 .04787 .34454 .04786 .33632 Metetra
.626 .512 .704 r
.04786 .33632 .04787 .34454 .06354 .3447 .06353 .33647 Metetra
.665 .544 .707 r
.06353 .33647 .06354 .3447 .0796 .3448 .0796 .33655 Metetra
.701 .573 .707 r
.0796 .33655 .0796 .3448 .09602 .34481 .09603 .33657 Metetra
.734 .599 .706 r
.09603 .33657 .09602 .34481 .11275 .34475 .11277 .33651 Metetra
.764 .621 .702 r
.11277 .33651 .11275 .34475 .12975 .34462 .1298 .33638 Metetra
.792 .642 .696 r
.1298 .33638 .12975 .34462 .14698 .34441 .14707 .33618 Metetra
.817 .659 .687 r
.14707 .33618 .14698 .34441 .1644 .34413 .16453 .33591 Metetra
.84 .674 .677 r
.16453 .33591 .1644 .34413 .18198 .34377 .18216 .33557 Metetra
.862 .687 .665 r
.18216 .33557 .18198 .34377 .19968 .34334 .1999 .33516 Metetra
.881 .698 .65 r
.1999 .33516 .19968 .34334 .21747 .34283 .21774 .33468 Metetra
.899 .706 .634 r
.21774 .33468 .21747 .34283 .23529 .34225 .23562 .33412 Metetra
.915 .713 .615 r
.23562 .33412 .23529 .34225 .25312 .34158 .2535 .33349 Metetra
.929 .717 .595 r
.2535 .33349 .25312 .34158 .27092 .34084 .27136 .33279 Metetra
.941 .719 .573 r
.27136 .33279 .27092 .34084 .28865 .34002 .28913 .332 Metetra
.952 .719 .549 r
.28913 .332 .28865 .34002 .30626 .33912 .30679 .33115 Metetra
.96 .716 .523 r
.30679 .33115 .30626 .33912 .32372 .33814 .32429 .33021 Metetra
.967 .711 .495 r
.32429 .33021 .32372 .33814 .34097 .33709 .34158 .32921 Metetra
.971 .703 .465 r
.34158 .32921 .34097 .33709 .35798 .33596 .35862 .32813 Metetra
.973 .692 .434 r
.35862 .32813 .35798 .33596 .37469 .33477 .37536 .32698 Metetra
.972 .677 .4 r
.37536 .32698 .37469 .33477 .39106 .33352 .39175 .32578 Metetra
.969 .657 .364 r
.39175 .32578 .39106 .33352 .40705 .33222 .40774 .32452 Metetra
.962 .633 .326 r
.40774 .32452 .40705 .33222 .42262 .3309 .42329 .32322 Metetra
.808 .428 .337 r
.42329 .32322 .42262 .3309 .4376 .32974 .4376 .3228 Metetra
.844 .69 .69 r
.96737 .33609 .96736 .34429 .98212 .34397 .98212 .3358 Metetra
.813 .664 .698 r
.95214 .33632 .95213 .34454 .96736 .34429 .96737 .33609 Metetra
.78 .638 .704 r
.93647 .33647 .93646 .3447 .95213 .34454 .95214 .33632 Metetra
.747 .61 .706 r
.9204 .33655 .9204 .3448 .93646 .3447 .93647 .33647 Metetra
.713 .582 .706 r
.90397 .33657 .90398 .34481 .9204 .3448 .9204 .33655 Metetra
.679 .552 .704 r
.88723 .33651 .88725 .34475 .90398 .34481 .90397 .33657 Metetra
.645 .522 .699 r
.8702 .33638 .87025 .34462 .88725 .34475 .88723 .33651 Metetra
.611 .491 .692 r
.85293 .33618 .85302 .34441 .87025 .34462 .8702 .33638 Metetra
.577 .459 .682 r
.83547 .33591 .8356 .34413 .85302 .34441 .85293 .33618 Metetra
.542 .426 .671 r
.81784 .33557 .81802 .34377 .8356 .34413 .83547 .33591 Metetra
.507 .392 .657 r
.8001 .33516 .80032 .34334 .81802 .34377 .81784 .33557 Metetra
.472 .357 .642 r
.78226 .33468 .78253 .34283 .80032 .34334 .8001 .33516 Metetra
.436 .321 .624 r
.76438 .33412 .76471 .34225 .78253 .34283 .78226 .33468 Metetra
.4 .284 .604 r
.7465 .33349 .74688 .34158 .76471 .34225 .76438 .33412 Metetra
.364 .246 .583 r
.72864 .33279 .72908 .34084 .74688 .34158 .7465 .33349 Metetra
.327 .206 .559 r
.71087 .332 .71135 .34002 .72908 .34084 .72864 .33279 Metetra
.29 .166 .533 r
.69321 .33115 .69374 .33912 .71135 .34002 .71087 .332 Metetra
.254 .126 .505 r
.67571 .33021 .67628 .33814 .69374 .33912 .69321 .33115 Metetra
.217 .084 .476 r
.65842 .32921 .65903 .33709 .67628 .33814 .67571 .33021 Metetra
.182 .042 .443 r
.64138 .32813 .64202 .33596 .65903 .33709 .65842 .32921 Metetra
.149 0 .409 r
.62464 .32698 .62531 .33477 .64202 .33596 .64138 .32813 Metetra
.118 0 .372 r
.60825 .32578 .60894 .33352 .62531 .33477 .62464 .32698 Metetra
.091 0 .332 r
.59226 .32452 .59295 .33222 .60894 .33352 .60825 .32578 Metetra
.069 0 .289 r
.57671 .32322 .57738 .3309 .59295 .33222 .59226 .32452 Metetra
.451 .368 .672 r
.5624 .3228 .5624 .32974 .57738 .3309 .57671 .32322 Metetra
.535 .437 .69 r
.01788 .32763 .01788 .3358 .03263 .33609 .03263 .32789 Metetra
.582 .476 .698 r
.03263 .32789 .03263 .33609 .04786 .33632 .04786 .3281 Metetra
.626 .511 .703 r
.04786 .3281 .04786 .33632 .06353 .33647 .06353 .32824 Metetra
.666 .544 .706 r
.06353 .32824 .06353 .33647 .0796 .33655 .0796 .32831 Metetra
.702 .573 .707 r
.0796 .32831 .0796 .33655 .09603 .33657 .09604 .32832 Metetra
.736 .6 .705 r
.09604 .32832 .09603 .33657 .11277 .33651 .11281 .32826 Metetra
.766 .623 .701 r
.11281 .32826 .11277 .33651 .1298 .33638 .12986 .32814 Metetra
.795 .644 .695 r
.12986 .32814 .1298 .33638 .14707 .33618 .14715 .32795 Metetra
.82 .662 .686 r
.14715 .32795 .14707 .33618 .16453 .33591 .16465 .3277 Metetra
.844 .678 .676 r
.16465 .3277 .16453 .33591 .18216 .33557 .18232 .32738 Metetra
.866 .691 .664 r
.18232 .32738 .18216 .33557 .1999 .33516 .20011 .327 Metetra
.886 .703 .649 r
.20011 .327 .1999 .33516 .21774 .33468 .21799 .32654 Metetra
.904 .712 .633 r
.21799 .32654 .21774 .33468 .23562 .33412 .23592 .32602 Metetra
.92 .719 .615 r
.23592 .32602 .23562 .33412 .2535 .33349 .25386 .32543 Metetra
.934 .724 .595 r
.25386 .32543 .2535 .33349 .27136 .33279 .27176 .32477 Metetra
.947 .727 .573 r
.27176 .32477 .27136 .33279 .28913 .332 .28959 .32403 Metetra
.957 .727 .549 r
.28959 .32403 .28913 .332 .30679 .33115 .30729 .32323 Metetra
.966 .725 .523 r
.30729 .32323 .30679 .33115 .32429 .33021 .32483 .32235 Metetra
.972 .721 .495 r
.32483 .32235 .32429 .33021 .34158 .32921 .34216 .3214 Metetra
.977 .714 .465 r
.34216 .3214 .34158 .32921 .35862 .32813 .35923 .32039 Metetra
.979 .703 .434 r
.35923 .32039 .35862 .32813 .37536 .32698 .37599 .3193 Metetra
.978 .69 .399 r
.37599 .3193 .37536 .32698 .39175 .32578 .39239 .31815 Metetra
.975 .672 .363 r
.39239 .31815 .39175 .32578 .40774 .32452 .40839 .31694 Metetra
.959 .63 .34 r
.40839 .31694 .40774 .32452 .42329 .32322 .42373 .31587 Metetra
.673 .374 .458 r
.42373 .31587 .42329 .32322 .4376 .3228 .4376 .31587 Metetra
.845 .69 .69 r
.96737 .32789 .96737 .33609 .98212 .3358 .98212 .32763 Metetra
.813 .664 .698 r
.95214 .3281 .95214 .33632 .96737 .33609 .96737 .32789 Metetra
.78 .637 .703 r
.93647 .32824 .93647 .33647 .95214 .33632 .95214 .3281 Metetra
.746 .609 .706 r
.9204 .32831 .9204 .33655 .93647 .33647 .93647 .32824 Metetra
.712 .58 .706 r
.90396 .32832 .90397 .33657 .9204 .33655 .9204 .32831 Metetra
.677 .55 .703 r
.88719 .32826 .88723 .33651 .90397 .33657 .90396 .32832 Metetra
.642 .519 .698 r
.87014 .32814 .8702 .33638 .88723 .33651 .88719 .32826 Metetra
.607 .488 .691 r
.85285 .32795 .85293 .33618 .8702 .33638 .87014 .32814 Metetra
.572 .455 .682 r
.83535 .3277 .83547 .33591 .85293 .33618 .85285 .32795 Metetra
.536 .422 .67 r
.81768 .32738 .81784 .33557 .83547 .33591 .83535 .3277 Metetra
.5 .387 .657 r
.79989 .327 .8001 .33516 .81784 .33557 .81768 .32738 Metetra
.463 .352 .642 r
.78201 .32654 .78226 .33468 .8001 .33516 .79989 .327 Metetra
.427 .315 .624 r
.76408 .32602 .76438 .33412 .78226 .33468 .78201 .32654 Metetra
.389 .278 .605 r
.74614 .32543 .7465 .33349 .76438 .33412 .76408 .32602 Metetra
.351 .239 .583 r
.72824 .32477 .72864 .33279 .7465 .33349 .74614 .32543 Metetra
.313 .199 .56 r
.71041 .32403 .71087 .332 .72864 .33279 .72824 .32477 Metetra
.275 .159 .534 r
.69271 .32323 .69321 .33115 .71087 .332 .71041 .32403 Metetra
.237 .117 .507 r
.67517 .32235 .67571 .33021 .69321 .33115 .69271 .32323 Metetra
.199 .075 .477 r
.65784 .3214 .65842 .32921 .67571 .33021 .67517 .32235 Metetra
.161 .032 .445 r
.64077 .32039 .64138 .32813 .65842 .32921 .65784 .3214 Metetra
.125 0 .41 r
.62401 .3193 .62464 .32698 .64138 .32813 .64077 .32039 Metetra
.091 0 .372 r
.60761 .31815 .60825 .32578 .62464 .32698 .62401 .3193 Metetra
.06 0 .331 r
.59161 .31694 .59226 .32452 .60825 .32578 .60761 .31815 Metetra
.092 0 .374 r
.57627 .31587 .57671 .32322 .59226 .32452 .59161 .31694 Metetra
.707 .577 .707 r
.5624 .31587 .5624 .3228 .57671 .32322 .57627 .31587 Metetra
.535 .437 .69 r
.01788 .31946 .01788 .32763 .03263 .32789 .03263 .3197 Metetra
.582 .476 .698 r
.03263 .3197 .03263 .32789 .04786 .3281 .04785 .31988 Metetra
.626 .511 .703 r
.04785 .31988 .04786 .3281 .06353 .32824 .06353 .32 Metetra
.666 .544 .706 r
.06353 .32 .06353 .32824 .0796 .32831 .07961 .32007 Metetra
.704 .574 .706 r
.07961 .32007 .0796 .32831 .09604 .32832 .09606 .32007 Metetra
.738 .601 .705 r
.09606 .32007 .09604 .32832 .11281 .32826 .11284 .32002 Metetra
.769 .625 .7 r
.11284 .32002 .11281 .32826 .12986 .32814 .12992 .3199 Metetra
.797 .646 .694 r
.12992 .3199 .12986 .32814 .14715 .32795 .14724 .31973 Metetra
.824 .665 .686 r
.14724 .31973 .14715 .32795 .16465 .3277 .16477 .3195 Metetra
.848 .681 .676 r
.16477 .3195 .16465 .3277 .18232 .32738 .18248 .3192 Metetra
.87 .695 .663 r
.18248 .3192 .18232 .32738 .20011 .327 .20031 .31885 Metetra
.89 .707 .649 r
.20031 .31885 .20011 .327 .21799 .32654 .21824 .31843 Metetra
.908 .717 .633 r
.21824 .31843 .21799 .32654 .23592 .32602 .23621 .31795 Metetra
.924 .725 .615 r
.23621 .31795 .23592 .32602 .25386 .32543 .25419 .3174 Metetra
.939 .731 .595 r
.25419 .3174 .25386 .32543 .27176 .32477 .27214 .31679 Metetra
.951 .734 .573 r
.27214 .31679 .27176 .32477 .28959 .32403 .29 .31611 Metetra
.962 .735 .55 r
.29 .31611 .28959 .32403 .30729 .32323 .30775 .31537 Metetra
.97 .734 .524 r
.30775 .31537 .30729 .32323 .32483 .32235 .32533 .31455 Metetra
.977 .731 .496 r
.32533 .31455 .32483 .32235 .34216 .3214 .34269 .31367 Metetra
.981 .725 .467 r
.34269 .31367 .34216 .3214 .35923 .32039 .35979 .31273 Metetra
.983 .715 .435 r
.35979 .31273 .35923 .32039 .37599 .3193 .37658 .31171 Metetra
.983 .703 .4 r
.37658 .31171 .37599 .3193 .39239 .31815 .393 .31063 Metetra
.98 .686 .363 r
.393 .31063 .39239 .31815 .40839 .31694 .40901 .30949 Metetra
.904 .564 .39 r
.40901 .30949 .40839 .31694 .42373 .31587 .42373 .30894 Metetra
.845 .69 .69 r
.96737 .3197 .96737 .32789 .98212 .32763 .98212 .31946 Metetra
.813 .664 .698 r
.95215 .31988 .95214 .3281 .96737 .32789 .96737 .3197 Metetra
.78 .637 .703 r
.93647 .32 .93647 .32824 .95214 .3281 .95215 .31988 Metetra
.746 .608 .705 r
.92039 .32007 .9204 .32831 .93647 .32824 .93647 .32 Metetra
.711 .579 .705 r
.90394 .32007 .90396 .32832 .9204 .32831 .92039 .32007 Metetra
.675 .548 .703 r
.88716 .32002 .88719 .32826 .90396 .32832 .90394 .32007 Metetra
.64 .517 .698 r
.87008 .3199 .87014 .32814 .88719 .32826 .88716 .32002 Metetra
.603 .485 .691 r
.85276 .31973 .85285 .32795 .87014 .32814 .87008 .3199 Metetra
.567 .452 .682 r
.83523 .3195 .83535 .3277 .85285 .32795 .85276 .31973 Metetra
.53 .418 .67 r
.81752 .3192 .81768 .32738 .83535 .3277 .83523 .3195 Metetra
.493 .383 .657 r
.79969 .31885 .79989 .327 .81768 .32738 .81752 .3192 Metetra
.456 .347 .642 r
.78176 .31843 .78201 .32654 .79989 .327 .79969 .31885 Metetra
.418 .31 .625 r
.76379 .31795 .76408 .32602 .78201 .32654 .78176 .31843 Metetra
.379 .273 .606 r
.74581 .3174 .74614 .32543 .76408 .32602 .76379 .31795 Metetra
.34 .234 .585 r
.72786 .31679 .72824 .32477 .74614 .32543 .74581 .3174 Metetra
.301 .194 .562 r
.71 .31611 .71041 .32403 .72824 .32477 .72786 .31679 Metetra
.261 .153 .536 r
.69225 .31537 .69271 .32323 .71041 .32403 .71 .31611 Metetra
.221 .111 .509 r
.67467 .31455 .67517 .32235 .69271 .32323 .69225 .31537 Metetra
.181 .068 .479 r
.65731 .31367 .65784 .3214 .67517 .32235 .67467 .31455 Metetra
.142 .024 .447 r
.64021 .31273 .64077 .32039 .65784 .3214 .65731 .31367 Metetra
.103 0 .412 r
.62342 .31171 .62401 .3193 .64077 .32039 .64021 .31273 Metetra
.065 0 .374 r
.607 .31063 .60761 .31815 .62401 .3193 .62342 .31171 Metetra
.03 0 .332 r
.59099 .30949 .59161 .31694 .60761 .31815 .607 .31063 Metetra
.297 .242 .626 r
.57627 .30894 .57627 .31587 .59161 .31694 .59099 .30949 Metetra
.535 .437 .69 r
.01788 .31129 .01788 .31946 .03263 .3197 .03263 .3115 Metetra
.583 .476 .698 r
.03263 .3115 .03263 .3197 .04785 .31988 .04785 .31166 Metetra
.627 .512 .703 r
.04785 .31166 .04785 .31988 .06353 .32 .06353 .31176 Metetra
.667 .545 .706 r
.06353 .31176 .06353 .32 .07961 .32007 .07962 .31182 Metetra
.705 .575 .706 r
.07962 .31182 .07961 .32007 .09606 .32007 .09608 .31182 Metetra
.739 .602 .704 r
.09608 .31182 .09606 .32007 .11284 .32002 .11288 .31177 Metetra
.771 .626 .7 r
.11288 .31177 .11284 .32002 .12992 .3199 .12997 .31167 Metetra
.8 .648 .694 r
.12997 .31167 .12992 .3199 .14724 .31973 .14732 .31151 Metetra
.826 .668 .686 r
.14732 .31151 .14724 .31973 .16477 .3195 .16488 .3113 Metetra
.851 .685 .676 r
.16488 .3113 .16477 .3195 .18248 .3192 .18262 .31103 Metetra
.873 .699 .663 r
.18262 .31103 .18248 .3192 .20031 .31885 .20049 .31071 Metetra
.893 .712 .649 r
.20049 .31071 .20031 .31885 .21824 .31843 .21846 .31033 Metetra
.912 .722 .634 r
.21846 .31033 .21824 .31843 .23621 .31795 .23647 .30989 Metetra
.928 .731 .616 r
.23647 .30989 .23621 .31795 .25419 .3174 .25449 .3094 Metetra
.942 .737 .596 r
.25449 .3094 .25419 .3174 .27214 .31679 .27248 .30884 Metetra
.955 .741 .575 r
.27248 .30884 .27214 .31679 .29 .31611 .29038 .30823 Metetra
.966 .743 .551 r
.29038 .30823 .29 .31611 .30775 .31537 .30817 .30755 Metetra
.974 .743 .526 r
.30817 .30755 .30775 .31537 .32533 .31455 .32578 .30681 Metetra
.981 .74 .498 r
.32578 .30681 .32533 .31455 .34269 .31367 .34317 .30601 Metetra
.985 .735 .469 r
.34317 .30601 .34269 .31367 .35979 .31273 .3603 .30514 Metetra
.987 .727 .437 r
.3603 .30514 .35979 .31273 .37658 .31171 .37711 .30421 Metetra
.987 .715 .402 r
.37711 .30421 .37658 .31171 .393 .31063 .39356 .30322 Metetra
.984 .7 .364 r
.39356 .30322 .393 .31063 .40901 .30949 .40958 .30217 Metetra
.774 .445 .431 r
.40958 .30217 .40901 .30949 .42373 .30894 .42373 .302 Metetra
.845 .69 .69 r
.96737 .3115 .96737 .3197 .98212 .31946 .98212 .31129 Metetra
.813 .664 .698 r
.95215 .31166 .95215 .31988 .96737 .3197 .96737 .3115 Metetra
.779 .636 .703 r
.93647 .31176 .93647 .32 .95215 .31988 .95215 .31166 Metetra
.745 .607 .705 r
.92038 .31182 .92039 .32007 .93647 .32 .93647 .31176 Metetra
.709 .578 .705 r
.90392 .31182 .90394 .32007 .92039 .32007 .92038 .31182 Metetra
.673 .547 .702 r
.88712 .31177 .88716 .32002 .90394 .32007 .90392 .31182 Metetra
.637 .515 .698 r
.87003 .31167 .87008 .3199 .88716 .32002 .88712 .31177 Metetra
.6 .483 .691 r
.85268 .31151 .85276 .31973 .87008 .3199 .87003 .31167 Metetra
.563 .449 .682 r
.83512 .3113 .83523 .3195 .85276 .31973 .85268 .31151 Metetra
.525 .415 .671 r
.81738 .31103 .81752 .3192 .83523 .3195 .83512 .3113 Metetra
.487 .38 .658 r
.79951 .31071 .79969 .31885 .81752 .3192 .81738 .31103 Metetra
.449 .344 .643 r
.78154 .31033 .78176 .31843 .79969 .31885 .79951 .31071 Metetra
.41 .307 .626 r
.76353 .30989 .76379 .31795 .78176 .31843 .78154 .31033 Metetra
.37 .268 .607 r
.74551 .3094 .74581 .3174 .76379 .31795 .76353 .30989 Metetra
.33 .229 .587 r
.72752 .30884 .72786 .31679 .74581 .3174 .74551 .3094 Metetra
.289 .189 .564 r
.70962 .30823 .71 .31611 .72786 .31679 .72752 .30884 Metetra
.248 .148 .539 r
.69183 .30755 .69225 .31537 .71 .31611 .70962 .30823 Metetra
.207 .106 .512 r
.67422 .30681 .67467 .31455 .69225 .31537 .69183 .30755 Metetra
.165 .062 .483 r
.65683 .30601 .65731 .31367 .67467 .31455 .67422 .30681 Metetra
.124 .018 .451 r
.6397 .30514 .64021 .31273 .65731 .31367 .65683 .30601 Metetra
.082 0 .416 r
.62289 .30421 .62342 .31171 .64021 .31273 .6397 .30514 Metetra
.042 0 .378 r
.60644 .30322 .607 .31063 .62342 .31171 .62289 .30421 Metetra
.003 0 .335 r
.59042 .30217 .59099 .30949 .607 .31063 .60644 .30322 Metetra
.57 .465 .696 r
.57627 .302 .57627 .30894 .59099 .30949 .59042 .30217 Metetra
.536 .438 .69 r
.01788 .30312 .01788 .31129 .03263 .3115 .03262 .3033 Metetra
.583 .476 .698 r
.03262 .3033 .03263 .3115 .04785 .31166 .04785 .30344 Metetra
.627 .512 .703 r
.04785 .30344 .04785 .31166 .06353 .31176 .06353 .30353 Metetra
.668 .545 .706 r
.06353 .30353 .06353 .31176 .07962 .31182 .07963 .30358 Metetra
.706 .575 .706 r
.07963 .30358 .07962 .31182 .09608 .31182 .0961 .30358 Metetra
.741 .603 .704 r
.0961 .30358 .09608 .31182 .11288 .31177 .11291 .30353 Metetra
.773 .628 .7 r
.11291 .30353 .11288 .31177 .12997 .31167 .13003 .30344 Metetra
.802 .65 .694 r
.13003 .30344 .12997 .31167 .14732 .31151 .1474 .3033 Metetra
.829 .67 .686 r
.1474 .3033 .14732 .31151 .16488 .3113 .16499 .30311 Metetra
.854 .688 .676 r
.16499 .30311 .16488 .3113 .18262 .31103 .18275 .30287 Metetra
.876 .703 .664 r
.18275 .30287 .18262 .31103 .20049 .31071 .20066 .30259 Metetra
.896 .716 .65 r
.20066 .30259 .20049 .31071 .21846 .31033 .21865 .30225 Metetra
.915 .727 .634 r
.21865 .30225 .21846 .31033 .23647 .30989 .2367 .30186 Metetra
.931 .736 .617 r
.2367 .30186 .23647 .30989 .25449 .3094 .25476 .30142 Metetra
.946 .743 .598 r
.25476 .30142 .25449 .3094 .27248 .30884 .27278 .30093 Metetra
.958 .748 .577 r
.27278 .30093 .27248 .30884 .29038 .30823 .29072 .30038 Metetra
.969 .751 .554 r
.29072 .30038 .29038 .30823 .30817 .30755 .30854 .29978 Metetra
.978 .752 .529 r
.30854 .29978 .30817 .30755 .32578 .30681 .32619 .29912 Metetra
.984 .75 .501 r
.32619 .29912 .32578 .30681 .34317 .30601 .34361 .29841 Metetra
.989 .746 .472 r
.34361 .29841 .34317 .30601 .3603 .30514 .36076 .29763 Metetra
.991 .738 .44 r
.36076 .29763 .3603 .30514 .37711 .30421 .3776 .2968 Metetra
.99 .728 .406 r
.3776 .2968 .37711 .30421 .39356 .30322 .39406 .29591 Metetra
.985 .705 .387 r
.39406 .29591 .39356 .30322 .40958 .30217 .40986 .29507 Metetra
.696 .466 .57 r
.40986 .29507 .40958 .30217 .42373 .302 .42373 .29507 Metetra
.844 .69 .69 r
.96738 .3033 .96737 .3115 .98212 .31129 .98212 .30312 Metetra
.813 .663 .698 r
.95215 .30344 .95215 .31166 .96737 .3115 .96738 .3033 Metetra
.779 .636 .703 r
.93647 .30353 .93647 .31176 .95215 .31166 .95215 .30344 Metetra
.744 .607 .705 r
.92037 .30358 .92038 .31182 .93647 .31176 .93647 .30353 Metetra
.708 .577 .705 r
.9039 .30358 .90392 .31182 .92038 .31182 .92037 .30358 Metetra
.672 .545 .703 r
.88709 .30353 .88712 .31177 .90392 .31182 .9039 .30358 Metetra
.635 .513 .698 r
.86997 .30344 .87003 .31167 .88712 .31177 .88709 .30353 Metetra
.597 .481 .691 r
.8526 .3033 .85268 .31151 .87003 .31167 .86997 .30344 Metetra
.559 .447 .682 r
.83501 .30311 .83512 .3113 .85268 .31151 .8526 .3033 Metetra
.521 .413 .672 r
.81725 .30287 .81738 .31103 .83512 .3113 .83501 .30311 Metetra
.482 .377 .659 r
.79934 .30259 .79951 .31071 .81738 .31103 .81725 .30287 Metetra
.443 .341 .644 r
.78135 .30225 .78154 .31033 .79951 .31071 .79934 .30259 Metetra
.403 .304 .628 r
.7633 .30186 .76353 .30989 .78154 .31033 .78135 .30225 Metetra
.362 .266 .61 r
.74524 .30142 .74551 .3094 .76353 .30989 .7633 .30186 Metetra
.321 .226 .589 r
.72722 .30093 .72752 .30884 .74551 .3094 .74524 .30142 Metetra
.279 .186 .567 r
.70928 .30038 .70962 .30823 .72752 .30884 .72722 .30093 Metetra
.237 .145 .543 r
.69146 .29978 .69183 .30755 .70962 .30823 .70928 .30038 Metetra
.194 .102 .516 r
.67381 .29912 .67422 .30681 .69183 .30755 .69146 .29978 Metetra
.151 .059 .487 r
.65639 .29841 .65683 .30601 .67422 .30681 .67381 .29912 Metetra
.107 .014 .456 r
.63924 .29763 .6397 .30514 .65683 .30601 .65639 .29841 Metetra
.064 0 .421 r
.6224 .2968 .62289 .30421 .6397 .30514 .63924 .29763 Metetra
.02 0 .383 r
.60594 .29591 .60644 .30322 .62289 .30421 .6224 .2968 Metetra
.028 0 .428 r
.59014 .29507 .59042 .30217 .60644 .30322 .60594 .29591 Metetra
.707 .577 .707 r
.57627 .29507 .57627 .302 .59042 .30217 .59014 .29507 Metetra
.536 .438 .69 r
.01787 .29494 .01788 .30312 .03262 .3033 .03262 .2951 Metetra
.583 .476 .698 r
.03262 .2951 .03262 .3033 .04785 .30344 .04786 .29521 Metetra
.627 .512 .703 r
.04786 .29521 .04785 .30344 .06353 .30353 .06354 .29529 Metetra
.669 .546 .706 r
.06354 .29529 .06353 .30353 .07963 .30358 .07964 .29533 Metetra
.707 .576 .706 r
.07964 .29533 .07963 .30358 .0961 .30358 .09612 .29533 Metetra
.742 .604 .704 r
.09612 .29533 .0961 .30358 .11291 .30353 .11295 .29529 Metetra
.774 .629 .7 r
.11295 .29529 .11291 .30353 .13003 .30344 .13008 .29521 Metetra
.804 .652 .694 r
.13008 .29521 .13003 .30344 .1474 .3033 .14747 .29509 Metetra
.831 .673 .686 r
.14747 .29509 .1474 .3033 .16499 .30311 .16508 .29493 Metetra
.856 .691 .676 r
.16508 .29493 .16499 .30311 .18275 .30287 .18287 .29472 Metetra
.879 .707 .665 r
.18287 .29472 .18275 .30287 .20066 .30259 .2008 .29448 Metetra
.899 .72 .651 r
.2008 .29448 .20066 .30259 .21865 .30225 .21883 .29418 Metetra
.918 .732 .636 r
.21883 .29418 .21865 .30225 .2367 .30186 .23691 .29385 Metetra
.934 .742 .619 r
.23691 .29385 .2367 .30186 .25476 .30142 .255 .29347 Metetra
.949 .749 .6 r
.255 .29347 .25476 .30142 .27278 .30093 .27305 .29304 Metetra
.961 .755 .579 r
.27305 .29304 .27278 .30093 .29072 .30038 .29102 .29257 Metetra
.972 .759 .557 r
.29102 .29257 .29072 .30038 .30854 .29978 .30887 .29205 Metetra
.981 .76 .532 r
.30887 .29205 .30854 .29978 .32619 .29912 .32654 .29148 Metetra
.987 .759 .505 r
.32654 .29148 .32619 .29912 .34361 .29841 .34399 .29086 Metetra
.991 .756 .476 r
.34399 .29086 .34361 .29841 .36076 .29763 .36117 .29019 Metetra
.993 .75 .445 r
.36117 .29019 .36076 .29763 .3776 .2968 .37803 .28946 Metetra
.993 .741 .41 r
.37803 .28946 .3776 .2968 .39406 .29591 .39451 .28868 Metetra
.975 .696 .436 r
.39451 .28868 .39406 .29591 .40986 .29507 .40986 .28814 Metetra
.844 .689 .69 r
.96738 .2951 .96738 .3033 .98212 .30312 .98213 .29494 Metetra
.812 .663 .698 r
.95214 .29521 .95215 .30344 .96738 .3033 .96738 .2951 Metetra
.779 .635 .703 r
.93646 .29529 .93647 .30353 .95215 .30344 .95214 .29521 Metetra
.744 .606 .705 r
.92036 .29533 .92037 .30358 .93647 .30353 .93646 .29529 Metetra
.707 .576 .705 r
.90388 .29533 .9039 .30358 .92037 .30358 .92036 .29533 Metetra
.67 .544 .703 r
.88705 .29529 .88709 .30353 .9039 .30358 .90388 .29533 Metetra
.633 .512 .698 r
.86992 .29521 .86997 .30344 .88709 .30353 .88705 .29529 Metetra
.595 .479 .692 r
.85253 .29509 .8526 .3033 .86997 .30344 .86992 .29521 Metetra
.556 .445 .683 r
.83492 .29493 .83501 .30311 .8526 .3033 .85253 .29509 Metetra
.517 .411 .673 r
.81713 .29472 .81725 .30287 .83501 .30311 .83492 .29493 Metetra
.477 .375 .66 r
.7992 .29448 .79934 .30259 .81725 .30287 .81713 .29472 Metetra
.437 .339 .646 r
.78117 .29418 .78135 .30225 .79934 .30259 .7992 .29448 Metetra
.396 .302 .63 r
.76309 .29385 .7633 .30186 .78135 .30225 .78117 .29418 Metetra
.355 .264 .612 r
.745 .29347 .74524 .30142 .7633 .30186 .76309 .29385 Metetra
.313 .225 .593 r
.72695 .29304 .72722 .30093 .74524 .30142 .745 .29347 Metetra
.271 .184 .571 r
.70898 .29257 .70928 .30038 .72722 .30093 .72695 .29304 Metetra
.227 .143 .547 r
.69113 .29205 .69146 .29978 .70928 .30038 .70898 .29257 Metetra
.183 .101 .521 r
.67346 .29148 .67381 .29912 .69146 .29978 .69113 .29205 Metetra
.139 .057 .493 r
.65601 .29086 .65639 .29841 .67381 .29912 .67346 .29148 Metetra
.093 .012 .462 r
.63883 .29019 .63924 .29763 .65639 .29841 .65601 .29086 Metetra
.048 0 .428 r
.62197 .28946 .6224 .2968 .63924 .29763 .63883 .29019 Metetra
.001 0 .39 r
.60549 .28868 .60594 .29591 .6224 .2968 .62197 .28946 Metetra
.134 .109 .563 r
.59014 .28814 .59014 .29507 .60594 .29591 .60549 .28868 Metetra
.536 .438 .691 r
.01787 .28677 .01787 .29494 .03262 .2951 .03262 .2869 Metetra
.583 .476 .698 r
.03262 .2869 .03262 .2951 .04786 .29521 .04786 .28699 Metetra
.628 .513 .703 r
.04786 .28699 .04786 .29521 .06354 .29529 .06354 .28706 Metetra
.669 .546 .706 r
.06354 .28706 .06354 .29529 .07964 .29533 .07965 .28709 Metetra
.708 .577 .706 r
.07965 .28709 .07964 .29533 .09612 .29533 .09614 .28709 Metetra
.743 .605 .704 r
.09614 .28709 .09612 .29533 .11295 .29529 .11298 .28706 Metetra
.776 .631 .7 r
.11298 .28706 .11295 .29529 .13008 .29521 .13012 .28699 Metetra
.806 .654 .694 r
.13012 .28699 .13008 .29521 .14747 .29509 .14753 .28689 Metetra
.833 .675 .687 r
.14753 .28689 .14747 .29509 .16508 .29493 .16516 .28675 Metetra
.858 .693 .677 r
.16516 .28675 .16508 .29493 .18287 .29472 .18297 .28658 Metetra
.881 .71 .666 r
.18297 .28658 .18287 .29472 .2008 .29448 .20093 .28637 Metetra
.901 .724 .653 r
.20093 .28637 .2008 .29448 .21883 .29418 .21898 .28613 Metetra
.92 .737 .638 r
.21898 .28613 .21883 .29418 .23691 .29385 .23708 .28585 Metetra
.937 .747 .621 r
.23708 .28585 .23691 .29385 .255 .29347 .2552 .28554 Metetra
.951 .755 .603 r
.2552 .28554 .255 .29347 .27305 .29304 .27328 .28518 Metetra
.964 .762 .583 r
.27328 .28518 .27305 .29304 .29102 .29257 .29127 .28479 Metetra
.974 .766 .561 r
.29127 .28479 .29102 .29257 .30887 .29205 .30914 .28435 Metetra
.983 .769 .537 r
.30914 .28435 .30887 .29205 .32654 .29148 .32684 .28388 Metetra
.99 .769 .51 r
.32684 .28388 .32654 .29148 .34399 .29086 .34431 .28336 Metetra
.994 .766 .482 r
.34431 .28336 .34399 .29086 .36117 .29019 .36151 .2828 Metetra
.995 .761 .451 r
.36151 .2828 .36117 .29019 .37803 .28946 .37839 .28219 Metetra
.995 .753 .417 r
.37839 .28219 .37803 .28946 .39451 .28868 .39489 .28153 Metetra
.951 .681 .488 r
.39489 .28153 .39451 .28868 .40986 .28814 .40986 .2812 Metetra
.844 .689 .69 r
.96738 .2869 .96738 .2951 .98213 .29494 .98213 .28677 Metetra
.812 .663 .698 r
.95214 .28699 .95214 .29521 .96738 .2951 .96738 .2869 Metetra
.778 .635 .703 r
.93646 .28706 .93646 .29529 .95214 .29521 .95214 .28699 Metetra
.743 .606 .705 r
.92035 .28709 .92036 .29533 .93646 .29529 .93646 .28706 Metetra
.706 .575 .705 r
.90386 .28709 .90388 .29533 .92036 .29533 .92035 .28709 Metetra
.669 .544 .703 r
.88702 .28706 .88705 .29529 .90388 .29533 .90386 .28709 Metetra
.631 .511 .699 r
.86988 .28699 .86992 .29521 .88705 .29529 .88702 .28706 Metetra
.592 .478 .692 r
.85247 .28689 .85253 .29509 .86992 .29521 .86988 .28699 Metetra
.553 .444 .684 r
.83484 .28675 .83492 .29493 .85253 .29509 .85247 .28689 Metetra
.514 .41 .674 r
.81703 .28658 .81713 .29472 .83492 .29493 .83484 .28675 Metetra
.473 .374 .662 r
.79907 .28637 .7992 .29448 .81713 .29472 .81703 .28658 Metetra
.433 .338 .648 r
.78102 .28613 .78117 .29418 .7992 .29448 .79907 .28637 Metetra
.391 .301 .633 r
.76292 .28585 .76309 .29385 .78117 .29418 .78102 .28613 Metetra
.349 .263 .616 r
.7448 .28554 .745 .29347 .76309 .29385 .76292 .28585 Metetra
.307 .224 .597 r
.72672 .28518 .72695 .29304 .745 .29347 .7448 .28554 Metetra
.263 .184 .576 r
.70873 .28479 .70898 .29257 .72695 .29304 .72672 .28518 Metetra
.219 .143 .553 r
.69086 .28435 .69113 .29205 .70898 .29257 .70873 .28479 Metetra
.174 .101 .527 r
.67316 .28388 .67346 .29148 .69113 .29205 .69086 .28435 Metetra
.128 .057 .5 r
.65569 .28336 .65601 .29086 .67346 .29148 .67316 .28388 Metetra
.081 .012 .47 r
.63849 .2828 .63883 .29019 .65601 .29086 .65569 .28336 Metetra
.034 0 .437 r
.62161 .28219 .62197 .28946 .63883 .29019 .63849 .2828 Metetra
0 0 .4 r
.60511 .28153 .60549 .28868 .62197 .28946 .62161 .28219 Metetra
.256 .209 .611 r
.59014 .2812 .59014 .28814 .60549 .28868 .60511 .28153 Metetra
.537 .438 .691 r
.01786 .2786 .01787 .28677 .03262 .2869 .03262 .2787 Metetra
.584 .477 .698 r
.03262 .2787 .03262 .2869 .04786 .28699 .04786 .27877 Metetra
.628 .513 .703 r
.04786 .27877 .04786 .28699 .06354 .28706 .06355 .27882 Metetra
.67 .547 .706 r
.06355 .27882 .06354 .28706 .07965 .28709 .07966 .27885 Metetra
.708 .578 .706 r
.07966 .27885 .07965 .28709 .09614 .28709 .09616 .27885 Metetra
.744 .606 .704 r
.09616 .27885 .09614 .28709 .11298 .28706 .113 .27882 Metetra
.777 .632 .701 r
.113 .27882 .11298 .28706 .13012 .28699 .13016 .27877 Metetra
.807 .656 .695 r
.13016 .27877 .13012 .28699 .14753 .28689 .14758 .27869 Metetra
.834 .677 .687 r
.14758 .27869 .14753 .28689 .16516 .28675 .16522 .27858 Metetra
.86 .696 .678 r
.16522 .27858 .16516 .28675 .18297 .28658 .18305 .27844 Metetra
.882 .713 .667 r
.18305 .27844 .18297 .28658 .20093 .28637 .20103 .27828 Metetra
.903 .728 .654 r
.20103 .27828 .20093 .28637 .21898 .28613 .2191 .27809 Metetra
.922 .741 .64 r
.2191 .27809 .21898 .28613 .23708 .28585 .23722 .27787 Metetra
.938 .752 .624 r
.23722 .27787 .23708 .28585 .2552 .28554 .25536 .27762 Metetra
.953 .761 .606 r
.25536 .27762 .2552 .28554 .27328 .28518 .27346 .27734 Metetra
.966 .768 .586 r
.27346 .27734 .27328 .28518 .29127 .28479 .29148 .27703 Metetra
.976 .773 .565 r
.29148 .27703 .29127 .28479 .30914 .28435 .30937 .27669 Metetra
.985 .777 .542 r
.30937 .27669 .30914 .28435 .32684 .28388 .32708 .27631 Metetra
.991 .778 .516 r
.32708 .27631 .32684 .28388 .34431 .28336 .34457 .2759 Metetra
.995 .776 .489 r
.34457 .2759 .34431 .28336 .36151 .2828 .36179 .27546 Metetra
.997 .773 .458 r
.36179 .27546 .36151 .2828 .37839 .28219 .37868 .27498 Metetra
.996 .766 .425 r
.37868 .27498 .37839 .28219 .39489 .28153 .3952 .27445 Metetra
.916 .662 .539 r
.3952 .27445 .39489 .28153 .40986 .2812 .40986 .27427 Metetra
.844 .689 .69 r
.96738 .2787 .96738 .2869 .98213 .28677 .98214 .2786 Metetra
.812 .663 .698 r
.95214 .27877 .95214 .28699 .96738 .2869 .96738 .2787 Metetra
.778 .635 .703 r
.93645 .27882 .93646 .28706 .95214 .28699 .95214 .27877 Metetra
.743 .605 .705 r
.92034 .27885 .92035 .28709 .93646 .28706 .93645 .27882 Metetra
.706 .575 .705 r
.90384 .27885 .90386 .28709 .92035 .28709 .92034 .27885 Metetra
.668 .543 .703 r
.887 .27882 .88702 .28706 .90386 .28709 .90384 .27885 Metetra
.63 .511 .699 r
.86984 .27877 .86988 .28699 .88702 .28706 .887 .27882 Metetra
.591 .478 .693 r
.85242 .27869 .85247 .28689 .86988 .28699 .86984 .27877 Metetra
.551 .444 .685 r
.83478 .27858 .83484 .28675 .85247 .28689 .85242 .27869 Metetra
.511 .409 .676 r
.81695 .27844 .81703 .28658 .83484 .28675 .83478 .27858 Metetra
.47 .374 .664 r
.79897 .27828 .79907 .28637 .81703 .28658 .81695 .27844 Metetra
.429 .338 .651 r
.7809 .27809 .78102 .28613 .79907 .28637 .79897 .27828 Metetra
.387 .301 .636 r
.76278 .27787 .76292 .28585 .78102 .28613 .7809 .27809 Metetra
.345 .263 .619 r
.74464 .27762 .7448 .28554 .76292 .28585 .76278 .27787 Metetra
.301 .225 .601 r
.72654 .27734 .72672 .28518 .7448 .28554 .74464 .27762 Metetra
.257 .185 .581 r
.70852 .27703 .70873 .28479 .72672 .28518 .72654 .27734 Metetra
.212 .144 .559 r
.69063 .27669 .69086 .28435 .70873 .28479 .70852 .27703 Metetra
.166 .102 .534 r
.67292 .27631 .67316 .28388 .69086 .28435 .69063 .27669 Metetra
.12 .059 .508 r
.65543 .2759 .65569 .28336 .67316 .28388 .67292 .27631 Metetra
.071 .014 .479 r
.63821 .27546 .63849 .2828 .65569 .28336 .65543 .2759 Metetra
.022 0 .447 r
.62132 .27498 .62161 .28219 .63849 .2828 .63821 .27546 Metetra
0 0 .411 r
.6048 .27445 .60511 .28153 .62161 .28219 .62132 .27498 Metetra
.373 .305 .651 r
.59014 .27427 .59014 .2812 .60511 .28153 .6048 .27445 Metetra
.537 .439 .691 r
.01786 .27043 .01786 .2786 .03262 .2787 .03262 .2705 Metetra
.584 .477 .698 r
.03262 .2705 .03262 .2787 .04786 .27877 .04786 .27055 Metetra
.629 .513 .703 r
.04786 .27055 .04786 .27877 .06355 .27882 .06355 .27059 Metetra
.67 .547 .706 r
.06355 .27059 .06355 .27882 .07966 .27885 .07967 .2706 Metetra
.709 .578 .706 r
.07967 .2706 .07966 .27885 .09616 .27885 .09617 .2706 Metetra
.745 .607 .705 r
.09617 .2706 .09616 .27885 .113 .27882 .11302 .27058 Metetra
.778 .633 .701 r
.11302 .27058 .113 .27882 .13016 .27877 .13018 .27055 Metetra
.808 .657 .696 r
.13018 .27055 .13016 .27877 .14758 .27869 .14761 .27049 Metetra
.836 .679 .688 r
.14761 .27049 .14758 .27869 .16522 .27858 .16527 .27041 Metetra
.861 .698 .679 r
.16527 .27041 .16522 .27858 .18305 .27844 .18312 .27031 Metetra
.884 .716 .669 r
.18312 .27031 .18305 .27844 .20103 .27828 .2011 .2702 Metetra
.905 .731 .656 r
.2011 .2702 .20103 .27828 .2191 .27809 .21919 .27006 Metetra
.923 .745 .643 r
.21919 .27006 .2191 .27809 .23722 .27787 .23733 .2699 Metetra
.94 .756 .627 r
.23733 .2699 .23722 .27787 .25536 .27762 .25548 .26972 Metetra
.955 .766 .61 r
.25548 .26972 .25536 .27762 .27346 .27734 .2736 .26952 Metetra
.967 .774 .591 r
.2736 .26952 .27346 .27734 .29148 .27703 .29163 .26929 Metetra
.978 .78 .57 r
.29163 .26929 .29148 .27703 .30937 .27669 .30954 .26905 Metetra
.986 .785 .548 r
.30954 .26905 .30937 .27669 .32708 .27631 .32727 .26878 Metetra
.993 .787 .523 r
.32727 .26878 .32708 .27631 .34457 .2759 .34477 .26848 Metetra
.997 .786 .497 r
.34477 .26848 .34457 .2759 .36179 .27546 .362 .26816 Metetra
.998 .784 .467 r
.362 .26816 .36179 .27546 .37868 .27498 .37891 .26781 Metetra
.997 .778 .435 r
.37891 .26781 .37868 .27498 .3952 .27445 .39544 .26743 Metetra
.875 .644 .586 r
.39544 .26743 .3952 .27445 .40986 .27427 .40986 .26733 Metetra
.844 .689 .69 r
.96738 .2705 .96738 .2787 .98214 .2786 .98214 .27043 Metetra
.812 .663 .698 r
.95214 .27055 .95214 .27877 .96738 .2787 .96738 .2705 Metetra
.778 .635 .703 r
.93645 .27059 .93645 .27882 .95214 .27877 .95214 .27055 Metetra
.742 .605 .705 r
.92033 .2706 .92034 .27885 .93645 .27882 .93645 .27059 Metetra
.705 .575 .706 r
.90383 .2706 .90384 .27885 .92034 .27885 .92033 .2706 Metetra
.667 .543 .704 r
.88698 .27058 .887 .27882 .90384 .27885 .90383 .2706 Metetra
.629 .511 .7 r
.86982 .27055 .86984 .27877 .887 .27882 .88698 .27058 Metetra
.589 .478 .694 r
.85239 .27049 .85242 .27869 .86984 .27877 .86982 .27055 Metetra
.549 .444 .687 r
.83473 .27041 .83478 .27858 .85242 .27869 .85239 .27049 Metetra
.509 .41 .678 r
.81688 .27031 .81695 .27844 .83478 .27858 .83473 .27041 Metetra
.468 .374 .667 r
.7989 .2702 .79897 .27828 .81695 .27844 .81688 .27031 Metetra
.426 .339 .654 r
.78081 .27006 .7809 .27809 .79897 .27828 .7989 .2702 Metetra
.384 .302 .64 r
.76267 .2699 .76278 .27787 .7809 .27809 .78081 .27006 Metetra
.341 .265 .624 r
.74452 .26972 .74464 .27762 .76278 .27787 .76267 .2699 Metetra
.297 .227 .606 r
.7264 .26952 .72654 .27734 .74464 .27762 .74452 .26972 Metetra
.253 .188 .587 r
.70837 .26929 .70852 .27703 .72654 .27734 .7264 .26952 Metetra
.207 .147 .566 r
.69046 .26905 .69063 .27669 .70852 .27703 .70837 .26929 Metetra
.161 .106 .542 r
.67273 .26878 .67292 .27631 .69063 .27669 .69046 .26905 Metetra
.113 .063 .517 r
.65523 .26848 .65543 .2759 .67292 .27631 .67273 .26878 Metetra
.064 .019 .489 r
.638 .26816 .63821 .27546 .65543 .2759 .65523 .26848 Metetra
.014 0 .458 r
.62109 .26781 .62132 .27498 .63821 .27546 .638 .26816 Metetra
0 0 .424 r
.60456 .26743 .6048 .27445 .62132 .27498 .62109 .26781 Metetra
.471 .385 .677 r
.59014 .26733 .59014 .27427 .6048 .27445 .60456 .26743 Metetra
.537 .439 .691 r
.01786 .26226 .01786 .27043 .03262 .2705 .03262 .2623 Metetra
.584 .477 .698 r
.03262 .2623 .03262 .2705 .04786 .27055 .04786 .26233 Metetra
.629 .513 .703 r
.04786 .26233 .04786 .27055 .06355 .27059 .06356 .26235 Metetra
.671 .547 .706 r
.06356 .26235 .06355 .27059 .07967 .2706 .07967 .26236 Metetra
.709 .579 .707 r
.07967 .26236 .07967 .2706 .09617 .2706 .09618 .26236 Metetra
.745 .608 .705 r
.09618 .26236 .09617 .2706 .11302 .27058 .11304 .26235 Metetra
.778 .634 .702 r
.11304 .26235 .11302 .27058 .13018 .27055 .1302 .26233 Metetra
.809 .659 .696 r
.1302 .26233 .13018 .27055 .14761 .27049 .14764 .26229 Metetra
.836 .681 .69 r
.14764 .26229 .14761 .27049 .16527 .27041 .16531 .26224 Metetra
.862 .701 .681 r
.16531 .26224 .16527 .27041 .18312 .27031 .18316 .26219 Metetra
.885 .718 .671 r
.18316 .26219 .18312 .27031 .2011 .2702 .20116 .26212 Metetra
.905 .734 .659 r
.20116 .26212 .2011 .2702 .21919 .27006 .21925 .26203 Metetra
.924 .749 .646 r
.21925 .26203 .21919 .27006 .23733 .2699 .2374 .26194 Metetra
.941 .761 .631 r
.2374 .26194 .23733 .2699 .25548 .26972 .25556 .26183 Metetra
.956 .771 .614 r
.25556 .26183 .25548 .26972 .2736 .26952 .27369 .26171 Metetra
.968 .78 .596 r
.27369 .26171 .2736 .26952 .29163 .26929 .29174 .26157 Metetra
.979 .787 .577 r
.29174 .26157 .29163 .26929 .30954 .26905 .30965 .26142 Metetra
.987 .792 .555 r
.30965 .26142 .30954 .26905 .32727 .26878 .32739 .26126 Metetra
.994 .795 .531 r
.32739 .26126 .32727 .26878 .34477 .26848 .34491 .26108 Metetra
.998 .796 .506 r
.34491 .26108 .34477 .26848 .362 .26816 .36215 .26088 Metetra
.999 .795 .478 r
.36215 .26088 .362 .26816 .37891 .26781 .37906 .26067 Metetra
.998 .791 .447 r
.37906 .26067 .37891 .26781 .39544 .26743 .3956 .26044 Metetra
.838 .635 .628 r
.3956 .26044 .39544 .26743 .40986 .26733 .40986 .2604 Metetra
0 0 .048 r
.4792 .2604 .4792 .26733 .49307 .26733 .49153 .26271 Metetra
.036 .606 .742 r
.49153 .26271 .49307 .26733 .50693 .26733 .50847 .26271 Metetra
.844 .689 .69 r
.96738 .2623 .96738 .2705 .98214 .27043 .98214 .26226 Metetra
.812 .663 .698 r
.95214 .26233 .95214 .27055 .96738 .2705 .96738 .2623 Metetra
.778 .635 .703 r
.93644 .26235 .93645 .27059 .95214 .27055 .95214 .26233 Metetra
.742 .605 .706 r
.92033 .26236 .92033 .2706 .93645 .27059 .93644 .26235 Metetra
.705 .575 .706 r
.90382 .26236 .90383 .2706 .92033 .2706 .92033 .26236 Metetra
.667 .543 .705 r
.88696 .26235 .88698 .27058 .90383 .2706 .90382 .26236 Metetra
.628 .511 .701 r
.8698 .26233 .86982 .27055 .88698 .27058 .88696 .26235 Metetra
.588 .478 .696 r
.85236 .26229 .85239 .27049 .86982 .27055 .8698 .26233 Metetra
.548 .445 .688 r
.83469 .26224 .83473 .27041 .85239 .27049 .85236 .26229 Metetra
.508 .41 .68 r
.81684 .26219 .81688 .27031 .83473 .27041 .83469 .26224 Metetra
.466 .376 .669 r
.79884 .26212 .7989 .2702 .81688 .27031 .81684 .26219 Metetra
.424 .34 .657 r
.78075 .26203 .78081 .27006 .7989 .2702 .79884 .26212 Metetra
.382 .304 .644 r
.7626 .26194 .76267 .2699 .78081 .27006 .78075 .26203 Metetra
.339 .267 .629 r
.74444 .26183 .74452 .26972 .76267 .2699 .7626 .26194 Metetra
.295 .23 .612 r
.72631 .26171 .7264 .26952 .74452 .26972 .74444 .26183 Metetra
.25 .191 .593 r
.70826 .26157 .70837 .26929 .7264 .26952 .72631 .26171 Metetra
.204 .152 .573 r
.69035 .26142 .69046 .26905 .70837 .26929 .70826 .26157 Metetra
.157 .111 .551 r
.67261 .26126 .67273 .26878 .69046 .26905 .69035 .26142 Metetra
.109 .069 .527 r
.65509 .26108 .65523 .26848 .67273 .26878 .67261 .26126 Metetra
.059 .026 .501 r
.63785 .26088 .638 .26816 .65523 .26848 .65509 .26108 Metetra
.008 0 .471 r
.62094 .26067 .62109 .26781 .638 .26816 .63785 .26088 Metetra
0 0 .439 r
.6044 .26044 .60456 .26743 .62109 .26781 .62094 .26067 Metetra
.54 .441 .691 r
.59014 .2604 .59014 .26733 .60456 .26743 .6044 .26044 Metetra
.521 .833 .521 r
.50847 .26271 .50693 .26733 .5208 .26733 .5208 .2604 Metetra
.537 .439 .69 r
.01786 .25409 .01786 .26226 .03262 .2623 .03262 .2541 Metetra
.584 .477 .698 r
.03262 .2541 .03262 .2623 .04786 .26233 .04786 .25411 Metetra
.629 .513 .703 r
.04786 .25411 .04786 .26233 .06356 .26235 .06356 .25412 Metetra
.671 .547 .706 r
.06356 .25412 .06356 .26235 .07967 .26236 .07968 .25412 Metetra
.71 .579 .707 r
.07968 .25412 .07967 .26236 .09618 .26236 .09618 .25412 Metetra
.746 .608 .706 r
.09618 .25412 .09618 .26236 .11304 .26235 .11304 .25412 Metetra
.779 .635 .702 r
.11304 .25412 .11304 .26235 .1302 .26233 .13021 .25411 Metetra
.809 .66 .697 r
.13021 .25411 .1302 .26233 .14764 .26229 .14765 .2541 Metetra
.837 .682 .691 r
.14765 .2541 .14764 .26229 .16531 .26224 .16532 .25408 Metetra
.862 .702 .683 r
.16532 .25408 .16531 .26224 .18316 .26219 .18318 .25406 Metetra
.885 .721 .673 r
.18318 .25406 .18316 .26219 .20116 .26212 .20118 .25404 Metetra
.906 .737 .662 r
.20118 .25404 .20116 .26212 .21925 .26203 .21928 .25401 Metetra
.925 .752 .649 r
.21928 .25401 .21925 .26203 .2374 .26194 .23744 .25398 Metetra
.941 .765 .635 r
.23744 .25398 .2374 .26194 .25556 .26183 .25561 .25394 Metetra
.956 .776 .619 r
.25561 .25394 .25556 .26183 .27369 .26171 .27374 .2539 Metetra
.969 .786 .602 r
.27374 .2539 .27369 .26171 .29174 .26157 .29179 .25386 Metetra
.979 .794 .583 r
.29179 .25386 .29174 .26157 .30965 .26142 .30971 .25381 Metetra
.988 .8 .563 r
.30971 .25381 .30965 .26142 .32739 .26126 .32745 .25375 Metetra
.994 .804 .54 r
.32745 .25375 .32739 .26126 .34491 .26108 .34497 .25369 Metetra
.998 .806 .516 r
.34497 .25369 .34491 .26108 .36215 .26088 .36222 .25363 Metetra
1 .806 .489 r
.36222 .25363 .36215 .26088 .37906 .26067 .37914 .25355 Metetra
.999 .803 .46 r
.37914 .25355 .37906 .26067 .3956 .26044 .39568 .25348 Metetra
.817 .642 .665 r
.39568 .25348 .3956 .26044 .40986 .2604 .40986 .25347 Metetra
0 0 .048 r
.4792 .25347 .4792 .2604 .49153 .26271 .49153 .25424 Metetra
.843 .689 .69 r
.96738 .2541 .96738 .2623 .98214 .26226 .98214 .25409 Metetra
.812 .663 .698 r
.95214 .25411 .95214 .26233 .96738 .2623 .96738 .2541 Metetra
.778 .635 .703 r
.93644 .25412 .93644 .26235 .95214 .26233 .95214 .25411 Metetra
.742 .605 .706 r
.92032 .25412 .92033 .26236 .93644 .26235 .93644 .25412 Metetra
.705 .575 .707 r
.90382 .25412 .90382 .26236 .92033 .26236 .92032 .25412 Metetra
.666 .544 .705 r
.88696 .25412 .88696 .26235 .90382 .26236 .90382 .25412 Metetra
.628 .512 .702 r
.86979 .25411 .8698 .26233 .88696 .26235 .88696 .25412 Metetra
.588 .479 .697 r
.85235 .2541 .85236 .26229 .8698 .26233 .86979 .25411 Metetra
.548 .446 .69 r
.83468 .25408 .83469 .26224 .85236 .26229 .85235 .2541 Metetra
.507 .412 .682 r
.81682 .25406 .81684 .26219 .83469 .26224 .83468 .25408 Metetra
.465 .377 .672 r
.79882 .25404 .79884 .26212 .81684 .26219 .81682 .25406 Metetra
.423 .343 .661 r
.78072 .25401 .78075 .26203 .79884 .26212 .79882 .25404 Metetra
.381 .307 .648 r
.76256 .25398 .7626 .26194 .78075 .26203 .78072 .25401 Metetra
.337 .271 .634 r
.74439 .25394 .74444 .26183 .7626 .26194 .76256 .25398 Metetra
.293 .234 .618 r
.72626 .2539 .72631 .26171 .74444 .26183 .74439 .25394 Metetra
.248 .196 .601 r
.70821 .25386 .70826 .26157 .72631 .26171 .72626 .2539 Metetra
.202 .158 .582 r
.69029 .25381 .69035 .26142 .70826 .26157 .70821 .25386 Metetra
.155 .118 .561 r
.67255 .25375 .67261 .26126 .69035 .26142 .69029 .25381 Metetra
.106 .077 .538 r
.65503 .25369 .65509 .26108 .67261 .26126 .67255 .25375 Metetra
.056 .035 .513 r
.63778 .25363 .63785 .26088 .65509 .26108 .65503 .25369 Metetra
.005 0 .486 r
.62086 .25355 .62094 .26067 .63785 .26088 .63778 .25363 Metetra
0 0 .456 r
.60432 .25348 .6044 .26044 .62094 .26067 .62086 .25355 Metetra
.575 .469 .697 r
.59014 .25347 .59014 .2604 .6044 .26044 .60432 .25348 Metetra
.753 .615 .048 r
.50847 .25424 .50847 .26271 .5208 .2604 .5208 .25347 Metetra
0 g
.25 Mabswid
0 0 m
0 .5 L
s
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .125 m
.00625 .125 L
s
[(-0.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1)] -0.0125 .5 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML00?oG8ML001cG100he`@0=mL203WG100ie`@04ML001cG00<0emL0>mL00`3Ge`0ee`040=OG03[G
00<0emL0>=L00`3Ge`0Be`007ML00`3Ge`0je`030=OG03GG00@0emL0>]L00`3Ge`0ie`030=OG017G
000Fe`@01=L00`3Ge`0ae`@01=L00`3Ge`0ee`040=OG03[G00<0emL0>]L00`3Ge`0@e`007mL00`3G
e`0he`030=OG03GG00@0emL0>]L00`3Ge`0ke`030=OG00oG000Le`040=OG03SG0`0ge`040=OG03SG
0`0je`040=OG017G000Ce`@01]L203_G00<0emL0=]L203_G00<0emL0>ML201;G000Ee`030=OG0?oG
2ML001GG00<0emL00mOc01;G000=e`@01=L00`3Ge`03e`<02ML00`3Ge`09e`030=OG00WG00<0emL0
2ML00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00[G00<0emL02ML00`3Ge`09e`03
0=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00[G00<0emL0
2ML00`3Ge`07e`<04]L001GG00<0emL00mL00`3Ge`0204GG6`0Xea/0A]L200;G00<0emL04=L001?G
0`05e`040=OGedH001^208:]PP22[H80PZf208:]PP28[HP0R:f808P0:0006jd0[HR]0:f8[@2]R:d0
[H:]0:f2[@2]PZd0[@1600CG00<0emL04=L001GG00<0emL00mL0kP3GemL0NjIk07^VN`1kYG/0NjEk
07^UN`1kYG/0NjEk07^UN`1kYG/0NjEk07^UN`1kY@2VNjH0YW^V0:IkYP2VPJH0YX:V0:J2YP2VPZH0
[8:/0:b2[02]PZd0[H:]0:f2[@2]PZd0[H:]0:f2[@29PXT0RH:908V2R@29PXT0RH80PXV208:9PP22
RH80PXV208:9PP22[H80PZf208:/PP22[880PZb208:/PP22YX80PJJ1086VP@21YX40PJJ107^UN`1k
YG/0NjEk07^U0:EkY@2UNjD0YG^U0:EkY@2UNjEk07^UN`1kYP04e`030=OG013G000Ke`040=OGenX0
1=L00`3Ge`0@e`006mL01`3GemL0NjH03`00ajEk07^UN`1kYG/0NjEk07^UN`1kYG/0NjD0YW^V0:Ik
YP2VPJH0YX6V0:J1YP2VPZH0YX:V0:b2[02/PZ`0[8:/0:f2[@2]PZd0[H:]0:f8[@2]R:d0[HR]0:f8
[@29R8T0RH:908V2R@29PP22RH80PXV208:9PP22RH80PXV208:9PP22RH80PZb208:/PP22YX80PZJ2
08:VPP21YX40PJJ1086VP@1kYW/0NjIk07^UN`1kYG/0NjEk07^UN`1kYG/0NjD03`000jH0e`03e`03
0=OG013G000Ke`040=OGe`<000nV0:J1YP2VP@21YX40YJH0F`004:f908V]R@29[HT0RJd0[HUL000?
YP2VPJH0YX6V0:JUYP2V00801=L00`3Ge`0@e`006mL01`3GemL0NjH07P00C7^U0:EkY@2VNjH0YW^V
0:J1YP2VPJH0YX6V0:J1YP2VPZH0[8:/0:b2[02/PZ`0[8:/0:f2[@2]R:d0[HR]0:f8[@2]R:d0[HR]
0:d@000NPP22RH80PXV208:9PP22RH80PXV208:9PP22RH800h801@22PX8000>202<0PZJ208:VPP21
YX40PJJ1086VP@1kYW/0NjIk07^VN`1kY@0O0003YP3G00?G00<0emL04=L001_G00@0emOG0`007ZH0
YX40PJJ1086VP@21YX40YJJU0:FVY@2UYZD0YC`002:][029[HT0RJf908V]R@29[HT0RJf908V]R@29
[@2]RJd00hT02`29RHT0RH>908V303`001nV0:IkYP2VNjH0YW^V0:J1YP2VPJH0YZFV0:JUYP2V00<0
0mL00`3Ge`0@e`006mL01`3GemL0Nh809P00=86V0:J1YP2VPJH0YX6V0:J1YP2VPZH0[8:/0:b2[02/
PZ`0[8:/0:b2[02]R:d0[HR]0:d`000>PP22RH80PX>208:3PP03PP0508:2PP000h801@22PX8000>2
01<0PX:2086VP@1kYW/0NjIk07^V02L000>VP@000mL00`3Ge`0@e`006mL0103GemL3000VYP2VP@21
YX40PJJ1086VP@2UYZD0YJJU0:FVY@2UYZD0YJJU0:D]000:[:d0[Jb]0:f/00>]01P0[Jf]08V]R@29
[HT0RJf908V]R@29[@03R@0G08V9R@29PhT0RH>908V3R@29PXT0RH80;0009jH0YX6V0:J1YP2VPJH0
YX6V0:J1YP2VPJH0YX6V0:JUYP2VYJH0[00300?G00<0emL04=L001_G00@0emOG;@00886V0:J1YP2V
PJJ10:FVY@2V[:H0YZbV0:J/YP2V[:H00j`01P2/[:`0[3l000IN08:3PP02PP0308:200:200D0PX:2
0003PP0508:2PP000h802`1kPW/0Nh9k07^202h00mL00`3Ge`0@e`006mL0<@3GemL0YW^V0:Ik086V
P@21YX40PJJ10:FVY@2UYZD0YJJU0:FVY@2UYZD0YJJU0:D08@00:Zb]0:f/[@2][:d0[Jb]0;>/0:fc
[@2]/jd0RJf908V]R@29[HT0RJf900:90280RHV908V3R@29PhT0RH>908V3R@29PXT0RH80PXV208:9
8@00;ZH0YX6V0:J1YP2VPJH0YX6V0:J1YP2VPJH0YX6V0:JUYP2VYJH0YZFV0:bU[003e`030=OG013G
000Ke`040=OGebd001b1YP2VYJJU0:FVY@2U[:D0YZbV0:J/YP2V[:H00j`00`2/000G000O[@2]R:d0
[HR]08V8R@29R8T0RH80PXV208:9PP1NR@0G0006PP22GX800h800`22PP02PP0C07b2O01lPW`0Nh9k
07^2N`1kPP0^00?G00<0emL04=L001_G0340emOG089kPP2VN`21YX40PJJ1086VP@2UYZD0YJJU0:FV
Y@2UYZD0YJJU0:F/Y@2U01d001b/[@2][:d0[Jb]0:f/[@2c[;<0/jbc0;>]/`2c7`006hT0RH<0PXV2
08:9PP22Ph80PX>208:3PP22P`0M000^YP2VPJH0YX6V0:J1YP2VPJH0YX6V0:J1YP2VPJH0YZFV0:JU
YP2VYJH0[:F/00?G00<0emL04=L001_G00@0emOG;P007:H0YZFVY@2U[:D0YJbU0:J/YP2V[:H0YZbV
0:`H000V[HP0R:d0[HR]0:f8[@29R8T0RHR908V208:9PP1NREh0GXUN05hH000MPP22F880PUR2089l
PP22O89l07^2N`1kPW/0Nh80;P03e`030=OG013G000Ke`0b0=OGe`22N`1kYW/0PJJ1086VP@21YX40
YJJU0:FVY@2UYZD0YJJU0:FVY@2U[:D0YJ`L000H[=40dJcA0=N/e`3G[=L0/jbc0;>//`2c9P0065l0
GXUN05j3GP1NPeh0GX=N08:3PP22Pad002f20:J1YP2VPJH0YX6V0:J1YP2VPJH0YX6V0:J1YP2VYJH0
YZFV0:bU[02/Y@001=L00`3Ge`0@e`006mL0103GemL^000GYZD0YJbU0:F/Y@2U[:D0YZbV0:J/YP00
0j`00`2/000?000f[J`0[:f/0:b][028[HP0R:d0[HR]08V8R@29R8T0RH80GXUN05j9GP1NR@23GX<0
Pej308=N40007H80PUR2089HPP22F880PWb2089kPW/0Nh9k07^202d01=L00`3Ge`0@e`006mL0<P3G
emL0PW/0NjIk07^VN`21YX40PJJ10:FVY@2UYZD0YJJU0:FVY@2U[:D0YJbU0:J/60005:c@0=6/d@3G
[=L0ejcG0=N/e`3G=P0055h0GX=N05j3GP1NPeh0GX=N08:36@00;H80PWb20:IkYP2VPJH0YX6V0:J1
YP2VPJH0YZFV0:JUYP2VYJH0[:F/0=2U0004e`030=OG013G000Ke`040=OGebh001>VY@2U[:D0YJbU
0:F/Y@2V[:H000>/00<0[0004`006Zf/0:b][02/[J`0[:f/08R]0:f8[@2]R:d00hT06@29PP1NREh0
GXUN05j308=NP`23GX<0Peh050006H80PUR2089HPP22F880PW^2N`1kPW/0Nh80;@04e`030=OG013G
000Ke`0b0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:FVY@2UYZD0YJbU0:F/Y@2U[:D0YZ`H000D
[=00d:c@0=N/e`3G[=L0ejcG0=L@000=[@29/hT0RJf908V]0003R@0708V3R@29P`0?000DGP1NPeh0
GX=N05j3GP1NPeh0F88I000]PP22O880YW^V0:IkYP2VPJH0YX6V0:J1YP2VYJH0YZFV0:JUYP2/YJ`0
d:D000CG00<0emL04=L001_G00@0emOG;P006:bU0:F/Y@2U[:D0YJbU0:F/Y@2/d:`0[1400Z`04@2c
[02//j`0[;>/0:bc[02801L001=N05j305mNG`1OGUl0GeQO05mH010001UN089HPP22F880PUR2089G
PP22Nh9k07^202d01=L00`3Ge`0@e`006mL0<P3GemL0PW/0Nh9k07^VN`21YX40PJJ10:FVY@2UYZD0
YJJU0:F/Y@2U[:D0YJbU0:K@6@004=00eZcF[02/ej`0[=N/0:`?000A[K<0/jd0RK>908VcR@29[@00
0hT02P29PhT0REl0GhT@000@GP1HPeP0F8=H05R3F01HPQT002f2089lPP22Nh80YW^V0:J1YP2VPJH0
YX6V0:JUYP2VYJH0YZFV0:bU[03@Y@001=L00`3Ge`0@e`006mL0103GemL^000I[:D0YJbU0:F/Y@2U
[:D0Zm2[0:c@[=00d00@000?[=H0/Z`0[;>/0:bc[02/01h0011O05mNG`1OF5l0GeQO05iH40006Eh0
GUQN089HPP22F880PUN2089GPUL0Nh80;@04e`030=OG013G000Ke`0b0=OGe`22N`1kPW/0NjIk086V
P@21YX40YJJU0:FVY@2UYZD0YJbU0:F/Y@2Ud:G@0=0I000@eZ`0[=J/0:cF[02/ej`0[0`0017G0;>]
/`2c[K<0/jd0RK>90002R@0B08V9R@29GhT0REl0Gh=O05j3300045P0F5l0GeQO089HPUP0F88I000]
PP22O880PWb20:IkYP2VPJH0YX6V0:J1YP2VYJH0YZFV0:bU[02/YJ`0d:D000CG00<0emL04=L001_G
00@0emOG;P006JbU0:F/Y@2U[:D0YM2U0:_@Zm00d:_@0=0030004:cF0=J/eP3F[=H0/jbc0;<U000?
G`1OF01HGeP0F5iH05QN00d000=H05P00UP0501HF5P0O5Ml07aGO022Eh9G05N2;@04e`030=OG013G
000Ke`0b0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:FVY@2U[:D0YJbU0:F/Y@2Ud:G@0=0E000@
d:`0[=J/0:cF[02/eZ`0[100017G0;>]/`2c[K<0/jd0RK>90002R@0<08V9R@29GhT0REl00el00`1N
G`0?000@G`1OF5l0GUQN05iHGP22F1H002f2089lPP22O880YW^V0:J1YP2VPJH0YX6V0:JUYP2VYJH0
[:F/0:bU[03@Y@001=L00`3Ge`0@e`006mL0103GemL^000E[:D0YJbU0:G@Y@2[d:/0Zm2[d03@0100
012/eP3F[=H0eZcF0=J/eP2c9@003el0Gc@0=5hd03AH=00dF00@009H01<0F5QH05QGF01lEg`0O5Ml
089G02h01=L00`3Ge`0@e`002=L200CG00<0emL00]L300GG0380emOG089k07^2N`1kYW/0PJJ1086V
P@2UYZD0YJJU0:F/Y@2U[:D0YJbU0:G@YM00d1D0013@[02/eZ`0d=K@0=3Fd03@30005MNb0;;G0=Nb
e`2c[K<0/jd0RK>90002R@0<08V9R@29G`1OREl00el01P1NG`1OF0`0011O05iHGP1NF5h0GUQN05iH
5@00;Wb2089lPP22O880PW^20:J1YP2VPJH0YX6V0:JUYP2VYJH0[:F/0:bU[03@Y@04e`030=OG013G
0007e`040=OG00_G00<0emL00]L0103GemL^000E[:D0YM2U0:G@Y@2[d:_@0=2[d03@010000b/eP3F
[=H0eZcF0=H/000<=00dF3@0=5Pd03AH40005EP0EeQGF01HEeP0O5Ml07aGO01lE`0^00CG00<0emL0
4=L000OG00@0emL02mL00`3Ge`02e`800]L0;P22N`1kPW/0NjIk086VP@21YX40YJJU0:FVY@2U[:D0
YJbU0:G@Y@2Ud:G@0=0E000@e]00d=K@0=3Fd03@e]00d0`000[G/P2bek80/]L00k<0202c[@29/hT0
0XT02029IHT0REl00el02P1OGel0F5l0Gc@<0006F01H=5P00eP01@1HF5P0009H5@00;Wb2089lPP22
O880PW^20:IkYP2VPJH0YX6VP@2UYP2VYJH0[:F/0:bU[03@Y@04e`030=OG013G00000mL0000200;G
00@0emL02=L300GG00@0emOG;P005JbU0:G@Y@2Ud:D0Zm2[d03@Zm00d00A000;eP3F[=H0eZcF0=H0
3`001[<0[HV]00:900H0GhUO05l?000<=00dF3@0=5Pd03AH40005EL0EeQGF01HEeP0F5MH07aGO01l
E`0^00CG00<0emL04=L000OG00@0emL02=L00`3Ge`05e`0b0=OGe`22N`1kPW/0NjIk086VP@21YX40
YJJU0:FVY@2U[:D0YJbU0:G@Y@2Ud:G@0=0E000Ae]00d=K@0=3Fd03@e]3F0=H02`002]Nb0;;G/P2b
e`03/`030;<000d000=O05l00Ul02P0jG`1O=5l0Gc@<000:F01H=5P0F3AH00=H00<0F5P05@00;UR2
089lPP22O880PW^20:IkYP2VPJH0YX6VP@2UYP2VYJH0[:F/0:bU[03@Y@04e`030=OG013G0007e`04
0=OG00SG00<0emL01ML0103GemL^000Ed:D0YM2U0:_@Zm00d:_@0=2[d03@014000_F[02/eZ`0[=H0
eP0?0006/`2cRK<00XT01P1OREl0G`l000<d03@00S@01@0d=3@0008d40005Bd0EeQG05MHEeP0F5MH
07aGO01lE`0^00CG00<0emL04=L000SG0P09e`@01=L0<P3GemL0PW/0Nh9k07^VN`21YX40PJJ10:FV
Y@2UYZD0YJbU0:F/Y@2Ud:G@0=2Ud03@5@004MK@0=3Fd03@e]3F0=K@eP3F00`000kF0;;G/P2bek80
/mL0/`h000mO03]O>`0dG`1O=5l0FC@03@003CAH=5P0F3AH05PdF0000UPE000^F01lPWb2089lPP22
Nh80YW^V0:J1YP2VPJJ10:FV0:JUYP2/YJ`0d:G@0=2U00CG00<0emL04=L001_G00@0emOG;P005M2U
0:G@Y@2[d:_@0=2[d03@Zm00d00A000<eZ/0ZmJ[0:cF[02/3P001[>808Vc00:900H0GXUN05h?000;
=00^=00d;S@0=2h04@005Bd0;EP]05MHEeP0F5MH05QGF01lE`0^00CG00<0emL04=L001_G0380emOG
089k07^2N`1kYW/0PJJ1086VP@2UYZD0YJbU0:F/Y@2U[:D0YM2Ud03@YM00d1X000c@eP3Fd=H0e]3F
0=H<000>eP3FemH0/]Nb0;;G0=L>000?D@0dG`1O=5l0=C@e03Dd00/000d^02iH;P0dF3AH05Pd01T0
02iH07b2O880PW^2089kPP2VNjH0YX6V0:J1YX40YJJU0:FV0:bU[03@YM00d:D01=L00`3Ge`0@e`00
6mL0103GemL^000Jd:D0YM2U0:_@Zm00d:_@0=2[d03@Zm2[0:/<000<eZ/0ZmJ[0:_FZ`2/5002eaH0
00Xd2S@0=2hd03@]3@006Bd0;EP]02eH;@1AF540EeQGF01HEeP0O5L0;P04e`030=OG013G000Ke`0b
0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:F/Y@2U[:D0YM2U0:G@YM00d:_@0=0J000<cmH0e/oF
0=K?eP3F3002eP0;0=KF0;;G/P2/e`004=L03@1GF00d;S@0=C@e03@0300032h0;S@^02iH;P0^F1X0
02iG05N2Eh80PW^2089kPP22Nh80YX6V0:J1YX40PJJ10:FV0:bU[03@YM00d:D01=L00`3Ge`0@e`00
6mL0103GemLc000EYM00d:_@0=2[d03@Zm00d:_@Z`3?010000SFc`3?e/l0Z`d04=L=0008=00d2C@0
=0T@000F=01H;EP]02eH;@0]F2d0DEQAF01HEc801=L00`3Ge`0@e`006mL0=`3GemL0PW/0Nh9k07^V
N`21YX40PJJ10:FVY@2U[:D0YJbU0:G@Y@2Ud:G@0=2[d03@Zm00d:/05@004<oF0=K?eP3FcmH0e/oF
0=H<0006eP2bek805]L01P1H;EP0=0`0010^02hd;P0^=2h0;C@]02eH5P00<UL0EgaG05N2Eh80PW^2
089kPP22Nh80YX6V0:J1YX40PJJ10:FV0:bU[03@YM00d:D01=L00`3Ge`0@e`006mL0103GemLc000E
YM00d:_@0=2[d03@Zm2[0<o@c`3?010000cFc`3?e/l0cmK?0;8601KG1P0032L0;PT^02h9;P0^2A00
01H^05P]F2d0;EP]02eH;@1AF55H05QG<P04e`030=OG013G000Ke`0g0=OGe`22N`1kPW/0NjIk086V
P@21YX40YJJU0:F/Y@2U[:D0YM2U0:G@YM00d:_@0=2[d03@Z`0I000<cmH0e/oF0=K?eP3F3`0Me`h0
00`902d^;@0]=2d0;C@J000bE`1GO5L0EgaGO022Nh80PW^2089kPP2VPJH0YX6VP@21YX40YJH0[:F/
0=2Ud03@Y@04e`030=OG013G000Ke`040=OGec<001V[d03@Zm00d:_@0=2[d:/0cm3?0<o@c`3?0140
00K?0<oFc`03[0030=OG01_G00X0DEP02P<:00X940006Rh0;Rd^02h];Rd0;EP]02eH;@1AF55H05QA
<P04e`030=OG013G000Ke`0g0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:F/Y@2U[:D0YM2U0:G@
YM00d:_@0=2[d03@c`0J000@eP3FcmK?0<oFc`3?e/l0e@X07ML:000@2@09;PT02Bh902d^;@0]=1X0
039G05MlE`1GO5Ml089kPP22Nh80PW^20:J1YP2VPJJ1086VP@2UYP2/YJ`0d:G@0=2U00CG00<0emL0
4=L001_G00@0emOG=`004:_@0=2[d03@Zm2[0<o@c`03c`030<oE010000K?0<oFc`0Te`0700<20`0:
0`0@000E;P0^;Bh0;Rd^05P]F2d0;EP]02eH03L01=L00`3Ge`0@e`006mL0>`3GemL0PW/0Nh9k07^V
N`21YX40PJJ10:FVY@2U[:D0YJbU0:G@Y@2Ud:G@0=2[d03@Zm00d<o@c`3?01X000cFc`3?e/l0cmK?
0=D602CG20002bh9;P0^2Bh900T^01T003MH05QGF5L0EgaG05MlEg`0PW^2089kPP22Nh80YX6V0:J1
YX40PJH0YZFV0:bU[03@YM00d:D000CG00<0emL04=L001_G00@0emOG=`002:_@0=2[d:/00ll01@3?
cll000??00<0cll00/l00`3E000A02CG4`001Rd0;@T]00<]0100;Rd^058]DRd0;EP]02eH=`04e`03
0=OG013G000Ke`0k0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:F/Y@2U[:D0YM2Ud03@YM00d:_@
0=2[d:/0cm3?0<l07P002mK?0<oEc`3?eLl000:/00<0emL08]L03P1kPP090`T02P<:02h97P00=eP0
F5MHE`1GO5L0EgaG05N2Eh80PW^2089kPP2VNjH0YX6VP@21YP2VYJH0[:F/0=2Ud03@Y@001=L00`3G
e`0@e`006mL0103GemLl0003cj/000??00D0clo?0004c`0:0<o?c`3EcmD0e@h09=L>000;0`03;@<0
0bd3;@000bd01@0];Bd000@]00<0;EP0>`04e`030=OG013G000Ke`100=OGe`22N`1kPW/0NjIk086V
P@21YX40YJJU0:F/Y@2U[:D0YM2Ud03@YM00d:_@0=2[d:/0cm3?0<o@c`3?d1d000OEc`3?eLl002[G
00L00`8300T301h003]H05QAF01HEeQG05MlE`1GO5L0Eh9GPP22Nh80PW^20:IkYP2VPJH0YX6V0:JU
YP2/YJ`0d:G@0=2U0004e`030=OG013G000Ke`040=OGed000/l01@3?cll000C?00D0clo?0003c`06
0=G?e@3E1`0Ze`L001<300<90`032@<00bd3;@0]2Bd000<]00<0;Bd0@004e`030=OG013G000Ke`14
0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:F/Y@2U[:D0YM2Ud03@YM00d:_@0=2[d:/0cm3?0<o@
c`3?d<o@0=0P02[G8000@2eH05P]F01HDEP0F5MHE`1GO5L0EgaG05MlEg`0PW^2089kPP2VNjH0YX6V
0:J1YP2VYJH0[:F/0=2Ud03@Y@04e`030=OG013G000Ke`040=OGed@00/l00`3?c`02c`050<o?c`00
0ll03@3?c/l0eLkE0=K?eP00:]L02@0];Bd00P<200030`0>00<90`03;@<]02d3;@02;D@01=L00`3G
e`0@e`006mL0B03GemL0PW/0Nh9k07^VN`21YX40PJJ10:FVY@2U[:D0YJbU0:G@YM00d:G@0=2[d03@
Zm2[0<o@c`3?d<l0cm3?d03@cm00eA`0:]LL0014;@0]DReB05P]F01HDEP0F55HD@1GO5L0EgaG05Ml
Eg`0PW^2089kPP2VNjH0YX6V0:J1YP2VYJH0[:F/0=2Ud03@Y@04e`030=OG013G000Ke`040=OGedd0
0/l04@3?c/l0clk?0<o>c`3@Zm0002[G00d0;EL]00830P020`8000<300<00bd0C@04e`030=OG013G
000Ke`1A0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:F/Y@2U[:D0YM2Ud03@YM00d:_@0=3?d<l0
cm3?0<o@c`3?d<o@0=3?d03EcmG?0<oEc`3?01<04=L;00oG4`000bd0;@03;@1702d];@0]DRd0;EP]
F01HDEP0F55HD@1GF5L0EgaG05MlEg`0PW^2089kPP2VNjH0YX6V0:J1YP2VYJH0[:F/0=2Ud03@Y@00
1=L00`3Ge`0@e`006mL0103GemMP013G2`0?ef001=L00`3Ge`0@e`005=L200GG04<0emOG089k07^2
N`1kYW/0PJJ1086VP@2UYZD0YJbU0:F/Y@2Ud:G@0=2Ud03@Zm00d<o@c`3?d<l0cm3?0<o@cm0000??
00<0cll00/l06@3?eLl0cmG?0<oEc`3>eLh0c]G>0:K@YP004=L010010003e`040::S00oG01X0PW^2
00<20`030P<0;@<]02d3;@0]9bdW00<]04<0;E4]02eH;EP0F55H05QAF540EeQG05MlE`1GO5Ml089k
PP22Nh80YW^V0:J1YP2VPJH0YZFV0:bU[03@YM00d:D000CG00<0emL04=L001?G00@0emL01=L0103G
emMP013G1003e`@03mMP00CG00<0emL04=L001?G00@0emL01=L200;G03l0PW/0Nh9k07^VN`21YX40
PJJ10:FVY@2U[:D0YJbU0:G@YM00d:G@0=2[d03@cm3?0<o@c`3?d<l0cm3?d0000ll00`3?c`02c`0I
0<o?c`3?eLl0cmG?0<kEcP3>eLh0YM2U000@e`04004000?G00@0XZ<03mL06P22Nh800`8300<20`0W
0bL0;@<]02dW;BL00bd0@`0]DBd0;EP]F01HDEP0F55HD@1GF5L0EgaG05MlEg`0PW^2089kPP2VNjH0
YX6V0:J1YP2VYJH0[:F/0=2Ud03@Y@001=L00`3Ge`0@e`004mL0103Ge`04e`040=OGef004=L400?G
100?ef001=L00`3Ge`0@e`004mL0103Ge`04e`0n0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:F/
Y@2U[:D0YM2Ud03@YM00d:_@0=3?d<l0cm3?0<o@c`04c`050<o?c`001<l01@3?cll000??0140c/o>
0<k?cP3>clh0YM2U000@e`04004000?G00@0XZ<03mL06P22Nh800`8300<20`0W0RL0;@<]02dW;BL0
0bd0@`0]DBd0;E4]D@1HDEP0F55HD@1GF5L0EgaG05MlEg`0PW^2089kPP2VNjH0YX6V0:J1YP2VYJH0
[:F/0=2Ud03@Y@001=L00`3Ge`0@e`004mL0103Ge`04e`040=OGef004=L;00oGH004e`030=OG013G
000De`801ML0?P3GemL0PW/0Nh9k07^VN`21YX40PJJ10:FVY@2U[:D0YJbU0:G@YM00d:G@0=2[d03@
cm3?0<o@c`3?d<l01<l01@3?cll000C?00D0clo?0002ca804=L;00oG4`001bd0;BL]9`000bd0@`0]
DBd0;E4]D@1HDEP0F55HD@1GF5L0EgaG05MlEg`0PW^2089kPP2VNjH0YX6V0:J1YP2VYJH0[:F/0=2U
d03@Y@001=L00`3Ge`0@e`006mL0103GemM>0006c`3?c/l00lh02@3>c/h0bJG9000Ze`0505MHE`00
0`802`020P800P<2008W04d01=L00`3Ge`0@e`006mL0?P3GemL0PW/0Nh9k07^VN`21YX40PJJ10:FV
Y@2U[:D0YJbU0:G@YM00d:G@0=2[d03@cm3?0<o@c`3?d<l01<l01@3?cll000;?6`0Zea/00Rd0@`0]
DBeA054]D@1HDEP0F55HD@1GF5L0EgaG05MlEg`0PW^2089kPP2VNjH0YX6V0:J1YP2VYJH0[:F/0=2U
d03@Y@001=L00`3Ge`0@e`006mL0103GemM5000?cP3>clk?0<o>c`3?c/l000?>00T0c/k>0<VTb@00
:]L01@0]Ebd000<201<00P8200830P029`8W02d2;@0]04D01=L00`3Ge`0@e`006mL0?P3GemL0PW/0
Nh9k07^VN`21YX40PJJ10:FVY@2U[:D0YJbU0:G@YM00d:G@0=2Ud03@Zm2[0<o@c`3?d<l01<l00`3?
c`0O02[G8000@2eA054]D@1GDEL0F55HD@1GO5L0EgaG05MlEg`0PW^2089kPP2VNjH0YX6V0:J1YP2V
YJH0[:F/0=2Ud03@Y@04e`030=OG013G000Ke`040=OGed4001W?0<k?cP3>clk?0<o>c`3?c/l0c/S>
0<k800H0:]L6008200D00P8200030P0@008W0RL0;@8]02dV;@0]9d001=L00`3Ge`0@e`006mL0?P3G
emL0PW/0Nh9k07^VN`21YX40PJJ10:FVY@2U[:D0YJbU0:G@YM00d:G@0=2Ud03@Zm2[0<o@c`3?d<l0
0/lN0006cP38clP0:]L01P0]0bd00Qh003`]D@1GDEL0F55HD@1GO5L0EgaG05MlEg`0PW^2089kPP2V
NjH0YX6V0:J1YP2VYJH0[:F/0=2Ud03@Y@04e`030=OG013G000Ke`040=OGec`001[?Y@39clT0b<o8
0<S?b<l0clS?0<k8cP3>b0d09=L=008201P00P82008W0RL0;@8]02dV;@0]9RdV02dl00CG00<0emL0
4=L001_G03X0emOG089k07^2N`1kYW/0PJJ1086VP@2UYZD0YJbU0:F/Y@2Ud:G@0=2Ud03@YM00d:_@
Z`3?d<l00/lN0003cP3>00;>00P0b<k807^U02CG00@0PJH00`801P020P809Qh003QAE`1HDEQA05Ml
E`1GO5L0EgaGO022Nh80PW^20:IkYP2VPJJ1086V0:JUYP2/YJ`0d:G@0=2U00CG00<0emL04=L001_G
00@0emOG>0006/l0cjG?Y@39clT0b<o80<S?b038clS?0<k84@0Tea8001T29P0W0RL0;BH]02dV;@0]
9RdV02eA;@0]03P01=L00`3Ge`0@e`006mL0>P3GemL0PW/0Nh9k07^VN`21YX40PJJ10:FVY@2U[:D0
YJbU0:G@Y@2Ud:G@0=2Ud03@Zm00d<o@c`02caX000K>0<k?cP03cP030<S>00D09=L600030P020082
00L09P8V0P0201X003MG05QAF540EgaG05MlEg`0O5Ml089kPP22Nh80YW^V0:J1YX40PJH0YZFV0:bU
[03@YM00d:D000CG00<0emL04=L001_G00@0emOG>0005Ll0cjG?0<o9clT0b<o80<S?b038c`0B0004
W/RN02CG00H0DBeA008@000F0RL0;BH]02dV;@1A9U4V02eA;@0]DCL01=L00`3Ge`0@e`006mL0=`3G
emL0PW/0Nh9k07^VN`21YX40PJJ10:FVY@2U[:D0YJbU0:G@Y@2Ud:G@0=2Ud03@YM00d<l06P004<l0
clk?cP3>clh0b<k80<P:01gG2@004081008V0P029P800RL202HJ000cF540EgaG05MlEg`0O7]l089k
PP22Nh80YW^V0:J1YX40PJJ10:FV0:bU[03@YM00d:D000CG00<0emL04=L001_G00@0emOG<`006ZG?
0<nUc`3?YLl0cjG?Y@38clP0b<o80<S?40002/L0alS707BNM00Me`09086V00810P02010001X29`0]
9Rd0;BH]9P0/DB`0;E4]02eA;E40Ec<01=L00`3Ge`0@e`006mL0=`3GemL0PW/0Nh9k07^VN`21YX40
PJJ10:FVY@2U[:D0YJbU0:G@Y@2Ud:G@0=2Ud03@YM00d<l06P003<l0clS?0<o8c`3>b0h07ML=000<
9P800RH202HW9P0V6P00<eQA05MlE`1GO5Ml07akO022Nh80PW^20:IkYP2VPJJ1086VP@2UYP2/YJ`0
d:G@0=2U0004e`030=OG013G000Ke`040=OGec<001JUc`3?YLl0cjG?0<nUcjD0b<o80<S?40003<P0
alS70<O8a`2MWPD05]L6000;F0020@800P4202H0400042H]02dV;BH0;54/02eA;@04D@0305L00380
1=L00`3Ge`0@e`006mL0=`3GemL0PW/0Nh9k07^VN`21YX40PJJ10:FVY@2U[:D0YJbU0:G@Y@2Ud:G@
0=2Ud03@YM00d:D05P004<l0clS?0<o8c`3?b<l0c/P=0004M9id01KG00H0YX6V02H;00039P8000<V
00X09RLV02H]9P0V5P00<eQA05MlE`1GO5Ml07akO022Nh80PW^20:IkYP2VPJJ1086VP@2UYP2/YJ`0
d:G@0=2U0004e`030=OG013G000Ke`040=OGec<001JUc`3?YLl0cjG?0<nUc`3?Y<nT0<S?40002<P0
alS70<O8300@e`d000LV02H19P0V014000l]054VDBH0;54/02eA;@0015400`1G000b00CG00<0emL0
4=L001_G03<0emOG089k07^2N`1kYW/0PJJ1086VP@2UYZD0YJbU0:F/Y@2Ud:D0YM2Ud03@YM00d:D0
6P003<l0clS?0<o8c`3?b0`000c80<S709g8W@1jW`0@e`0=086V051:D00V9BH09P0;008V00/09RdV
02H]9P0VD@0I000_O5L0EgaGO01lNg`0PW^2089kPP2VNjH0YX6VP@21YX40YJH0[:F/0=2Ud03@Y@00
1=L00`3Ge`0@e`006mL0103GemL_000JY@2UcjD0YLnUc`3?YLl0cjG?0<nTcj@0b<l<0003b03800;8
00L0alS70:?801<00]LD000;9P0V0BH09P4V02H03@006BdV02IA9P0/DB`0;E4]055GDEL0Ee5G07/0
;`04e`030=OG013G000Ke`0c0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:F/Y@2U[:D0YM2U0:G@
YM00d:G@0=2U01X000c?0<o8c`3?b<l0clP=000=alS709g8W@2MWP2NM00=0005P@1:D0000bD01P0V
9BH09P/00RH02`0V;BH09U4VD@1A01T002mlE`1GO5Ml089kPP22Nh80PW^20:J1YP2VPJJ1086VP@2U
YP2/YJ`0d:G@0=2U0004e`030=OG013G000Ke`040=OGebl001VU0:G?Y@2UcjG?0<nUc`3?YLl0cjC?
0<nT00d000^T0:C8Y02Sb:<0X`0?0005U`1]L`000W<01P1cLg<090h000/V0@019P0V9BH09P0=000;
DBH09U4V02aA;00015402P1GDEL0Ee5G07/_00CG00<0emL04=L001_G03<0emOG089k07^2N`1kYW/0
PJJ1086VP@2UYZD0YJJU0:F/Y@2U[:D0YM2Ud03@YM00d:D06@003LT0b<o8c`3?b<l0clP02`003LP0
alS709g8W@2M`P000Yd=000>B@0UBBD09DX09RDV02H<000<9P0VDBIA054VD@1A6P00;UL0NgakO022
Nh80PW^20:IkYP2VPJH0YX6VP@2UYP2VYJH0[:F/0=2Ud03@Y@04e`030=OG013G000Ke`040=OGebl0
01FU0:G?Y@2UcjG?0<nUc`3?YLl0cj@04@002j@0Y<RT0:?80<RS010000bGLiL0Lfd0BFe904T>0007
9RD09BHU00039P0302H000l000MA;00/DB`000AA00/0Ee5G05MAE`1kD@0^00CG00<0emL04=L000SG
0P04e`030=OG00;G0`05e`0c0=OGe`22N`1kPW/0NjIk086VP@21YX40YJJU0:FVY@2U[:D0YJbU0:G@
Y@2Ud:G@0=2U01D001790<W?b@38clP0b<o8c`3?b00;000>b02Mb9d0WLP0`Yg209d>000>B@0UBBD0
9DX0BRE:04X<000@9U00DBIA054VD@1A;540DAH002iGO01lNg`0PW^2089kPP2VNjH0YX6V0:J1YX40
YJH0YZFV0:bU[03@YM00d:D01=L00`3Ge`0@e`001mL0103Ge`0;e`030=OG00;G00@0emOG;`005JD0
YLnU0:G?Y@2UcjG?0<nUc`3?Y00B000:b:C80<RTb038W@h000jM09McU`1cK@19LdT0B@h000LV9@0U
9RD000<V00<09P003`00254/051AD5400e402`1GDEL0Ne5k07]G02h01=L00`3Ge`0@e`001mL0103G
e`0;e`030=OG00;G0P02e`0_089k07^2N`1kYW/0PJJ1086VP@2UYZD0YJJU0:F/Y@2U[:D0YM2U0:G@
YM00d:D05@004<T0bLo90<S?b038clP0b<l<000DY02Mb9d0WLP0`Yg209jM07>ML`02L`0D07=9L`1c
B@19BTT09DXU02E:04X<000@9U00DBIA054/D@1AD540DAH002iGO01lNg`0PW^2089kPP2VNjH0YX6V
0:J1YX40YJH0YZFV0:bU[02/YJ`0d:D01=L00`3Ge`0@e`001mL0103Ge`08e`<01ML0103GemL_000E
Y@2UcjD0YLnU0:G?YLl0cjG?0<nT010000c80<RTb038Y<P0b9dZ000<BRD09DXU02I:9P0V4@005E00
D55@D@1GDEL0Ee5G07]AN`1kE`0^00CG00<0emL04=L000OG00@0emL02=L00`3Ge`05e`0c0=OGe`22
N`1kPW/0NjIk086VP@21YX40YJJU0:FVY@2U[:D0YJbU0:G@Y@2Ud:G@0=2U01D001390<W?b@38clP0
b<o80<S93000:Z@0W/P0b9g809jMWP2NW@1cWW<0Lg@0M6ed07A904U@B@19BTT0BDX0D0`0014VD01A
9U40DE1A055@D@1GD@0E000^Ng`0O7]l089kPP22Nh80YW^V0:J1YP2VPJH0YZFV0:JUYP2/YJ`0[:F/
0=2U00CG00<0emL04=L000OG00@0emL02=L00`3Ge`05e`040=OGebl001FU0:G?Y@2UcjD0YLnU0:G?
YLl0bJ@040003lP0b:C80<RNb038WLP0b00T000?9DX0BRD09DXU02I@9P0V014001E@D@1AD540Ee5G
07]AN`1kDG/0NeL0;P04e`030=OG013G0008e`802ML400CG01P0emOG089k07^2N`1kYW/0PJJ108:V
PP03YP0H0:FVY@2U[:D0YJbU0:F/Y@2Ud:G@0=2U5@004:D0YLnU0<S?b038clP0b<T?000Tb038WLP0
WYfN09jG07>NL`1cM01dLg@0M4Ud07A904U@B@193`004DYA055@D@1AD540DE1A05MA01D001]kO022
Nh80PW^2089kPP2VNjH0YX6V0:J1YP000jH0402VYJH0[:F/0:bU[03@Y@04e`030=OG013G000Ke`04
0=OGebl000>U0:D00ZD0502UbJD0YLVU0:G9YLT0bJC90<VT30003lP0b:C80<RNb038WLP0Y00T000?
9DX0BRD09E0U02I@9P0V00d001U@D@1AD540Ee1G05MAE`1kDG/0NeMkE`1G02h01=L00`3Ge`0@e`00
6mL0603GemL0PW/0Nh9k07^VN`22YX80PZJ200>V01P0YZJV0:F/Y@2U[:D0YJbU0:G@YM00d:DI000@
Y@2Tcj@0Y<VT0:C9Y02Tb@/002C80:BNY02NWIh0WYL0Liic07=d07AcM01dBG@0M4T0BE1904T<000@
D4X0D540DE1A055@DE00D1T001]kO022Nh80PW^20:IkYP2VPJH0YX6V0:J2YP000jH0402VYZH0[:F/
0:bU[03@Y@04e`030=OG013G000Ke`040=OGebl000>U0:D00ZD0502UYJD0YLVU0:G9Y@2UbJG90<VT
40003lP0b9h0WZBN09fNW@2MWP0L000@BE00D4U@0519D01@BU00D10001U@D@1AD540Ee5G07]AN`1k
DG/0NeMkE`1G02h01=L00`3Ge`0@e`006mL0603GemL0PW/0Nh9k086VP@22YX80PZJ200>V01L0YZJV
0:F/Y@2U[:D0YJbU0:G@Y@2Ud00K000?bJG9Y@2TbJ@0Y<VT0:C900l001bN09jM09NNU`1cWW<0LiP0
M7=d07AcM01dB@194002D00>051AD01@DE00D7E@054I000KNh80PW^2089kPP2VNjH0YX6V0:J2YP2V
PZH000>V0100YZJV0:bV[02/YJ`0d:D01=L00`3Ge`0@e`006mL0103GemL^0003YZD000>U00D0YJFU
0003Y@0;0:G9Y@2UbJD0Y<T04@004/P0Y9h0WZBN09fNW@2MWYd0UaH001=dB@19D01@BE00D4U@051:
D01@010001U@D@1GD5L0Ne5k07]AN`1kEg/0NeMkE`1k02h01=L00`3Ge`0@e`006mL0603GemL0PW/0
Nh9k086VP@22YX80PZJ200>V01L0YZJV0:J/YP2U[:D0YJbU0:F/Y@2Ud00I000Db@39YLT0bJC90<VT
b@39Y<T0b9h?000FWP2GWYL0Liic07>N07AcM01dLg@0M0l00U004P1@D500D7E@051eD01@Ne00DAT0
01]kPP22Nh80PW^20:IkYP2VPJH0YX:V0:J2YP000jH0402VYZH0[:J/0:bU[03@Y@04e`030=OG013G
000Ke`040=OGebh000NVY@2UYZD000>U00D0YJFU0003Y@070:G9Y@2Tb@0D000dWP2NY9h0WIjM09fN
W@1cWP2NLih0WW>N07AcM01dL`19M4T0BGA904Ud0519D01@BE00D1@001A@D@1kD7/0Ne5k07]AN`1k
Eg]G00=k00<0N`00;@04e`030=OG013G000Ke`0H0=OGe`22N`1kPW/0PZJ208:VPP22YX800jH05`2V
YZH0YZbV0:J/YP2U[:D0YJbU0:F/01T001C90<VUb@39Y<T0bJC90<VTb@38WS@001AdD01@M500D7E@
051kD01@Ne00DAT001]kPP22Nh80YW^V0:J1YP2VPZH0YX:V0:J2YP000jH0402/YZ`0[:J/0:bU[03@
Y@04e`030=OG013G000Ke`040=OGebh000NVY@2UYZD000>U00D0YJFU0003Y@0;0:FUY@2TYJ@0Y:D0
40000ih0WP02WP0_09jNWP2MWYd0Lih0WW>N09icWP1dLg@0M7<0CgA?04UdB@19M01dBG@0M4Yd07@0
40004e1e07]@N`1kD7/0Ne5k07]GN`0017/01P1kNg/0Nbh01=L00`3Ge`0@e`006mL0603GemL0PW/0
NjIk08:VPP22YX80PZJ200>V01L0YZJV0:J/YP2V[:H0YJbU0:F/Y@2U[00M000Hb@39Y<T0bJC90<VN
b@39W/T0Y9jT0:BN9@005e00D7A@051dD01@ME00D7]@051kD01@01d001]kPP22Nh80YW^V0:J2YP2V
PZH0YX:V0:J2YP000jH0402/YZ`0[:J/0:bV[03@Y@04e`030=OG013G000Ke`040=OGebh000NV0:JU
YZD000>U00D0YJFU0003Y@0?0:FUY@2TYJ@0Y:FT09jU01@002FN07VN09icWP2NLih0WW>N07AcM01d
L`1cM7<0CgA?04mdC`1?01<001=@M@1kD7/0Ne1k07]@N`1kEg/000Ak00D0Ng]k0003N`0307/002h0
0mL00`3Ge`0@e`006mL0603GemL0PW^20:Ik08:VPP22YX80PZJ200>V01L0YZbV0:J/YP2V[:H0YZbV
0:F/Y@2U[00Q000Bb@39Y<T0bIk90:FNY@2TWZ@00ih00`2N000M009d01D0M500D7A@051dD01@Ne00
D7]@07@08@00;g^20:IkYP2VPJH0YX:V0:J2YP2VPZH0YX:V0:J2YP2/YZ`0[:J/0:bV[02/YJ`000?G
00<0emL04=L001_G00@0emOG;P002jH0YZFVY@2UYZD000>U00D0YJFU0003Y@0;0:FUY@2NYIh0WZD0
5`007Yh0WW>N09icWP2NLih0M7=d07Ac07=dL`1?M4l0CaL0011@N`1kD7/0Ne1k07]ANe400g/01@1k
Ng/000=k00H0Nh9k07/_00?G00<0emL04=L001_G01P0emOG089kPP2VPP22YX80PZJ208:VPP03YP0G
0:J/YP2V[:H0YZbV0:J/YP2V[:H0YJ`08@004JD0YIjU0:FNY@2UWZD0Y9h000>N00D0WYjN0003WP0@
07BNM01dWW@0M9id07Aj00=d00D0M7Ad0003M00507AdM0000g@03@1jM7X0Ng@0M7]d07@08@00;g^V
0:J1YP2VPZH0YX:V0:J2YP2VPZH0YX:V0:J2YP2/YZ`0[:J/0:bV[02/YJ`000?G00<0emL04=L001_G
00@0emOG;P002jH0YZFV0:JUYZD000>U00D0YJFU0003Y@0C09nUW`2NYIh0WZFN09jUWP2NY00m000C
M500D7Y@051k07]@Ne00M7]d0003N`0507]kN`000g/02P1kPG/0Nh9k07/_00?G00<0emL04=L001_G
02h0emOG0:IkYP2VPP22YX80PZJ208:VPP2V[:H0YZbV0:J/YP2V[:H0YZbV0:J/;@002JD0YIjU0:FN
0003WP0a09jNWP1jWWX0M9id07BNM01dWW@0M9h0NWAj07YdNP1jM7X0NWAj07YdNP1kM7/0N`0/000/
PJH0YX:V0:J2YP2VPZH0YX:V0:J2YP2VPZH0[:J/0:bV[02/YZ`0[:J/0=L400;G0`0<e`006mL0103G
emLZ000>YP2VPJH0YX6V0:J1YP03Y@0M0:FUY@2UWjD0YInU0:FNY@2UWZD0YIjU0:FNY@000ih00`2N
NP0^000KM500D7A@051jD01dNg@0M7]d07AkM01jNgX000=k00D0Ng]k0003N`0>07^1N`1kPW/0Nh9k
07/[0004e`3G00KG00<0emL02ML001_G00@0emOG0P0097^V0:J208:VPP22YX80PZJ20:J/YP2V[:H0
YZbV0:J/YP2V[3P000>N09h00Yh0:@2NWYh0NYij07BNM01dWW@0M9id07BN07YdNP1jM7X0NWAj07Yd
NP1j03P002F2YP2VPZH0YX:V0:J2YP2VPZH0YX:V0:b2[02/YZ`0[:J/0:bV00<000CG003G0`02e`03
0=OG00WG000Ke`060=OGe`1k9000B:H0YX6V0:J1YP2VPJH0YX6V0:J1YP2UNjD0YG^U0:EkY@2UNZD0
YGZU0:EjY@2ONYl0WWZN09ijWP2NNYh0WWBN09idWP2NL`h000MdL`1cM7<000=d00D0M7Ad0003M00I
07AjM01dNW@0M7]d07AkM01jNgX0NW]j0003N`0J07]kN`1kPG/0NjIk07^VN`1kYW/0PJJ1084V00CG
00@0emOG0`0<e`006mL0103GemL2000EPJH0YX:V0:J208:VPP22[880YZbV05L000id07BNM01dWW@0
M9h0WUP001B2YP2VPZH0YX:V0:bV[02/YZ`0[0@00]L30003e`0000;G00<0emL00]L300?G000Ke`06
0=OGe`1k5@00K880PZJ208:VPP22YX80PJJ1086V0:J1YP2VPJH0YX6V0:IkYP2UNjD0YG^U0:EkY@2U
NjD0YGZU09mjW`2ONYl0WWZN09ijWP2NNYh0WWBN09idWP2NLih0NW=j07YcNP1jLgX0M7<0LgAc00=d
01d0M7Yd07AjM01dNW@0M7Yd07AkM01jNgX0NW]j0003N`0^07^ON`1kYG/0NjEk07^VN`1kYW/0PJJ1
086VP@21YX40PJJ108:VPP22YX80PQ@000JV0=OG0=L500?G00<0emL01ML1007G0ML001_G00@0emOG
jP02e`D000?G00000P000mL0e`05e`400ML1e`006mL0kP3GemL0NjIk086VP@21YX40PJJ108:VPP22
YX80PZJ208:VPP22YX80PZJ2086VP@21YP2VPJH0YX6V0:IkYP2UNjD0YG^U0:EkY@2UNjD0WgZO09mj
W`2ONYl0WWZN09ijWP2NM9h0WWBN09idWP2NM9h0NW=j07YcNP1jLgX0NW<0M7Yd07AjM01dNW@0M7Yd
07AjM01dNW@0NW]j07ZONP1jWgX0Nimk07^UN`1kYG/0NjEk07^VN`21YX40PJJ1086VP@21YX40PZJ2
08:V0:J2YP2VPZH0YX:V0:J2YP2VPZJ2086VP@21YP02e`030=L000801]L0103GemL300?G000Ke`04
0=OGed40026VN`1kYG/0NjEk07^UN`1kYG/0NZEj07ZONP1jWgX0NYl09`0089h0WgBO09mjW`2ONYl0
WgZO09mkW`2UNjD0YG^U0:Ek@@02e`030=L000D01=L0103Ge`05e`004mL400CG00@0emOG0P0oeb40
9mLP043G10000mL00005e`040=OG00;G00<0emL00mL001GG00<0emL00mL0103G003Ze`H01ML400;G
1002e`005ML00`3Ge`03eo@04ML001GG00<0emL0m]L00`3Ge`0?e`005ML00`3Ge`3oe`WG000Ce`<0
omL;e`005ML00`3Ge`3oe`WG003oeb7G003oeb7G003oeb7G0000\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.111573, -0.115104, \
0.00412782, 0.00825565}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[p3,ViewPoint->{1.3,-2.4,2.}]", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0418911 0.647101 [
[.02757 .15175 -12 -8.70276 ]
[.02757 .15175 0 .29724 ]
[.17646 .11563 -11.7989 -9 ]
[.17646 .11563 .20112 0 ]
[.3345 .07731 -5.5867 -9 ]
[.3345 .07731 .4133 0 ]
[.50253 .03658 -5.27396 -9 ]
[.50253 .03658 .72604 0 ]
[.68156 -0.00677 -4.96123 -9 ]
[.68156 -0.00677 1.03877 0 ]
[.70096 -0.00295 0 -6.26206 ]
[.70096 -0.00295 12 2.73794 ]
[.78313 .07461 0 -6.13858 ]
[.78313 .07461 24 2.86142 ]
[.8565 .14386 0 -6.03127 ]
[.8565 .14386 6 2.96873 ]
[.9224 .20607 0 -5.93715 ]
[.9224 .20607 18 3.06285 ]
[.98191 .26226 0 -5.85393 ]
[.98191 .26226 6 3.14607 ]
[.02494 .16022 -6 -2.73794 ]
[.02494 .16022 0 6.26206 ]
[.0176 .18856 -24 -2.7768 ]
[.0176 .18856 0 6.2232 ]
[.01004 .21777 -18 -2.81695 ]
[.01004 .21777 0 6.18305 ]
[.00225 .24787 -24 -2.85847 ]
[.00225 .24787 0 6.14153 ]
[-0.00578 .27892 -6 -2.90143 ]
[-0.00578 .27892 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .15727 m
.68874 0 L
s
.03716 .15727 m
.04196 .16003 L
s
[(-2)] .02757 .15175 1 .93395 Mshowa
.18558 .12145 m
.19014 .12435 L
s
[(-1)] .17646 .11563 .96648 1 Mshowa
.34306 .08344 m
.34735 .0865 L
s
[(0)] .3345 .07731 .86223 1 Mshowa
.51046 .04303 m
.51442 .04625 L
s
[(1)] .50253 .03658 .75799 1 Mshowa
.68874 0 m
.69233 .00339 L
s
[(2)] .68156 -0.00677 .65374 1 Mshowa
.125 Mabswid
.06616 .15027 m
.06901 .15195 L
s
.09549 .14319 m
.09832 .14488 L
s
.12517 .13603 m
.12797 .13774 L
s
.1552 .12878 m
.15797 .13051 L
s
.21633 .11403 m
.21903 .11579 L
s
.24744 .10652 m
.25012 .1083 L
s
.27893 .09891 m
.28157 .10071 L
s
.3108 .09122 m
.31341 .09304 L
s
.37572 .07555 m
.37826 .07741 L
s
.40878 .06757 m
.41128 .06945 L
s
.44225 .05949 m
.44471 .06139 L
s
.47614 .05131 m
.47856 .05323 L
s
.54521 .03464 m
.54755 .0366 L
s
.58041 .02615 m
.5827 .02812 L
s
.61605 .01754 m
.6183 .01954 L
s
.65216 .00883 m
.65436 .01084 L
s
.25 Mabswid
.68874 0 m
.96935 .26459 L
s
.68874 0 m
.68263 .00147 L
s
[(-1)] .70096 -0.00295 -1 .39157 Mshowa
.7708 .07738 m
.76464 .07876 L
s
[(-0.5)] .78313 .07461 -1 .36413 Mshowa
.84407 .14647 m
.83786 .14777 L
s
[(0)] .8565 .14386 -1 .34028 Mshowa
.9099 .20853 m
.90365 .20976 L
s
[(0.5)] .9224 .20607 -1 .31937 Mshowa
.96935 .26459 m
.96306 .26576 L
s
[(1)] .98191 .26226 -1 .30087 Mshowa
.125 Mabswid
.70593 .01621 m
.70226 .01708 L
s
.72272 .03204 m
.71904 .0329 L
s
.73912 .0475 m
.73543 .04836 L
s
.75514 .06261 m
.75145 .06345 L
s
.78611 .09182 m
.78241 .09264 L
s
.80108 .10593 m
.79737 .10674 L
s
.81573 .11974 m
.81201 .12054 L
s
.83006 .13325 m
.82633 .13404 L
s
.8578 .15941 m
.85407 .16018 L
s
.87123 .17208 m
.8675 .17284 L
s
.88439 .18448 m
.88065 .18524 L
s
.89727 .19663 m
.89353 .19738 L
s
.92227 .2202 m
.91851 .22093 L
s
.93439 .23163 m
.93063 .23235 L
s
.94627 .24283 m
.94251 .24355 L
s
.95792 .25382 m
.95416 .25452 L
s
.25 Mabswid
.03716 .15727 m
0 .30182 L
s
.03716 .15727 m
.04327 .1558 L
s
[(0)] .02494 .16022 1 -0.39157 Mshowa
.02986 .18567 m
.03599 .18423 L
s
[(0.25)] .0176 .18856 1 -0.38293 Mshowa
.02234 .21494 m
.02848 .21352 L
s
[(0.5)] .01004 .21777 1 -0.37401 Mshowa
.01458 .2451 m
.02074 .24372 L
s
[(0.75)] .00225 .24787 1 -0.36478 Mshowa
.00658 .27622 m
.01276 .27486 L
s
[(1)] -0.00578 .27892 1 -0.35524 Mshowa
.125 Mabswid
.03572 .16288 m
.03938 .162 L
s
.03427 .16853 m
.03794 .16765 L
s
.03281 .17421 m
.03648 .17334 L
s
.03134 .17992 m
.03501 .17905 L
s
.02837 .19145 m
.03205 .19059 L
s
.02688 .19727 m
.03056 .19641 L
s
.02537 .20312 m
.02906 .20227 L
s
.02386 .20901 m
.02754 .20816 L
s
.0208 .2209 m
.02449 .22005 L
s
.01926 .22689 m
.02295 .22605 L
s
.01771 .23292 m
.0214 .23209 L
s
.01615 .239 m
.01985 .23816 L
s
.013 .25125 m
.0167 .25042 L
s
.01141 .25743 m
.01511 .25661 L
s
.00981 .26365 m
.01352 .26283 L
s
.0082 .26992 m
.01191 .2691 L
s
.00495 .28256 m
.00866 .28175 L
s
.00331 .28894 m
.00703 .28813 L
s
.00166 .29536 m
.00538 .29456 L
s
.25 Mabswid
.03716 .15727 m
0 .30182 L
s
0 .30182 m
.39787 .5 L
s
.39787 .5 m
.40529 .3692 L
s
.40529 .3692 m
.03716 .15727 L
s
.68874 0 m
.96935 .26459 L
s
.96935 .26459 m
1 .40283 L
s
1 .40283 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.03716 .15727 m
0 .30182 L
s
0 .30182 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.68874 0 m
.03716 .15727 L
s
.40529 .3692 m
.96935 .26459 L
s
.96935 .26459 m
1 .40283 L
s
1 .40283 m
.39787 .5 L
s
.39787 .5 m
.40529 .3692 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.623 .76 .944 r
.39372 .47441 .39917 .47709 .40827 .4756 .40282 .47319 Metetra
.641 .785 .951 r
.40282 .47319 .40827 .4756 .41741 .47387 .41197 .4717 Metetra
.652 .805 .957 r
.41197 .4717 .41741 .47387 .42659 .472 .42116 .47003 Metetra
.656 .822 .963 r
.42116 .47003 .42659 .472 .4358 .47007 .43039 .46824 Metetra
.656 .834 .968 r
.43039 .46824 .4358 .47007 .44503 .46814 .43965 .46641 Metetra
.652 .841 .973 r
.43965 .46641 .44503 .46814 .4543 .46627 .44893 .46458 Metetra
.646 .843 .976 r
.44893 .46458 .4543 .46627 .46358 .46449 .45825 .46279 Metetra
.639 .842 .978 r
.45825 .46279 .46358 .46449 .4729 .46283 .46759 .46106 Metetra
.633 .836 .978 r
.46759 .46106 .4729 .46283 .48224 .46129 .47696 .4594 Metetra
.63 .826 .976 r
.47696 .4594 .48224 .46129 .49162 .45987 .48636 .45781 Metetra
.629 .813 .971 r
.48636 .45781 .49162 .45987 .50102 .45857 .49579 .45629 Metetra
.63 .797 .963 r
.49579 .45629 .50102 .45857 .51046 .45737 .50526 .45481 Metetra
.634 .779 .951 r
.50526 .45481 .51046 .45737 .51994 .45623 .51476 .45337 Metetra
.638 .759 .936 r
.51476 .45337 .51994 .45623 .52945 .45514 .52429 .45192 Metetra
.644 .738 .918 r
.52429 .45192 .52945 .45514 .539 .45405 .53386 .45044 Metetra
.649 .717 .898 r
.53386 .45044 .539 .45405 .54859 .45294 .54346 .44891 Metetra
.653 .697 .878 r
.54346 .44891 .54859 .45294 .55821 .45178 .55309 .44729 Metetra
.657 .677 .858 r
.55309 .44729 .55821 .45178 .56787 .45053 .56276 .44558 Metetra
.66 .66 .838 r
.56276 .44558 .56787 .45053 .57756 .44918 .57245 .44374 Metetra
.663 .644 .821 r
.57245 .44374 .57756 .44918 .58729 .44771 .58218 .44177 Metetra
.664 .629 .805 r
.58218 .44177 .58729 .44771 .59705 .44611 .59193 .43968 Metetra
.664 .616 .791 r
.59193 .43968 .59705 .44611 .60683 .4444 .60171 .43749 Metetra
.663 .604 .779 r
.60171 .43749 .60683 .4444 .61665 .44258 .61152 .43521 Metetra
.661 .593 .769 r
.61152 .43521 .61665 .44258 .6265 .44068 .62135 .43288 Metetra
.658 .584 .76 r
.62135 .43288 .6265 .44068 .63638 .43873 .63121 .43054 Metetra
.654 .575 .754 r
.63121 .43054 .63638 .43873 .64629 .43678 .6411 .42826 Metetra
.649 .567 .749 r
.6411 .42826 .64629 .43678 .65623 .43485 .65103 .42607 Metetra
.644 .56 .746 r
.65103 .42607 .65623 .43485 .66621 .43299 .661 .42401 Metetra
.638 .554 .744 r
.661 .42401 .66621 .43299 .67623 .43122 .67101 .42214 Metetra
.632 .55 .744 r
.67101 .42214 .67623 .43122 .6863 .42955 .68107 .42045 Metetra
.626 .546 .745 r
.68107 .42045 .6863 .42955 .69641 .42799 .69118 .41896 Metetra
.621 .545 .747 r
.69118 .41896 .69641 .42799 .70656 .42652 .70135 .41765 Metetra
.618 .546 .751 r
.70135 .41765 .70656 .42652 .71676 .42511 .71156 .41648 Metetra
.615 .548 .756 r
.71156 .41648 .71676 .42511 .727 .42374 .72183 .41541 Metetra
.614 .553 .763 r
.72183 .41541 .727 .42374 .73728 .42236 .73215 .41438 Metetra
.615 .561 .771 r
.73215 .41438 .73728 .42236 .7476 .42093 .74251 .41336 Metetra
.617 .571 .78 r
.74251 .41336 .7476 .42093 .75795 .41942 .75291 .41228 Metetra
.621 .583 .79 r
.75291 .41228 .75795 .41942 .76832 .4178 .76335 .41113 Metetra
.626 .598 .802 r
.76335 .41113 .76832 .4178 .77873 .41607 .77381 .40987 Metetra
.632 .614 .814 r
.77381 .40987 .77873 .41607 .78915 .4142 .78431 .40848 Metetra
.639 .633 .828 r
.78431 .40848 .78915 .4142 .7996 .41222 .79483 .40696 Metetra
.645 .653 .844 r
.79483 .40696 .7996 .41222 .81006 .41012 .80538 .40532 Metetra
.651 .675 .86 r
.80538 .40532 .81006 .41012 .82055 .40794 .81595 .40357 Metetra
.656 .698 .877 r
.81595 .40357 .82055 .40794 .83107 .40569 .82655 .40174 Metetra
.659 .721 .894 r
.82655 .40174 .83107 .40569 .84162 .40342 .83718 .39985 Metetra
.66 .744 .912 r
.83718 .39985 .84162 .40342 .85221 .40116 .84785 .39793 Metetra
.658 .765 .929 r
.84785 .39793 .85221 .40116 .86283 .39893 .85855 .396 Metetra
.652 .785 .945 r
.85855 .396 .86283 .39893 .87351 .39678 .8693 .39411 Metetra
.643 .801 .959 r
.8693 .39411 .87351 .39678 .88423 .39472 .8801 .39226 Metetra
.631 .814 .97 r
.8801 .39226 .88423 .39472 .89502 .39278 .89094 .39048 Metetra
.618 .822 .979 r
.89094 .39048 .89502 .39278 .90586 .39096 .90185 .38877 Metetra
.606 .827 .984 r
.90185 .38877 .90586 .39096 .91677 .38928 .9128 .38713 Metetra
.596 .828 .988 r
.9128 .38713 .91677 .38928 .92775 .38772 .92382 .38556 Metetra
.592 .826 .988 r
.92382 .38556 .92775 .38772 .93879 .38625 .93489 .38403 Metetra
.594 .823 .987 r
.93489 .38403 .93879 .38625 .94989 .38484 .946 .38251 Metetra
.603 .818 .982 r
.946 .38251 .94989 .38484 .96104 .38344 .95715 .38093 Metetra
.619 .811 .974 r
.95715 .38093 .96104 .38344 .97222 .38197 .96832 .37924 Metetra
.641 .804 .961 r
.96832 .37924 .97222 .38197 .98342 .38035 .97949 .37734 Metetra
.665 .794 .943 r
.97949 .37734 .98342 .38035 .9946 .37848 .99065 .37516 Metetra
.6 .751 .95 r
.38823 .47167 .39372 .47441 .40282 .47319 .39734 .47071 Metetra
.622 .776 .954 r
.39734 .47071 .40282 .47319 .41197 .4717 .4065 .46944 Metetra
.637 .796 .959 r
.4065 .46944 .41197 .4717 .42116 .47003 .41571 .46794 Metetra
.646 .812 .963 r
.41571 .46794 .42116 .47003 .43039 .46824 .42495 .46628 Metetra
.651 .823 .966 r
.42495 .46628 .43039 .46824 .43965 .46641 .43423 .46453 Metetra
.652 .831 .969 r
.43423 .46453 .43965 .46641 .44893 .46458 .44354 .46273 Metetra
.651 .834 .97 r
.44354 .46273 .44893 .46458 .45825 .46279 .45287 .46092 Metetra
.65 .833 .97 r
.45287 .46092 .45825 .46279 .46759 .46106 .46224 .45912 Metetra
.649 .828 .969 r
.46224 .45912 .46759 .46106 .47696 .4594 .47164 .45734 Metetra
.65 .82 .965 r
.47164 .45734 .47696 .4594 .48636 .45781 .48107 .45558 Metetra
.652 .808 .958 r
.48107 .45558 .48636 .45781 .49579 .45629 .49053 .45384 Metetra
.655 .793 .948 r
.49053 .45384 .49579 .45629 .50526 .45481 .50002 .4521 Metetra
.659 .776 .935 r
.50002 .4521 .50526 .45481 .51476 .45337 .50954 .45035 Metetra
.664 .757 .92 r
.50954 .45035 .51476 .45337 .52429 .45192 .5191 .44855 Metetra
.668 .738 .902 r
.5191 .44855 .52429 .45192 .53386 .45044 .52869 .44669 Metetra
.672 .718 .883 r
.52869 .44669 .53386 .45044 .54346 .44891 .5383 .44474 Metetra
.675 .699 .864 r
.5383 .44474 .54346 .44891 .55309 .44729 .54795 .44268 Metetra
.678 .68 .845 r
.54795 .44268 .55309 .44729 .56276 .44558 .55762 .44049 Metetra
.679 .663 .827 r
.55762 .44049 .56276 .44558 .57245 .44374 .56732 .43817 Metetra
.68 .648 .811 r
.56732 .43817 .57245 .44374 .58218 .44177 .57705 .43571 Metetra
.68 .633 .796 r
.57705 .43571 .58218 .44177 .59193 .43968 .5868 .43313 Metetra
.678 .62 .783 r
.5868 .43313 .59193 .43968 .60171 .43749 .59657 .43045 Metetra
.676 .608 .772 r
.59657 .43045 .60171 .43749 .61152 .43521 .60636 .4277 Metetra
.672 .597 .763 r
.60636 .4277 .61152 .43521 .62135 .43288 .61618 .42493 Metetra
.667 .586 .755 r
.61618 .42493 .62135 .43288 .63121 .43054 .62603 .4222 Metetra
.662 .577 .749 r
.62603 .4222 .63121 .43054 .6411 .42826 .63591 .41957 Metetra
.655 .568 .745 r
.63591 .41957 .6411 .42826 .65103 .42607 .64582 .4171 Metetra
.648 .56 .742 r
.64582 .4171 .65103 .42607 .661 .42401 .65577 .41486 Metetra
.639 .553 .74 r
.65577 .41486 .661 .42401 .67101 .42214 .66577 .41287 Metetra
.631 .547 .741 r
.66577 .41287 .67101 .42214 .68107 .42045 .67583 .41117 Metetra
.623 .542 .742 r
.67583 .41117 .68107 .42045 .69118 .41896 .68594 .40976 Metetra
.616 .539 .745 r
.68594 .40976 .69118 .41896 .70135 .41765 .69612 .4086 Metetra
.609 .538 .75 r
.69612 .4086 .70135 .41765 .71156 .41648 .70635 .40767 Metetra
.604 .54 .755 r
.70635 .40767 .71156 .41648 .72183 .41541 .71664 .40691 Metetra
.601 .544 .762 r
.71664 .40691 .72183 .41541 .73215 .41438 .727 .40626 Metetra
.6 .55 .77 r
.727 .40626 .73215 .41438 .74251 .41336 .7374 .40564 Metetra
.601 .559 .78 r
.7374 .40564 .74251 .41336 .75291 .41228 .74785 .40502 Metetra
.603 .571 .791 r
.74785 .40502 .75291 .41228 .76335 .41113 .75834 .40433 Metetra
.607 .585 .803 r
.75834 .40433 .76335 .41113 .77381 .40987 .76887 .40354 Metetra
.612 .601 .816 r
.76887 .40354 .77381 .40987 .78431 .40848 .77943 .40262 Metetra
.617 .619 .83 r
.77943 .40262 .78431 .40848 .79483 .40696 .79003 .40157 Metetra
.624 .639 .845 r
.79003 .40157 .79483 .40696 .80538 .40532 .80065 .40038 Metetra
.629 .661 .862 r
.80065 .40038 .80538 .40532 .81595 .40357 .8113 .39907 Metetra
.634 .683 .878 r
.8113 .39907 .81595 .40357 .82655 .40174 .82198 .39764 Metetra
.638 .706 .895 r
.82198 .39764 .82655 .40174 .83718 .39985 .83269 .39612 Metetra
.64 .728 .912 r
.83269 .39612 .83718 .39985 .84785 .39793 .84344 .39454 Metetra
.639 .749 .928 r
.84344 .39454 .84785 .39793 .85855 .396 .85422 .39291 Metetra
.636 .768 .943 r
.85422 .39291 .85855 .396 .8693 .39411 .86504 .39127 Metetra
.63 .785 .956 r
.86504 .39127 .8693 .39411 .8801 .39226 .8759 .38963 Metetra
.622 .798 .967 r
.8759 .38963 .8801 .39226 .89094 .39048 .88681 .388 Metetra
.614 .808 .975 r
.88681 .388 .89094 .39048 .90185 .38877 .89777 .3864 Metetra
.607 .815 .98 r
.89777 .3864 .90185 .38877 .9128 .38713 .90877 .38482 Metetra
.603 .818 .982 r
.90877 .38482 .9128 .38713 .92382 .38556 .91982 .38324 Metetra
.603 .819 .983 r
.91982 .38324 .92382 .38556 .93489 .38403 .93092 .38166 Metetra
.609 .818 .98 r
.93092 .38166 .93489 .38403 .946 .38251 .94205 .38002 Metetra
.621 .815 .975 r
.94205 .38002 .946 .38251 .95715 .38093 .95321 .37829 Metetra
.638 .81 .966 r
.95321 .37829 .95715 .38093 .96832 .37924 .96437 .37639 Metetra
.66 .804 .952 r
.96437 .37639 .96832 .37924 .97949 .37734 .97553 .37424 Metetra
.683 .796 .935 r
.97553 .37424 .97949 .37734 .99065 .37516 .98665 .37177 Metetra
.577 .742 .954 r
.38272 .46889 .38823 .47167 .39734 .47071 .39183 .46816 Metetra
.604 .767 .957 r
.39183 .46816 .39734 .47071 .4065 .46944 .401 .46708 Metetra
.623 .787 .96 r
.401 .46708 .4065 .46944 .41571 .46794 .41021 .46574 Metetra
.637 .802 .962 r
.41021 .46574 .41571 .46794 .42495 .46628 .41947 .4642 Metetra
.646 .814 .964 r
.41947 .4642 .42495 .46628 .43423 .46453 .42877 .46252 Metetra
.652 .821 .965 r
.42877 .46252 .43423 .46453 .44354 .46273 .4381 .46074 Metetra
.656 .825 .964 r
.4381 .46074 .44354 .46273 .45287 .46092 .44747 .45891 Metetra
.66 .824 .963 r
.44747 .45891 .45287 .46092 .46224 .45912 .45686 .45704 Metetra
.663 .82 .959 r
.45686 .45704 .46224 .45912 .47164 .45734 .46629 .45513 Metetra
.667 .813 .953 r
.46629 .45513 .47164 .45734 .48107 .45558 .47575 .45321 Metetra
.671 .802 .945 r
.47575 .45321 .48107 .45558 .49053 .45384 .48523 .45125 Metetra
.675 .788 .934 r
.48523 .45125 .49053 .45384 .50002 .4521 .49475 .44925 Metetra
.68 .772 .92 r
.49475 .44925 .50002 .4521 .50954 .45035 .5043 .44719 Metetra
.685 .755 .905 r
.5043 .44719 .50954 .45035 .5191 .44855 .51388 .44505 Metetra
.689 .737 .887 r
.51388 .44505 .5191 .44855 .52869 .44669 .52348 .4428 Metetra
.692 .718 .869 r
.52348 .4428 .52869 .44669 .5383 .44474 .53312 .44044 Metetra
.694 .7 .851 r
.53312 .44044 .5383 .44474 .54795 .44268 .54278 .43794 Metetra
.696 .683 .833 r
.54278 .43794 .54795 .44268 .55762 .44049 .55246 .43529 Metetra
.696 .666 .817 r
.55246 .43529 .55762 .44049 .56732 .43817 .56217 .43249 Metetra
.696 .651 .801 r
.56217 .43249 .56732 .43817 .57705 .43571 .5719 .42953 Metetra
.694 .637 .788 r
.5719 .42953 .57705 .43571 .5868 .43313 .58164 .42645 Metetra
.692 .624 .776 r
.58164 .42645 .5868 .43313 .59657 .43045 .59141 .42328 Metetra
.688 .611 .765 r
.59141 .42328 .59657 .43045 .60636 .4277 .6012 .42005 Metetra
.683 .6 .756 r
.6012 .42005 .60636 .4277 .61618 .42493 .611 .41683 Metetra
.677 .589 .749 r
.611 .41683 .61618 .42493 .62603 .4222 .62083 .41369 Metetra
.669 .578 .744 r
.62083 .41369 .62603 .4222 .63591 .41957 .63069 .41071 Metetra
.661 .568 .74 r
.63069 .41071 .63591 .41957 .64582 .4171 .64059 .40796 Metetra
.651 .559 .738 r
.64059 .40796 .64582 .4171 .65577 .41486 .65053 .40551 Metetra
.641 .551 .737 r
.65053 .40551 .65577 .41486 .66577 .41287 .66052 .40341 Metetra
.63 .543 .738 r
.66052 .40341 .66577 .41287 .67583 .41117 .67057 .40169 Metetra
.62 .537 .74 r
.67057 .40169 .67583 .41117 .68594 .40976 .68068 .40035 Metetra
.61 .533 .743 r
.68068 .40035 .68594 .40976 .69612 .4086 .69086 .39937 Metetra
.601 .531 .748 r
.69086 .39937 .69612 .4086 .70635 .40767 .70111 .3987 Metetra
.593 .531 .754 r
.70111 .3987 .70635 .40767 .71664 .40691 .71143 .39826 Metetra
.588 .533 .761 r
.71143 .39826 .71664 .40691 .727 .40626 .72182 .39798 Metetra
.584 .539 .77 r
.72182 .39798 .727 .40626 .7374 .40564 .73226 .39779 Metetra
.583 .547 .78 r
.73226 .39779 .7374 .40564 .74785 .40502 .74276 .39762 Metetra
.584 .558 .791 r
.74276 .39762 .74785 .40502 .75834 .40433 .75331 .3974 Metetra
.586 .571 .804 r
.75331 .3974 .75834 .40433 .76887 .40354 .7639 .39708 Metetra
.59 .587 .817 r
.7639 .39708 .76887 .40354 .77943 .40262 .77453 .39664 Metetra
.595 .605 .832 r
.77453 .39664 .77943 .40262 .79003 .40157 .78519 .39606 Metetra
.601 .625 .847 r
.78519 .39606 .79003 .40157 .80065 .40038 .79589 .39532 Metetra
.607 .646 .863 r
.79589 .39532 .80065 .40038 .8113 .39907 .80662 .39443 Metetra
.612 .668 .88 r
.80662 .39443 .8113 .39907 .82198 .39764 .81737 .3934 Metetra
.616 .69 .896 r
.81737 .3934 .82198 .39764 .83269 .39612 .82816 .39225 Metetra
.619 .712 .912 r
.82816 .39225 .83269 .39612 .84344 .39454 .83898 .391 Metetra
.62 .733 .928 r
.83898 .391 .84344 .39454 .85422 .39291 .84983 .38966 Metetra
.619 .753 .942 r
.84983 .38966 .85422 .39291 .86504 .39127 .86072 .38827 Metetra
.617 .77 .954 r
.86072 .38827 .86504 .39127 .8759 .38963 .87165 .38683 Metetra
.613 .784 .963 r
.87165 .38683 .8759 .38963 .88681 .388 .88262 .38536 Metetra
.609 .795 .97 r
.88262 .38536 .88681 .388 .89777 .3864 .89363 .38386 Metetra
.607 .803 .975 r
.89363 .38386 .89777 .3864 .90877 .38482 .90468 .38234 Metetra
.608 .809 .977 r
.90468 .38234 .90877 .38482 .91982 .38324 .91577 .38077 Metetra
.612 .812 .977 r
.91577 .38077 .91982 .38324 .93092 .38166 .9269 .37914 Metetra
.621 .813 .974 r
.9269 .37914 .93092 .38166 .94205 .38002 .93805 .3774 Metetra
.635 .812 .967 r
.93805 .3774 .94205 .38002 .95321 .37829 .94921 .37552 Metetra
.654 .809 .958 r
.94921 .37552 .95321 .37829 .96437 .37639 .96038 .37344 Metetra
.675 .804 .944 r
.96038 .37344 .96437 .37639 .97553 .37424 .97152 .37106 Metetra
.698 .798 .927 r
.97152 .37106 .97553 .37424 .98665 .37177 .98263 .36832 Metetra
.555 .733 .958 r
.37717 .46607 .38272 .46889 .39183 .46816 .38628 .46554 Metetra
.587 .758 .96 r
.38628 .46554 .39183 .46816 .401 .46708 .39546 .46464 Metetra
.611 .778 .961 r
.39546 .46464 .401 .46708 .41021 .46574 .40469 .46343 Metetra
.629 .794 .962 r
.40469 .46343 .41021 .46574 .41947 .4642 .41396 .46199 Metetra
.642 .805 .961 r
.41396 .46199 .41947 .4642 .42877 .46252 .42328 .46038 Metetra
.653 .813 .96 r
.42328 .46038 .42877 .46252 .4381 .46074 .43264 .45862 Metetra
.661 .817 .958 r
.43264 .45862 .4381 .46074 .44747 .45891 .44203 .45676 Metetra
.668 .816 .955 r
.44203 .45676 .44747 .45891 .45686 .45704 .45145 .4548 Metetra
.674 .813 .95 r
.45145 .4548 .45686 .45704 .46629 .45513 .4609 .45278 Metetra
.68 .806 .942 r
.4609 .45278 .46629 .45513 .47575 .45321 .47039 .45068 Metetra
.687 .796 .933 r
.47039 .45068 .47575 .45321 .48523 .45125 .47991 .44851 Metetra
.692 .783 .921 r
.47991 .44851 .48523 .45125 .49475 .44925 .48945 .44625 Metetra
.698 .769 .907 r
.48945 .44625 .49475 .44925 .5043 .44719 .49902 .44389 Metetra
.702 .752 .891 r
.49902 .44389 .5043 .44719 .51388 .44505 .50863 .44141 Metetra
.706 .735 .874 r
.50863 .44141 .51388 .44505 .52348 .4428 .51825 .4388 Metetra
.709 .718 .856 r
.51825 .4388 .52348 .4428 .53312 .44044 .52791 .43602 Metetra
.71 .701 .839 r
.52791 .43602 .53312 .44044 .54278 .43794 .53758 .43309 Metetra
.711 .684 .822 r
.53758 .43309 .54278 .43794 .55246 .43529 .54728 .42997 Metetra
.711 .669 .807 r
.54728 .42997 .55246 .43529 .56217 .43249 .55699 .42669 Metetra
.71 .654 .792 r
.55699 .42669 .56217 .43249 .5719 .42953 .56672 .42324 Metetra
.707 .64 .78 r
.56672 .42324 .5719 .42953 .58164 .42645 .57647 .41966 Metetra
.704 .627 .768 r
.57647 .41966 .58164 .42645 .59141 .42328 .58623 .41598 Metetra
.699 .614 .758 r
.58623 .41598 .59141 .42328 .6012 .42005 .59601 .41226 Metetra
.693 .603 .75 r
.59601 .41226 .6012 .42005 .611 .41683 .6058 .40858 Metetra
.686 .591 .744 r
.6058 .40858 .611 .41683 .62083 .41369 .61562 .40502 Metetra
.677 .58 .739 r
.61562 .40502 .62083 .41369 .63069 .41071 .62547 .40166 Metetra
.667 .569 .736 r
.62547 .40166 .63069 .41071 .64059 .40796 .63535 .39861 Metetra
.655 .559 .734 r
.63535 .39861 .64059 .40796 .65053 .40551 .64527 .39594 Metetra
.643 .549 .733 r
.64527 .39594 .65053 .40551 .66052 .40341 .65525 .39373 Metetra
.63 .54 .734 r
.65525 .39373 .66052 .40341 .67057 .40169 .66529 .39199 Metetra
.616 .532 .737 r
.66529 .39199 .67057 .40169 .68068 .40035 .6754 .39074 Metetra
.603 .526 .741 r
.6754 .39074 .68068 .40035 .69086 .39937 .68559 .38994 Metetra
.592 .522 .746 r
.68559 .38994 .69086 .39937 .70111 .3987 .69586 .38953 Metetra
.581 .521 .752 r
.69586 .38953 .70111 .3987 .71143 .39826 .7062 .38943 Metetra
.573 .522 .76 r
.7062 .38943 .71143 .39826 .72182 .39798 .71662 .38955 Metetra
.568 .527 .769 r
.71662 .38955 .72182 .39798 .73226 .39779 .7271 .3898 Metetra
.564 .534 .78 r
.7271 .3898 .73226 .39779 .74276 .39762 .73765 .39008 Metetra
.564 .544 .791 r
.73765 .39008 .74276 .39762 .75331 .3974 .74825 .39034 Metetra
.565 .557 .804 r
.74825 .39034 .75331 .3974 .7639 .39708 .7589 .39051 Metetra
.568 .573 .818 r
.7589 .39051 .7639 .39708 .77453 .39664 .76959 .39055 Metetra
.572 .59 .833 r
.76959 .39055 .77453 .39664 .78519 .39606 .78032 .39043 Metetra
.578 .61 .848 r
.78032 .39043 .78519 .39606 .79589 .39532 .79109 .39014 Metetra
.584 .631 .864 r
.79109 .39014 .79589 .39532 .80662 .39443 .80189 .38967 Metetra
.589 .653 .88 r
.80189 .38967 .80662 .39443 .81737 .3934 .81272 .38904 Metetra
.594 .675 .896 r
.81272 .38904 .81737 .3934 .82816 .39225 .82358 .38825 Metetra
.598 .697 .912 r
.82358 .38825 .82816 .39225 .83898 .391 .83448 .38732 Metetra
.601 .718 .927 r
.83448 .38732 .83898 .391 .84983 .38966 .8454 .38627 Metetra
.603 .738 .94 r
.8454 .38627 .84983 .38966 .86072 .38827 .85636 .38512 Metetra
.603 .755 .951 r
.85636 .38512 .86072 .38827 .87165 .38683 .86735 .38388 Metetra
.603 .77 .96 r
.86735 .38388 .87165 .38683 .88262 .38536 .87838 .38256 Metetra
.604 .783 .966 r
.87838 .38256 .88262 .38536 .89363 .38386 .88944 .38117 Metetra
.606 .792 .97 r
.88944 .38117 .89363 .38386 .90468 .38234 .90054 .3797 Metetra
.611 .8 .972 r
.90054 .3797 .90468 .38234 .91577 .38077 .91167 .37815 Metetra
.619 .805 .971 r
.91167 .37815 .91577 .38077 .9269 .37914 .92282 .37648 Metetra
.631 .807 .967 r
.92282 .37648 .9269 .37914 .93805 .3774 .93399 .37466 Metetra
.647 .808 .961 r
.93399 .37466 .93805 .3774 .94921 .37552 .94517 .37265 Metetra
.666 .807 .95 r
.94517 .37265 .94921 .37552 .96038 .37344 .95634 .37039 Metetra
.688 .804 .937 r
.95634 .37039 .96038 .37344 .97152 .37106 .96748 .36781 Metetra
.711 .799 .92 r
.96748 .36781 .97152 .37106 .98263 .36832 .97857 .36483 Metetra
.535 .724 .961 r
.37158 .46322 .37717 .46607 .38628 .46554 .3807 .46286 Metetra
.571 .75 .962 r
.3807 .46286 .38628 .46554 .39546 .46464 .38989 .46211 Metetra
.6 .771 .962 r
.38989 .46211 .39546 .46464 .40469 .46343 .39913 .46103 Metetra
.622 .787 .961 r
.39913 .46103 .40469 .46343 .41396 .46199 .40842 .45969 Metetra
.639 .798 .959 r
.40842 .45969 .41396 .46199 .42328 .46038 .41776 .45812 Metetra
.653 .805 .956 r
.41776 .45812 .42328 .46038 .43264 .45862 .42714 .45637 Metetra
.665 .809 .952 r
.42714 .45637 .43264 .45862 .44203 .45676 .43655 .45447 Metetra
.675 .809 .947 r
.43655 .45447 .44203 .45676 .45145 .4548 .446 .45244 Metetra
.684 .806 .94 r
.446 .45244 .45145 .4548 .4609 .45278 .45549 .45029 Metetra
.692 .8 .932 r
.45549 .45029 .4609 .45278 .47039 .45068 .465 .44803 Metetra
.7 .791 .921 r
.465 .44803 .47039 .45068 .47991 .44851 .47454 .44564 Metetra
.706 .779 .908 r
.47454 .44564 .47991 .44851 .48945 .44625 .48412 .44313 Metetra
.712 .765 .894 r
.48412 .44313 .48945 .44625 .49902 .44389 .49372 .44047 Metetra
.717 .75 .878 r
.49372 .44047 .49902 .44389 .50863 .44141 .50334 .43766 Metetra
.721 .734 .861 r
.50334 .43766 .50863 .44141 .51825 .4388 .51299 .43467 Metetra
.723 .718 .845 r
.51299 .43467 .51825 .4388 .52791 .43602 .52267 .4315 Metetra
.724 .702 .828 r
.52267 .4315 .52791 .43602 .53758 .43309 .53236 .42812 Metetra
.725 .686 .812 r
.53236 .42812 .53758 .43309 .54728 .42997 .54207 .42455 Metetra
.724 .671 .797 r
.54207 .42455 .54728 .42997 .55699 .42669 .5518 .42078 Metetra
.722 .657 .784 r
.5518 .42078 .55699 .42669 .56672 .42324 .56153 .41683 Metetra
.719 .643 .772 r
.56153 .41683 .56672 .42324 .57647 .41966 .57128 .41274 Metetra
.715 .63 .761 r
.57128 .41274 .57647 .41966 .58623 .41598 .58104 .40855 Metetra
.71 .617 .752 r
.58104 .40855 .58623 .41598 .59601 .41226 .59081 .40434 Metetra
.703 .605 .744 r
.59081 .40434 .59601 .41226 .6058 .40858 .60059 .40018 Metetra
.695 .593 .738 r
.60059 .40018 .6058 .40858 .61562 .40502 .6104 .39617 Metetra
.684 .581 .734 r
.6104 .39617 .61562 .40502 .62547 .40166 .62022 .39243 Metetra
.673 .57 .731 r
.62022 .39243 .62547 .40166 .63535 .39861 .63009 .38906 Metetra
.659 .558 .73 r
.63009 .38906 .63535 .39861 .64527 .39594 .64 .38616 Metetra
.644 .547 .73 r
.64 .38616 .64527 .39594 .65525 .39373 .64996 .38381 Metetra
.629 .536 .731 r
.64996 .38381 .65525 .39373 .66529 .39199 .66 .38206 Metetra
.612 .527 .734 r
.66 .38206 .66529 .39199 .6754 .39074 .67011 .3809 Metetra
.597 .519 .738 r
.67011 .3809 .6754 .39074 .68559 .38994 .6803 .3803 Metetra
.582 .514 .744 r
.6803 .3803 .68559 .38994 .69586 .38953 .69058 .38017 Metetra
.569 .511 .75 r
.69058 .38017 .69586 .38953 .7062 .38943 .70095 .38043 Metetra
.558 .511 .759 r
.70095 .38043 .7062 .38943 .71662 .38955 .71139 .38096 Metetra
.55 .514 .768 r
.71139 .38096 .71662 .38955 .7271 .3898 .72192 .38166 Metetra
.545 .52 .779 r
.72192 .38166 .7271 .3898 .73765 .39008 .73251 .38242 Metetra
.542 .53 .791 r
.73251 .38242 .73765 .39008 .74825 .39034 .74316 .38317 Metetra
.542 .542 .804 r
.74316 .38317 .74825 .39034 .7589 .39051 .75387 .38382 Metetra
.544 .557 .818 r
.75387 .38382 .7589 .39051 .76959 .39055 .76462 .38434 Metetra
.548 .575 .833 r
.76462 .38434 .76959 .39055 .78032 .39043 .77542 .38469 Metetra
.554 .594 .849 r
.77542 .38469 .78032 .39043 .79109 .39014 .78626 .38484 Metetra
.56 .615 .865 r
.78626 .38484 .79109 .39014 .80189 .38967 .79713 .38479 Metetra
.566 .637 .881 r
.79713 .38479 .80189 .38967 .81272 .38904 .80803 .38455 Metetra
.572 .66 .897 r
.80803 .38455 .81272 .38904 .82358 .38825 .81896 .38412 Metetra
.577 .682 .912 r
.81896 .38412 .82358 .38825 .83448 .38732 .82993 .38351 Metetra
.582 .703 .926 r
.82993 .38351 .83448 .38732 .8454 .38627 .84092 .38274 Metetra
.586 .723 .938 r
.84092 .38274 .8454 .38627 .85636 .38512 .85195 .38183 Metetra
.59 .742 .948 r
.85195 .38183 .85636 .38512 .86735 .38388 .863 .38079 Metetra
.594 .758 .957 r
.863 .38079 .86735 .38388 .87838 .38256 .87409 .37963 Metetra
.598 .771 .963 r
.87409 .37963 .87838 .38256 .88944 .38117 .8852 .37834 Metetra
.604 .782 .966 r
.8852 .37834 .88944 .38117 .90054 .3797 .89634 .37693 Metetra
.613 .791 .967 r
.89634 .37693 .90054 .3797 .91167 .37815 .90751 .37539 Metetra
.624 .798 .966 r
.90751 .37539 .91167 .37815 .92282 .37648 .91869 .37369 Metetra
.639 .802 .961 r
.91869 .37369 .92282 .37648 .93399 .37466 .92989 .37179 Metetra
.656 .805 .954 r
.92989 .37179 .93399 .37466 .94517 .37265 .94108 .36967 Metetra
.677 .805 .944 r
.94108 .36967 .94517 .37265 .95634 .37039 .95225 .36725 Metetra
.698 .803 .93 r
.95225 .36725 .95634 .37039 .96748 .36781 .96339 .36449 Metetra
.721 .8 .913 r
.96339 .36449 .96748 .36781 .97857 .36483 .97448 .3613 Metetra
.515 .716 .963 r
.36596 .46033 .37158 .46322 .3807 .46286 .37509 .46014 Metetra
.557 .743 .963 r
.37509 .46014 .3807 .46286 .38989 .46211 .38428 .45952 Metetra
.59 .764 .962 r
.38428 .45952 .38989 .46211 .39913 .46103 .39354 .45855 Metetra
.615 .78 .96 r
.39354 .45855 .39913 .46103 .40842 .45969 .40285 .45728 Metetra
.636 .791 .957 r
.40285 .45728 .40842 .45969 .41776 .45812 .4122 .45575 Metetra
.654 .799 .952 r
.4122 .45575 .41776 .45812 .42714 .45637 .4216 .454 Metetra
.669 .803 .947 r
.4216 .454 .42714 .45637 .43655 .45447 .43104 .45206 Metetra
.681 .803 .94 r
.43104 .45206 .43655 .45447 .446 .45244 .44052 .44995 Metetra
.692 .8 .932 r
.44052 .44995 .446 .45244 .45549 .45029 .45003 .44768 Metetra
.702 .794 .922 r
.45003 .44768 .45549 .45029 .465 .44803 .45957 .44525 Metetra
.711 .786 .91 r
.45957 .44525 .465 .44803 .47454 .44564 .46915 .44265 Metetra
.718 .775 .897 r
.46915 .44265 .47454 .44564 .48412 .44313 .47875 .43989 Metetra
.725 .762 .882 r
.47875 .43989 .48412 .44313 .49372 .44047 .48838 .43694 Metetra
.73 .747 .866 r
.48838 .43694 .49372 .44047 .50334 .43766 .49803 .4338 Metetra
.733 .733 .85 r
.49803 .4338 .50334 .43766 .51299 .43467 .50771 .43045 Metetra
.736 .717 .834 r
.50771 .43045 .51299 .43467 .52267 .4315 .5174 .42687 Metetra
.737 .702 .818 r
.5174 .42687 .52267 .4315 .53236 .42812 .52711 .42306 Metetra
.737 .687 .803 r
.52711 .42306 .53236 .42812 .54207 .42455 .53684 .41903 Metetra
.736 .673 .789 r
.53684 .41903 .54207 .42455 .5518 .42078 .54658 .41477 Metetra
.734 .659 .776 r
.54658 .41477 .5518 .42078 .56153 .41683 .55632 .41032 Metetra
.731 .646 .764 r
.55632 .41032 .56153 .41683 .57128 .41274 .56607 .40571 Metetra
.726 .633 .754 r
.56607 .40571 .57128 .41274 .58104 .40855 .57583 .40101 Metetra
.72 .62 .746 r
.57583 .40101 .58104 .40855 .59081 .40434 .5856 .39627 Metetra
.712 .608 .738 r
.5856 .39627 .59081 .40434 .60059 .40018 .59537 .39161 Metetra
.703 .595 .733 r
.59537 .39161 .60059 .40018 .6104 .39617 .60516 .38714 Metetra
.692 .583 .729 r
.60516 .38714 .6104 .39617 .62022 .39243 .61497 .38299 Metetra
.678 .57 .726 r
.61497 .38299 .62022 .39243 .63009 .38906 .62482 .37928 Metetra
.663 .558 .725 r
.62482 .37928 .63009 .38906 .64 .38616 .63471 .37614 Metetra
.646 .545 .726 r
.63471 .37614 .64 .38616 .64996 .38381 .64466 .37365 Metetra
.628 .533 .728 r
.64466 .37365 .64996 .38381 .66 .38206 .65469 .37188 Metetra
.608 .522 .731 r
.65469 .37188 .66 .38206 .67011 .3809 .66479 .37082 Metetra
.589 .512 .735 r
.66479 .37082 .67011 .3809 .6803 .3803 .67499 .37043 Metetra
.572 .505 .741 r
.67499 .37043 .6803 .3803 .69058 .38017 .68529 .37061 Metetra
.555 .5 .748 r
.68529 .37061 .69058 .38017 .70095 .38043 .69567 .37125 Metetra
.542 .498 .757 r
.69567 .37125 .70095 .38043 .71139 .38096 .70615 .37221 Metetra
.531 .5 .767 r
.70615 .37221 .71139 .38096 .72192 .38166 .71671 .37338 Metetra
.524 .506 .778 r
.71671 .37338 .72192 .38166 .73251 .38242 .72735 .37464 Metetra
.519 .514 .79 r
.72735 .37464 .73251 .38242 .74316 .38317 .73805 .37588 Metetra
.518 .526 .804 r
.73805 .37588 .74316 .38317 .75387 .38382 .74881 .37703 Metetra
.52 .541 .818 r
.74881 .37703 .75387 .38382 .76462 .38434 .75963 .37803 Metetra
.523 .559 .833 r
.75963 .37803 .76462 .38434 .77542 .38469 .77049 .37884 Metetra
.528 .578 .849 r
.77049 .37884 .77542 .38469 .78626 .38484 .78139 .37944 Metetra
.535 .599 .865 r
.78139 .37944 .78626 .38484 .79713 .38479 .79233 .37981 Metetra
.542 .621 .881 r
.79233 .37981 .79713 .38479 .80803 .38455 .8033 .37995 Metetra
.549 .644 .896 r
.8033 .37995 .80803 .38455 .81896 .38412 .8143 .37987 Metetra
.556 .667 .911 r
.8143 .37987 .81896 .38412 .82993 .38351 .82533 .37958 Metetra
.563 .689 .924 r
.82533 .37958 .82993 .38351 .84092 .38274 .83639 .37909 Metetra
.57 .709 .936 r
.83639 .37909 .84092 .38274 .85195 .38183 .84748 .37841 Metetra
.577 .729 .946 r
.84748 .37841 .85195 .38183 .863 .38079 .8586 .37757 Metetra
.584 .746 .954 r
.8586 .37757 .863 .38079 .87409 .37963 .86974 .37655 Metetra
.592 .761 .959 r
.86974 .37655 .87409 .37963 .8852 .37834 .88091 .37538 Metetra
.602 .773 .962 r
.88091 .37538 .8852 .37834 .89634 .37693 .8921 .37403 Metetra
.613 .783 .963 r
.8921 .37403 .89634 .37693 .90751 .37539 .9033 .3725 Metetra
.628 .792 .961 r
.9033 .3725 .90751 .37539 .91869 .37369 .91452 .37078 Metetra
.645 .798 .956 r
.91452 .37078 .91869 .37369 .92989 .37179 .92573 .36882 Metetra
.664 .801 .948 r
.92573 .36882 .92989 .37179 .94108 .36967 .93694 .36659 Metetra
.685 .803 .938 r
.93694 .36659 .94108 .36967 .95225 .36725 .94813 .36404 Metetra
.707 .803 .924 r
.94813 .36404 .95225 .36725 .96339 .36449 .95927 .36111 Metetra
.73 .8 .908 r
.95927 .36111 .96339 .36449 .97448 .3613 .97035 .35772 Metetra
.497 .708 .965 r
.36031 .45741 .36596 .46033 .37509 .46014 .36944 .45736 Metetra
.544 .736 .965 r
.36944 .45736 .37509 .46014 .38428 .45952 .37864 .45687 Metetra
.58 .758 .962 r
.37864 .45687 .38428 .45952 .39354 .45855 .38791 .45599 Metetra
.61 .774 .959 r
.38791 .45599 .39354 .45855 .40285 .45728 .39724 .45478 Metetra
.635 .786 .954 r
.39724 .45478 .40285 .45728 .4122 .45575 .40661 .45328 Metetra
.655 .793 .948 r
.40661 .45328 .4122 .45575 .4216 .454 .41604 .45153 Metetra
.672 .797 .942 r
.41604 .45153 .4216 .454 .43104 .45206 .4255 .44955 Metetra
.687 .798 .933 r
.4255 .44955 .43104 .45206 .44052 .44995 .43501 .44735 Metetra
.7 .795 .924 r
.43501 .44735 .44052 .44995 .45003 .44768 .44454 .44495 Metetra
.711 .789 .913 r
.44454 .44495 .45003 .44768 .45957 .44525 .45412 .44235 Metetra
.721 .781 .9 r
.45412 .44235 .45957 .44525 .46915 .44265 .46372 .43955 Metetra
.729 .771 .886 r
.46372 .43955 .46915 .44265 .47875 .43989 .47335 .43654 Metetra
.736 .759 .871 r
.47335 .43654 .47875 .43989 .48838 .43694 .48301 .43331 Metetra
.741 .745 .856 r
.48301 .43331 .48838 .43694 .49803 .4338 .49269 .42984 Metetra
.745 .731 .84 r
.49269 .42984 .49803 .4338 .50771 .43045 .50239 .42612 Metetra
.747 .717 .824 r
.50239 .42612 .50771 .43045 .5174 .42687 .51211 .42215 Metetra
.748 .703 .809 r
.51211 .42215 .5174 .42687 .52711 .42306 .52184 .41791 Metetra
.748 .689 .794 r
.52184 .41791 .52711 .42306 .53684 .41903 .53159 .41342 Metetra
.747 .675 .781 r
.53159 .41342 .53684 .41903 .54658 .41477 .54134 .40868 Metetra
.745 .662 .768 r
.54134 .40868 .54658 .41477 .55632 .41032 .55109 .40372 Metetra
.741 .649 .757 r
.55109 .40372 .55632 .41032 .56607 .40571 .56085 .39858 Metetra
.736 .636 .748 r
.56085 .39858 .56607 .40571 .57583 .40101 .57061 .39334 Metetra
.73 .623 .739 r
.57061 .39334 .57583 .40101 .5856 .39627 .58037 .38807 Metetra
.722 .611 .733 r
.58037 .38807 .5856 .39627 .59537 .39161 .59013 .38289 Metetra
.711 .598 .727 r
.59013 .38289 .59537 .39161 .60516 .38714 .59991 .37793 Metetra
.699 .584 .724 r
.59991 .37793 .60516 .38714 .61497 .38299 .6097 .37334 Metetra
.684 .571 .721 r
.6097 .37334 .61497 .38299 .62482 .37928 .61953 .36926 Metetra
.667 .557 .721 r
.61953 .36926 .62482 .37928 .63471 .37614 .62941 .36586 Metetra
.648 .543 .722 r
.62941 .36586 .63471 .37614 .64466 .37365 .63934 .36323 Metetra
.627 .529 .724 r
.63934 .36323 .64466 .37365 .65469 .37188 .64936 .36144 Metetra
.604 .516 .727 r
.64936 .36144 .65469 .37188 .66479 .37082 .65946 .36049 Metetra
.582 .504 .732 r
.65946 .36049 .66479 .37082 .67499 .37043 .66967 .36032 Metetra
.56 .495 .739 r
.66967 .36032 .67499 .37043 .68529 .37061 .67997 .36083 Metetra
.541 .488 .746 r
.67997 .36083 .68529 .37061 .69567 .37125 .69038 .36188 Metetra
.524 .485 .755 r
.69038 .36188 .69567 .37125 .70615 .37221 .70089 .3633 Metetra
.511 .486 .765 r
.70089 .3633 .70615 .37221 .71671 .37338 .71148 .36497 Metetra
.501 .49 .777 r
.71148 .36497 .71671 .37338 .72735 .37464 .72216 .36673 Metetra
.495 .498 .789 r
.72216 .36673 .72735 .37464 .73805 .37588 .73291 .36848 Metetra
.493 .51 .803 r
.73291 .36848 .73805 .37588 .74881 .37703 .74373 .37014 Metetra
.493 .524 .818 r
.74373 .37014 .74881 .37703 .75963 .37803 .7546 .37163 Metetra
.496 .542 .833 r
.7546 .37163 .75963 .37803 .77049 .37884 .76553 .37291 Metetra
.502 .562 .849 r
.76553 .37291 .77049 .37884 .78139 .37944 .77649 .37394 Metetra
.509 .583 .865 r
.77649 .37394 .78139 .37944 .79233 .37981 .78749 .37473 Metetra
.517 .606 .881 r
.78749 .37473 .79233 .37981 .8033 .37995 .79853 .37525 Metetra
.526 .629 .896 r
.79853 .37525 .8033 .37995 .8143 .37987 .8096 .37552 Metetra
.535 .652 .91 r
.8096 .37552 .8143 .37987 .82533 .37958 .8207 .37553 Metetra
.544 .675 .923 r
.8207 .37553 .82533 .37958 .83639 .37909 .83183 .37532 Metetra
.554 .696 .934 r
.83183 .37532 .83639 .37909 .84748 .37841 .84298 .37488 Metetra
.563 .716 .944 r
.84298 .37488 .84748 .37841 .8586 .37757 .85415 .37422 Metetra
.574 .734 .951 r
.85415 .37422 .8586 .37757 .86974 .37655 .86535 .37335 Metetra
.585 .75 .956 r
.86535 .37335 .86974 .37655 .88091 .37538 .87657 .37229 Metetra
.598 .764 .959 r
.87657 .37229 .88091 .37538 .8921 .37403 .8878 .37101 Metetra
.613 .776 .959 r
.8878 .37101 .8921 .37403 .9033 .3725 .89904 .3695 Metetra
.63 .786 .956 r
.89904 .3695 .9033 .3725 .91452 .37078 .91029 .36776 Metetra
.649 .793 .951 r
.91029 .36776 .91452 .37078 .92573 .36882 .92154 .36575 Metetra
.67 .798 .943 r
.92154 .36575 .92573 .36882 .93694 .36659 .93276 .36343 Metetra
.692 .801 .933 r
.93276 .36343 .93694 .36659 .94813 .36404 .94396 .36075 Metetra
.715 .802 .919 r
.94396 .36075 .94813 .36404 .95927 .36111 .95511 .35767 Metetra
.737 .801 .903 r
.95511 .35767 .95927 .36111 .97035 .35772 .96619 .35411 Metetra
.481 .701 .966 r
.35461 .45448 .36031 .45741 .36944 .45736 .36375 .45454 Metetra
.532 .73 .966 r
.36375 .45454 .36944 .45736 .37864 .45687 .37296 .45415 Metetra
.573 .752 .963 r
.37296 .45415 .37864 .45687 .38791 .45599 .38225 .45335 Metetra
.606 .769 .958 r
.38225 .45335 .38791 .45599 .39724 .45478 .39159 .4522 Metetra
.633 .78 .952 r
.39159 .4522 .39724 .45478 .40661 .45328 .40099 .45072 Metetra
.656 .788 .945 r
.40099 .45072 .40661 .45328 .41604 .45153 .41043 .44896 Metetra
.676 .792 .937 r
.41043 .44896 .41604 .45153 .4255 .44955 .41992 .44693 Metetra
.692 .793 .927 r
.41992 .44693 .4255 .44955 .43501 .44735 .42946 .44464 Metetra
.707 .79 .916 r
.42946 .44464 .43501 .44735 .44454 .44495 .43902 .44212 Metetra
.719 .785 .904 r
.43902 .44212 .44454 .44495 .45412 .44235 .44863 .43935 Metetra
.729 .777 .891 r
.44863 .43935 .45412 .44235 .46372 .43955 .45826 .43635 Metetra
.738 .768 .877 r
.45826 .43635 .46372 .43955 .47335 .43654 .46792 .43309 Metetra
.745 .756 .861 r
.46792 .43309 .47335 .43654 .48301 .43331 .47761 .42958 Metetra
.751 .744 .846 r
.47761 .42958 .48301 .43331 .49269 .42984 .48732 .42579 Metetra
.755 .731 .83 r
.48732 .42579 .49269 .42984 .50239 .42612 .49705 .42171 Metetra
.757 .717 .815 r
.49705 .42171 .50239 .42612 .51211 .42215 .50679 .41735 Metetra
.758 .704 .8 r
.50679 .41735 .51211 .42215 .52184 .41791 .51655 .41269 Metetra
.758 .69 .786 r
.51655 .41269 .52184 .41791 .53159 .41342 .52631 .40773 Metetra
.757 .677 .773 r
.52631 .40773 .53159 .41342 .54134 .40868 .53608 .4025 Metetra
.755 .664 .761 r
.53608 .4025 .54134 .40868 .55109 .40372 .54584 .39703 Metetra
.751 .651 .75 r
.54584 .39703 .55109 .40372 .56085 .39858 .55561 .39136 Metetra
.746 .639 .741 r
.55561 .39136 .56085 .39858 .57061 .39334 .56537 .38556 Metetra
.739 .626 .733 r
.56537 .38556 .57061 .39334 .58037 .38807 .57513 .37974 Metetra
.731 .613 .727 r
.57513 .37974 .58037 .38807 .59013 .38289 .58488 .37401 Metetra
.72 .6 .722 r
.58488 .37401 .59013 .38289 .59991 .37793 .59465 .36853 Metetra
.706 .586 .718 r
.59465 .36853 .59991 .37793 .6097 .37334 .60443 .36347 Metetra
.69 .572 .717 r
.60443 .36347 .6097 .37334 .61953 .36926 .61424 .359 Metetra
.671 .556 .716 r
.61424 .359 .61953 .36926 .62941 .36586 .62409 .3553 Metetra
.65 .541 .717 r
.62409 .3553 .62941 .36586 .63934 .36323 .63401 .35251 Metetra
.625 .525 .72 r
.63401 .35251 .63934 .36323 .64936 .36144 .64402 .3507 Metetra
.6 .509 .724 r
.64402 .3507 .64936 .36144 .65946 .36049 .65412 .34988 Metetra
.574 .496 .729 r
.65412 .34988 .65946 .36049 .66967 .36032 .66432 .34997 Metetra
.548 .484 .736 r
.66432 .34997 .66967 .36032 .67997 .36083 .67464 .35084 Metetra
.525 .475 .743 r
.67464 .35084 .67997 .36083 .69038 .36188 .68507 .35232 Metetra
.505 .47 .752 r
.68507 .35232 .69038 .36188 .70089 .3633 .6956 .35423 Metetra
.489 .47 .763 r
.6956 .35423 .70089 .3633 .71148 .36497 .70624 .35641 Metetra
.477 .473 .775 r
.70624 .35641 .71148 .36497 .72216 .36673 .71696 .35871 Metetra
.469 .48 .788 r
.71696 .35871 .72216 .36673 .73291 .36848 .72776 .36099 Metetra
.465 .492 .802 r
.72776 .36099 .73291 .36848 .74373 .37014 .73862 .36316 Metetra
.465 .506 .817 r
.73862 .36316 .74373 .37014 .7546 .37163 .74955 .36514 Metetra
.468 .524 .832 r
.74955 .36514 .7546 .37163 .76553 .37291 .76053 .36689 Metetra
.474 .544 .848 r
.76053 .36689 .76553 .37291 .77649 .37394 .77156 .36837 Metetra
.482 .566 .864 r
.77156 .36837 .77649 .37394 .78749 .37473 .78263 .36956 Metetra
.491 .589 .88 r
.78263 .36956 .78749 .37473 .79853 .37525 .79373 .37046 Metetra
.502 .613 .895 r
.79373 .37046 .79853 .37525 .8096 .37552 .80486 .37107 Metetra
.513 .637 .909 r
.80486 .37107 .8096 .37552 .8207 .37553 .81603 .37139 Metetra
.525 .661 .922 r
.81603 .37139 .8207 .37553 .83183 .37532 .82721 .37144 Metetra
.537 .683 .933 r
.82721 .37144 .83183 .37532 .84298 .37488 .83843 .37123 Metetra
.55 .704 .942 r
.83843 .37123 .84298 .37488 .85415 .37422 .84966 .37076 Metetra
.564 .724 .949 r
.84966 .37076 .85415 .37422 .86535 .37335 .86091 .37004 Metetra
.578 .741 .953 r
.86091 .37004 .86535 .37335 .87657 .37229 .87218 .36908 Metetra
.595 .756 .956 r
.87218 .36908 .87657 .37229 .8878 .37101 .88345 .36787 Metetra
.612 .77 .955 r
.88345 .36787 .8878 .37101 .89904 .3695 .89474 .36639 Metetra
.632 .78 .953 r
.89474 .36639 .89904 .3695 .91029 .36776 .90602 .36464 Metetra
.653 .789 .947 r
.90602 .36464 .91029 .36776 .92154 .36575 .91729 .36258 Metetra
.675 .795 .939 r
.91729 .36258 .92154 .36575 .93276 .36343 .92854 .36018 Metetra
.698 .799 .928 r
.92854 .36018 .93276 .36343 .94396 .36075 .93976 .3574 Metetra
.721 .801 .914 r
.93976 .3574 .94396 .36075 .95511 .35767 .95092 .35418 Metetra
.743 .801 .899 r
.95092 .35418 .95511 .35767 .96619 .35411 .96201 .35047 Metetra
.466 .695 .967 r
.34889 .45151 .35461 .45448 .36375 .45454 .35803 .45168 Metetra
.521 .725 .966 r
.35803 .45168 .36375 .45454 .37296 .45415 .36725 .45138 Metetra
.566 .748 .963 r
.36725 .45138 .37296 .45415 .38225 .45335 .37655 .45065 Metetra
.602 .764 .957 r
.37655 .45065 .38225 .45335 .39159 .4522 .38591 .44954 Metetra
.632 .776 .95 r
.38591 .44954 .39159 .4522 .40099 .45072 .39533 .44808 Metetra
.658 .784 .941 r
.39533 .44808 .40099 .45072 .41043 .44896 .4048 .44629 Metetra
.679 .788 .932 r
.4048 .44629 .41043 .44896 .41992 .44693 .41431 .44421 Metetra
.697 .788 .921 r
.41431 .44421 .41992 .44693 .42946 .44464 .42387 .44184 Metetra
.713 .786 .909 r
.42387 .44184 .42946 .44464 .43902 .44212 .43347 .43919 Metetra
.726 .781 .896 r
.43347 .43919 .43902 .44212 .44863 .43935 .4431 .43626 Metetra
.737 .774 .882 r
.4431 .43626 .44863 .43935 .45826 .43635 .45277 .43305 Metetra
.746 .765 .868 r
.45277 .43305 .45826 .43635 .46792 .43309 .46246 .42955 Metetra
.754 .754 .853 r
.46246 .42955 .46792 .43309 .47761 .42958 .47218 .42576 Metetra
.759 .742 .837 r
.47218 .42576 .47761 .42958 .48732 .42579 .48192 .42165 Metetra
.764 .73 .822 r
.48192 .42165 .48732 .42579 .49705 .42171 .49168 .41723 Metetra
.766 .717 .807 r
.49168 .41723 .49705 .42171 .50679 .41735 .50145 .41247 Metetra
.768 .704 .792 r
.50145 .41247 .50679 .41735 .51655 .41269 .51123 .40739 Metetra
.768 .692 .778 r
.51123 .40739 .51655 .41269 .52631 .40773 .52101 .40198 Metetra
.767 .679 .766 r
.52101 .40198 .52631 .40773 .53608 .4025 .5308 .39626 Metetra
.764 .666 .754 r
.5308 .39626 .53608 .4025 .54584 .39703 .54058 .39026 Metetra
.761 .654 .744 r
.54058 .39026 .54584 .39703 .55561 .39136 .55035 .38404 Metetra
.755 .641 .735 r
.55035 .38404 .55561 .39136 .56537 .38556 .56012 .37768 Metetra
.748 .629 .727 r
.56012 .37768 .56537 .38556 .57513 .37974 .56988 .37128 Metetra
.739 .616 .721 r
.56988 .37128 .57513 .37974 .58488 .37401 .57963 .36497 Metetra
.728 .602 .716 r
.57963 .36497 .58488 .37401 .59465 .36853 .58938 .35894 Metetra
.714 .588 .713 r
.58938 .35894 .59465 .36853 .60443 .36347 .59914 .35337 Metetra
.697 .572 .712 r
.59914 .35337 .60443 .36347 .61424 .359 .60893 .34847 Metetra
.676 .556 .712 r
.60893 .34847 .61424 .359 .62409 .3553 .61877 .34446 Metetra
.652 .539 .713 r
.61877 .34446 .62409 .3553 .63401 .35251 .62867 .34149 Metetra
.624 .521 .716 r
.62867 .34149 .63401 .35251 .64402 .3507 .63866 .33966 Metetra
.595 .503 .72 r
.63866 .33966 .64402 .3507 .65412 .34988 .64875 .33897 Metetra
.564 .486 .726 r
.64875 .33897 .65412 .34988 .66432 .34997 .65896 .33934 Metetra
.535 .472 .732 r
.65896 .33934 .66432 .34997 .67464 .35084 .66929 .34061 Metetra
.508 .461 .74 r
.66929 .34061 .67464 .35084 .68507 .35232 .67974 .34257 Metetra
.484 .455 .749 r
.67974 .34257 .68507 .35232 .6956 .35423 .6903 .34501 Metetra
.464 .452 .76 r
.6903 .34501 .6956 .35423 .70624 .35641 .70097 .34774 Metetra
.45 .455 .772 r
.70097 .34774 .70624 .35641 .71696 .35871 .71173 .35058 Metetra
.44 .462 .785 r
.71173 .35058 .71696 .35871 .72776 .36099 .72258 .3534 Metetra
.436 .473 .8 r
.72258 .3534 .72776 .36099 .73862 .36316 .7335 .3561 Metetra
.435 .487 .815 r
.7335 .3561 .73862 .36316 .74955 .36514 .74448 .35858 Metetra
.438 .505 .831 r
.74448 .35858 .74955 .36514 .76053 .36689 .75552 .3608 Metetra
.445 .526 .847 r
.75552 .3608 .76053 .36689 .77156 .36837 .7666 .36272 Metetra
.454 .549 .863 r
.7666 .36272 .77156 .36837 .78263 .36956 .77773 .36432 Metetra
.465 .573 .879 r
.77773 .36432 .78263 .36956 .79373 .37046 .78889 .36559 Metetra
.477 .598 .894 r
.78889 .36559 .79373 .37046 .80486 .37107 .80009 .36653 Metetra
.491 .623 .908 r
.80009 .36653 .80486 .37107 .81603 .37139 .81131 .36716 Metetra
.505 .647 .921 r
.81131 .36716 .81603 .37139 .82721 .37144 .82256 .36747 Metetra
.52 .671 .931 r
.82256 .36747 .82721 .37144 .83843 .37123 .83383 .36748 Metetra
.536 .693 .94 r
.83383 .36748 .83843 .37123 .84966 .37076 .84512 .36719 Metetra
.553 .714 .947 r
.84512 .36719 .84966 .37076 .86091 .37004 .85643 .36662 Metetra
.571 .732 .951 r
.85643 .36662 .86091 .37004 .87218 .36908 .86774 .36577 Metetra
.59 .749 .953 r
.86774 .36577 .87218 .36908 .88345 .36787 .87906 .36463 Metetra
.611 .763 .952 r
.87906 .36463 .88345 .36787 .89474 .36639 .89039 .36318 Metetra
.632 .775 .949 r
.89039 .36318 .89474 .36639 .90602 .36464 .90171 .36143 Metetra
.655 .785 .943 r
.90171 .36143 .90602 .36464 .91729 .36258 .91301 .35933 Metetra
.678 .792 .935 r
.91301 .35933 .91729 .36258 .92854 .36018 .92428 .35686 Metetra
.702 .797 .924 r
.92428 .35686 .92854 .36018 .93976 .3574 .93551 .35398 Metetra
.726 .8 .911 r
.93551 .35398 .93976 .3574 .95092 .35418 .94669 .35065 Metetra
.749 .802 .895 r
.94669 .35065 .95092 .35418 .96201 .35047 .95779 .3468 Metetra
.452 .689 .967 r
.34312 .44853 .34889 .45151 .35803 .45168 .35227 .44879 Metetra
.512 .72 .967 r
.35227 .44879 .35803 .45168 .36725 .45138 .36151 .44856 Metetra
.56 .743 .962 r
.36151 .44856 .36725 .45138 .37655 .45065 .37082 .44789 Metetra
.599 .76 .956 r
.37082 .44789 .37655 .45065 .38591 .44954 .3802 .44681 Metetra
.632 .772 .948 r
.3802 .44681 .38591 .44954 .39533 .44808 .38963 .44535 Metetra
.659 .78 .938 r
.38963 .44535 .39533 .44808 .4048 .44629 .39913 .44354 Metetra
.682 .784 .927 r
.39913 .44354 .4048 .44629 .41431 .44421 .40867 .4414 Metetra
.702 .785 .916 r
.40867 .4414 .41431 .44421 .42387 .44184 .41826 .43894 Metetra
.718 .783 .903 r
.41826 .43894 .42387 .44184 .43347 .43919 .42788 .43617 Metetra
.733 .778 .889 r
.42788 .43617 .43347 .43919 .4431 .43626 .43755 .43308 Metetra
.744 .771 .875 r
.43755 .43308 .4431 .43626 .45277 .43305 .44724 .42967 Metetra
.754 .762 .86 r
.44724 .42967 .45277 .43305 .46246 .42955 .45697 .42594 Metetra
.762 .752 .844 r
.45697 .42594 .46246 .42955 .47218 .42576 .46672 .42187 Metetra
.767 .741 .829 r
.46672 .42187 .47218 .42576 .48192 .42165 .47649 .41745 Metetra
.772 .73 .814 r
.47649 .41745 .48192 .42165 .49168 .41723 .48628 .41268 Metetra
.775 .718 .799 r
.48628 .41268 .49168 .41723 .50145 .41247 .49608 .40754 Metetra
.776 .705 .785 r
.49608 .40754 .50145 .41247 .51123 .40739 .50589 .40203 Metetra
.777 .693 .771 r
.50589 .40203 .51123 .40739 .52101 .40198 .51569 .39616 Metetra
.776 .681 .759 r
.51569 .39616 .52101 .40198 .5308 .39626 .5255 .38995 Metetra
.773 .669 .748 r
.5255 .38995 .5308 .39626 .54058 .39026 .5353 .38343 Metetra
.77 .657 .738 r
.5353 .38343 .54058 .39026 .55035 .38404 .54508 .37665 Metetra
.764 .644 .729 r
.54508 .37665 .55035 .38404 .56012 .37768 .55486 .36971 Metetra
.757 .632 .721 r
.55486 .36971 .56012 .37768 .56988 .37128 .56461 .3627 Metetra
.748 .619 .715 r
.56461 .3627 .56988 .37128 .57963 .36497 .57436 .35579 Metetra
.736 .605 .711 r
.57436 .35579 .57963 .36497 .58938 .35894 .5841 .34915 Metetra
.722 .59 .708 r
.5841 .34915 .58938 .35894 .59914 .35337 .59385 .34303 Metetra
.703 .573 .706 r
.59385 .34303 .59914 .35337 .60893 .34847 .60362 .33766 Metetra
.681 .556 .707 r
.60362 .33766 .60893 .34847 .61877 .34446 .61343 .33329 Metetra
.654 .536 .708 r
.61343 .33329 .61877 .34446 .62867 .34149 .62331 .33012 Metetra
.623 .516 .712 r
.62331 .33012 .62867 .34149 .63866 .33966 .63329 .32827 Metetra
.589 .496 .716 r
.63329 .32827 .63866 .33966 .64875 .33897 .64337 .32775 Metetra
.554 .476 .722 r
.64337 .32775 .64875 .33897 .65896 .33934 .65358 .32844 Metetra
.52 .459 .729 r
.65358 .32844 .65896 .33934 .66929 .34061 .66393 .33014 Metetra
.488 .446 .737 r
.66393 .33014 .66929 .34061 .67974 .34257 .67439 .33262 Metetra
.46 .437 .746 r
.67439 .33262 .67974 .34257 .6903 .34501 .68498 .33563 Metetra
.438 .433 .757 r
.68498 .33563 .6903 .34501 .70097 .34774 .69569 .33894 Metetra
.421 .435 .769 r
.69569 .33894 .70097 .34774 .71173 .35058 .70649 .34236 Metetra
.409 .441 .782 r
.70649 .34236 .71173 .35058 .72258 .3534 .71738 .34574 Metetra
.404 .452 .797 r
.71738 .34574 .72258 .3534 .7335 .3561 .72835 .34897 Metetra
.403 .467 .812 r
.72835 .34897 .7335 .3561 .74448 .35858 .73938 .35196 Metetra
.406 .486 .829 r
.73938 .35196 .74448 .35858 .75552 .3608 .75047 .35465 Metetra
.414 .507 .845 r
.75047 .35465 .75552 .3608 .7666 .36272 .76162 .35701 Metetra
.424 .531 .862 r
.76162 .35701 .7666 .36272 .77773 .36432 .7728 .35901 Metetra
.437 .556 .878 r
.7728 .35901 .77773 .36432 .78889 .36559 .78403 .36065 Metetra
.452 .582 .893 r
.78403 .36065 .78889 .36559 .80009 .36653 .79528 .36192 Metetra
.468 .608 .907 r
.79528 .36192 .80009 .36653 .81131 .36716 .80656 .36284 Metetra
.485 .634 .919 r
.80656 .36284 .81131 .36716 .82256 .36747 .81787 .36341 Metetra
.504 .659 .93 r
.81787 .36341 .82256 .36747 .83383 .36748 .8292 .36364 Metetra
.523 .682 .939 r
.8292 .36364 .83383 .36748 .84512 .36719 .84054 .36354 Metetra
.543 .704 .945 r
.84054 .36354 .84512 .36719 .85643 .36662 .8519 .36311 Metetra
.564 .724 .949 r
.8519 .36311 .85643 .36662 .86774 .36577 .86326 .36236 Metetra
.586 .742 .951 r
.86326 .36236 .86774 .36577 .87906 .36463 .87463 .36129 Metetra
.609 .758 .95 r
.87463 .36129 .87906 .36463 .89039 .36318 .88599 .35988 Metetra
.633 .771 .946 r
.88599 .35988 .89039 .36318 .90171 .36143 .89735 .35812 Metetra
.657 .781 .94 r
.89735 .35812 .90171 .36143 .91301 .35933 .90868 .35599 Metetra
.681 .79 .932 r
.90868 .35599 .91301 .35933 .92428 .35686 .91998 .35347 Metetra
.706 .796 .921 r
.91998 .35347 .92428 .35686 .93551 .35398 .93123 .3505 Metetra
.73 .8 .907 r
.93123 .3505 .93551 .35398 .94669 .35065 .94243 .34707 Metetra
.753 .802 .892 r
.94243 .34707 .94669 .35065 .95779 .3468 .95354 .3431 Metetra
.44 .684 .968 r
.33732 .44553 .34312 .44853 .35227 .44879 .34648 .44587 Metetra
.504 .716 .967 r
.34648 .44587 .35227 .44879 .36151 .44856 .35573 .4457 Metetra
.555 .74 .962 r
.35573 .4457 .36151 .44856 .37082 .44789 .36505 .44507 Metetra
.597 .757 .955 r
.36505 .44507 .37082 .44789 .3802 .44681 .37445 .44401 Metetra
.632 .769 .946 r
.37445 .44401 .3802 .44681 .38963 .44535 .3839 .44256 Metetra
.661 .777 .935 r
.3839 .44256 .38963 .44535 .39913 .44354 .39342 .44072 Metetra
.685 .781 .923 r
.39342 .44072 .39913 .44354 .40867 .4414 .40299 .43852 Metetra
.706 .782 .911 r
.40299 .43852 .40867 .4414 .41826 .43894 .4126 .43597 Metetra
.724 .78 .897 r
.4126 .43597 .41826 .43894 .42788 .43617 .42226 .43306 Metetra
.738 .775 .883 r
.42226 .43306 .42788 .43617 .43755 .43308 .43196 .42982 Metetra
.751 .769 .868 r
.43196 .42982 .43755 .43308 .44724 .42967 .44169 .42621 Metetra
.761 .761 .852 r
.44169 .42621 .44724 .42967 .45697 .42594 .45144 .42225 Metetra
.769 .751 .837 r
.45144 .42225 .45697 .42594 .46672 .42187 .46123 .41791 Metetra
.775 .741 .822 r
.46123 .41791 .46672 .42187 .47649 .41745 .47103 .41319 Metetra
.779 .73 .807 r
.47103 .41319 .47649 .41745 .48628 .41268 .48085 .40808 Metetra
.783 .718 .792 r
.48085 .40808 .48628 .41268 .49608 .40754 .49068 .40256 Metetra
.784 .706 .778 r
.49068 .40256 .49608 .40754 .50589 .40203 .50052 .39663 Metetra
.785 .695 .765 r
.50052 .39663 .50589 .40203 .51569 .39616 .51035 .39031 Metetra
.784 .683 .753 r
.51035 .39031 .51569 .39616 .5255 .38995 .52018 .3836 Metetra
.782 .671 .742 r
.52018 .3836 .5255 .38995 .5353 .38343 .53 .37655 Metetra
.778 .659 .732 r
.53 .37655 .5353 .38343 .54508 .37665 .5398 .3692 Metetra
.773 .647 .723 r
.5398 .3692 .54508 .37665 .55486 .36971 .54958 .36165 Metetra
.766 .635 .716 r
.54958 .36165 .55486 .36971 .56461 .3627 .55934 .35401 Metetra
.757 .622 .71 r
.55934 .35401 .56461 .3627 .57436 .35579 .56908 .34645 Metetra
.745 .607 .705 r
.56908 .34645 .57436 .35579 .5841 .34915 .57882 .33918 Metetra
.729 .592 .702 r
.57882 .33918 .5841 .34915 .59385 .34303 .58855 .33245 Metetra
.71 .575 .701 r
.58855 .33245 .59385 .34303 .60362 .33766 .59829 .32655 Metetra
.686 .555 .702 r
.59829 .32655 .60362 .33766 .61343 .33329 .60809 .32178 Metetra
.656 .534 .704 r
.60809 .32178 .61343 .33329 .62331 .33012 .61795 .31838 Metetra
.622 .511 .707 r
.61795 .31838 .62331 .33012 .63329 .32827 .6279 .31652 Metetra
.583 .488 .712 r
.6279 .31652 .63329 .32827 .64337 .32775 .63798 .31618 Metetra
.543 .465 .718 r
.63798 .31618 .64337 .32775 .65358 .32844 .64819 .31723 Metetra
.503 .445 .725 r
.64819 .31723 .65358 .32844 .66393 .33014 .65854 .31943 Metetra
.467 .429 .733 r
.65854 .31943 .66393 .33014 .67439 .33262 .66903 .32248 Metetra
.434 .418 .742 r
.66903 .32248 .67439 .33262 .68498 .33563 .67965 .3261 Metetra
.408 .413 .753 r
.67965 .3261 .68498 .33563 .69569 .33894 .69039 .33003 Metetra
.389 .413 .765 r
.69039 .33003 .69569 .33894 .70649 .34236 .70123 .33405 Metetra
.376 .419 .778 r
.70123 .33405 .70649 .34236 .71738 .34574 .71216 .33801 Metetra
.369 .43 .793 r
.71216 .33801 .71738 .34574 .72835 .34897 .72318 .34179 Metetra
.368 .445 .809 r
.72318 .34179 .72835 .34897 .73938 .35196 .73426 .34529 Metetra
.372 .465 .826 r
.73426 .34529 .73938 .35196 .75047 .35465 .74541 .34845 Metetra
.381 .487 .843 r
.74541 .34845 .75047 .35465 .76162 .35701 .75661 .35125 Metetra
.393 .512 .859 r
.75661 .35125 .76162 .35701 .7728 .35901 .76785 .35365 Metetra
.408 .538 .876 r
.76785 .35365 .7728 .35901 .78403 .36065 .77913 .35565 Metetra
.426 .566 .891 r
.77913 .35565 .78403 .36065 .79528 .36192 .79044 .35725 Metetra
.445 .593 .905 r
.79044 .35725 .79528 .36192 .80656 .36284 .80178 .35845 Metetra
.465 .621 .918 r
.80178 .35845 .80656 .36284 .81787 .36341 .81314 .35927 Metetra
.487 .647 .929 r
.81314 .35927 .81787 .36341 .8292 .36364 .82453 .35972 Metetra
.509 .672 .937 r
.82453 .35972 .8292 .36364 .84054 .36354 .83592 .35979 Metetra
.532 .695 .943 r
.83592 .35979 .84054 .36354 .8519 .36311 .84733 .35951 Metetra
.557 .717 .947 r
.84733 .35951 .8519 .36311 .86326 .36236 .85874 .35886 Metetra
.581 .736 .949 r
.85874 .35886 .86326 .36236 .87463 .36129 .87015 .35786 Metetra
.607 .752 .947 r
.87015 .35786 .87463 .36129 .88599 .35988 .88156 .35649 Metetra
.632 .767 .944 r
.88156 .35649 .88599 .35988 .89735 .35812 .89294 .35474 Metetra
.658 .778 .937 r
.89294 .35474 .89735 .35812 .90868 .35599 .90431 .35259 Metetra
.684 .787 .929 r
.90431 .35259 .90868 .35599 .91998 .35347 .91564 .35001 Metetra
.709 .794 .918 r
.91564 .35001 .91998 .35347 .93123 .3505 .92691 .34697 Metetra
.733 .799 .905 r
.92691 .34697 .93123 .3505 .94243 .34707 .93813 .34345 Metetra
.756 .802 .89 r
.93813 .34345 .94243 .34707 .95354 .3431 .94926 .33938 Metetra
.43 .68 .968 r
.33149 .44252 .33732 .44553 .34648 .44587 .34065 .44291 Metetra
.497 .713 .967 r
.34065 .44291 .34648 .44587 .35573 .4457 .34991 .44279 Metetra
.551 .737 .962 r
.34991 .44279 .35573 .4457 .36505 .44507 .35925 .4422 Metetra
.596 .754 .954 r
.35925 .4422 .36505 .44507 .37445 .44401 .36866 .44116 Metetra
.632 .767 .944 r
.36866 .44116 .37445 .44401 .3839 .44256 .37814 .43969 Metetra
.663 .774 .932 r
.37814 .43969 .3839 .44256 .39342 .44072 .38768 .43782 Metetra
.689 .778 .919 r
.38768 .43782 .39342 .44072 .40299 .43852 .39727 .43556 Metetra
.71 .779 .906 r
.39727 .43556 .40299 .43852 .4126 .43597 .40692 .43292 Metetra
.729 .777 .892 r
.40692 .43292 .4126 .43597 .42226 .43306 .4166 .42989 Metetra
.744 .773 .877 r
.4166 .42989 .42226 .43306 .43196 .42982 .42633 .42648 Metetra
.756 .767 .861 r
.42633 .42648 .43196 .42982 .44169 .42621 .4361 .42269 Metetra
.767 .759 .846 r
.4361 .42269 .44169 .42621 .45144 .42225 .44589 .4185 Metetra
.775 .75 .83 r
.44589 .4185 .45144 .42225 .46123 .41791 .45571 .4139 Metetra
.782 .74 .815 r
.45571 .4139 .46123 .41791 .47103 .41319 .46554 .40888 Metetra
.786 .73 .8 r
.46554 .40888 .47103 .41319 .48085 .40808 .4754 .40343 Metetra
.79 .719 .786 r
.4754 .40343 .48085 .40808 .49068 .40256 .48526 .39754 Metetra
.792 .708 .772 r
.48526 .39754 .49068 .40256 .50052 .39663 .49513 .3912 Metetra
.792 .697 .759 r
.49513 .3912 .50052 .39663 .51035 .39031 .50499 .38442 Metetra
.792 .685 .747 r
.50499 .38442 .51035 .39031 .52018 .3836 .51484 .37722 Metetra
.79 .674 .736 r
.51484 .37722 .52018 .3836 .53 .37655 .52468 .36963 Metetra
.787 .662 .726 r
.52468 .36963 .53 .37655 .5398 .3692 .5345 .3617 Metetra
.782 .65 .717 r
.5345 .3617 .5398 .3692 .54958 .36165 .54429 .35353 Metetra
.775 .638 .71 r
.54429 .35353 .54958 .36165 .55934 .35401 .55406 .34523 Metetra
.766 .625 .704 r
.55406 .34523 .55934 .35401 .56908 .34645 .5638 .33698 Metetra
.754 .61 .699 r
.5638 .33698 .56908 .34645 .57882 .33918 .57352 .32901 Metetra
.738 .594 .697 r
.57352 .32901 .57882 .33918 .58855 .33245 .58324 .32161 Metetra
.717 .576 .695 r
.58324 .32161 .58855 .33245 .59829 .32655 .59297 .31512 Metetra
.691 .556 .696 r
.59297 .31512 .59829 .32655 .60809 .32178 .60273 .30989 Metetra
.659 .532 .699 r
.60273 .30989 .60809 .32178 .61795 .31838 .61257 .30624 Metetra
.62 .506 .702 r
.61257 .30624 .61795 .31838 .6279 .31652 .62251 .30435 Metetra
.576 .479 .707 r
.62251 .30435 .6279 .31652 .63798 .31618 .63257 .30423 Metetra
.53 .453 .713 r
.63257 .30423 .63798 .31618 .64819 .31723 .64279 .30571 Metetra
.484 .429 .72 r
.64279 .30571 .64819 .31723 .65854 .31943 .65315 .30846 Metetra
.442 .41 .728 r
.65315 .30846 .65854 .31943 .66903 .32248 .66366 .31215 Metetra
.405 .397 .737 r
.66366 .31215 .66903 .32248 .67965 .3261 .6743 .31643 Metetra
.375 .389 .747 r
.6743 .31643 .67965 .3261 .69039 .33003 .68507 .32102 Metetra
.353 .389 .759 r
.68507 .32102 .69039 .33003 .70123 .33405 .69595 .32568 Metetra
.338 .394 .773 r
.69595 .32568 .70123 .33405 .71216 .33801 .70693 .33024 Metetra
.331 .406 .788 r
.70693 .33024 .71216 .33801 .72318 .34179 .71799 .33457 Metetra
.331 .422 .805 r
.71799 .33457 .72318 .34179 .73426 .34529 .72912 .33858 Metetra
.336 .442 .822 r
.72912 .33858 .73426 .34529 .74541 .34845 .74032 .34222 Metetra
.346 .466 .839 r
.74032 .34222 .74541 .34845 .75661 .35125 .75157 .34545 Metetra
.361 .493 .857 r
.75157 .34545 .75661 .35125 .76785 .35365 .76286 .34825 Metetra
.378 .521 .873 r
.76286 .34825 .76785 .35365 .77913 .35565 .7742 .3506 Metetra
.399 .55 .889 r
.7742 .3506 .77913 .35565 .79044 .35725 .78557 .35252 Metetra
.421 .579 .904 r
.78557 .35252 .79044 .35725 .80178 .35845 .79696 .35401 Metetra
.445 .608 .917 r
.79696 .35401 .80178 .35845 .81314 .35927 .80838 .35507 Metetra
.469 .636 .927 r
.80838 .35507 .81314 .35927 .82453 .35972 .81981 .35572 Metetra
.495 .662 .936 r
.81981 .35572 .82453 .35972 .83592 .35979 .83126 .35597 Metetra
.522 .687 .942 r
.83126 .35597 .83592 .35979 .84733 .35951 .84272 .35582 Metetra
.549 .71 .946 r
.84272 .35582 .84733 .35951 .85874 .35886 .85418 .35529 Metetra
.576 .73 .947 r
.85418 .35529 .85874 .35886 .87015 .35786 .86563 .35435 Metetra
.604 .748 .946 r
.86563 .35435 .87015 .35786 .88156 .35649 .87708 .35302 Metetra
.631 .763 .942 r
.87708 .35302 .88156 .35649 .89294 .35474 .8885 .35128 Metetra
.659 .775 .935 r
.8885 .35128 .89294 .35474 .90431 .35259 .8999 .34911 Metetra
.685 .785 .926 r
.8999 .34911 .90431 .35259 .91564 .35001 .91125 .34649 Metetra
.711 .793 .915 r
.91125 .34649 .91564 .35001 .92691 .34697 .92256 .34339 Metetra
.736 .798 .902 r
.92256 .34339 .92691 .34697 .93813 .34345 .9338 .33979 Metetra
.759 .802 .888 r
.9338 .33979 .93813 .34345 .94926 .33938 .94496 .33563 Metetra
.421 .676 .968 r
.32561 .43948 .33149 .44252 .34065 .44291 .33478 .43992 Metetra
.491 .71 .967 r
.33478 .43992 .34065 .44291 .34991 .44279 .34405 .43985 Metetra
.548 .734 .962 r
.34405 .43985 .34991 .44279 .35925 .4422 .35341 .43928 Metetra
.595 .752 .953 r
.35341 .43928 .35925 .4422 .36866 .44116 .36284 .43825 Metetra
.633 .764 .942 r
.36284 .43825 .36866 .44116 .37814 .43969 .37234 .43677 Metetra
.665 .772 .929 r
.37234 .43677 .37814 .43969 .38768 .43782 .3819 .43486 Metetra
.692 .776 .916 r
.3819 .43486 .38768 .43782 .39727 .43556 .39152 .43254 Metetra
.714 .777 .902 r
.39152 .43254 .39727 .43556 .40692 .43292 .40119 .4298 Metetra
.733 .775 .887 r
.40119 .4298 .40692 .43292 .4166 .42989 .41091 .42665 Metetra
.749 .771 .871 r
.41091 .42665 .4166 .42989 .42633 .42648 .42067 .42309 Metetra
.762 .765 .856 r
.42067 .42309 .42633 .42648 .4361 .42269 .43047 .41911 Metetra
.773 .758 .84 r
.43047 .41911 .4361 .42269 .44589 .4185 .4403 .4147 Metetra
.781 .75 .824 r
.4403 .4147 .44589 .4185 .45571 .4139 .45015 .40984 Metetra
.788 .74 .809 r
.45015 .40984 .45571 .4139 .46554 .40888 .46003 .40453 Metetra
.793 .73 .794 r
.46003 .40453 .46554 .40888 .4754 .40343 .46992 .39875 Metetra
.797 .72 .78 r
.46992 .39875 .4754 .40343 .48526 .39754 .47981 .39249 Metetra
.799 .709 .766 r
.47981 .39249 .48526 .39754 .49513 .3912 .48971 .38575 Metetra
.8 .699 .753 r
.48971 .38575 .49513 .3912 .50499 .38442 .4996 .37852 Metetra
.8 .688 .741 r
.4996 .37852 .50499 .38442 .51484 .37722 .50949 .37082 Metetra
.798 .677 .73 r
.50949 .37082 .51484 .37722 .52468 .36963 .51935 .36269 Metetra
.795 .665 .72 r
.51935 .36269 .52468 .36963 .5345 .3617 .52919 .35417 Metetra
.79 .654 .712 r
.52919 .35417 .5345 .3617 .54429 .35353 .539 .34535 Metetra
.784 .641 .704 r
.539 .34535 .54429 .35353 .55406 .34523 .54877 .33636 Metetra
.775 .628 .698 r
.54877 .33636 .55406 .34523 .5638 .33698 .55851 .32739 Metetra
.762 .614 .694 r
.55851 .32739 .5638 .33698 .57352 .32901 .56823 .31866 Metetra
.746 .597 .691 r
.56823 .31866 .57352 .32901 .58324 .32161 .57793 .31052 Metetra
.725 .578 .69 r
.57793 .31052 .58324 .32161 .59297 .31512 .58763 .30335 Metetra
.697 .556 .691 r
.58763 .30335 .59297 .31512 .60273 .30989 .59737 .2976 Metetra
.662 .53 .693 r
.59737 .2976 .60273 .30989 .61257 .30624 .60718 .29364 Metetra
.618 .501 .698 r
.60718 .29364 .61257 .30624 .62251 .30435 .6171 .29173 Metetra
.569 .47 .703 r
.6171 .29173 .62251 .30435 .63257 .30423 .62715 .29188 Metetra
.515 .439 .708 r
.62715 .29188 .63257 .30423 .64279 .30571 .63737 .29384 Metetra
.463 .411 .715 r
.63737 .29384 .64279 .30571 .65315 .30846 .64774 .29724 Metetra
.414 .389 .722 r
.64774 .29724 .65315 .30846 .66366 .31215 .65827 .30163 Metetra
.372 .373 .731 r
.65827 .30163 .66366 .31215 .6743 .31643 .66894 .30664 Metetra
.338 .364 .741 r
.66894 .30664 .6743 .31643 .68507 .32102 .67974 .31192 Metetra
.313 .362 .753 r
.67974 .31192 .68507 .32102 .69595 .32568 .69066 .31725 Metetra
.297 .368 .767 r
.69066 .31725 .69595 .32568 .70693 .33024 .70168 .32243 Metetra
.29 .379 .782 r
.70168 .32243 .70693 .33024 .71799 .33457 .71278 .32733 Metetra
.29 .397 .799 r
.71278 .32733 .71799 .33457 .72912 .33858 .72396 .33186 Metetra
.297 .419 .817 r
.72396 .33186 .72912 .33858 .74032 .34222 .73521 .33598 Metetra
.309 .444 .835 r
.73521 .33598 .74032 .34222 .75157 .34545 .74651 .33963 Metetra
.326 .472 .853 r
.74651 .33963 .75157 .34545 .76286 .34825 .75786 .34282 Metetra
.347 .502 .871 r
.75786 .34282 .76286 .34825 .7742 .3506 .76924 .34552 Metetra
.371 .533 .887 r
.76924 .34552 .7742 .3506 .78557 .35252 .78066 .34775 Metetra
.396 .564 .902 r
.78066 .34775 .78557 .35252 .79696 .35401 .79211 .34951 Metetra
.424 .595 .915 r
.79211 .34951 .79696 .35401 .80838 .35507 .80358 .35081 Metetra
.452 .625 .926 r
.80358 .35081 .80838 .35507 .81981 .35572 .81507 .35166 Metetra
.481 .653 .935 r
.81507 .35166 .81981 .35572 .83126 .35597 .82656 .35208 Metetra
.511 .679 .941 r
.82656 .35208 .83126 .35597 .84272 .35582 .83807 .35207 Metetra
.541 .703 .945 r
.83807 .35207 .84272 .35582 .85418 .35529 .84957 .35163 Metetra
.571 .724 .946 r
.84957 .35163 .85418 .35529 .86563 .35435 .86107 .35077 Metetra
.601 .743 .944 r
.86107 .35077 .86563 .35435 .87708 .35302 .87255 .34948 Metetra
.63 .759 .94 r
.87255 .34948 .87708 .35302 .8885 .35128 .88402 .34775 Metetra
.659 .773 .933 r
.88402 .34775 .8885 .35128 .8999 .34911 .89545 .34557 Metetra
.687 .783 .924 r
.89545 .34557 .8999 .34911 .91125 .34649 .90684 .34292 Metetra
.713 .792 .913 r
.90684 .34292 .91125 .34649 .92256 .34339 .91817 .33977 Metetra
.738 .798 .9 r
.91817 .33977 .92256 .34339 .9338 .33979 .92944 .33609 Metetra
.761 .802 .886 r
.92944 .33609 .9338 .33979 .94496 .33563 .94062 .33186 Metetra
.414 .673 .968 r
.31969 .43644 .32561 .43948 .33478 .43992 .32888 .43691 Metetra
.487 .708 .968 r
.32888 .43691 .33478 .43992 .34405 .43985 .33816 .43686 Metetra
.546 .733 .962 r
.33816 .43686 .34405 .43985 .35341 .43928 .34753 .43632 Metetra
.594 .75 .952 r
.34753 .43632 .35341 .43928 .36284 .43825 .35698 .43529 Metetra
.634 .763 .94 r
.35698 .43529 .36284 .43825 .37234 .43677 .3665 .43379 Metetra
.667 .77 .927 r
.3665 .43379 .37234 .43677 .3819 .43486 .37609 .43185 Metetra
.695 .774 .913 r
.37609 .43185 .3819 .43486 .39152 .43254 .38574 .42946 Metetra
.718 .775 .898 r
.38574 .42946 .39152 .43254 .40119 .4298 .39544 .42663 Metetra
.737 .774 .882 r
.39544 .42663 .40119 .4298 .41091 .42665 .40519 .42336 Metetra
.754 .77 .866 r
.40519 .42336 .41091 .42665 .42067 .42309 .41498 .41965 Metetra
.767 .764 .85 r
.41498 .41965 .42067 .42309 .43047 .41911 .42481 .41548 Metetra
.778 .757 .834 r
.42481 .41548 .43047 .41911 .4403 .4147 .43468 .41085 Metetra
.787 .749 .819 r
.43468 .41085 .4403 .4147 .45015 .40984 .44457 .40575 Metetra
.794 .741 .803 r
.44457 .40575 .45015 .40984 .46003 .40453 .45448 .40016 Metetra
.799 .731 .789 r
.45448 .40016 .46003 .40453 .46992 .39875 .4644 .39406 Metetra
.803 .721 .774 r
.4644 .39406 .46992 .39875 .47981 .39249 .47434 .38744 Metetra
.806 .711 .761 r
.47434 .38744 .47981 .39249 .48971 .38575 .48427 .38029 Metetra
.807 .701 .748 r
.48427 .38029 .48971 .38575 .4996 .37852 .4942 .37262 Metetra
.807 .69 .736 r
.4942 .37262 .4996 .37852 .50949 .37082 .50411 .36442 Metetra
.806 .68 .725 r
.50411 .36442 .50949 .37082 .51935 .36269 .514 .35574 Metetra
.803 .669 .715 r
.514 .35574 .51935 .36269 .52919 .35417 .52386 .34662 Metetra
.799 .657 .706 r
.52386 .34662 .52919 .35417 .539 .34535 .53369 .33715 Metetra
.792 .645 .699 r
.53369 .33715 .539 .34535 .54877 .33636 .54348 .32744 Metetra
.784 .632 .693 r
.54348 .32744 .54877 .33636 .55851 .32739 .55322 .31768 Metetra
.772 .617 .688 r
.55322 .31768 .55851 .32739 .56823 .31866 .56293 .30814 Metetra
.755 .6 .685 r
.56293 .30814 .56823 .31866 .57793 .31052 .57262 .29917 Metetra
.734 .581 .684 r
.57262 .29917 .57793 .31052 .58763 .30335 .5823 .29123 Metetra
.704 .557 .685 r
.5823 .29123 .58763 .30335 .59737 .2976 .59201 .28485 Metetra
.665 .529 .688 r
.59201 .28485 .59737 .2976 .60718 .29364 .60179 .28054 Metetra
.617 .496 .692 r
.60179 .28054 .60718 .29364 .6171 .29173 .61168 .27861 Metetra
.56 .46 .697 r
.61168 .27861 .6171 .29173 .62715 .29188 .62172 .27908 Metetra
.498 .423 .703 r
.62172 .27908 .62715 .29188 .63737 .29384 .63193 .28162 Metetra
.437 .391 .709 r
.63193 .28162 .63737 .29384 .64774 .29724 .64232 .28575 Metetra
.381 .364 .715 r
.64232 .28575 .64774 .29724 .65827 .30163 .65287 .29094 Metetra
.333 .345 .723 r
.65287 .29094 .65827 .30163 .66894 .30664 .66357 .29673 Metetra
.295 .335 .733 r
.66357 .29673 .66894 .30664 .67974 .31192 .67441 .30277 Metetra
.268 .332 .745 r
.67441 .30277 .67974 .31192 .69066 .31725 .68536 .30879 Metetra
.251 .338 .758 r
.68536 .30879 .69066 .31725 .70168 .32243 .69642 .3146 Metetra
.244 .351 .774 r
.69642 .3146 .70168 .32243 .71278 .32733 .70756 .32008 Metetra
.246 .369 .792 r
.70756 .32008 .71278 .32733 .72396 .33186 .71879 .32514 Metetra
.255 .393 .81 r
.71879 .32514 .72396 .33186 .73521 .33598 .73008 .32973 Metetra
.27 .421 .829 r
.73008 .32973 .73521 .33598 .74651 .33963 .74143 .33381 Metetra
.29 .451 .848 r
.74143 .33381 .74651 .33963 .75786 .34282 .75282 .33737 Metetra
.314 .483 .867 r
.75282 .33737 .75786 .34282 .76924 .34552 .76426 .34042 Metetra
.342 .517 .884 r
.76426 .34042 .76924 .34552 .78066 .34775 .77573 .34295 Metetra
.371 .55 .9 r
.77573 .34295 .78066 .34775 .79211 .34951 .78723 .34497 Metetra
.402 .583 .914 r
.78723 .34497 .79211 .34951 .80358 .35081 .79875 .3465 Metetra
.435 .614 .925 r
.79875 .3465 .80358 .35081 .81507 .35166 .81028 .34755 Metetra
.467 .644 .934 r
.81028 .34755 .81507 .35166 .82656 .35208 .82183 .34813 Metetra
.5 .672 .94 r
.82183 .34813 .82656 .35208 .83807 .35207 .83338 .34825 Metetra
.533 .697 .944 r
.83338 .34825 .83807 .35207 .84957 .35163 .84493 .34791 Metetra
.566 .719 .945 r
.84493 .34791 .84957 .35163 .86107 .35077 .85647 .34712 Metetra
.598 .739 .943 r
.85647 .34712 .86107 .35077 .87255 .34948 .86799 .34587 Metetra
.629 .756 .939 r
.86799 .34587 .87255 .34948 .88402 .34775 .87949 .34416 Metetra
.659 .77 .932 r
.87949 .34416 .88402 .34775 .89545 .34557 .89096 .34197 Metetra
.687 .782 .923 r
.89096 .34197 .89545 .34557 .90684 .34292 .90238 .33929 Metetra
.714 .791 .911 r
.90238 .33929 .90684 .34292 .91817 .33977 .91374 .3361 Metetra
.74 .797 .899 r
.91374 .3361 .91817 .33977 .92944 .33609 .92504 .33236 Metetra
.763 .802 .885 r
.92504 .33236 .92944 .33609 .94062 .33186 .93625 .32807 Metetra
.409 .671 .968 r
.31374 .43337 .31969 .43644 .32888 .43691 .32294 .43387 Metetra
.483 .706 .968 r
.32294 .43387 .32888 .43691 .33816 .43686 .33223 .43385 Metetra
.544 .731 .961 r
.33223 .43385 .33816 .43686 .34753 .43632 .34161 .43331 Metetra
.594 .749 .951 r
.34161 .43331 .34753 .43632 .35698 .43529 .35108 .43228 Metetra
.635 .761 .939 r
.35108 .43228 .35698 .43529 .3665 .43379 .36063 .43076 Metetra
.669 .769 .925 r
.36063 .43076 .3665 .43379 .37609 .43185 .37024 .42877 Metetra
.698 .773 .91 r
.37024 .42877 .37609 .43185 .38574 .42946 .37991 .42632 Metetra
.722 .774 .894 r
.37991 .42632 .38574 .42946 .39544 .42663 .38964 .4234 Metetra
.741 .772 .878 r
.38964 .4234 .39544 .42663 .40519 .42336 .39943 .42001 Metetra
.758 .769 .862 r
.39943 .42001 .40519 .42336 .41498 .41965 .40925 .41615 Metetra
.772 .764 .846 r
.40925 .41615 .41498 .41965 .42481 .41548 .41912 .41181 Metetra
.783 .757 .83 r
.41912 .41181 .42481 .41548 .43468 .41085 .42902 .40698 Metetra
.792 .749 .814 r
.42902 .40698 .43468 .41085 .44457 .40575 .43895 .40163 Metetra
.799 .741 .798 r
.43895 .40163 .44457 .40575 .45448 .40016 .4489 .39576 Metetra
.805 .732 .784 r
.4489 .39576 .45448 .40016 .4644 .39406 .45886 .38935 Metetra
.809 .723 .769 r
.45886 .38935 .4644 .39406 .47434 .38744 .46883 .38238 Metetra
.812 .713 .756 r
.46883 .38238 .47434 .38744 .48427 .38029 .4788 .37484 Metetra
.814 .703 .743 r
.4788 .37484 .48427 .38029 .4942 .37262 .48877 .36673 Metetra
.814 .693 .731 r
.48877 .36673 .4942 .37262 .50411 .36442 .49871 .35805 Metetra
.813 .683 .72 r
.49871 .35805 .50411 .36442 .514 .35574 .50863 .34882 Metetra
.811 .672 .71 r
.50863 .34882 .514 .35574 .52386 .34662 .51852 .33909 Metetra
.807 .661 .701 r
.51852 .33909 .52386 .34662 .53369 .33715 .52837 .32893 Metetra
.801 .649 .694 r
.52837 .32893 .53369 .33715 .54348 .32744 .53817 .31847 Metetra
.793 .636 .687 r
.53817 .31847 .54348 .32744 .55322 .31768 .54793 .30789 Metetra
.781 .621 .682 r
.54793 .30789 .55322 .31768 .56293 .30814 .55764 .29745 Metetra
.765 .604 .679 r
.55764 .29745 .56293 .30814 .57262 .29917 .56731 .28756 Metetra
.743 .584 .678 r
.56731 .28756 .57262 .29917 .5823 .29123 .57696 .27873 Metetra
.712 .558 .679 r
.57696 .27873 .5823 .29123 .59201 .28485 .58664 .27161 Metetra
.628 .501 .689 r
.58664 .27161 .59201 .28485 .60179 .28054 .59646 .26909 Metetra
.622 .514 .71 r
.59646 .26909 .60179 .28054 .61168 .27861 .60634 .26715 Metetra
.608 .505 .712 r
.60634 .26715 .61168 .27861 .62172 .27908 .61628 .26577 Metetra
.477 .405 .697 r
.61628 .26577 .62172 .27908 .63193 .28162 .62649 .26902 Metetra
.407 .367 .701 r
.62649 .26902 .63193 .28162 .64232 .28575 .63689 .27401 Metetra
.343 .336 .707 r
.63689 .27401 .64232 .28575 .65287 .29094 .64746 .28009 Metetra
.289 .314 .714 r
.64746 .28009 .65287 .29094 .66357 .29673 .65819 .28674 Metetra
.247 .302 .723 r
.65819 .28674 .66357 .29673 .67441 .30277 .66906 .29358 Metetra
.218 .299 .734 r
.66906 .29358 .67441 .30277 .68536 .30879 .68005 .30032 Metetra
.201 .305 .748 r
.68005 .30032 .68536 .30879 .69642 .3146 .69114 .30679 Metetra
.194 .319 .764 r
.69114 .30679 .69642 .3146 .70756 .32008 .70233 .31285 Metetra
.198 .34 .782 r
.70233 .31285 .70756 .32008 .71879 .32514 .7136 .31844 Metetra
.21 .366 .802 r
.7136 .31844 .71879 .32514 .73008 .32973 .72493 .32349 Metetra
.228 .396 .823 r
.72493 .32349 .73008 .32973 .74143 .33381 .73632 .32799 Metetra
.252 .429 .843 r
.73632 .32799 .74143 .33381 .75282 .33737 .74777 .33193 Metetra
.281 .464 .863 r
.74777 .33193 .75282 .33737 .76426 .34042 .75925 .3353 Metetra
.312 .5 .881 r
.75925 .3353 .76426 .34042 .77573 .34295 .77077 .33812 Metetra
.346 .535 .898 r
.77077 .33812 .77573 .34295 .78723 .34497 .78232 .3404 Metetra
.381 .57 .912 r
.78232 .3404 .78723 .34497 .79875 .3465 .79388 .34216 Metetra
.417 .604 .924 r
.79388 .34216 .79875 .3465 .81028 .34755 .80547 .3434 Metetra
.453 .635 .933 r
.80547 .3434 .81028 .34755 .82183 .34813 .81706 .34413 Metetra
.49 .664 .94 r
.81706 .34413 .82183 .34813 .83338 .34825 .82866 .34438 Metetra
.525 .691 .943 r
.82866 .34438 .83338 .34825 .84493 .34791 .84025 .34414 Metetra
.56 .715 .944 r
.84025 .34414 .84493 .34791 .85647 .34712 .85183 .34341 Metetra
.594 .735 .942 r
.85183 .34341 .85647 .34712 .86799 .34587 .8634 .34221 Metetra
.627 .753 .938 r
.8634 .34221 .86799 .34587 .87949 .34416 .87493 .34051 Metetra
.658 .768 .931 r
.87493 .34051 .87949 .34416 .89096 .34197 .88643 .33832 Metetra
.688 .78 .921 r
.88643 .33832 .89096 .34197 .90238 .33929 .89789 .33562 Metetra
.715 .79 .91 r
.89789 .33562 .90238 .33929 .91374 .3361 .90928 .33238 Metetra
.741 .797 .897 r
.90928 .33238 .91374 .3361 .92504 .33236 .92061 .3286 Metetra
.765 .803 .883 r
.92061 .3286 .92504 .33236 .93625 .32807 .93185 .32425 Metetra
.404 .669 .968 r
.30775 .43029 .31374 .43337 .32294 .43387 .31695 .43081 Metetra
.48 .704 .968 r
.31695 .43081 .32294 .43387 .33223 .43385 .32626 .4308 Metetra
.543 .73 .961 r
.32626 .4308 .33223 .43385 .34161 .43331 .33566 .43027 Metetra
.594 .748 .95 r
.33566 .43027 .34161 .43331 .35108 .43228 .34515 .42923 Metetra
.637 .76 .937 r
.34515 .42923 .35108 .43228 .36063 .43076 .35471 .42769 Metetra
.672 .768 .923 r
.35471 .42769 .36063 .43076 .37024 .42877 .36435 .42566 Metetra
.701 .772 .907 r
.36435 .42566 .37024 .42877 .37991 .42632 .37405 .42313 Metetra
.725 .773 .891 r
.37405 .42313 .37991 .42632 .38964 .4234 .38381 .42013 Metetra
.745 .772 .874 r
.38381 .42013 .38964 .4234 .39943 .42001 .39363 .41662 Metetra
.762 .768 .858 r
.39363 .41662 .39943 .42001 .40925 .41615 .40349 .41262 Metetra
.776 .763 .841 r
.40349 .41262 .40925 .41615 .41912 .41181 .41339 .40811 Metetra
.788 .757 .825 r
.41339 .40811 .41912 .41181 .42902 .40698 .42333 .40308 Metetra
.797 .75 .809 r
.42333 .40308 .42902 .40698 .43895 .40163 .4333 .3975 Metetra
.805 .742 .794 r
.4333 .3975 .43895 .40163 .4489 .39576 .44329 .39136 Metetra
.811 .733 .779 r
.44329 .39136 .4489 .39576 .45886 .38935 .45329 .38465 Metetra
.815 .725 .765 r
.45329 .38465 .45886 .38935 .46883 .38238 .4633 .37734 Metetra
.818 .715 .751 r
.4633 .37734 .46883 .38238 .4788 .37484 .47331 .36941 Metetra
.82 .706 .739 r
.47331 .36941 .4788 .37484 .48877 .36673 .48331 .36087 Metetra
.821 .696 .727 r
.48331 .36087 .48877 .36673 .49871 .35805 .49329 .35171 Metetra
.82 .686 .716 r
.49329 .35171 .49871 .35805 .50863 .34882 .50325 .34193 Metetra
.818 .676 .705 r
.50325 .34193 .50863 .34882 .51852 .33909 .51317 .33159 Metetra
.815 .665 .696 r
.51317 .33159 .51852 .33909 .52837 .32893 .52304 .32074 Metetra
.81 .653 .688 r
.52304 .32074 .52837 .32893 .53817 .31847 .53286 .30949 Metetra
.802 .64 .681 r
.53286 .30949 .53817 .31847 .54793 .30789 .54263 .29803 Metetra
.791 .625 .676 r
.54263 .29803 .54793 .30789 .55764 .29745 .55234 .28663 Metetra
.775 .608 .673 r
.55234 .28663 .55764 .29745 .56731 .28756 .562 .2757 Metetra
.705 .56 .687 r
.562 .2757 .56731 .28756 .57696 .27873 .57171 .26939 Metetra
.632 .546 .739 r
.57171 .26939 .57696 .27873 .58664 .27161 .58154 .26745 Metetra
.663 .709 .882 r
.58154 .26745 .58664 .27161 .59646 .26909 .59141 .26549 Metetra
.664 .741 .907 r
.60131 .26353 .60634 .26715 .61628 .26577 .61125 .26157 Metetra
.663 .709 .882 r
.61125 .26157 .61628 .26577 .62649 .26902 .62122 .2596 Metetra
.468 .449 .754 r
.62122 .2596 .62649 .26902 .63689 .27401 .63146 .26201 Metetra
.298 .303 .696 r
.63146 .26201 .63689 .27401 .64746 .28009 .64205 .2691 Metetra
.237 .278 .702 r
.64205 .2691 .64746 .28009 .65819 .28674 .65281 .27669 Metetra
.192 .264 .709 r
.65281 .27669 .65819 .28674 .66906 .29358 .66371 .28437 Metetra
.161 .262 .72 r
.66371 .28437 .66906 .29358 .68005 .30032 .67473 .29187 Metetra
.144 .269 .734 r
.67473 .29187 .68005 .30032 .69114 .30679 .68586 .29901 Metetra
.14 .285 .752 r
.68586 .29901 .69114 .30679 .70233 .31285 .69708 .30566 Metetra
.146 .308 .771 r
.69708 .30566 .70233 .31285 .7136 .31844 .70839 .31177 Metetra
.162 .337 .792 r
.70839 .31177 .7136 .31844 .72493 .32349 .71976 .31728 Metetra
.184 .37 .814 r
.71976 .31728 .72493 .32349 .73632 .32799 .7312 .32219 Metetra
.212 .406 .836 r
.7312 .32219 .73632 .32799 .74777 .33193 .74269 .32649 Metetra
.245 .444 .857 r
.74269 .32649 .74777 .33193 .75925 .3353 .75422 .33019 Metetra
.281 .482 .877 r
.75422 .33019 .75925 .3353 .77077 .33812 .76578 .33329 Metetra
.319 .521 .895 r
.76578 .33329 .77077 .33812 .78232 .3404 .77737 .33582 Metetra
.359 .558 .91 r
.77737 .33582 .78232 .3404 .79388 .34216 .78899 .33778 Metetra
.399 .594 .923 r
.78899 .33778 .79388 .34216 .80547 .3434 .80062 .3392 Metetra
.439 .627 .933 r
.80062 .3392 .80547 .3434 .81706 .34413 .81225 .34009 Metetra
.479 .658 .939 r
.81225 .34009 .81706 .34413 .82866 .34438 .8239 .34045 Metetra
.517 .686 .943 r
.8239 .34045 .82866 .34438 .84025 .34414 .83553 .3403 Metetra
.555 .711 .944 r
.83553 .3403 .84025 .34414 .85183 .34341 .84715 .33965 Metetra
.591 .732 .942 r
.84715 .33965 .85183 .34341 .8634 .34221 .85876 .33848 Metetra
.625 .751 .937 r
.85876 .33848 .8634 .34221 .87493 .34051 .87033 .33681 Metetra
.658 .766 .93 r
.87033 .33681 .87493 .34051 .88643 .33832 .88187 .33462 Metetra
.688 .779 .92 r
.88187 .33462 .88643 .33832 .89789 .33562 .89336 .33189 Metetra
.716 .789 .909 r
.89336 .33189 .89789 .33562 .90928 .33238 .90479 .32863 Metetra
.742 .797 .896 r
.90479 .32863 .90928 .33238 .92061 .3286 .91614 .32481 Metetra
.766 .803 .883 r
.91614 .32481 .92061 .3286 .93185 .32425 .92742 .32041 Metetra
.401 .668 .968 r
.30171 .42719 .30775 .43029 .31695 .43081 .31093 .42773 Metetra
.478 .703 .968 r
.31093 .42773 .31695 .43081 .32626 .4308 .32025 .42773 Metetra
.542 .729 .961 r
.32025 .42773 .32626 .4308 .33566 .43027 .32967 .42719 Metetra
.595 .747 .95 r
.32967 .42719 .33566 .43027 .34515 .42923 .33918 .42614 Metetra
.638 .759 .936 r
.33918 .42614 .34515 .42923 .35471 .42769 .34876 .42457 Metetra
.674 .767 .921 r
.34876 .42457 .35471 .42769 .36435 .42566 .35843 .42249 Metetra
.703 .771 .905 r
.35843 .42249 .36435 .42566 .37405 .42313 .36816 .41991 Metetra
.728 .772 .888 r
.36816 .41991 .37405 .42313 .38381 .42013 .37795 .41681 Metetra
.749 .771 .871 r
.37795 .41681 .38381 .42013 .39363 .41662 .3878 .4132 Metetra
.766 .768 .854 r
.3878 .4132 .39363 .41662 .40349 .41262 .39769 .40906 Metetra
.78 .763 .838 r
.39769 .40906 .40349 .41262 .41339 .40811 .40763 .40439 Metetra
.792 .757 .821 r
.40763 .40439 .41339 .40811 .42333 .40308 .41761 .39916 Metetra
.802 .751 .805 r
.41761 .39916 .42333 .40308 .4333 .3975 .42761 .39336 Metetra
.81 .743 .79 r
.42761 .39336 .4333 .3975 .44329 .39136 .43764 .38697 Metetra
.816 .735 .775 r
.43764 .38697 .44329 .39136 .45329 .38465 .44769 .37996 Metetra
.821 .726 .761 r
.44769 .37996 .45329 .38465 .4633 .37734 .45774 .37232 Metetra
.824 .718 .747 r
.45774 .37232 .4633 .37734 .47331 .36941 .46779 .36403 Metetra
.826 .709 .735 r
.46779 .36403 .47331 .36941 .48331 .36087 .47783 .35506 Metetra
.828 .699 .723 r
.47783 .35506 .48331 .36087 .49329 .35171 .48785 .34542 Metetra
.827 .69 .711 r
.48785 .34542 .49329 .35171 .50325 .34193 .49784 .33511 Metetra
.826 .68 .701 r
.49784 .33511 .50325 .34193 .51317 .33159 .5078 .32415 Metetra
.823 .669 .692 r
.5078 .32415 .51317 .33159 .52304 .32074 .5177 .3126 Metetra
.818 .657 .683 r
.5177 .3126 .52304 .32074 .53286 .30949 .52755 .30054 Metetra
.811 .645 .676 r
.52755 .30054 .53286 .30949 .54263 .29803 .53733 .28816 Metetra
.801 .63 .67 r
.53733 .28816 .54263 .29803 .55234 .28663 .54704 .27571 Metetra
.738 .587 .687 r
.54704 .27571 .55234 .28663 .562 .2757 .55676 .26775 Metetra
.639 .574 .766 r
.55676 .26775 .562 .2757 .57171 .26939 .56658 .26579 Metetra
.664 .741 .907 r
.6162 .25593 .62122 .2596 .63146 .26201 .62623 .25394 Metetra
.339 .4 .778 r
.62623 .25394 .63146 .26201 .64205 .2691 .63664 .258 Metetra
.177 .236 .686 r
.63664 .258 .64205 .2691 .65281 .27669 .64742 .26661 Metetra
.129 .221 .692 r
.64742 .26661 .65281 .27669 .66371 .28437 .65835 .27519 Metetra
.097 .22 .703 r
.65835 .27519 .66371 .28437 .67473 .29187 .6694 .28347 Metetra
.082 .229 .718 r
.6694 .28347 .67473 .29187 .68586 .29901 .68057 .29129 Metetra
.08 .247 .736 r
.68057 .29129 .68586 .29901 .69708 .30566 .69183 .29853 Metetra
.09 .274 .757 r
.69183 .29853 .69708 .30566 .70839 .31177 .70317 .30515 Metetra
.11 .306 .78 r
.70317 .30515 .70839 .31177 .71976 .31728 .71458 .31112 Metetra
.137 .342 .804 r
.71458 .31112 .71976 .31728 .7312 .32219 .72606 .31643 Metetra
.171 .382 .828 r
.72606 .31643 .7312 .32219 .74269 .32649 .73759 .32108 Metetra
.209 .423 .851 r
.73759 .32108 .74269 .32649 .75422 .33019 .74916 .32508 Metetra
.25 .465 .873 r
.74916 .32508 .75422 .33019 .76578 .33329 .76077 .32846 Metetra
.293 .506 .892 r
.76077 .32846 .76578 .33329 .77737 .33582 .7724 .33122 Metetra
.337 .546 .908 r
.7724 .33122 .77737 .33582 .78899 .33778 .78406 .33339 Metetra
.381 .584 .922 r
.78406 .33339 .78899 .33778 .80062 .3392 .79573 .33498 Metetra
.425 .619 .932 r
.79573 .33498 .80062 .3392 .81225 .34009 .80741 .336 Metetra
.468 .652 .939 r
.80741 .336 .81225 .34009 .8239 .34045 .8191 .33649 Metetra
.51 .681 .943 r
.8191 .33649 .8239 .34045 .83553 .3403 .83078 .33643 Metetra
.55 .707 .944 r
.83078 .33643 .83553 .3403 .84715 .33965 .84244 .33583 Metetra
.587 .729 .941 r
.84244 .33583 .84715 .33965 .85876 .33848 .85408 .33471 Metetra
.623 .748 .936 r
.85408 .33471 .85876 .33848 .87033 .33681 .8657 .33306 Metetra
.657 .764 .929 r
.8657 .33306 .87033 .33681 .88187 .33462 .87727 .33087 Metetra
.688 .777 .92 r
.87727 .33087 .88187 .33462 .89336 .33189 .88879 .32813 Metetra
.716 .788 .908 r
.88879 .32813 .89336 .33189 .90479 .32863 .90026 .32484 Metetra
.742 .796 .896 r
.90026 .32484 .90479 .32863 .91614 .32481 .91165 .32098 Metetra
.766 .803 .882 r
.91165 .32098 .91614 .32481 .92742 .32041 .92295 .31654 Metetra
.398 .667 .968 r
.29564 .42408 .30171 .42719 .31093 .42773 .30487 .42462 Metetra
.477 .703 .968 r
.30487 .42462 .31093 .42773 .32025 .42773 .31421 .42462 Metetra
.542 .728 .961 r
.31421 .42462 .32025 .42773 .32967 .42719 .32364 .42408 Metetra
.596 .747 .949 r
.32364 .42408 .32967 .42719 .33918 .42614 .33317 .42302 Metetra
.64 .759 .935 r
.33317 .42302 .33918 .42614 .34876 .42457 .34278 .42142 Metetra
.676 .766 .919 r
.34278 .42142 .34876 .42457 .35843 .42249 .35246 .41929 Metetra
.706 .771 .902 r
.35246 .41929 .35843 .42249 .36816 .41991 .36222 .41664 Metetra
.731 .772 .885 r
.36222 .41664 .36816 .41991 .37795 .41681 .37204 .41346 Metetra
.752 .771 .868 r
.37204 .41346 .37795 .41681 .3878 .4132 .38192 .40974 Metetra
.77 .768 .851 r
.38192 .40974 .3878 .4132 .39769 .40906 .39186 .40548 Metetra
.784 .763 .834 r
.39186 .40548 .39769 .40906 .40763 .40439 .40183 .40065 Metetra
.796 .758 .818 r
.40183 .40065 .40763 .40439 .41761 .39916 .41185 .39523 Metetra
.806 .751 .802 r
.41185 .39523 .41761 .39916 .42761 .39336 .42189 .38922 Metetra
.814 .744 .786 r
.42189 .38922 .42761 .39336 .43764 .38697 .43196 .38258 Metetra
.821 .737 .772 r
.43196 .38258 .43764 .38697 .44769 .37996 .44205 .3753 Metetra
.826 .729 .757 r
.44205 .3753 .44769 .37996 .45774 .37232 .45214 .36734 Metetra
.83 .72 .744 r
.45214 .36734 .45774 .37232 .46779 .36403 .46224 .35869 Metetra
.833 .712 .731 r
.46224 .35869 .46779 .36403 .47783 .35506 .47232 .34932 Metetra
.834 .703 .719 r
.47232 .34932 .47783 .35506 .48785 .34542 .48239 .33922 Metetra
.834 .693 .707 r
.48239 .33922 .48785 .34542 .49784 .33511 .49242 .32837 Metetra
.834 .684 .697 r
.49242 .32837 .49784 .33511 .5078 .32415 .50241 .3168 Metetra
.831 .673 .687 r
.50241 .3168 .5078 .32415 .5177 .3126 .51235 .30453 Metetra
.827 .662 .678 r
.51235 .30453 .5177 .3126 .52755 .30054 .52222 .29165 Metetra
.821 .65 .671 r
.52222 .29165 .52755 .30054 .53733 .28816 .53203 .2783 Metetra
.799 .63 .672 r
.53203 .2783 .53733 .28816 .54704 .27571 .54176 .2661 Metetra
.63 .541 .736 r
.54176 .2661 .54704 .27571 .55676 .26775 .55157 .26414 Metetra
.664 .741 .907 r
.62121 .25024 .62623 .25394 .63664 .258 .6313 .24823 Metetra
.119 .219 .694 r
.6313 .24823 .63664 .258 .64742 .26661 .64203 .25655 Metetra
.056 .173 .67 r
.64203 .25655 .64742 .26661 .65835 .27519 .65299 .26607 Metetra
.026 .173 .681 r
.65299 .26607 .65835 .27519 .6694 .28347 .66407 .27516 Metetra
.013 .185 .696 r
.66407 .27516 .6694 .28347 .68057 .29129 .67527 .28366 Metetra
.016 .207 .716 r
.67527 .28366 .68057 .29129 .69183 .29853 .68656 .29149 Metetra
.031 .237 .74 r
.68656 .29149 .69183 .29853 .70317 .30515 .69794 .29862 Metetra
.055 .273 .765 r
.69794 .29862 .70317 .30515 .71458 .31112 .70939 .30503 Metetra
.088 .313 .792 r
.70939 .30503 .71458 .31112 .72606 .31643 .7209 .31072 Metetra
.127 .357 .818 r
.7209 .31072 .72606 .31643 .73759 .32108 .73246 .31571 Metetra
.171 .402 .844 r
.73246 .31571 .73759 .32108 .74916 .32508 .74408 .32001 Metetra
.217 .447 .867 r
.74408 .32001 .74916 .32508 .76077 .32846 .75572 .32364 Metetra
.265 .491 .888 r
.75572 .32364 .76077 .32846 .7724 .33122 .7674 .32662 Metetra
.314 .534 .906 r
.7674 .32662 .7724 .33122 .78406 .33339 .7791 .32898 Metetra
.363 .574 .921 r
.7791 .32898 .78406 .33339 .79573 .33498 .79082 .33073 Metetra
.411 .612 .932 r
.79082 .33073 .79573 .33498 .80741 .336 .80254 .33189 Metetra
.457 .646 .939 r
.80254 .33189 .80741 .336 .8191 .33649 .81427 .33248 Metetra
.502 .676 .943 r
.81427 .33248 .8191 .33649 .83078 .33643 .82599 .33251 Metetra
.544 .703 .944 r
.82599 .33251 .83078 .33643 .84244 .33583 .83769 .33198 Metetra
.584 .727 .941 r
.83769 .33198 .84244 .33583 .85408 .33471 .84937 .33089 Metetra
.621 .746 .936 r
.84937 .33089 .85408 .33471 .8657 .33306 .86102 .32926 Metetra
.656 .763 .929 r
.86102 .32926 .8657 .33306 .87727 .33087 .87263 .32707 Metetra
.687 .776 .919 r
.87263 .32707 .87727 .33087 .88879 .32813 .88419 .32433 Metetra
.716 .787 .908 r
.88419 .32433 .88879 .32813 .90026 .32484 .89569 .32101 Metetra
.743 .796 .895 r
.89569 .32101 .90026 .32484 .91165 .32098 .90712 .31712 Metetra
.767 .803 .882 r
.90712 .31712 .91165 .32098 .92295 .31654 .91846 .31265 Metetra
.397 .666 .968 r
.28953 .42095 .29564 .42408 .30487 .42462 .29877 .42149 Metetra
.476 .702 .968 r
.29877 .42149 .30487 .42462 .31421 .42462 .30812 .42149 Metetra
.542 .728 .96 r
.30812 .42149 .31421 .42462 .32364 .42408 .31757 .42094 Metetra
.596 .746 .948 r
.31757 .42094 .32364 .42408 .33317 .42302 .32712 .41986 Metetra
.641 .758 .934 r
.32712 .41986 .33317 .42302 .34278 .42142 .33675 .41823 Metetra
.678 .766 .917 r
.33675 .41823 .34278 .42142 .35246 .41929 .34646 .41606 Metetra
.709 .77 .9 r
.34646 .41606 .35246 .41929 .36222 .41664 .35625 .41335 Metetra
.734 .772 .883 r
.35625 .41335 .36222 .41664 .37204 .41346 .3661 .41009 Metetra
.755 .771 .866 r
.3661 .41009 .37204 .41346 .38192 .40974 .37601 .40627 Metetra
.773 .768 .848 r
.37601 .40627 .38192 .40974 .39186 .40548 .38598 .40187 Metetra
.788 .764 .831 r
.38598 .40187 .39186 .40548 .40183 .40065 .396 .39689 Metetra
.8 .759 .815 r
.396 .39689 .40183 .40065 .41185 .39523 .40605 .39131 Metetra
.81 .753 .799 r
.40605 .39131 .41185 .39523 .42189 .38922 .41614 .38509 Metetra
.819 .746 .783 r
.41614 .38509 .42189 .38922 .43196 .38258 .42625 .37823 Metetra
.826 .739 .768 r
.42625 .37823 .43196 .38258 .44205 .3753 .43638 .37068 Metetra
.831 .731 .754 r
.43638 .37068 .44205 .3753 .45214 .36734 .44652 .36242 Metetra
.835 .723 .741 r
.44652 .36242 .45214 .36734 .46224 .35869 .45666 .35343 Metetra
.838 .715 .728 r
.45666 .35343 .46224 .35869 .47232 .34932 .46679 .34366 Metetra
.84 .706 .715 r
.46679 .34366 .47232 .34932 .48239 .33922 .4769 .33311 Metetra
.841 .697 .704 r
.4769 .33311 .48239 .33922 .49242 .32837 .48698 .32175 Metetra
.841 .688 .693 r
.48698 .32175 .49242 .32837 .50241 .3168 .49701 .30957 Metetra
.839 .678 .683 r
.49701 .30957 .50241 .3168 .51235 .30453 .50699 .2966 Metetra
.836 .667 .673 r
.50699 .2966 .51235 .30453 .52222 .29165 .51689 .28287 Metetra
.83 .655 .665 r
.51689 .28287 .52222 .29165 .53203 .2783 .52672 .26852 Metetra
.721 .59 .709 r
.52672 .26852 .53203 .2783 .54176 .2661 .53651 .26248 Metetra
.256 .54 .923 r
.62626 .24449 .6313 .24823 .64203 .25655 .63665 .24657 Metetra
0 .117 .642 r
.63665 .24657 .64203 .25655 .65299 .26607 .64763 .25706 Metetra
0 .12 .653 r
.64763 .25706 .65299 .26607 .66407 .27516 .65874 .26696 Metetra
0 .136 .67 r
.65874 .26696 .66407 .27516 .67527 .28366 .66996 .27615 Metetra
0 .163 .692 r
.66996 .27615 .67527 .28366 .68656 .29149 .68129 .28456 Metetra
0 .197 .719 r
.68129 .28456 .68656 .29149 .69794 .29862 .69269 .29218 Metetra
0 .238 .748 r
.69269 .29218 .69794 .29862 .70939 .30503 .70418 .29902 Metetra
.037 .283 .777 r
.70418 .29902 .70939 .30503 .7209 .31072 .71572 .30508 Metetra
.082 .331 .807 r
.71572 .30508 .7209 .31072 .73246 .31571 .72732 .31039 Metetra
.132 .38 .836 r
.72732 .31039 .73246 .31571 .74408 .32001 .73897 .31496 Metetra
.184 .429 .862 r
.73897 .31496 .74408 .32001 .75572 .32364 .75066 .31884 Metetra
.238 .477 .885 r
.75066 .31884 .75572 .32364 .7674 .32662 .76238 .32203 Metetra
.292 .523 .904 r
.76238 .32203 .7674 .32662 .7791 .32898 .77412 .32457 Metetra
.345 .565 .92 r
.77412 .32457 .7791 .32898 .79082 .33073 .78587 .32647 Metetra
.397 .605 .932 r
.78587 .32647 .79082 .33073 .80254 .33189 .79764 .32776 Metetra
.447 .641 .939 r
.79764 .32776 .80254 .33189 .81427 .33248 .8094 .32845 Metetra
.494 .672 .943 r
.8094 .32845 .81427 .33248 .82599 .33251 .82116 .32855 Metetra
.539 .7 .944 r
.82116 .32855 .82599 .33251 .83769 .33198 .8329 .32808 Metetra
.58 .724 .942 r
.8329 .32808 .83769 .33198 .84937 .33089 .84462 .32703 Metetra
.619 .745 .936 r
.84462 .32703 .84937 .33089 .86102 .32926 .85631 .32542 Metetra
.654 .762 .928 r
.85631 .32542 .86102 .32926 .87263 .32707 .86796 .32324 Metetra
.687 .776 .919 r
.86796 .32324 .87263 .32707 .88419 .32433 .87956 .32048 Metetra
.716 .787 .907 r
.87956 .32048 .88419 .32433 .89569 .32101 .89109 .31715 Metetra
.743 .796 .895 r
.89109 .31715 .89569 .32101 .90712 .31712 .90255 .31324 Metetra
.767 .803 .881 r
.90255 .31324 .90712 .31712 .91846 .31265 .91393 .30873 Metetra
.396 .666 .968 r
.28337 .4178 .28953 .42095 .29877 .42149 .29263 .41834 Metetra
.476 .702 .968 r
.29263 .41834 .29877 .42149 .30812 .42149 .30199 .41833 Metetra
.543 .728 .96 r
.30199 .41833 .30812 .42149 .31757 .42094 .31146 .41778 Metetra
.597 .746 .948 r
.31146 .41778 .31757 .42094 .32712 .41986 .32103 .41667 Metetra
.643 .758 .933 r
.32103 .41667 .32712 .41986 .33675 .41823 .33068 .41501 Metetra
.68 .766 .916 r
.33068 .41501 .33675 .41823 .34646 .41606 .34042 .4128 Metetra
.711 .77 .899 r
.34042 .4128 .34646 .41606 .35625 .41335 .35023 .41002 Metetra
.737 .772 .881 r
.35023 .41002 .35625 .41335 .3661 .41009 .36012 .40668 Metetra
.758 .771 .863 r
.36012 .40668 .3661 .41009 .37601 .40627 .37007 .40277 Metetra
.776 .768 .846 r
.37007 .40277 .37601 .40627 .38598 .40187 .38007 .39826 Metetra
.791 .765 .829 r
.38007 .39826 .38598 .40187 .396 .39689 .39012 .39314 Metetra
.804 .76 .812 r
.39012 .39314 .396 .39689 .40605 .39131 .40022 .38739 Metetra
.814 .754 .796 r
.40022 .38739 .40605 .39131 .41614 .38509 .41034 .38099 Metetra
.823 .748 .781 r
.41034 .38099 .41614 .38509 .42625 .37823 .4205 .3739 Metetra
.83 .741 .766 r
.4205 .3739 .42625 .37823 .43638 .37068 .43068 .36611 Metetra
.836 .734 .751 r
.43068 .36611 .43638 .37068 .44652 .36242 .44086 .35756 Metetra
.841 .726 .738 r
.44086 .35756 .44652 .36242 .45666 .35343 .45105 .34824 Metetra
.844 .718 .725 r
.45105 .34824 .45666 .35343 .46679 .34366 .46123 .33811 Metetra
.847 .71 .712 r
.46123 .33811 .46679 .34366 .4769 .33311 .47138 .32712 Metetra
.848 .702 .7 r
.47138 .32712 .4769 .33311 .48698 .32175 .48151 .31526 Metetra
.848 .693 .689 r
.48151 .31526 .48698 .32175 .49701 .30957 .49159 .30249 Metetra
.847 .683 .679 r
.49159 .30249 .49701 .30957 .50699 .2966 .50161 .28882 Metetra
.844 .672 .669 r
.50161 .28882 .50699 .2966 .51689 .28287 .51156 .27425 Metetra
.825 .655 .671 r
.51156 .27425 .51689 .28287 .52672 .26852 .52141 .26081 Metetra
.64 .582 .773 r
.52141 .26081 .52672 .26852 .53651 .26248 .53123 .25883 Metetra
.664 .741 .907 r
.62119 .24073 .62626 .24449 .63665 .24657 .63137 .23868 Metetra
0 .083 .637 r
.63137 .23868 .63665 .24657 .64763 .25706 .64227 .24822 Metetra
0 .063 .618 r
.64227 .24822 .64763 .25706 .65874 .26696 .65341 .25893 Metetra
0 .084 .637 r
.65341 .25893 .65874 .26696 .66996 .27615 .66465 .26879 Metetra
0 .116 .663 r
.66465 .26879 .66996 .27615 .68129 .28456 .676 .27777 Metetra
0 .156 .694 r
.676 .27777 .68129 .28456 .69269 .29218 .68744 .28587 Metetra
0 .202 .727 r
.68744 .28587 .69269 .29218 .70418 .29902 .69895 .29311 Metetra
0 .252 .761 r
.69895 .29311 .70418 .29902 .71572 .30508 .71053 .29952 Metetra
.036 .305 .794 r
.71053 .29952 .71572 .30508 .72732 .31039 .72216 .30513 Metetra
.092 .358 .826 r
.72216 .30513 .72732 .31039 .73897 .31496 .73385 .30997 Metetra
.151 .411 .855 r
.73385 .30997 .73897 .31496 .75066 .31884 .74557 .31407 Metetra
.21 .463 .88 r
.74557 .31407 .75066 .31884 .76238 .32203 .75732 .31746 Metetra
.269 .511 .902 r
.75732 .31746 .76238 .32203 .77412 .32457 .7691 .32016 Metetra
.327 .557 .919 r
.7691 .32016 .77412 .32457 .78587 .32647 .78089 .3222 Metetra
.383 .598 .931 r
.78089 .3222 .78587 .32647 .79764 .32776 .7927 .32361 Metetra
.437 .636 .94 r
.7927 .32361 .79764 .32776 .8094 .32845 .8045 .32439 Metetra
.487 .669 .944 r
.8045 .32439 .8094 .32845 .82116 .32855 .8163 .32457 Metetra
.534 .698 .944 r
.8163 .32457 .82116 .32855 .8329 .32808 .82808 .32415 Metetra
.577 .722 .942 r
.82808 .32415 .8329 .32808 .84462 .32703 .83984 .32314 Metetra
.617 .743 .936 r
.83984 .32314 .84462 .32703 .85631 .32542 .85157 .32154 Metetra
.653 .761 .928 r
.85157 .32154 .85631 .32542 .86796 .32324 .86325 .31937 Metetra
.686 .775 .918 r
.86325 .31937 .86796 .32324 .87956 .32048 .87488 .3166 Metetra
.716 .786 .907 r
.87488 .3166 .87956 .32048 .89109 .31715 .88645 .31325 Metetra
.743 .795 .894 r
.88645 .31325 .89109 .31715 .90255 .31324 .89795 .30932 Metetra
.767 .803 .881 r
.89795 .30932 .90255 .31324 .91393 .30873 .90937 .30479 Metetra
.395 .666 .968 r
.27717 .41463 .28337 .4178 .29263 .41834 .28644 .41516 Metetra
.476 .702 .968 r
.28644 .41516 .29263 .41834 .30199 .41833 .29582 .41515 Metetra
.543 .728 .96 r
.29582 .41515 .30199 .41833 .31146 .41778 .30531 .41458 Metetra
.599 .746 .947 r
.30531 .41458 .31146 .41778 .32103 .41667 .3149 .41345 Metetra
.644 .758 .932 r
.3149 .41345 .32103 .41667 .33068 .41501 .32457 .41176 Metetra
.682 .766 .915 r
.32457 .41176 .33068 .41501 .34042 .4128 .33434 .40951 Metetra
.713 .77 .897 r
.33434 .40951 .34042 .4128 .35023 .41002 .34418 .40668 Metetra
.739 .772 .879 r
.34418 .40668 .35023 .41002 .36012 .40668 .3541 .40326 Metetra
.761 .771 .861 r
.3541 .40326 .36012 .40668 .37007 .40277 .36408 .39926 Metetra
.779 .769 .844 r
.36408 .39926 .37007 .40277 .38007 .39826 .37412 .39464 Metetra
.794 .765 .827 r
.37412 .39464 .38007 .39826 .39012 .39314 .38421 .38939 Metetra
.807 .761 .81 r
.38421 .38939 .39012 .39314 .40022 .38739 .39434 .38349 Metetra
.818 .756 .794 r
.39434 .38349 .40022 .38739 .41034 .38099 .40451 .37691 Metetra
.827 .75 .778 r
.40451 .37691 .41034 .38099 .4205 .3739 .41471 .36962 Metetra
.834 .743 .763 r
.41471 .36962 .4205 .3739 .43068 .36611 .42494 .36159 Metetra
.841 .737 .749 r
.42494 .36159 .43068 .36611 .44086 .35756 .43517 .35279 Metetra
.846 .729 .735 r
.43517 .35279 .44086 .35756 .45105 .34824 .4454 .34316 Metetra
.85 .722 .722 r
.4454 .34316 .45105 .34824 .46123 .33811 .45563 .33267 Metetra
.853 .714 .709 r
.45563 .33267 .46123 .33811 .47138 .32712 .46584 .32128 Metetra
.854 .706 .697 r
.46584 .32128 .47138 .32712 .48151 .31526 .47601 .30894 Metetra
.855 .697 .686 r
.47601 .30894 .48151 .31526 .49159 .30249 .48614 .29561 Metetra
.855 .688 .675 r
.48614 .29561 .49159 .30249 .50161 .28882 .49621 .28125 Metetra
.853 .678 .664 r
.49621 .28125 .50161 .28882 .51156 .27425 .50621 .26584 Metetra
.779 .638 .705 r
.50621 .26584 .51156 .27425 .52141 .26081 .51607 .25716 Metetra
0 .27 .768 r
.62629 .23488 .63137 .23868 .64227 .24822 .63692 .23958 Metetra
0 .001 .575 r
.63692 .23958 .64227 .24822 .65341 .25893 .64807 .25111 Metetra
0 .028 .599 r
.64807 .25111 .65341 .25893 .66465 .26879 .65934 .26163 Metetra
0 .066 .629 r
.65934 .26163 .66465 .26879 .676 .27777 .67071 .27115 Metetra
0 .112 .665 r
.67071 .27115 .676 .27777 .68744 .28587 .68217 .2797 Metetra
0 .164 .703 r
.68217 .2797 .68744 .28587 .69895 .29311 .69371 .28733 Metetra
0 .22 .742 r
.69371 .28733 .69895 .29311 .71053 .29952 .70532 .29406 Metetra
0 .278 .78 r
.70532 .29406 .71053 .29952 .72216 .30513 .71698 .29995 Metetra
.052 .336 .815 r
.71698 .29995 .72216 .30513 .73385 .30997 .7287 .30503 Metetra
.117 .393 .848 r
.7287 .30503 .73385 .30997 .74557 .31407 .74045 .30934 Metetra
.182 .449 .876 r
.74045 .30934 .74557 .31407 .75732 .31746 .75224 .31291 Metetra
.247 .501 .899 r
.75224 .31291 .75732 .31746 .7691 .32016 .76406 .31576 Metetra
.31 .549 .918 r
.76406 .31576 .7691 .32016 .78089 .3222 .77589 .31793 Metetra
.37 .592 .931 r
.77589 .31793 .78089 .3222 .7927 .32361 .78773 .31945 Metetra
.427 .631 .94 r
.78773 .31945 .7927 .32361 .8045 .32439 .79957 .32032 Metetra
.48 .666 .944 r
.79957 .32032 .8045 .32439 .8163 .32457 .8114 .32056 Metetra
.529 .695 .945 r
.8114 .32056 .8163 .32457 .82808 .32415 .82322 .32019 Metetra
.574 .721 .942 r
.82322 .32019 .82808 .32415 .83984 .32314 .83502 .31921 Metetra
.615 .742 .937 r
.83502 .31921 .83984 .32314 .85157 .32154 .84678 .31763 Metetra
.652 .76 .928 r
.84678 .31763 .85157 .32154 .86325 .31937 .8585 .31546 Metetra
.686 .774 .918 r
.8585 .31546 .86325 .31937 .87488 .3166 .87017 .31269 Metetra
.716 .786 .907 r
.87017 .31269 .87488 .3166 .88645 .31325 .88178 .30933 Metetra
.743 .795 .894 r
.88178 .30933 .88645 .31325 .89795 .30932 .89332 .30537 Metetra
.768 .803 .881 r
.89332 .30537 .89795 .30932 .90937 .30479 .90477 .30082 Metetra
.395 .666 .968 r
.27094 .41144 .27717 .41463 .28644 .41516 .28022 .41197 Metetra
.476 .702 .968 r
.28022 .41197 .28644 .41516 .29582 .41515 .28962 .41194 Metetra
.544 .728 .96 r
.28962 .41194 .29582 .41515 .30531 .41458 .29912 .41136 Metetra
.6 .746 .947 r
.29912 .41136 .30531 .41458 .3149 .41345 .30873 .41021 Metetra
.646 .758 .931 r
.30873 .41021 .3149 .41345 .32457 .41176 .31843 .40849 Metetra
.684 .766 .914 r
.31843 .40849 .32457 .41176 .33434 .40951 .32822 .40619 Metetra
.715 .77 .896 r
.32822 .40619 .33434 .40951 .34418 .40668 .33809 .40331 Metetra
.741 .772 .878 r
.33809 .40331 .34418 .40668 .3541 .40326 .34803 .39983 Metetra
.763 .772 .86 r
.34803 .39983 .3541 .40326 .36408 .39926 .35805 .39573 Metetra
.782 .77 .842 r
.35805 .39573 .36408 .39926 .37412 .39464 .36812 .39101 Metetra
.797 .767 .825 r
.36812 .39101 .37412 .39464 .38421 .38939 .37825 .38565 Metetra
.81 .762 .808 r
.37825 .38565 .38421 .38939 .39434 .38349 .38843 .37961 Metetra
.821 .758 .792 r
.38843 .37961 .39434 .38349 .40451 .37691 .39864 .37287 Metetra
.831 .752 .777 r
.39864 .37287 .40451 .37691 .41471 .36962 .40889 .36539 Metetra
.839 .746 .762 r
.40889 .36539 .41471 .36962 .42494 .36159 .41916 .35715 Metetra
.845 .74 .747 r
.41916 .35715 .42494 .36159 .43517 .35279 .42944 .3481 Metetra
.851 .733 .733 r
.42944 .3481 .43517 .35279 .4454 .34316 .43973 .33819 Metetra
.855 .726 .72 r
.43973 .33819 .4454 .34316 .45563 .33267 .45 .32738 Metetra
.858 .718 .707 r
.45 .32738 .45563 .33267 .46584 .32128 .46026 .31561 Metetra
.861 .711 .694 r
.46026 .31561 .46584 .32128 .47601 .30894 .47049 .30281 Metetra
.862 .703 .682 r
.47049 .30281 .47601 .30894 .48614 .29561 .48067 .28894 Metetra
.863 .694 .671 r
.48067 .28894 .48614 .29561 .49621 .28125 .4908 .27392 Metetra
.862 .684 .66 r
.4908 .27392 .49621 .28125 .50621 .26584 .50084 .25771 Metetra
.702 .605 .746 r
.50084 .25771 .50621 .26584 .51607 .25716 .5107 .25348 Metetra
.485 .665 .942 r
.62118 .23105 .62629 .23488 .63692 .23958 .63157 .23122 Metetra
0 0 .524 r
.63157 .23122 .63692 .23958 .64807 .25111 .64274 .24354 Metetra
0 0 .553 r
.64274 .24354 .64807 .25111 .65934 .26163 .65403 .25468 Metetra
0 .015 .59 r
.65403 .25468 .65934 .26163 .67071 .27115 .66542 .26472 Metetra
0 .068 .631 r
.66542 .26472 .67071 .27115 .68217 .2797 .6769 .2737 Metetra
0 .126 .675 r
.6769 .2737 .68217 .2797 .69371 .28733 .68846 .28168 Metetra
0 .187 .72 r
.68846 .28168 .69371 .28733 .70532 .29406 .70009 .28872 Metetra
0 .25 .763 r
.70009 .28872 .70532 .29406 .71698 .29995 .71179 .29486 Metetra
.011 .314 .803 r
.71179 .29486 .71698 .29995 .7287 .30503 .72353 .30017 Metetra
.083 .376 .84 r
.72353 .30017 .7287 .30503 .74045 .30934 .73532 .30466 Metetra
.155 .435 .871 r
.73532 .30466 .74045 .30934 .75224 .31291 .74714 .30839 Metetra
.225 .49 .896 r
.74714 .30839 .75224 .31291 .76406 .31576 .75898 .31138 Metetra
.293 .541 .916 r
.75898 .31138 .76406 .31576 .77589 .31793 .77085 .31367 Metetra
.357 .587 .931 r
.77085 .31367 .77589 .31793 .78773 .31945 .78272 .31528 Metetra
.417 .627 .94 r
.78272 .31528 .78773 .31945 .79957 .32032 .7946 .31622 Metetra
.473 .663 .945 r
.7946 .31622 .79957 .32032 .8114 .32056 .80647 .31653 Metetra
.524 .693 .946 r
.80647 .31653 .8114 .32056 .82322 .32019 .81833 .3162 Metetra
.57 .719 .943 r
.81833 .3162 .82322 .32019 .83502 .31921 .83016 .31525 Metetra
.613 .741 .937 r
.83016 .31525 .83502 .31921 .84678 .31763 .84196 .31368 Metetra
.651 .759 .929 r
.84196 .31368 .84678 .31763 .8585 .31546 .85372 .31151 Metetra
.685 .774 .918 r
.85372 .31151 .8585 .31546 .87017 .31269 .86543 .30874 Metetra
.716 .785 .907 r
.86543 .30874 .87017 .31269 .88178 .30933 .87707 .30537 Metetra
.743 .795 .894 r
.87707 .30537 .88178 .30933 .89332 .30537 .88865 .30139 Metetra
.767 .803 .881 r
.88865 .30139 .89332 .30537 .90477 .30082 .90014 .29682 Metetra
.396 .667 .968 r
.26466 .40823 .27094 .41144 .28022 .41197 .27395 .40875 Metetra
.477 .702 .968 r
.27395 .40875 .28022 .41197 .28962 .41194 .28336 .40871 Metetra
.545 .728 .959 r
.28336 .40871 .28962 .41194 .29912 .41136 .29289 .40811 Metetra
.601 .746 .946 r
.29289 .40811 .29912 .41136 .30873 .41021 .30251 .40694 Metetra
.647 .759 .931 r
.30251 .40694 .30873 .41021 .31843 .40849 .31224 .40519 Metetra
.685 .766 .913 r
.31224 .40519 .31843 .40849 .32822 .40619 .32205 .40286 Metetra
.717 .771 .895 r
.32205 .40286 .32822 .40619 .33809 .40331 .33195 .39992 Metetra
.743 .773 .877 r
.33195 .39992 .33809 .40331 .34803 .39983 .34193 .39638 Metetra
.765 .773 .859 r
.34193 .39638 .34803 .39983 .35805 .39573 .35198 .39221 Metetra
.784 .771 .841 r
.35198 .39221 .35805 .39573 .36812 .39101 .36209 .3874 Metetra
.8 .768 .824 r
.36209 .3874 .36812 .39101 .37825 .38565 .37226 .38192 Metetra
.813 .764 .807 r
.37226 .38192 .37825 .38565 .38843 .37961 .38247 .37575 Metetra
.825 .76 .791 r
.38247 .37575 .38843 .37961 .39864 .37287 .39273 .36887 Metetra
.834 .754 .775 r
.39273 .36887 .39864 .37287 .40889 .36539 .40302 .36122 Metetra
.843 .749 .76 r
.40302 .36122 .40889 .36539 .41916 .35715 .41334 .35279 Metetra
.85 .743 .745 r
.41334 .35279 .41916 .35715 .42944 .3481 .42367 .34351 Metetra
.855 .737 .731 r
.42367 .34351 .42944 .3481 .43973 .33819 .43401 .33335 Metetra
.86 .73 .718 r
.43401 .33335 .43973 .33819 .45 .32738 .44434 .32224 Metetra
.864 .723 .705 r
.44434 .32224 .45 .32738 .46026 .31561 .45466 .31012 Metetra
.867 .716 .692 r
.45466 .31012 .46026 .31561 .47049 .30281 .46494 .29691 Metetra
.869 .708 .68 r
.46494 .29691 .47049 .30281 .48067 .28894 .47518 .28253 Metetra
.87 .7 .668 r
.47518 .28253 .48067 .28894 .4908 .27392 .48536 .2669 Metetra
.859 .688 .668 r
.48536 .2669 .4908 .27392 .50084 .25771 .49543 .25179 Metetra
.652 .638 .823 r
.49543 .25179 .50084 .25771 .5107 .25348 .50528 .24978 Metetra
.664 .741 .907 r
.61604 .2272 .62118 .23105 .63157 .23122 .62633 .2251 Metetra
0 0 .447 r
.62633 .2251 .63157 .23122 .64274 .24354 .63741 .23626 Metetra
0 0 .501 r
.63741 .23626 .64274 .24354 .65403 .25468 .64871 .248 Metetra
0 0 .545 r
.64871 .248 .65403 .25468 .66542 .26472 .66012 .25851 Metetra
0 .023 .594 r
.66012 .25851 .66542 .26472 .6769 .2737 .67162 .26788 Metetra
0 .087 .645 r
.67162 .26788 .6769 .2737 .68846 .28168 .6832 .27619 Metetra
0 .154 .696 r
.6832 .27619 .68846 .28168 .70009 .28872 .69485 .2835 Metetra
0 .223 .745 r
.69485 .2835 .70009 .28872 .71179 .29486 .70657 .28988 Metetra
0 .292 .79 r
.70657 .28988 .71179 .29486 .72353 .30017 .71834 .29538 Metetra
.049 .358 .831 r
.71834 .29538 .72353 .30017 .73532 .30466 .73015 .30004 Metetra
.127 .422 .865 r
.73015 .30004 .73532 .30466 .74714 .30839 .742 .30391 Metetra
.203 .48 .894 r
.742 .30391 .74714 .30839 .75898 .31138 .75388 .30703 Metetra
.276 .534 .915 r
.75388 .30703 .75898 .31138 .77085 .31367 .76578 .30942 Metetra
.344 .582 .931 r
.76578 .30942 .77085 .31367 .78272 .31528 .77769 .31111 Metetra
.408 .624 .941 r
.77769 .31111 .78272 .31528 .7946 .31622 .7896 .31212 Metetra
.466 .661 .946 r
.7896 .31212 .7946 .31622 .80647 .31653 .80151 .31247 Metetra
.519 .692 .947 r
.80151 .31247 .80647 .31653 .81833 .3162 .8134 .31218 Metetra
.567 .718 .943 r
.8134 .31218 .81833 .3162 .83016 .31525 .82527 .31126 Metetra
.611 .74 .937 r
.82527 .31126 .83016 .31525 .84196 .31368 .83711 .30971 Metetra
.65 .758 .929 r
.83711 .30971 .84196 .31368 .85372 .31151 .8489 .30754 Metetra
.684 .773 .919 r
.8489 .30754 .85372 .31151 .86543 .30874 .86065 .30476 Metetra
.715 .785 .907 r
.86065 .30476 .86543 .30874 .87707 .30537 .87233 .30137 Metetra
.743 .795 .894 r
.87233 .30137 .87707 .30537 .88865 .30139 .88394 .29738 Metetra
.767 .802 .881 r
.88394 .29738 .88865 .30139 .90014 .29682 .89548 .2928 Metetra
.396 .667 .968 r
.25833 .405 .26466 .40823 .27395 .40875 .26764 .40551 Metetra
.477 .702 .968 r
.26764 .40551 .27395 .40875 .28336 .40871 .27707 .40546 Metetra
.545 .728 .959 r
.27707 .40546 .28336 .40871 .29289 .40811 .28661 .40484 Metetra
.602 .746 .946 r
.28661 .40484 .29289 .40811 .30251 .40694 .29626 .40365 Metetra
.648 .759 .93 r
.29626 .40365 .30251 .40694 .31224 .40519 .30601 .40188 Metetra
.686 .767 .913 r
.30601 .40188 .31224 .40519 .32205 .40286 .31585 .3995 Metetra
.718 .771 .894 r
.31585 .3995 .32205 .40286 .33195 .39992 .32578 .39652 Metetra
.745 .773 .876 r
.32578 .39652 .33195 .39992 .34193 .39638 .33578 .39292 Metetra
.767 .773 .858 r
.33578 .39292 .34193 .39638 .35198 .39221 .34587 .38868 Metetra
.786 .772 .84 r
.34587 .38868 .35198 .39221 .36209 .3874 .35601 .38379 Metetra
.802 .769 .823 r
.35601 .38379 .36209 .3874 .37226 .38192 .36622 .37821 Metetra
.816 .766 .806 r
.36622 .37821 .37226 .38192 .38247 .37575 .37648 .37193 Metetra
.828 .762 .79 r
.37648 .37193 .38247 .37575 .39273 .36887 .38678 .36491 Metetra
.838 .757 .774 r
.38678 .36491 .39273 .36887 .40302 .36122 .39712 .35712 Metetra
.846 .752 .759 r
.39712 .35712 .40302 .36122 .41334 .35279 .40748 .34851 Metetra
.854 .746 .744 r
.40748 .34851 .41334 .35279 .42367 .34351 .41786 .33904 Metetra
.86 .741 .73 r
.41786 .33904 .42367 .34351 .43401 .33335 .42825 .32865 Metetra
.865 .734 .716 r
.42825 .32865 .43401 .33335 .44434 .32224 .43864 .31727 Metetra
.87 .728 .703 r
.43864 .31727 .44434 .32224 .45466 .31012 .44901 .30483 Metetra
.873 .721 .69 r
.44901 .30483 .45466 .31012 .46494 .29691 .45935 .29125 Metetra
.876 .714 .677 r
.45935 .29125 .46494 .29691 .47518 .28253 .46965 .27642 Metetra
.878 .706 .665 r
.46965 .27642 .47518 .28253 .48536 .2669 .4799 .26022 Metetra
.843 .689 .692 r
.4799 .26022 .48536 .2669 .49543 .25179 .48996 .24807 Metetra
0 0 .457 r
.62117 .22121 .62633 .2251 .63741 .23626 .63208 .22934 Metetra
0 0 .444 r
.63208 .22934 .63741 .23626 .64871 .248 .64339 .24162 Metetra
0 0 .497 r
.64339 .24162 .64871 .248 .66012 .25851 .65481 .25256 Metetra
0 0 .553 r
.65481 .25256 .66012 .25851 .67162 .26788 .66632 .26227 Metetra
0 .049 .612 r
.66632 .26227 .67162 .26788 .6832 .27619 .67792 .27087 Metetra
0 .122 .67 r
.67792 .27087 .6832 .27619 .69485 .2835 .68959 .27842 Metetra
0 .196 .725 r
.68959 .27842 .69485 .2835 .70657 .28988 .70133 .285 Metetra
0 .27 .776 r
.70133 .285 .70657 .28988 .71834 .29538 .71313 .29067 Metetra
.016 .342 .822 r
.71313 .29067 .71834 .29538 .73015 .30004 .72497 .29549 Metetra
.101 .409 .86 r
.72497 .29549 .73015 .30004 .742 .30391 .73684 .29948 Metetra
.182 .471 .891 r
.73684 .29948 .742 .30391 .75388 .30703 .74875 .30271 Metetra
.26 .528 .914 r
.74875 .30271 .75388 .30703 .76578 .30942 .76068 .30518 Metetra
.332 .578 .931 r
.76068 .30518 .76578 .30942 .77769 .31111 .77262 .30694 Metetra
.399 .621 .942 r
.77262 .30694 .77769 .31111 .7896 .31212 .78457 .30801 Metetra
.46 .659 .947 r
.78457 .30801 .7896 .31212 .80151 .31247 .79651 .30841 Metetra
.515 .691 .947 r
.79651 .30841 .80151 .31247 .8134 .31218 .80844 .30815 Metetra
.565 .717 .944 r
.80844 .30815 .8134 .31218 .82527 .31126 .82034 .30724 Metetra
.609 .74 .938 r
.82034 .30724 .82527 .31126 .83711 .30971 .83222 .3057 Metetra
.649 .758 .929 r
.83222 .3057 .83711 .30971 .8489 .30754 .84405 .30354 Metetra
.684 .773 .919 r
.84405 .30354 .8489 .30754 .86065 .30476 .85583 .30075 Metetra
.715 .785 .907 r
.85583 .30075 .86065 .30476 .87233 .30137 .86755 .29735 Metetra
.743 .795 .894 r
.86755 .29735 .87233 .30137 .88394 .29738 .8792 .29334 Metetra
.767 .802 .881 r
.8792 .29334 .88394 .29738 .89548 .2928 .89078 .28874 Metetra
.397 .667 .968 r
.25197 .40175 .25833 .405 .26764 .40551 .26129 .40225 Metetra
.478 .702 .967 r
.26129 .40225 .26764 .40551 .27707 .40546 .27073 .40218 Metetra
.546 .728 .959 r
.27073 .40218 .27707 .40546 .28661 .40484 .28029 .40155 Metetra
.602 .747 .946 r
.28029 .40155 .28661 .40484 .29626 .40365 .28996 .40034 Metetra
.649 .759 .93 r
.28996 .40034 .29626 .40365 .30601 .40188 .29973 .39854 Metetra
.688 .767 .912 r
.29973 .39854 .30601 .40188 .31585 .3995 .3096 .39613 Metetra
.72 .772 .894 r
.3096 .39613 .31585 .3995 .32578 .39652 .31955 .39311 Metetra
.747 .774 .875 r
.31955 .39311 .32578 .39652 .33578 .39292 .32959 .38946 Metetra
.769 .774 .857 r
.32959 .38946 .33578 .39292 .34587 .38868 .33971 .38516 Metetra
.788 .773 .839 r
.33971 .38516 .34587 .38868 .35601 .38379 .34989 .38019 Metetra
.805 .771 .822 r
.34989 .38019 .35601 .38379 .36622 .37821 .36014 .37453 Metetra
.819 .768 .805 r
.36014 .37453 .36622 .37821 .37648 .37193 .37044 .36815 Metetra
.83 .764 .789 r
.37044 .36815 .37648 .37193 .38678 .36491 .38078 .36102 Metetra
.841 .76 .773 r
.38078 .36102 .38678 .36491 .39712 .35712 .39117 .35309 Metetra
.85 .755 .758 r
.39117 .35309 .39712 .35712 .40748 .34851 .40158 .34433 Metetra
.858 .75 .743 r
.40158 .34433 .40748 .34851 .41786 .33904 .41201 .33469 Metetra
.864 .745 .729 r
.41201 .33469 .41786 .33904 .42825 .32865 .42246 .32409 Metetra
.87 .739 .715 r
.42246 .32409 .42825 .32865 .43864 .31727 .4329 .31248 Metetra
.875 .733 .702 r
.4329 .31248 .43864 .31727 .44901 .30483 .44333 .29977 Metetra
.879 .727 .688 r
.44333 .29977 .44901 .30483 .45935 .29125 .45373 .28586 Metetra
.882 .72 .675 r
.45373 .28586 .45935 .29125 .46965 .27642 .4641 .27063 Metetra
.885 .712 .663 r
.4641 .27063 .46965 .27642 .4799 .26022 .4744 .25393 Metetra
.824 .692 .719 r
.4744 .25393 .4799 .26022 .48996 .24807 .48446 .24433 Metetra
0 .183 .699 r
.61598 .21729 .62117 .22121 .63208 .22934 .62676 .22281 Metetra
0 0 .384 r
.62676 .22281 .63208 .22934 .64339 .24162 .63807 .23556 Metetra
0 0 .445 r
.63807 .23556 .64339 .24162 .65481 .25256 .6495 .24687 Metetra
0 0 .51 r
.6495 .24687 .65481 .25256 .66632 .26227 .66102 .25689 Metetra
0 .012 .576 r
.66102 .25689 .66632 .26227 .67792 .27087 .67263 .26573 Metetra
0 .091 .642 r
.67263 .26573 .67792 .27087 .68959 .27842 .68432 .27349 Metetra
0 .171 .705 r
.68432 .27349 .68959 .27842 .70133 .285 .69608 .28025 Metetra
0 .25 .762 r
.69608 .28025 .70133 .285 .71313 .29067 .70789 .28607 Metetra
0 .326 .812 r
.70789 .28607 .71313 .29067 .72497 .29549 .71975 .291 Metetra
.075 .398 .854 r
.71975 .291 .72497 .29549 .73684 .29948 .73166 .29511 Metetra
.162 .463 .888 r
.73166 .29511 .73684 .29948 .74875 .30271 .74359 .29842 Metetra
.245 .522 .913 r
.74359 .29842 .74875 .30271 .76068 .30518 .75555 .30097 Metetra
.321 .574 .931 r
.75555 .30097 .76068 .30518 .77262 .30694 .76752 .30279 Metetra
.391 .619 .943 r
.76752 .30279 .77262 .30694 .78457 .30801 .7795 .3039 Metetra
.455 .657 .948 r
.7795 .3039 .78457 .30801 .79651 .30841 .79148 .30433 Metetra
.512 .69 .948 r
.79148 .30433 .79651 .30841 .80844 .30815 .80344 .3041 Metetra
.562 .717 .945 r
.80344 .3041 .80844 .30815 .82034 .30724 .81538 .3032 Metetra
.608 .739 .938 r
.81538 .3032 .82034 .30724 .83222 .3057 .82729 .30167 Metetra
.648 .758 .93 r
.82729 .30167 .83222 .3057 .84405 .30354 .83916 .2995 Metetra
.683 .773 .919 r
.83916 .2995 .84405 .30354 .85583 .30075 .85098 .29671 Metetra
.715 .785 .907 r
.85098 .29671 .85583 .30075 .86755 .29735 .86274 .29329 Metetra
.743 .795 .894 r
.86274 .29329 .86755 .29735 .8792 .29334 .87443 .28927 Metetra
.767 .802 .881 r
.87443 .28927 .8792 .29334 .89078 .28874 .88604 .28465 Metetra
.397 .667 .968 r
.24556 .39848 .25197 .40175 .26129 .40225 .2549 .39896 Metetra
.478 .703 .967 r
.2549 .39896 .26129 .40225 .27073 .40218 .26435 .39889 Metetra
.546 .729 .959 r
.26435 .39889 .27073 .40218 .28029 .40155 .27393 .39824 Metetra
.603 .747 .946 r
.27393 .39824 .28029 .40155 .28996 .40034 .28362 .39701 Metetra
.65 .759 .929 r
.28362 .39701 .28996 .40034 .29973 .39854 .29341 .39518 Metetra
.689 .768 .912 r
.29341 .39518 .29973 .39854 .3096 .39613 .30331 .39274 Metetra
.721 .772 .893 r
.30331 .39274 .3096 .39613 .31955 .39311 .31329 .38969 Metetra
.748 .775 .875 r
.31329 .38969 .31955 .39311 .32959 .38946 .32336 .38599 Metetra
.771 .775 .857 r
.32336 .38599 .32959 .38946 .33971 .38516 .33351 .38163 Metetra
.79 .775 .839 r
.33351 .38163 .33971 .38516 .34989 .38019 .34373 .3766 Metetra
.807 .773 .822 r
.34373 .3766 .34989 .38019 .36014 .37453 .35401 .37087 Metetra
.821 .77 .805 r
.35401 .37087 .36014 .37453 .37044 .36815 .36435 .36441 Metetra
.833 .767 .789 r
.36435 .36441 .37044 .36815 .38078 .36102 .37474 .35718 Metetra
.844 .763 .773 r
.37474 .35718 .38078 .36102 .39117 .35309 .38517 .34914 Metetra
.853 .759 .758 r
.38517 .34914 .39117 .35309 .40158 .34433 .39563 .34026 Metetra
.861 .754 .743 r
.39563 .34026 .40158 .34433 .41201 .33469 .40612 .33046 Metetra
.868 .749 .729 r
.40612 .33046 .41201 .33469 .42246 .32409 .41662 .3197 Metetra
.875 .744 .715 r
.41662 .3197 .42246 .32409 .4329 .31248 .42711 .3079 Metetra
.88 .738 .701 r
.42711 .3079 .4329 .31248 .44333 .29977 .4376 .29496 Metetra
.885 .732 .687 r
.4376 .29496 .44333 .29977 .45373 .28586 .44807 .28077 Metetra
.889 .726 .674 r
.44807 .28077 .45373 .28586 .4641 .27063 .4585 .2652 Metetra
.892 .719 .661 r
.4585 .2652 .4641 .27063 .4744 .25393 .46887 .24806 Metetra
.803 .697 .748 r
.46887 .24806 .4744 .25393 .48446 .24433 .47891 .24057 Metetra
.067 .417 .865 r
.61075 .21334 .61598 .21729 .62676 .22281 .62143 .21671 Metetra
.634 .245 0 r
.62143 .21671 .62676 .22281 .63807 .23556 .63274 .22986 Metetra
0 0 .392 r
.63274 .22986 .63807 .23556 .6495 .24687 .64417 .24149 Metetra
0 0 .465 r
.64417 .24149 .6495 .24687 .66102 .25689 .6557 .25176 Metetra
0 0 .54 r
.6557 .25176 .66102 .25689 .67263 .26573 .66732 .2608 Metetra
0 .061 .613 r
.66732 .2608 .67263 .26573 .68432 .27349 .67903 .26873 Metetra
0 .146 .683 r
.67903 .26873 .68432 .27349 .69608 .28025 .6908 .27562 Metetra
0 .23 .746 r
.6908 .27562 .69608 .28025 .70789 .28607 .70263 .28156 Metetra
0 .311 .802 r
.70263 .28156 .70789 .28607 .71975 .291 .71452 .2866 Metetra
.051 .387 .848 r
.71452 .2866 .71975 .291 .73166 .29511 .72645 .29079 Metetra
.144 .456 .885 r
.72645 .29079 .73166 .29511 .74359 .29842 .73841 .29416 Metetra
.231 .517 .913 r
.73841 .29416 .74359 .29842 .75555 .30097 .75039 .29677 Metetra
.311 .571 .932 r
.75039 .29677 .75555 .30097 .76752 .30279 .76239 .29864 Metetra
.384 .617 .943 r
.76239 .29864 .76752 .30279 .7795 .3039 .7744 .29979 Metetra
.45 .657 .949 r
.7744 .29979 .7795 .3039 .79148 .30433 .78641 .30025 Metetra
.508 .69 .949 r
.78641 .30025 .79148 .30433 .80344 .3041 .79841 .30003 Metetra
.56 .717 .946 r
.79841 .30003 .80344 .3041 .81538 .3032 .81038 .29914 Metetra
.606 .739 .939 r
.81038 .29914 .81538 .3032 .82729 .30167 .82233 .29761 Metetra
.647 .758 .93 r
.82233 .29761 .82729 .30167 .83916 .2995 .83423 .29544 Metetra
.683 .773 .919 r
.83423 .29544 .83916 .2995 .85098 .29671 .84609 .29263 Metetra
.715 .785 .907 r
.84609 .29263 .85098 .29671 .86274 .29329 .85789 .28921 Metetra
.742 .795 .894 r
.85789 .28921 .86274 .29329 .87443 .28927 .86962 .28517 Metetra
.767 .802 .881 r
.86962 .28517 .87443 .28927 .88604 .28465 .88127 .28054 Metetra
.398 .668 .968 r
.23911 .39518 .24556 .39848 .2549 .39896 .24846 .39565 Metetra
.479 .703 .967 r
.24846 .39565 .2549 .39896 .26435 .39889 .25793 .39557 Metetra
.547 .729 .959 r
.25793 .39557 .26435 .39889 .27393 .39824 .26753 .39491 Metetra
.604 .747 .946 r
.26753 .39491 .27393 .39824 .28362 .39701 .27723 .39366 Metetra
.65 .76 .929 r
.27723 .39366 .28362 .39701 .29341 .39518 .28705 .39181 Metetra
.689 .768 .912 r
.28705 .39181 .29341 .39518 .30331 .39274 .29697 .38934 Metetra
.722 .773 .893 r
.29697 .38934 .30331 .39274 .31329 .38969 .30698 .38625 Metetra
.749 .776 .875 r
.30698 .38625 .31329 .38969 .32336 .38599 .31708 .38252 Metetra
.772 .777 .857 r
.31708 .38252 .32336 .38599 .33351 .38163 .32726 .37812 Metetra
.792 .776 .839 r
.32726 .37812 .33351 .38163 .34373 .3766 .33752 .37304 Metetra
.808 .775 .822 r
.33752 .37304 .34373 .3766 .35401 .37087 .34784 .36724 Metetra
.823 .772 .805 r
.34784 .36724 .35401 .37087 .36435 .36441 .35822 .36071 Metetra
.835 .769 .789 r
.35822 .36071 .36435 .36441 .37474 .35718 .36866 .3534 Metetra
.846 .766 .773 r
.36866 .3534 .37474 .35718 .38517 .34914 .37913 .34528 Metetra
.856 .762 .758 r
.37913 .34528 .38517 .34914 .39563 .34026 .38964 .33629 Metetra
.865 .758 .743 r
.38964 .33629 .39563 .34026 .40612 .33046 .40018 .32638 Metetra
.872 .753 .729 r
.40018 .32638 .40612 .33046 .41662 .3197 .41073 .31548 Metetra
.879 .749 .714 r
.41073 .31548 .41662 .3197 .42711 .3079 .42128 .30352 Metetra
.885 .744 .7 r
.42128 .30352 .42711 .3079 .4376 .29496 .43183 .29039 Metetra
.89 .738 .687 r
.43183 .29039 .4376 .29496 .44807 .28077 .44236 .27598 Metetra
.895 .733 .673 r
.44236 .27598 .44807 .28077 .4585 .2652 .45286 .26014 Metetra
.899 .727 .659 r
.45286 .26014 .4585 .2652 .46887 .24806 .4633 .24267 Metetra
.781 .705 .78 r
.4633 .24267 .46887 .24806 .47891 .24057 .47333 .23678 Metetra
.301 .566 .93 r
.60549 .20936 .61075 .21334 .62143 .21671 .6161 .21108 Metetra
.693 .286 0 r
.6161 .21108 .62143 .21671 .63274 .22986 .62741 .22454 Metetra
.631 .215 0 r
.62741 .22454 .63274 .22986 .64417 .24149 .63884 .23641 Metetra
0 0 .421 r
.63884 .23641 .64417 .24149 .6557 .25176 .65037 .24687 Metetra
0 0 .503 r
.65037 .24687 .6557 .25176 .66732 .2608 .662 .25608 Metetra
0 .034 .584 r
.662 .25608 .66732 .2608 .67903 .26873 .67371 .26413 Metetra
0 .124 .661 r
.67371 .26413 .67903 .26873 .6908 .27562 .6855 .27114 Metetra
0 .212 .731 r
.6855 .27114 .6908 .27562 .70263 .28156 .69735 .27716 Metetra
0 .298 .792 r
.69735 .27716 .70263 .28156 .71452 .2866 .70926 .28228 Metetra
.028 .377 .843 r
.70926 .28228 .71452 .2866 .72645 .29079 .72121 .28652 Metetra
.126 .45 .883 r
.72121 .28652 .72645 .29079 .73841 .29416 .73319 .28996 Metetra
.218 .514 .912 r
.73319 .28996 .73841 .29416 .75039 .29677 .7452 .29261 Metetra
.302 .569 .932 r
.7452 .29261 .75039 .29677 .76239 .29864 .75723 .2945 Metetra
.378 .616 .944 r
.75723 .2945 .76239 .29864 .7744 .29979 .76927 .29568 Metetra
.446 .656 .95 r
.76927 .29568 .7744 .29979 .78641 .30025 .78131 .29615 Metetra
.506 .69 .95 r
.78131 .29615 .78641 .30025 .79841 .30003 .79334 .29594 Metetra
.559 .717 .947 r
.79334 .29594 .79841 .30003 .81038 .29914 .80534 .29506 Metetra
.605 .74 .94 r
.80534 .29506 .81038 .29914 .82233 .29761 .81732 .29353 Metetra
.646 .758 .93 r
.81732 .29353 .82233 .29761 .83423 .29544 .82927 .29135 Metetra
.683 .773 .919 r
.82927 .29135 .83423 .29544 .84609 .29263 .84116 .28853 Metetra
.714 .785 .907 r
.84116 .28853 .84609 .29263 .85789 .28921 .853 .28509 Metetra
.742 .795 .895 r
.853 .28509 .85789 .28921 .86962 .28517 .86477 .28104 Metetra
.767 .802 .882 r
.86477 .28104 .86962 .28517 .88127 .28054 .87646 .27638 Metetra
.398 .668 .968 r
.23261 .39186 .23911 .39518 .24846 .39565 .24197 .39232 Metetra
.479 .703 .967 r
.24197 .39232 .24846 .39565 .25793 .39557 .25146 .39222 Metetra
.547 .729 .959 r
.25146 .39222 .25793 .39557 .26753 .39491 .26108 .39155 Metetra
.604 .747 .946 r
.26108 .39155 .26753 .39491 .27723 .39366 .27081 .39029 Metetra
.651 .76 .929 r
.27081 .39029 .27723 .39366 .28705 .39181 .28064 .38842 Metetra
.69 .769 .912 r
.28064 .38842 .28705 .39181 .29697 .38934 .29059 .38593 Metetra
.722 .774 .893 r
.29059 .38593 .29697 .38934 .30698 .38625 .30063 .38281 Metetra
.75 .777 .875 r
.30063 .38281 .30698 .38625 .31708 .38252 .31076 .37905 Metetra
.773 .778 .857 r
.31076 .37905 .31708 .38252 .32726 .37812 .32097 .37461 Metetra
.793 .778 .839 r
.32097 .37461 .32726 .37812 .33752 .37304 .33126 .36949 Metetra
.81 .777 .822 r
.33126 .36949 .33752 .37304 .34784 .36724 .34162 .36365 Metetra
.824 .775 .805 r
.34162 .36365 .34784 .36724 .35822 .36071 .35205 .35706 Metetra
.837 .772 .789 r
.35205 .35706 .35822 .36071 .36866 .3534 .36252 .34969 Metetra
.849 .769 .774 r
.36252 .34969 .36866 .3534 .37913 .34528 .37304 .3415 Metetra
.859 .766 .758 r
.37304 .3415 .37913 .34528 .38964 .33629 .3836 .33243 Metetra
.868 .762 .744 r
.3836 .33243 .38964 .33629 .40018 .32638 .39419 .32243 Metetra
.876 .758 .729 r
.39419 .32243 .40018 .32638 .41073 .31548 .40479 .31144 Metetra
.883 .754 .715 r
.40479 .31144 .41073 .31548 .42128 .30352 .4154 .29936 Metetra
.89 .75 .701 r
.4154 .29936 .42128 .30352 .43183 .29039 .42601 .2861 Metetra
.896 .745 .686 r
.42601 .2861 .43183 .29039 .44236 .27598 .43661 .27153 Metetra
.901 .74 .672 r
.43661 .27153 .44236 .27598 .45286 .26014 .44717 .25549 Metetra
.906 .734 .658 r
.44717 .25549 .45286 .26014 .4633 .24267 .45769 .23777 Metetra
.764 .718 .81 r
.45769 .23777 .4633 .24267 .47333 .23678 .46771 .23297 Metetra
.966 .67 .419 r
.51791 .22251 .52341 .22639 .53354 .22429 .52829 .36139 Metetra
.538 .31 .516 r
.52829 .36139 .53354 .22429 .5437 .22218 .53922 .3594 Metetra
0 0 .319 r
.53922 .3594 .5437 .22218 .55391 .22007 .54848 .21614 Metetra
.435 .639 .943 r
.60019 .20536 .60549 .20936 .6161 .21108 .61077 .20595 Metetra
.74 .319 0 r
.61077 .20595 .6161 .21108 .62741 .22454 .62207 .21963 Metetra
.678 .248 0 r
.62207 .21963 .62741 .22454 .63884 .23641 .63349 .23167 Metetra
.605 .168 0 r
.63349 .23167 .63884 .23641 .65037 .24687 .64503 .24226 Metetra
0 0 .467 r
.64503 .24226 .65037 .24687 .662 .25608 .65666 .25157 Metetra
0 .009 .555 r
.65666 .25157 .662 .25608 .67371 .26413 .66838 .25971 Metetra
0 .103 .639 r
.66838 .25971 .67371 .26413 .6855 .27114 .68018 .26679 Metetra
0 .196 .716 r
.68018 .26679 .6855 .27114 .69735 .27716 .69205 .27288 Metetra
0 .286 .782 r
.69205 .27288 .69735 .27716 .70926 .28228 .70397 .27804 Metetra
.007 .37 .837 r
.70397 .27804 .70926 .28228 .72121 .28652 .71594 .28233 Metetra
.111 .445 .88 r
.71594 .28233 .72121 .28652 .73319 .28996 .72794 .28579 Metetra
.207 .511 .912 r
.72794 .28579 .73319 .28996 .7452 .29261 .73998 .28847 Metetra
.294 .568 .933 r
.73998 .28847 .7452 .29261 .75723 .2945 .75204 .29038 Metetra
.372 .616 .946 r
.75204 .29038 .75723 .2945 .76927 .29568 .7641 .29157 Metetra
.442 .656 .951 r
.7641 .29157 .76927 .29568 .78131 .29615 .77617 .29205 Metetra
.503 .69 .951 r
.77617 .29205 .78131 .29615 .79334 .29594 .78823 .29185 Metetra
.557 .717 .947 r
.78823 .29185 .79334 .29594 .80534 .29506 .80027 .29096 Metetra
.605 .74 .94 r
.80027 .29096 .80534 .29506 .81732 .29353 .81229 .28942 Metetra
.646 .758 .931 r
.81229 .28942 .81732 .29353 .82927 .29135 .82426 .28723 Metetra
.682 .773 .92 r
.82426 .28723 .82927 .29135 .84116 .28853 .8362 .2844 Metetra
.714 .785 .907 r
.8362 .2844 .84116 .28853 .853 .28509 .84807 .28095 Metetra
.742 .795 .895 r
.84807 .28095 .853 .28509 .86477 .28104 .85988 .27687 Metetra
.767 .802 .882 r
.85988 .27687 .86477 .28104 .87646 .27638 .87162 .2722 Metetra
.399 .668 .968 r
.22607 .38852 .23261 .39186 .24197 .39232 .23545 .38897 Metetra
.479 .703 .967 r
.23545 .38897 .24197 .39232 .25146 .39222 .24495 .38886 Metetra
.547 .729 .959 r
.24495 .38886 .25146 .39222 .26108 .39155 .25458 .38817 Metetra
.604 .748 .946 r
.25458 .38817 .26108 .39155 .27081 .39029 .26433 .3869 Metetra
.651 .76 .929 r
.26433 .3869 .27081 .39029 .28064 .38842 .27419 .38501 Metetra
.69 .769 .912 r
.27419 .38501 .28064 .38842 .29059 .38593 .28416 .38251 Metetra
.723 .774 .894 r
.28416 .38251 .29059 .38593 .30063 .38281 .29423 .37937 Metetra
.75 .778 .875 r
.29423 .37937 .30063 .38281 .31076 .37905 .30439 .37558 Metetra
.774 .779 .857 r
.30439 .37558 .31076 .37905 .32097 .37461 .31463 .37112 Metetra
.794 .779 .84 r
.31463 .37112 .32097 .37461 .33126 .36949 .32496 .36596 Metetra
.811 .778 .823 r
.32496 .36596 .33126 .36949 .34162 .36365 .33536 .36009 Metetra
.826 .777 .806 r
.33536 .36009 .34162 .36365 .35205 .35706 .34582 .35346 Metetra
.839 .775 .79 r
.34582 .35346 .35205 .35706 .36252 .34969 .35634 .34605 Metetra
.851 .772 .775 r
.35634 .34605 .36252 .34969 .37304 .3415 .3669 .33781 Metetra
.861 .77 .759 r
.3669 .33781 .37304 .3415 .3836 .33243 .37751 .32869 Metetra
.871 .767 .744 r
.37751 .32869 .3836 .33243 .39419 .32243 .38815 .31863 Metetra
.879 .763 .73 r
.38815 .31863 .39419 .32243 .40479 .31144 .3988 .30757 Metetra
.887 .76 .715 r
.3988 .30757 .40479 .31144 .4154 .29936 .40947 .29542 Metetra
.894 .756 .701 r
.40947 .29542 .4154 .29936 .42601 .2861 .42014 .28208 Metetra
.901 .752 .687 r
.42014 .28208 .42601 .2861 .43661 .27153 .4308 .26741 Metetra
.907 .747 .673 r
.4308 .26741 .43661 .27153 .44717 .25549 .44143 .25125 Metetra
.912 .743 .658 r
.44143 .25125 .44717 .25549 .45769 .23777 .45202 .23339 Metetra
.756 .738 .836 r
.45202 .23339 .45769 .23777 .46771 .23297 .46205 .22913 Metetra
.966 .67 .419 r
.51237 .2186 .51791 .22251 .52829 .36139 .52238 .3577 Metetra
.966 .702 .482 r
.53333 .35569 .53922 .3594 .54848 .21614 .54302 .21218 Metetra
.493 .669 .941 r
.59485 .20133 .60019 .20536 .61077 .20595 .60543 .20134 Metetra
.778 .345 0 r
.60543 .20134 .61077 .20595 .62207 .21963 .61672 .21514 Metetra
.717 .274 0 r
.61672 .21514 .62207 .21963 .63349 .23167 .62813 .22727 Metetra
.644 .194 0 r
.62813 .22727 .63349 .23167 .64503 .24226 .63967 .23793 Metetra
0 0 .432 r
.63967 .23793 .64503 .24226 .65666 .25157 .6513 .24729 Metetra
0 0 .527 r
.6513 .24729 .65666 .25157 .66838 .25971 .66303 .25548 Metetra
0 .085 .618 r
.66303 .25548 .66838 .25971 .68018 .26679 .67484 .26259 Metetra
0 .183 .701 r
.67484 .26259 .68018 .26679 .69205 .27288 .68671 .26871 Metetra
0 .276 .773 r
.68671 .26871 .69205 .27288 .70397 .27804 .69865 .27389 Metetra
0 .363 .832 r
.69865 .27389 .70397 .27804 .71594 .28233 .71064 .2782 Metetra
.097 .441 .878 r
.71064 .2782 .71594 .28233 .72794 .28579 .72267 .28167 Metetra
.197 .509 .912 r
.72267 .28167 .72794 .28579 .73998 .28847 .73473 .28436 Metetra
.288 .568 .934 r
.73473 .28436 .73998 .28847 .75204 .29038 .74681 .28628 Metetra
.368 .617 .947 r
.74681 .28628 .75204 .29038 .7641 .29157 .7589 .28747 Metetra
.439 .657 .953 r
.7589 .28747 .7641 .29157 .77617 .29205 .771 .28795 Metetra
.502 .691 .953 r
.771 .28795 .77617 .29205 .78823 .29185 .78309 .28773 Metetra
.556 .718 .948 r
.78309 .28773 .78823 .29185 .80027 .29096 .79516 .28684 Metetra
.604 .74 .941 r
.79516 .28684 .80027 .29096 .81229 .28942 .80721 .28529 Metetra
.646 .758 .931 r
.80721 .28529 .81229 .28942 .82426 .28723 .81922 .28309 Metetra
.682 .773 .92 r
.81922 .28309 .82426 .28723 .8362 .2844 .83119 .28024 Metetra
.714 .785 .908 r
.83119 .28024 .8362 .2844 .84807 .28095 .84311 .27677 Metetra
.742 .795 .895 r
.84311 .27677 .84807 .28095 .85988 .27687 .85496 .27268 Metetra
.767 .802 .882 r
.85496 .27268 .85988 .27687 .87162 .2722 .86673 .26798 Metetra
.399 .668 .968 r
.21948 .38515 .22607 .38852 .23545 .38897 .22887 .38559 Metetra
.479 .703 .967 r
.22887 .38559 .23545 .38897 .24495 .38886 .23839 .38547 Metetra
.547 .729 .959 r
.23839 .38547 .24495 .38886 .25458 .38817 .24804 .38477 Metetra
.604 .748 .946 r
.24804 .38477 .25458 .38817 .26433 .3869 .25781 .38349 Metetra
.651 .761 .93 r
.25781 .38349 .26433 .3869 .27419 .38501 .26769 .38159 Metetra
.69 .769 .912 r
.26769 .38159 .27419 .38501 .28416 .38251 .27769 .37907 Metetra
.723 .775 .894 r
.27769 .37907 .28416 .38251 .29423 .37937 .28778 .37592 Metetra
.751 .779 .876 r
.28778 .37592 .29423 .37937 .30439 .37558 .29797 .37211 Metetra
.774 .78 .858 r
.29797 .37211 .30439 .37558 .31463 .37112 .30825 .36763 Metetra
.794 .781 .841 r
.30825 .36763 .31463 .37112 .32496 .36596 .31861 .36246 Metetra
.812 .781 .824 r
.31861 .36246 .32496 .36596 .33536 .36009 .32904 .35656 Metetra
.827 .779 .807 r
.32904 .35656 .33536 .36009 .34582 .35346 .33954 .34991 Metetra
.841 .778 .791 r
.33954 .34991 .34582 .35346 .35634 .34605 .3501 .34248 Metetra
.853 .776 .776 r
.3501 .34248 .35634 .34605 .3669 .33781 .36071 .33421 Metetra
.864 .774 .761 r
.36071 .33421 .3669 .33781 .37751 .32869 .37136 .32507 Metetra
.874 .771 .746 r
.37136 .32507 .37751 .32869 .38815 .31863 .38205 .31498 Metetra
.883 .768 .731 r
.38205 .31498 .38815 .31863 .3988 .30757 .39276 .30389 Metetra
.891 .765 .717 r
.39276 .30389 .3988 .30757 .40947 .29542 .40349 .29171 Metetra
.898 .762 .702 r
.40349 .29171 .40947 .29542 .42014 .28208 .41421 .27833 Metetra
.906 .759 .688 r
.41421 .27833 .42014 .28208 .4308 .26741 .42493 .26363 Metetra
.912 .755 .673 r
.42493 .26363 .4308 .26741 .44143 .25125 .43563 .24744 Metetra
.919 .751 .658 r
.43563 .24744 .44143 .25125 .45202 .23339 .44629 .22954 Metetra
.766 .766 .853 r
.44629 .22954 .45202 .23339 .46205 .22913 .45636 .22526 Metetra
.966 .67 .419 r
.5068 .21466 .51237 .2186 .52238 .3577 .51643 .35398 Metetra
.966 .702 .482 r
.52741 .35196 .53333 .35569 .54302 .21218 .53751 .2082 Metetra
.493 .669 .941 r
.58948 .19728 .59485 .20133 .60543 .20134 .60008 .19727 Metetra
.805 .364 0 r
.60008 .19727 .60543 .20134 .61672 .21514 .61135 .21108 Metetra
.747 .294 0 r
.61135 .21108 .61672 .21514 .62813 .22727 .62276 .22321 Metetra
.677 .214 0 r
.62276 .22321 .62813 .22727 .63967 .23793 .63429 .23387 Metetra
.592 .126 0 r
.63429 .23387 .63967 .23793 .6513 .24729 .64592 .24324 Metetra
0 0 .501 r
.64592 .24324 .6513 .24729 .66303 .25548 .65765 .25143 Metetra
0 .071 .599 r
.65765 .25143 .66303 .25548 .67484 .26259 .66947 .25854 Metetra
0 .171 .688 r
.66947 .25854 .67484 .26259 .68671 .26871 .68135 .26465 Metetra
0 .269 .765 r
.68135 .26465 .68671 .26871 .69865 .27389 .69331 .26983 Metetra
0 .359 .828 r
.69331 .26983 .69865 .27389 .71064 .2782 .70531 .27413 Metetra
.085 .439 .877 r
.70531 .27413 .71064 .2782 .72267 .28167 .71736 .2776 Metetra
.189 .509 .912 r
.71736 .2776 .72267 .28167 .73473 .28436 .72944 .28028 Metetra
.282 .568 .935 r
.72944 .28028 .73473 .28436 .74681 .28628 .74154 .28219 Metetra
.365 .618 .948 r
.74154 .28219 .74681 .28628 .7589 .28747 .75366 .28337 Metetra
.438 .658 .954 r
.75366 .28337 .7589 .28747 .771 .28795 .76579 .28384 Metetra
.501 .692 .954 r
.76579 .28384 .771 .28795 .78309 .28773 .77791 .28361 Metetra
.556 .719 .949 r
.77791 .28361 .78309 .28773 .79516 .28684 .79002 .28271 Metetra
.604 .741 .941 r
.79002 .28271 .79516 .28684 .80721 .28529 .8021 .28114 Metetra
.646 .759 .931 r
.8021 .28114 .80721 .28529 .81922 .28309 .81415 .27891 Metetra
.682 .773 .92 r
.81415 .27891 .81922 .28309 .83119 .28024 .82615 .27605 Metetra
.714 .785 .908 r
.82615 .27605 .83119 .28024 .84311 .27677 .8381 .27256 Metetra
.742 .795 .895 r
.8381 .27256 .84311 .27677 .85496 .27268 .84999 .26844 Metetra
.767 .802 .882 r
.84999 .26844 .85496 .27268 .86673 .26798 .86181 .26373 Metetra
.399 .668 .968 r
.21285 .38175 .21948 .38515 .22887 .38559 .22226 .38219 Metetra
.479 .703 .967 r
.22226 .38219 .22887 .38559 .23839 .38547 .23179 .38206 Metetra
.547 .729 .959 r
.23179 .38206 .23839 .38547 .24804 .38477 .24146 .38136 Metetra
.604 .748 .946 r
.24146 .38136 .24804 .38477 .25781 .38349 .25125 .38006 Metetra
.651 .761 .93 r
.25125 .38006 .25781 .38349 .26769 .38159 .26115 .37815 Metetra
.69 .77 .913 r
.26115 .37815 .26769 .38159 .27769 .37907 .27117 .37562 Metetra
.723 .776 .895 r
.27117 .37562 .27769 .37907 .28778 .37592 .28129 .37246 Metetra
.75 .779 .877 r
.28129 .37246 .28778 .37592 .29797 .37211 .29151 .36864 Metetra
.774 .782 .859 r
.29151 .36864 .29797 .37211 .30825 .36763 .30182 .36415 Metetra
.795 .783 .842 r
.30182 .36415 .30825 .36763 .31861 .36246 .31221 .35897 Metetra
.812 .783 .825 r
.31221 .35897 .31861 .36246 .32904 .35656 .32268 .35307 Metetra
.828 .782 .809 r
.32268 .35307 .32904 .35656 .33954 .34991 .33322 .34642 Metetra
.842 .781 .793 r
.33322 .34642 .33954 .34991 .3501 .34248 .34381 .33898 Metetra
.854 .78 .778 r
.34381 .33898 .3501 .34248 .36071 .33421 .35447 .33071 Metetra
.866 .778 .762 r
.35447 .33071 .36071 .33421 .37136 .32507 .36517 .32156 Metetra
.876 .776 .748 r
.36517 .32156 .37136 .32507 .38205 .31498 .3759 .31148 Metetra
.885 .774 .733 r
.3759 .31148 .38205 .31498 .39276 .30389 .38666 .3004 Metetra
.894 .771 .718 r
.38666 .3004 .39276 .30389 .40349 .29171 .39744 .28823 Metetra
.902 .769 .704 r
.39744 .28823 .40349 .29171 .41421 .27833 .40823 .27487 Metetra
.91 .766 .689 r
.40823 .27487 .41421 .27833 .42493 .26363 .41901 .2602 Metetra
.918 .763 .675 r
.41901 .2602 .42493 .26363 .43563 .24744 .42977 .24406 Metetra
.925 .76 .659 r
.42977 .24406 .43563 .24744 .44629 .22954 .4405 .22623 Metetra
.794 .797 .855 r
.4405 .22623 .44629 .22954 .45636 .22526 .45062 .22137 Metetra
.966 .67 .419 r
.50118 .21069 .5068 .21466 .51643 .35398 .51043 .35024 Metetra
.966 .702 .482 r
.52144 .3482 .52741 .35196 .53751 .2082 .53197 .20419 Metetra
.435 .639 .943 r
.58407 .19319 .58948 .19728 .60008 .19727 .59471 .19374 Metetra
.824 .377 0 r
.59471 .19374 .60008 .19727 .61135 .21108 .60596 .20745 Metetra
.77 .308 0 r
.60596 .20745 .61135 .21108 .62276 .22321 .61736 .2195 Metetra
.702 .23 0 r
.61736 .2195 .62276 .22321 .63429 .23387 .62888 .2301 Metetra
.619 .141 0 r
.62888 .2301 .63429 .23387 .64592 .24324 .64052 .23942 Metetra
0 0 .477 r
.64052 .23942 .64592 .24324 .65765 .25143 .65225 .24756 Metetra
0 .059 .581 r
.65225 .24756 .65765 .25143 .66947 .25854 .66407 .25464 Metetra
0 .163 .676 r
.66407 .25464 .66947 .25854 .68135 .26465 .67597 .26071 Metetra
0 .263 .758 r
.67597 .26071 .68135 .26465 .69331 .26983 .68793 .26586 Metetra
0 .356 .825 r
.68793 .26586 .69331 .26983 .70531 .27413 .69995 .27014 Metetra
.076 .439 .876 r
.69995 .27014 .70531 .27413 .71736 .2776 .71201 .27358 Metetra
.183 .51 .913 r
.71201 .27358 .71736 .2776 .72944 .28028 .72412 .27623 Metetra
.279 .57 .936 r
.72412 .27623 .72944 .28028 .74154 .28219 .73624 .27812 Metetra
.363 .62 .95 r
.73624 .27812 .74154 .28219 .75366 .28337 .74839 .27928 Metetra
.437 .66 .955 r
.74839 .27928 .75366 .28337 .76579 .28384 .76054 .27972 Metetra
.501 .693 .955 r
.76054 .27972 .76579 .28384 .77791 .28361 .77269 .27947 Metetra
.556 .72 .95 r
.77269 .27947 .77791 .28361 .79002 .28271 .78483 .27855 Metetra
.604 .742 .942 r
.78483 .27855 .79002 .28271 .8021 .28114 .79695 .27696 Metetra
.646 .759 .932 r
.79695 .27696 .8021 .28114 .81415 .27891 .80903 .27472 Metetra
.682 .774 .92 r
.80903 .27472 .81415 .27891 .82615 .27605 .82107 .27183 Metetra
.714 .785 .908 r
.82107 .27183 .82615 .27605 .8381 .27256 .83306 .26832 Metetra
.742 .795 .895 r
.83306 .26832 .8381 .27256 .84999 .26844 .84499 .26418 Metetra
.767 .802 .882 r
.84499 .26418 .84999 .26844 .86181 .26373 .85685 .25944 Metetra
.399 .667 .968 r
.20618 .37833 .21285 .38175 .22226 .38219 .21559 .37876 Metetra
.479 .703 .967 r
.21559 .37876 .22226 .38219 .23179 .38206 .22514 .37863 Metetra
.547 .729 .959 r
.22514 .37863 .23179 .38206 .24146 .38136 .23482 .37791 Metetra
.603 .748 .946 r
.23482 .37791 .24146 .38136 .25125 .38006 .24463 .37661 Metetra
.65 .761 .93 r
.24463 .37661 .25125 .38006 .26115 .37815 .25456 .37469 Metetra
.69 .77 .913 r
.25456 .37469 .26115 .37815 .27117 .37562 .2646 .37216 Metetra
.722 .776 .895 r
.2646 .37216 .27117 .37562 .28129 .37246 .27475 .36899 Metetra
.75 .78 .878 r
.27475 .36899 .28129 .37246 .29151 .36864 .28499 .36517 Metetra
.774 .783 .86 r
.28499 .36517 .29151 .36864 .30182 .36415 .29533 .36069 Metetra
.794 .784 .843 r
.29533 .36069 .30182 .36415 .31221 .35897 .30576 .35551 Metetra
.812 .785 .827 r
.30576 .35551 .31221 .35897 .32268 .35307 .31626 .34961 Metetra
.828 .785 .811 r
.31626 .34961 .32268 .35307 .33322 .34642 .32684 .34297 Metetra
.843 .784 .795 r
.32684 .34297 .33322 .34642 .34381 .33898 .33747 .33554 Metetra
.856 .783 .78 r
.33747 .33554 .34381 .33898 .35447 .33071 .34817 .3273 Metetra
.867 .782 .765 r
.34817 .3273 .35447 .33071 .36517 .32156 .35891 .31818 Metetra
.878 .781 .75 r
.35891 .31818 .36517 .32156 .3759 .31148 .36969 .30813 Metetra
.888 .779 .735 r
.36969 .30813 .3759 .31148 .38666 .3004 .38051 .29709 Metetra
.897 .777 .721 r
.38051 .29709 .38666 .3004 .39744 .28823 .39134 .28497 Metetra
.906 .776 .706 r
.39134 .28497 .39744 .28823 .40823 .27487 .40218 .27169 Metetra
.914 .774 .692 r
.40218 .27169 .40823 .27487 .41901 .2602 .41302 .25711 Metetra
.922 .772 .677 r
.41302 .25711 .41901 .2602 .42977 .24406 .42385 .24109 Metetra
.93 .77 .661 r
.42385 .24109 .42977 .24406 .4405 .22623 .43465 .22344 Metetra
.835 .825 .838 r
.43465 .22344 .4405 .22623 .45062 .22137 .44485 .21745 Metetra
.664 .741 .907 r
.49553 .2067 .50118 .21069 .51043 .35024 .50578 .20453 Metetra
.549 .338 .546 r
.50578 .20453 .51043 .35024 .52144 .3482 .51607 .20234 Metetra
.549 .338 .546 r
.51607 .20234 .52144 .3482 .53197 .20419 .5264 .20015 Metetra
.301 .566 .93 r
.57862 .18908 .58407 .19319 .59471 .19374 .58932 .19074 Metetra
.836 .383 0 r
.58932 .19074 .59471 .19374 .60596 .20745 .60055 .20424 Metetra
.786 .317 0 r
.60055 .20424 .60596 .20745 .61736 .2195 .61194 .21613 Metetra
.721 .24 0 r
.61194 .21613 .61736 .2195 .62888 .2301 .62345 .22661 Metetra
.64 .151 0 r
.62345 .22661 .62888 .2301 .64052 .23942 .63508 .23582 Metetra
.542 .053 0 r
.63508 .23582 .64052 .23942 .65225 .24756 .64682 .24388 Metetra
0 .051 .565 r
.64682 .24388 .65225 .24756 .66407 .25464 .65864 .25088 Metetra
0 .158 .666 r
.65864 .25088 .66407 .25464 .67597 .26071 .67055 .25689 Metetra
0 .261 .753 r
.67055 .25689 .67597 .26071 .68793 .26586 .68252 .26199 Metetra
0 .356 .823 r
.68252 .26199 .68793 .26586 .69995 .27014 .69456 .26621 Metetra
.069 .44 .877 r
.69456 .26621 .69995 .27014 .71201 .27358 .70664 .26961 Metetra
.179 .512 .914 r
.70664 .26961 .71201 .27358 .72412 .27623 .71876 .27221 Metetra
.277 .573 .938 r
.71876 .27221 .72412 .27623 .73624 .27812 .73091 .27407 Metetra
.363 .622 .951 r
.73091 .27407 .73624 .27812 .74839 .27928 .74308 .27519 Metetra
.437 .662 .956 r
.74308 .27519 .74839 .27928 .76054 .27972 .75526 .2756 Metetra
.501 .695 .955 r
.75526 .2756 .76054 .27972 .77269 .27947 .76744 .27532 Metetra
.556 .721 .95 r
.76744 .27532 .77269 .27947 .78483 .27855 .77961 .27437 Metetra
.604 .743 .942 r
.77961 .27437 .78483 .27855 .79695 .27696 .79176 .27275 Metetra
.646 .76 .932 r
.79176 .27275 .79695 .27696 .80903 .27472 .80388 .27049 Metetra
.683 .774 .92 r
.80388 .27049 .80903 .27472 .82107 .27183 .81595 .26758 Metetra
.714 .785 .908 r
.81595 .26758 .82107 .27183 .83306 .26832 .82798 .26404 Metetra
.742 .795 .895 r
.82798 .26404 .83306 .26832 .84499 .26418 .83995 .25988 Metetra
.767 .802 .881 r
.83995 .25988 .84499 .26418 .85685 .25944 .85185 .25512 Metetra
.398 .667 .968 r
.19945 .37489 .20618 .37833 .21559 .37876 .20888 .37531 Metetra
.479 .703 .967 r
.20888 .37531 .21559 .37876 .22514 .37863 .21845 .37517 Metetra
.546 .729 .959 r
.21845 .37517 .22514 .37863 .23482 .37791 .22815 .37445 Metetra
.603 .748 .946 r
.22815 .37445 .23482 .37791 .24463 .37661 .23797 .37314 Metetra
.65 .761 .931 r
.23797 .37314 .24463 .37661 .25456 .37469 .24792 .37122 Metetra
.689 .77 .914 r
.24792 .37122 .25456 .37469 .2646 .37216 .25798 .36868 Metetra
.722 .777 .896 r
.25798 .36868 .2646 .37216 .27475 .36899 .26816 .36552 Metetra
.749 .781 .879 r
.26816 .36552 .27475 .36899 .28499 .36517 .27843 .3617 Metetra
.773 .784 .862 r
.27843 .3617 .28499 .36517 .29533 .36069 .2888 .35723 Metetra
.794 .786 .845 r
.2888 .35723 .29533 .36069 .30576 .35551 .29925 .35206 Metetra
.812 .787 .829 r
.29925 .35206 .30576 .35551 .31626 .34961 .30979 .34618 Metetra
.829 .787 .813 r
.30979 .34618 .31626 .34961 .32684 .34297 .3204 .33957 Metetra
.843 .787 .797 r
.3204 .33957 .32684 .34297 .33747 .33554 .33108 .33218 Metetra
.856 .787 .782 r
.33108 .33218 .33747 .33554 .34817 .3273 .34182 .32397 Metetra
.869 .786 .767 r
.34182 .32397 .34817 .3273 .35891 .31818 .3526 .3149 Metetra
.88 .786 .753 r
.3526 .3149 .35891 .31818 .36969 .30813 .36343 .30492 Metetra
.89 .785 .738 r
.36343 .30492 .36969 .30813 .38051 .29709 .37429 .29396 Metetra
.9 .784 .724 r
.37429 .29396 .38051 .29709 .39134 .28497 .38517 .28194 Metetra
.909 .783 .709 r
.38517 .28194 .39134 .28497 .40218 .27169 .39607 .26878 Metetra
.918 .782 .694 r
.39607 .26878 .40218 .27169 .41302 .25711 .40697 .25436 Metetra
.927 .781 .679 r
.40697 .25436 .41302 .25711 .42385 .24109 .41785 .23854 Metetra
.935 .78 .664 r
.41785 .23854 .42385 .24109 .43465 .22344 .42872 .22115 Metetra
.878 .842 .806 r
.42872 .22115 .43465 .22344 .44485 .21745 .43903 .2135 Metetra
.067 .417 .865 r
.57313 .18493 .57862 .18908 .58932 .19074 .5839 .18825 Metetra
.842 .385 0 r
.5839 .18825 .58932 .19074 .60055 .20424 .59512 .20144 Metetra
.796 .321 0 r
.59512 .20144 .60055 .20424 .61194 .21613 .60649 .2131 Metetra
.734 .245 0 r
.60649 .2131 .61194 .21613 .62345 .22661 .618 .2234 Metetra
.655 .158 0 r
.618 .2234 .62345 .22661 .63508 .23582 .62962 .23245 Metetra
.558 .059 0 r
.62962 .23245 .63508 .23582 .64682 .24388 .64136 .24038 Metetra
0 .047 .552 r
.64136 .24038 .64682 .24388 .65864 .25088 .65319 .24727 Metetra
0 .155 .658 r
.65319 .24727 .65864 .25088 .67055 .25689 .6651 .25319 Metetra
0 .261 .749 r
.6651 .25319 .67055 .25689 .68252 .26199 .67708 .2582 Metetra
0 .358 .822 r
.67708 .2582 .68252 .26199 .69456 .26621 .68913 .26234 Metetra
.066 .444 .878 r
.68913 .26234 .69456 .26621 .70664 .26961 .70123 .26568 Metetra
.178 .516 .916 r
.70123 .26568 .70664 .26961 .71876 .27221 .71337 .26823 Metetra
.277 .576 .94 r
.71337 .26823 .71876 .27221 .73091 .27407 .72554 .27003 Metetra
.363 .625 .953 r
.72554 .27003 .73091 .27407 .74308 .27519 .73773 .2711 Metetra
.438 .665 .958 r
.73773 .2711 .74308 .27519 .75526 .2756 .74994 .27147 Metetra
.502 .697 .956 r
.74994 .27147 .75526 .2756 .76744 .27532 .76214 .27116 Metetra
.557 .723 .951 r
.76214 .27116 .76744 .27532 .77961 .27437 .77434 .27017 Metetra
.605 .744 .942 r
.77434 .27017 .77961 .27437 .79176 .27275 .78653 .26853 Metetra
.647 .761 .932 r
.78653 .26853 .79176 .27275 .80388 .27049 .79868 .26623 Metetra
.683 .774 .92 r
.79868 .26623 .80388 .27049 .81595 .26758 .8108 .2633 Metetra
.715 .786 .908 r
.8108 .2633 .81595 .26758 .82798 .26404 .82286 .25973 Metetra
.742 .795 .895 r
.82286 .25973 .82798 .26404 .83995 .25988 .83487 .25555 Metetra
.767 .802 .881 r
.83487 .25555 .83995 .25988 .85185 .25512 .84682 .25076 Metetra
.398 .667 .968 r
.19268 .37142 .19945 .37489 .20888 .37531 .20212 .37184 Metetra
.478 .702 .967 r
.20212 .37184 .20888 .37531 .21845 .37517 .2117 .37169 Metetra
.546 .729 .959 r
.2117 .37169 .21845 .37517 .22815 .37445 .22142 .37096 Metetra
.602 .748 .947 r
.22142 .37096 .22815 .37445 .23797 .37314 .23127 .36965 Metetra
.649 .761 .931 r
.23127 .36965 .23797 .37314 .24792 .37122 .24123 .36773 Metetra
.688 .77 .914 r
.24123 .36773 .24792 .37122 .25798 .36868 .25132 .36519 Metetra
.721 .777 .897 r
.25132 .36519 .25798 .36868 .26816 .36552 .26152 .36203 Metetra
.749 .782 .88 r
.26152 .36203 .26816 .36552 .27843 .3617 .27182 .35823 Metetra
.772 .785 .863 r
.27182 .35823 .27843 .3617 .2888 .35723 .28221 .35377 Metetra
.793 .787 .847 r
.28221 .35377 .2888 .35723 .29925 .35206 .2927 .34863 Metetra
.812 .789 .831 r
.2927 .34863 .29925 .35206 .30979 .34618 .30327 .34279 Metetra
.828 .79 .815 r
.30327 .34279 .30979 .34618 .3204 .33957 .31392 .33622 Metetra
.843 .79 .8 r
.31392 .33622 .3204 .33957 .33108 .33218 .32463 .32888 Metetra
.857 .791 .785 r
.32463 .32888 .33108 .33218 .34182 .32397 .3354 .32073 Metetra
.869 .791 .77 r
.3354 .32073 .34182 .32397 .3526 .3149 .34623 .31174 Metetra
.881 .791 .756 r
.34623 .31174 .3526 .3149 .36343 .30492 .3571 .30185 Metetra
.892 .79 .742 r
.3571 .30185 .36343 .30492 .37429 .29396 .36801 .291 Metetra
.902 .79 .727 r
.36801 .291 .37429 .29396 .38517 .28194 .37894 .27912 Metetra
.912 .79 .713 r
.37894 .27912 .38517 .28194 .39607 .26878 .38989 .26613 Metetra
.922 .79 .698 r
.38989 .26613 .39607 .26878 .40697 .25436 .40084 .25192 Metetra
.931 .79 .683 r
.40084 .25192 .40697 .25436 .41785 .23854 .41179 .23638 Metetra
.94 .791 .667 r
.41179 .23638 .41785 .23854 .42872 .22115 .42271 .21935 Metetra
.914 .846 .763 r
.42271 .21935 .42872 .22115 .43903 .2135 .43318 .20953 Metetra
0 .183 .699 r
.56761 .18076 .57313 .18493 .5839 .18825 .57844 .18624 Metetra
.844 .382 .009 r
.57844 .18624 .5839 .18825 .59512 .20144 .58965 .19905 Metetra
.801 .321 0 r
.58965 .19905 .59512 .20144 .60649 .2131 .60101 .2104 Metetra
.742 .247 0 r
.60101 .2104 .60649 .2131 .618 .2234 .61251 .22044 Metetra
.666 .16 0 r
.61251 .22044 .618 .2234 .62962 .23245 .62413 .2293 Metetra
.57 .061 0 r
.62413 .2293 .62962 .23245 .64136 .24038 .63587 .23706 Metetra
0 .046 .543 r
.63587 .23706 .64136 .24038 .65319 .24727 .6477 .2438 Metetra
0 .157 .652 r
.6477 .2438 .65319 .24727 .6651 .25319 .65962 .24959 Metetra
0 .264 .747 r
.65962 .24959 .6651 .25319 .67708 .2582 .67161 .25449 Metetra
0 .363 .823 r
.67161 .25449 .67708 .2582 .68913 .26234 .68367 .25854 Metetra
.065 .449 .88 r
.68367 .25854 .68913 .26234 .70123 .26568 .69578 .26179 Metetra
.179 .521 .918 r
.69578 .26179 .70123 .26568 .71337 .26823 .70794 .26426 Metetra
.279 .581 .942 r
.70794 .26426 .71337 .26823 .72554 .27003 .72013 .266 Metetra
.366 .629 .955 r
.72013 .266 .72554 .27003 .73773 .2711 .73235 .26701 Metetra
.44 .668 .959 r
.73235 .26701 .73773 .2711 .74994 .27147 .74458 .26733 Metetra
.504 .699 .957 r
.74458 .26733 .74994 .27147 .76214 .27116 .75681 .26697 Metetra
.559 .724 .951 r
.75681 .26697 .76214 .27116 .77434 .27017 .76904 .26595 Metetra
.606 .745 .943 r
.76904 .26595 .77434 .27017 .78653 .26853 .78126 .26427 Metetra
.647 .761 .932 r
.78126 .26427 .78653 .26853 .79868 .26623 .79345 .26195 Metetra
.683 .775 .92 r
.79345 .26195 .79868 .26623 .8108 .2633 .8056 .25898 Metetra
.715 .786 .908 r
.8056 .25898 .8108 .2633 .82286 .25973 .8177 .25539 Metetra
.743 .795 .895 r
.8177 .25539 .82286 .25973 .83487 .25555 .82975 .25119 Metetra
.767 .802 .881 r
.82975 .25119 .83487 .25555 .84682 .25076 .84174 .24637 Metetra
.397 .666 .968 r
.18587 .36793 .19268 .37142 .20212 .37184 .19532 .36834 Metetra
.478 .702 .967 r
.19532 .36834 .20212 .37184 .2117 .37169 .20491 .36819 Metetra
.545 .728 .959 r
.20491 .36819 .2117 .37169 .22142 .37096 .21465 .36745 Metetra
.601 .747 .947 r
.21465 .36745 .22142 .37096 .23127 .36965 .22451 .36613 Metetra
.648 .761 .932 r
.22451 .36613 .23127 .36965 .24123 .36773 .2345 .36421 Metetra
.687 .77 .915 r
.2345 .36421 .24123 .36773 .25132 .36519 .24461 .36169 Metetra
.719 .777 .898 r
.24461 .36169 .25132 .36519 .26152 .36203 .25483 .35854 Metetra
.747 .782 .881 r
.25483 .35854 .26152 .36203 .27182 .35823 .26515 .35476 Metetra
.771 .786 .865 r
.26515 .35476 .27182 .35823 .28221 .35377 .27558 .35032 Metetra
.792 .789 .849 r
.27558 .35032 .28221 .35377 .2927 .34863 .28609 .34522 Metetra
.811 .791 .833 r
.28609 .34522 .2927 .34863 .30327 .34279 .2967 .33942 Metetra
.828 .792 .818 r
.2967 .33942 .30327 .34279 .31392 .33622 .30737 .3329 Metetra
.843 .793 .803 r
.30737 .3329 .31392 .33622 .32463 .32888 .31812 .32564 Metetra
.857 .794 .788 r
.31812 .32564 .32463 .32888 .3354 .32073 .32893 .31758 Metetra
.87 .795 .774 r
.32893 .31758 .3354 .32073 .34623 .31174 .3398 .30869 Metetra
.882 .796 .76 r
.3398 .30869 .34623 .31174 .3571 .30185 .35071 .29892 Metetra
.894 .796 .745 r
.35071 .29892 .3571 .30185 .36801 .291 .36166 .28821 Metetra
.904 .797 .731 r
.36166 .28821 .36801 .291 .37894 .27912 .37264 .27651 Metetra
.915 .798 .717 r
.37264 .27651 .37894 .27912 .38989 .26613 .38364 .26373 Metetra
.925 .799 .702 r
.38364 .26373 .38989 .26613 .40084 .25192 .39464 .24979 Metetra
.935 .8 .687 r
.39464 .24979 .40084 .25192 .41179 .23638 .40564 .23459 Metetra
.945 .802 .671 r
.40564 .23459 .41179 .23638 .42271 .21935 .41662 .218 Metetra
.939 .841 .719 r
.41662 .218 .42271 .21935 .43318 .20953 .42729 .20553 Metetra
0 0 .457 r
.56204 .17656 .56761 .18076 .57844 .18624 .57295 .18468 Metetra
.841 .375 .024 r
.57295 .18468 .57844 .18624 .58965 .19905 .58414 .19702 Metetra
.802 .316 0 r
.58414 .19702 .58965 .19905 .60101 .2104 .59549 .208 Metetra
.746 .244 0 r
.59549 .208 .60101 .2104 .61251 .22044 .60698 .21775 Metetra
.671 .157 0 r
.60698 .21775 .61251 .22044 .62413 .2293 .6186 .22635 Metetra
.576 .058 0 r
.6186 .22635 .62413 .2293 .63587 .23706 .63034 .2339 Metetra
0 .05 .537 r
.63034 .2339 .63587 .23706 .6477 .2438 .64217 .24046 Metetra
0 .162 .65 r
.64217 .24046 .6477 .2438 .65962 .24959 .6541 .2461 Metetra
0 .27 .748 r
.6541 .2461 .65962 .24959 .67161 .25449 .6661 .25086 Metetra
0 .37 .826 r
.6661 .25086 .67161 .25449 .68367 .25854 .67817 .2548 Metetra
.067 .456 .883 r
.67817 .2548 .68367 .25854 .69578 .26179 .6903 .25794 Metetra
.182 .528 .921 r
.6903 .25794 .69578 .26179 .70794 .26426 .70247 .26032 Metetra
.283 .587 .945 r
.70247 .26032 .70794 .26426 .72013 .266 .71468 .26198 Metetra
.369 .634 .957 r
.71468 .26198 .72013 .266 .73235 .26701 .72692 .26292 Metetra
.443 .672 .96 r
.72692 .26292 .73235 .26701 .74458 .26733 .73918 .26318 Metetra
.507 .702 .958 r
.73918 .26318 .74458 .26733 .75681 .26697 .75144 .26277 Metetra
.561 .726 .951 r
.75144 .26277 .75681 .26697 .76904 .26595 .7637 .2617 Metetra
.608 .746 .943 r
.7637 .2617 .76904 .26595 .78126 .26427 .77595 .25998 Metetra
.648 .762 .932 r
.77595 .25998 .78126 .26427 .79345 .26195 .78817 .25763 Metetra
.684 .775 .92 r
.78817 .25763 .79345 .26195 .8056 .25898 .80036 .25464 Metetra
.715 .786 .908 r
.80036 .25464 .8056 .25898 .8177 .25539 .8125 .25102 Metetra
.743 .795 .894 r
.8125 .25102 .8177 .25539 .82975 .25119 .82459 .24679 Metetra
.767 .802 .881 r
.82459 .24679 .82975 .25119 .84174 .24637 .83662 .24194 Metetra
.396 .666 .968 r
.179 .36441 .18587 .36793 .19532 .36834 .18847 .36481 Metetra
.477 .702 .967 r
.18847 .36481 .19532 .36834 .20491 .36819 .19807 .36466 Metetra
.545 .728 .959 r
.19807 .36466 .20491 .36819 .21465 .36745 .20782 .36392 Metetra
.6 .747 .947 r
.20782 .36392 .21465 .36745 .22451 .36613 .21771 .3626 Metetra
.647 .761 .932 r
.21771 .3626 .22451 .36613 .2345 .36421 .22772 .36068 Metetra
.685 .77 .916 r
.22772 .36068 .2345 .36421 .24461 .36169 .23785 .35816 Metetra
.718 .777 .899 r
.23785 .35816 .24461 .36169 .25483 .35854 .24809 .35503 Metetra
.746 .783 .883 r
.24809 .35503 .25483 .35854 .26515 .35476 .25844 .35127 Metetra
.77 .787 .867 r
.25844 .35127 .26515 .35476 .27558 .35032 .26889 .34687 Metetra
.791 .79 .851 r
.26889 .34687 .27558 .35032 .28609 .34522 .27944 .34182 Metetra
.81 .792 .836 r
.27944 .34182 .28609 .34522 .2967 .33942 .29007 .33608 Metetra
.827 .794 .821 r
.29007 .33608 .2967 .33942 .30737 .3329 .30077 .32963 Metetra
.842 .796 .807 r
.30077 .32963 .30737 .3329 .31812 .32564 .31156 .32245 Metetra
.857 .798 .792 r
.31156 .32245 .31812 .32564 .32893 .31758 .3224 .3145 Metetra
.87 .799 .778 r
.3224 .3145 .32893 .31758 .3398 .30869 .33331 .30573 Metetra
.883 .801 .764 r
.33331 .30573 .3398 .30869 .35071 .29892 .34426 .29611 Metetra
.895 .802 .75 r
.34426 .29611 .35071 .29892 .36166 .28821 .35525 .28559 Metetra
.906 .804 .736 r
.35525 .28559 .36166 .28821 .37264 .27651 .36627 .27409 Metetra
.917 .806 .722 r
.36627 .27409 .37264 .27651 .38364 .26373 .37731 .26157 Metetra
.927 .807 .707 r
.37731 .26157 .38364 .26373 .39464 .24979 .38837 .24795 Metetra
.938 .81 .692 r
.38837 .24795 .39464 .24979 .40564 .23459 .39942 .23314 Metetra
.948 .813 .677 r
.39942 .23314 .40564 .23459 .41662 .218 .41045 .21705 Metetra
.955 .829 .68 r
.41045 .21705 .41662 .218 .42729 .20553 .42135 .2015 Metetra
.727 .27 0 r
.55644 .17232 .56204 .17656 .57295 .18468 .56741 .18353 Metetra
.836 .365 .034 r
.56741 .18353 .57295 .18468 .58414 .19702 .57859 .19533 Metetra
.799 .308 0 r
.57859 .19533 .58414 .19702 .59549 .208 .58993 .20589 Metetra
.745 .237 0 r
.58993 .20589 .59549 .208 .60698 .21775 .60142 .21528 Metetra
.672 .151 0 r
.60142 .21528 .60698 .21775 .6186 .22635 .61304 .2236 Metetra
.578 .052 0 r
.61304 .2236 .6186 .22635 .63034 .2339 .62477 .2309 Metetra
0 .057 .535 r
.62477 .2309 .63034 .2339 .64217 .24046 .63661 .23725 Metetra
0 .17 .651 r
.63661 .23725 .64217 .24046 .6541 .2461 .64854 .24271 Metetra
0 .28 .751 r
.64854 .24271 .6541 .2461 .6661 .25086 .66055 .24731 Metetra
0 .379 .83 r
.66055 .24731 .6661 .25086 .67817 .2548 .67263 .2511 Metetra
.073 .465 .887 r
.67263 .2511 .67817 .2548 .6903 .25794 .68477 .25412 Metetra
.188 .536 .925 r
.68477 .25412 .6903 .25794 .70247 .26032 .69696 .2564 Metetra
.288 .594 .947 r
.69696 .2564 .70247 .26032 .71468 .26198 .70919 .25796 Metetra
.374 .639 .958 r
.70919 .25796 .71468 .26198 .72692 .26292 .72145 .25883 Metetra
.447 .675 .961 r
.72145 .25883 .72692 .26292 .73918 .26318 .73373 .25902 Metetra
.51 .704 .958 r
.73373 .25902 .73918 .26318 .75144 .26277 .74602 .25855 Metetra
.563 .728 .952 r
.74602 .25855 .75144 .26277 .7637 .2617 .75831 .25743 Metetra
.609 .747 .943 r
.75831 .25743 .7637 .2617 .77595 .25998 .77059 .25567 Metetra
.649 .762 .932 r
.77059 .25567 .77595 .25998 .78817 .25763 .78285 .25328 Metetra
.684 .775 .92 r
.78285 .25328 .78817 .25763 .80036 .25464 .79508 .25025 Metetra
.715 .786 .907 r
.79508 .25025 .80036 .25464 .8125 .25102 .80726 .24661 Metetra
.743 .795 .894 r
.80726 .24661 .8125 .25102 .82459 .24679 .81939 .24235 Metetra
.767 .802 .881 r
.81939 .24235 .82459 .24679 .83662 .24194 .83146 .23748 Metetra
.396 .666 .968 r
.17209 .36086 .179 .36441 .18847 .36481 .18156 .36127 Metetra
.477 .702 .967 r
.18156 .36127 .18847 .36481 .19807 .36466 .19119 .3611 Metetra
.544 .728 .96 r
.19119 .3611 .19807 .36466 .20782 .36392 .20095 .36036 Metetra
.599 .747 .947 r
.20095 .36036 .20782 .36392 .21771 .3626 .21086 .35903 Metetra
.645 .76 .933 r
.21086 .35903 .21771 .3626 .22772 .36068 .22089 .35712 Metetra
.684 .77 .917 r
.22089 .35712 .22772 .36068 .23785 .35816 .23104 .35461 Metetra
.716 .777 .901 r
.23104 .35461 .23785 .35816 .24809 .35503 .2413 .3515 Metetra
.744 .783 .885 r
.2413 .3515 .24809 .35503 .25844 .35127 .25168 .34778 Metetra
.768 .787 .869 r
.25168 .34778 .25844 .35127 .26889 .34687 .26215 .34342 Metetra
.789 .791 .854 r
.26215 .34342 .26889 .34687 .27944 .34182 .27272 .33842 Metetra
.808 .794 .839 r
.27272 .33842 .27944 .34182 .29007 .33608 .28338 .33275 Metetra
.825 .797 .825 r
.28338 .33275 .29007 .33608 .30077 .32963 .29412 .3264 Metetra
.841 .799 .81 r
.29412 .3264 .30077 .32963 .31156 .32245 .30493 .31932 Metetra
.856 .802 .796 r
.30493 .31932 .31156 .32245 .3224 .3145 .31581 .31149 Metetra
.87 .804 .783 r
.31581 .31149 .3224 .3145 .33331 .30573 .32675 .30287 Metetra
.883 .806 .769 r
.32675 .30287 .33331 .30573 .34426 .29611 .33774 .29343 Metetra
.895 .808 .755 r
.33774 .29343 .34426 .29611 .35525 .28559 .34877 .28311 Metetra
.907 .811 .741 r
.34877 .28311 .35525 .28559 .36627 .27409 .35983 .27186 Metetra
.918 .814 .727 r
.35983 .27186 .36627 .27409 .37731 .26157 .37092 .25963 Metetra
.929 .817 .713 r
.37092 .25963 .37731 .26157 .38837 .24795 .38202 .24637 Metetra
.94 .82 .698 r
.38202 .24637 .38837 .24795 .39942 .23314 .39311 .232 Metetra
.951 .825 .683 r
.39311 .232 .39942 .23314 .41045 .21705 .40419 .21647 Metetra
.962 .83 .667 r
.40419 .21647 .41045 .21705 .42135 .2015 .41525 .19973 Metetra
.796 .896 .914 r
.41525 .19973 .42135 .2015 .43151 .19931 .42556 .19524 Metetra
.485 .665 .942 r
.54014 .17037 .54581 .17462 .55644 .17232 .55083 .17037 Metetra
.841 .376 .009 r
.55083 .17037 .55644 .17232 .56741 .18353 .56182 .18276 Metetra
.827 .352 .039 r
.56182 .18276 .56741 .18353 .57859 .19533 .57299 .19396 Metetra
.792 .296 0 r
.57299 .19396 .57859 .19533 .58993 .20589 .58433 .20404 Metetra
.741 .226 0 r
.58433 .20404 .58993 .20589 .60142 .21528 .59581 .21304 Metetra
.669 .14 0 r
.59581 .21304 .60142 .21528 .61304 .2236 .60743 .22103 Metetra
.575 .041 0 r
.60743 .22103 .61304 .2236 .62477 .2309 .61916 .22805 Metetra
.459 0 0 r
.61916 .22805 .62477 .2309 .63661 .23725 .63101 .23416 Metetra
0 .183 .655 r
.63101 .23416 .63661 .23725 .64854 .24271 .64294 .23941 Metetra
0 .293 .757 r
.64294 .23941 .64854 .24271 .66055 .24731 .65496 .24383 Metetra
0 .392 .836 r
.65496 .24383 .66055 .24731 .67263 .2511 .66705 .24746 Metetra
.082 .476 .893 r
.66705 .24746 .67263 .2511 .68477 .25412 .67921 .25034 Metetra
.197 .546 .929 r
.67921 .25034 .68477 .25412 .69696 .2564 .69142 .25249 Metetra
.296 .601 .95 r
.69142 .25249 .69696 .2564 .70919 .25796 .70366 .25395 Metetra
.381 .645 .96 r
.70366 .25395 .70919 .25796 .72145 .25883 .71595 .25472 Metetra
.453 .68 .962 r
.71595 .25472 .72145 .25883 .73373 .25902 .72825 .25484 Metetra
.514 .707 .959 r
.72825 .25484 .73373 .25902 .74602 .25855 .74057 .2543 Metetra
.566 .73 .952 r
.74057 .2543 .74602 .25855 .75831 .25743 .75289 .25313 Metetra
.611 .748 .942 r
.75289 .25313 .75831 .25743 .77059 .25567 .7652 .25132 Metetra
.65 .763 .932 r
.7652 .25132 .77059 .25567 .78285 .25328 .77749 .24889 Metetra
.685 .776 .92 r
.77749 .24889 .78285 .25328 .79508 .25025 .78976 .24584 Metetra
.716 .786 .907 r
.78976 .24584 .79508 .25025 .80726 .24661 .80198 .24217 Metetra
.743 .795 .894 r
.80198 .24217 .80726 .24661 .81939 .24235 .81415 .23788 Metetra
.767 .802 .881 r
.81415 .23788 .81939 .24235 .83146 .23748 .82626 .23298 Metetra
.396 .666 .968 r
.16513 .3573 .17209 .36086 .18156 .36127 .17461 .35769 Metetra
.476 .702 .967 r
.17461 .35769 .18156 .36127 .19119 .3611 .18425 .35751 Metetra
.543 .728 .96 r
.18425 .35751 .19119 .3611 .20095 .36036 .19403 .35677 Metetra
.598 .746 .947 r
.19403 .35677 .20095 .36036 .21086 .35903 .20395 .35544 Metetra
.644 .76 .933 r
.20395 .35544 .21086 .35903 .22089 .35712 .214 .35353 Metetra
.682 .77 .918 r
.214 .35353 .22089 .35712 .23104 .35461 .22418 .35104 Metetra
.714 .777 .902 r
.22418 .35104 .23104 .35461 .2413 .3515 .23446 .34795 Metetra
.742 .783 .886 r
.23446 .34795 .2413 .3515 .25168 .34778 .24486 .34427 Metetra
.766 .788 .871 r
.24486 .34427 .25168 .34778 .26215 .34342 .25536 .33996 Metetra
.787 .792 .857 r
.25536 .33996 .26215 .34342 .27272 .33842 .26596 .33503 Metetra
.806 .795 .842 r
.26596 .33503 .27272 .33842 .28338 .33275 .27664 .32944 Metetra
.823 .799 .828 r
.27664 .32944 .28338 .33275 .29412 .3264 .28741 .32319 Metetra
.84 .802 .815 r
.28741 .32319 .29412 .3264 .30493 .31932 .29825 .31623 Metetra
.855 .805 .801 r
.29825 .31623 .30493 .31932 .31581 .31149 .30916 .30855 Metetra
.869 .808 .788 r
.30916 .30855 .31581 .31149 .32675 .30287 .32013 .3001 Metetra
.882 .811 .774 r
.32013 .3001 .32675 .30287 .33774 .29343 .33115 .29085 Metetra
.895 .814 .761 r
.33115 .29085 .33774 .29343 .34877 .28311 .34222 .28076 Metetra
.907 .818 .747 r
.34222 .28076 .34877 .28311 .35983 .27186 .35332 .26979 Metetra
.919 .822 .734 r
.35332 .26979 .35983 .27186 .37092 .25963 .36444 .25789 Metetra
.931 .826 .72 r
.36444 .25789 .37092 .25963 .38202 .24637 .37558 .24502 Metetra
.942 .831 .705 r
.37558 .24502 .38202 .24637 .39311 .232 .38672 .23114 Metetra
.954 .837 .69 r
.38672 .23114 .39311 .232 .40419 .21647 .39785 .21621 Metetra
.965 .844 .674 r
.39785 .21621 .40419 .21647 .41525 .19973 .40895 .20023 Metetra
.93 .95 .779 r
.40895 .20023 .41525 .19973 .42556 .19524 .41956 .19114 Metetra
0 .27 .768 r
.53442 .1661 .54014 .17037 .55083 .17037 .54518 .1707 Metetra
.835 .376 .121 r
.54518 .1707 .55083 .17037 .56182 .18276 .55618 .1823 Metetra
.816 .335 .039 r
.55618 .1823 .56182 .18276 .57299 .19396 .56735 .19288 Metetra
.783 .28 0 r
.56735 .19288 .57299 .19396 .58433 .20404 .57868 .20243 Metetra
.733 .211 0 r
.57868 .20243 .58433 .20404 .59581 .21304 .59016 .211 Metetra
.661 .125 0 r
.59016 .211 .59581 .21304 .60743 .22103 .60178 .21862 Metetra
.567 .026 0 r
.60178 .21862 .60743 .22103 .61916 .22805 .61352 .22534 Metetra
.45 0 0 r
.61352 .22534 .61916 .22805 .63101 .23416 .62536 .23118 Metetra
0 .199 .663 r
.62536 .23118 .63101 .23416 .64294 .23941 .6373 .23619 Metetra
0 .309 .765 r
.6373 .23619 .64294 .23941 .65496 .24383 .64933 .2404 Metetra
0 .407 .844 r
.64933 .2404 .65496 .24383 .66705 .24746 .66144 .24386 Metetra
.094 .489 .899 r
.66144 .24386 .66705 .24746 .67921 .25034 .6736 .24658 Metetra
.208 .556 .934 r
.6736 .24658 .67921 .25034 .69142 .25249 .68583 .2486 Metetra
.306 .61 .953 r
.68583 .2486 .69142 .25249 .70366 .25395 .69809 .24993 Metetra
.389 .651 .962 r
.69809 .24993 .70366 .25395 .71595 .25472 .7104 .25061 Metetra
.459 .684 .963 r
.7104 .25061 .71595 .25472 .72825 .25484 .72272 .25063 Metetra
.518 .71 .959 r
.72272 .25063 .72825 .25484 .74057 .2543 .73507 .25002 Metetra
.569 .731 .951 r
.73507 .25002 .74057 .2543 .75289 .25313 .74742 .24879 Metetra
.613 .749 .942 r
.74742 .24879 .75289 .25313 .7652 .25132 .75976 .24694 Metetra
.652 .763 .931 r
.75976 .24694 .7652 .25132 .77749 .24889 .77209 .24447 Metetra
.686 .776 .919 r
.77209 .24447 .77749 .24889 .78976 .24584 .78439 .24138 Metetra
.716 .786 .907 r
.78439 .24138 .78976 .24584 .80198 .24217 .79665 .23768 Metetra
.743 .795 .894 r
.79665 .23768 .80198 .24217 .81415 .23788 .80887 .23337 Metetra
.767 .802 .881 r
.80887 .23337 .81415 .23788 .82626 .23298 .82102 .22845 Metetra
.396 .666 .968 r
.15811 .35371 .16513 .3573 .17461 .35769 .16761 .35409 Metetra
.477 .702 .967 r
.16761 .35409 .17461 .35769 .18425 .35751 .17727 .3539 Metetra
.543 .727 .96 r
.17727 .3539 .18425 .35751 .19403 .35677 .18707 .35315 Metetra
.598 .746 .947 r
.18707 .35315 .19403 .35677 .20395 .35544 .197 .35182 Metetra
.643 .759 .933 r
.197 .35182 .20395 .35544 .214 .35353 .20707 .34992 Metetra
.68 .769 .918 r
.20707 .34992 .214 .35353 .22418 .35104 .21727 .34744 Metetra
.712 .777 .903 r
.21727 .34744 .22418 .35104 .23446 .34795 .22758 .34438 Metetra
.739 .783 .888 r
.22758 .34438 .23446 .34795 .24486 .34427 .238 .34074 Metetra
.763 .788 .874 r
.238 .34074 .24486 .34427 .25536 .33996 .24852 .33649 Metetra
.784 .793 .859 r
.24852 .33649 .25536 .33996 .26596 .33503 .25914 .33163 Metetra
.803 .797 .846 r
.25914 .33163 .26596 .33503 .27664 .32944 .26985 .32614 Metetra
.821 .801 .832 r
.26985 .32614 .27664 .32944 .28741 .32319 .28064 .32 Metetra
.838 .805 .819 r
.28064 .32 .28741 .32319 .29825 .31623 .29151 .31318 Metetra
.853 .808 .806 r
.29151 .31318 .29825 .31623 .30916 .30855 .30244 .30566 Metetra
.867 .812 .793 r
.30244 .30566 .30916 .30855 .32013 .3001 .31344 .2974 Metetra
.881 .816 .78 r
.31344 .2974 .32013 .3001 .33115 .29085 .3245 .28837 Metetra
.895 .821 .767 r
.3245 .28837 .33115 .29085 .34222 .28076 .3356 .27854 Metetra
.907 .825 .754 r
.3356 .27854 .34222 .28076 .35332 .26979 .34673 .26787 Metetra
.92 .83 .741 r
.34673 .26787 .35332 .26979 .36444 .25789 .35789 .25633 Metetra
.932 .835 .727 r
.35789 .25633 .36444 .25789 .37558 .24502 .36907 .24389 Metetra
.943 .842 .713 r
.36907 .24389 .37558 .24502 .38672 .23114 .38025 .23053 Metetra
.955 .849 .698 r
.38025 .23053 .38672 .23114 .39785 .21621 .39142 .21624 Metetra
.966 .859 .683 r
.39142 .21624 .39785 .21621 .40895 .20023 .40255 .20104 Metetra
.971 .891 .689 r
.40255 .20104 .40895 .20023 .41956 .19114 .41353 .18701 Metetra
.652 .186 0 r
.52867 .16179 .53442 .1661 .54518 .1707 .53947 .17135 Metetra
.82 .356 .115 r
.53947 .17135 .54518 .1707 .55618 .1823 .55047 .18213 Metetra
.803 .316 .034 r
.55047 .18213 .55618 .1823 .56735 .19288 .56164 .19203 Metetra
.771 .261 0 r
.56164 .19203 .56735 .19288 .57868 .20243 .57298 .20104 Metetra
.721 .192 0 r
.57298 .20104 .57868 .20243 .59016 .211 .58446 .20915 Metetra
.65 .106 0 r
.58446 .20915 .59016 .211 .60178 .21862 .59608 .21637 Metetra
.555 .006 0 r
.59608 .21637 .60178 .21862 .61352 .22534 .60782 .22274 Metetra
.436 0 0 r
.60782 .22274 .61352 .22534 .62536 .23118 .61967 .22829 Metetra
0 .22 .675 r
.61967 .22829 .62536 .23118 .6373 .23619 .63162 .23304 Metetra
0 .328 .776 r
.63162 .23304 .6373 .23619 .64933 .2404 .64366 .23703 Metetra
0 .424 .853 r
.64366 .23703 .64933 .2404 .66144 .24386 .65577 .24029 Metetra
.11 .504 .906 r
.65577 .24029 .66144 .24386 .6736 .24658 .66795 .24284 Metetra
.222 .568 .939 r
.66795 .24284 .6736 .24658 .68583 .2486 .68019 .2447 Metetra
.317 .619 .957 r
.68019 .2447 .68583 .2486 .69809 .24993 .69248 .24591 Metetra
.398 .658 .963 r
.69248 .24591 .69809 .24993 .7104 .25061 .7048 .24647 Metetra
.466 .689 .963 r
.7048 .24647 .7104 .25061 .72272 .25063 .71715 .2464 Metetra
.523 .713 .959 r
.71715 .2464 .72272 .25063 .73507 .25002 .72952 .24572 Metetra
.573 .733 .951 r
.72952 .24572 .73507 .25002 .74742 .24879 .7419 .24442 Metetra
.615 .75 .941 r
.7419 .24442 .74742 .24879 .75976 .24694 .75428 .24251 Metetra
.653 .764 .931 r
.75428 .24251 .75976 .24694 .77209 .24447 .76664 .24 Metetra
.686 .776 .919 r
.76664 .24 .77209 .24447 .78439 .24138 .77898 .23688 Metetra
.716 .786 .907 r
.77898 .23688 .78439 .24138 .79665 .23768 .79129 .23316 Metetra
.743 .795 .894 r
.79129 .23316 .79665 .23768 .80887 .23337 .80354 .22883 Metetra
.767 .802 .881 r
.80354 .22883 .80887 .23337 .82102 .22845 .81574 .22388 Metetra
.396 .666 .968 r
.15105 .35009 .15811 .35371 .16761 .35409 .16056 .35046 Metetra
.477 .702 .967 r
.16056 .35046 .16761 .35409 .17727 .3539 .17023 .35026 Metetra
.543 .727 .959 r
.17023 .35026 .17727 .3539 .18707 .35315 .18005 .34949 Metetra
.597 .745 .947 r
.18005 .34949 .18707 .35315 .197 .35182 .19001 .34816 Metetra
.641 .758 .934 r
.19001 .34816 .197 .35182 .20707 .34992 .20009 .34627 Metetra
.678 .768 .919 r
.20009 .34627 .20707 .34992 .21727 .34744 .21031 .34381 Metetra
.709 .776 .904 r
.21031 .34381 .21727 .34744 .22758 .34438 .22064 .34078 Metetra
.736 .782 .89 r
.22064 .34078 .22758 .34438 .238 .34074 .23108 .33719 Metetra
.76 .788 .876 r
.23108 .33719 .238 .34074 .24852 .33649 .24162 .33301 Metetra
.781 .793 .862 r
.24162 .33301 .24852 .33649 .25914 .33163 .25226 .32823 Metetra
.8 .798 .849 r
.25226 .32823 .25914 .33163 .26985 .32614 .26299 .32285 Metetra
.818 .802 .836 r
.26299 .32285 .26985 .32614 .28064 .32 .27381 .31683 Metetra
.835 .807 .824 r
.27381 .31683 .28064 .32 .29151 .31318 .2847 .31016 Metetra
.851 .812 .811 r
.2847 .31016 .29151 .31318 .30244 .30566 .29566 .30282 Metetra
.865 .816 .799 r
.29566 .30282 .30244 .30566 .31344 .2974 .30669 .29476 Metetra
.88 .821 .787 r
.30669 .29476 .31344 .2974 .3245 .28837 .31777 .28598 Metetra
.893 .827 .774 r
.31777 .28598 .3245 .28837 .3356 .27854 .3289 .27643 Metetra
.907 .832 .761 r
.3289 .27643 .3356 .27854 .34673 .26787 .34007 .26609 Metetra
.919 .838 .748 r
.34007 .26609 .34673 .26787 .35789 .25633 .35127 .25494 Metetra
.932 .845 .735 r
.35127 .25494 .35789 .25633 .36907 .24389 .36248 .24295 Metetra
.944 .853 .722 r
.36248 .24295 .36907 .24389 .38025 .23053 .37369 .23013 Metetra
.955 .862 .707 r
.37369 .23013 .38025 .23053 .39142 .21624 .38489 .21649 Metetra
.966 .873 .692 r
.38489 .21649 .39142 .21624 .40255 .20104 .39607 .20209 Metetra
.976 .887 .675 r
.39607 .20209 .40255 .20104 .41353 .18701 .40719 .18705 Metetra
.864 .975 .857 r
.40719 .18705 .41353 .18701 .42379 .18476 .41774 .18058 Metetra
.256 .54 .923 r
.51218 .15981 .518 .16413 .52867 .16179 .52287 .16169 Metetra
.821 .347 .075 r
.52287 .16169 .52867 .16179 .53947 .17135 .53369 .17224 Metetra
.803 .332 .106 r
.53369 .17224 .53947 .17135 .55047 .18213 .5447 .18219 Metetra
.787 .293 .024 r
.5447 .18219 .55047 .18213 .56164 .19203 .55588 .1914 Metetra
.755 .239 0 r
.55588 .1914 .56164 .19203 .57298 .20104 .56722 .19983 Metetra
.706 .169 0 r
.56722 .19983 .57298 .20104 .58446 .20915 .57871 .20745 Metetra
.634 .083 0 r
.57871 .20745 .58446 .20915 .59608 .21637 .59033 .21425 Metetra
.537 0 0 r
.59033 .21425 .59608 .21637 .60782 .22274 .60208 .22026 Metetra
.417 0 0 r
.60208 .22026 .60782 .22274 .61967 .22829 .61394 .22549 Metetra
0 .244 .69 r
.61394 .22549 .61967 .22829 .63162 .23304 .62589 .22996 Metetra
0 .351 .79 r
.62589 .22996 .63162 .23304 .64366 .23703 .63794 .2337 Metetra
.003 .444 .864 r
.63794 .2337 .64366 .23703 .65577 .24029 .65007 .23675 Metetra
.129 .521 .914 r
.65007 .23675 .65577 .24029 .66795 .24284 .66226 .23911 Metetra
.238 .581 .944 r
.66226 .23911 .66795 .24284 .68019 .2447 .67452 .24081 Metetra
.33 .628 .96 r
.67452 .24081 .68019 .2447 .69248 .24591 .68682 .24187 Metetra
.408 .665 .965 r
.68682 .24187 .69248 .24591 .7048 .24647 .69916 .24231 Metetra
.473 .693 .964 r
.69916 .24231 .7048 .24647 .71715 .2464 .71154 .24214 Metetra
.529 .716 .958 r
.71154 .24214 .71715 .2464 .72952 .24572 .72394 .24137 Metetra
.576 .735 .95 r
.72394 .24137 .72952 .24572 .7419 .24442 .73634 .24 Metetra
.618 .75 .941 r
.73634 .24 .7419 .24442 .75428 .24251 .74875 .23805 Metetra
.654 .764 .93 r
.74875 .23805 .75428 .24251 .76664 .24 .76115 .23549 Metetra
.687 .775 .919 r
.76115 .23549 .76664 .24 .77898 .23688 .77353 .23235 Metetra
.716 .786 .907 r
.77353 .23235 .77898 .23688 .79129 .23316 .78587 .2286 Metetra
.743 .794 .894 r
.78587 .2286 .79129 .23316 .80354 .22883 .79817 .22424 Metetra
.767 .802 .881 r
.79817 .22424 .80354 .22883 .81574 .22388 .81042 .21928 Metetra
.398 .667 .968 r
.14394 .34646 .15105 .35009 .16056 .35046 .15346 .34681 Metetra
.478 .702 .967 r
.15346 .34681 .16056 .35046 .17023 .35026 .16315 .34659 Metetra
.543 .727 .959 r
.16315 .34659 .17023 .35026 .18005 .34949 .17298 .34581 Metetra
.596 .745 .947 r
.17298 .34581 .18005 .34949 .19001 .34816 .18296 .34447 Metetra
.64 .757 .934 r
.18296 .34447 .19001 .34816 .20009 .34627 .19307 .34258 Metetra
.676 .767 .92 r
.19307 .34258 .20009 .34627 .21031 .34381 .2033 .34014 Metetra
.707 .775 .905 r
.2033 .34014 .21031 .34381 .22064 .34078 .21365 .33715 Metetra
.733 .782 .892 r
.21365 .33715 .22064 .34078 .23108 .33719 .22411 .33361 Metetra
.756 .788 .878 r
.22411 .33361 .23108 .33719 .24162 .33301 .23467 .3295 Metetra
.778 .793 .866 r
.23467 .3295 .24162 .33301 .25226 .32823 .24533 .32481 Metetra
.797 .798 .853 r
.24533 .32481 .25226 .32823 .26299 .32285 .25609 .31954 Metetra
.815 .804 .841 r
.25609 .31954 .26299 .32285 .27381 .31683 .26692 .31367 Metetra
.832 .809 .829 r
.26692 .31367 .27381 .31683 .2847 .31016 .27784 .30716 Metetra
.848 .815 .817 r
.27784 .30716 .2847 .31016 .29566 .30282 .28882 .30001 Metetra
.863 .82 .805 r
.28882 .30001 .29566 .30282 .30669 .29476 .29987 .29219 Metetra
.877 .826 .793 r
.29987 .29219 .30669 .29476 .31777 .28598 .31098 .28366 Metetra
.892 .833 .781 r
.31098 .28366 .31777 .28598 .3289 .27643 .32214 .27442 Metetra
.905 .839 .769 r
.32214 .27442 .3289 .27643 .34007 .26609 .33333 .26443 Metetra
.918 .847 .757 r
.33333 .26443 .34007 .26609 .35127 .25494 .34456 .25368 Metetra
.931 .855 .744 r
.34456 .25368 .35127 .25494 .36248 .24295 .3558 .24217 Metetra
.943 .864 .731 r
.3558 .24217 .36248 .24295 .37369 .23013 .36705 .22991 Metetra
.955 .875 .718 r
.36705 .22991 .37369 .23013 .38489 .21649 .37828 .21694 Metetra
.965 .887 .703 r
.37828 .21694 .38489 .21649 .39607 .20209 .38949 .20334 Metetra
.973 .903 .686 r
.38949 .20334 .39607 .20209 .40719 .18705 .40064 .18926 Metetra
.964 .94 .682 r
.40064 .18926 .40719 .18705 .41774 .18058 .41164 .17638 Metetra
.576 .106 0 r
.50632 .15545 .51218 .15981 .52287 .16169 .517 .16377 Metetra
.788 .332 .159 r
.517 .16377 .52287 .16169 .53369 .17224 .52784 .17333 Metetra
.785 .306 .091 r
.52784 .17333 .53369 .17224 .5447 .18219 .53886 .18244 Metetra
.769 .267 .011 r
.53886 .18244 .5447 .18219 .55588 .1914 .55006 .19095 Metetra
.737 .213 0 r
.55006 .19095 .55588 .1914 .56722 .19983 .5614 .19878 Metetra
.687 .142 0 r
.5614 .19878 .56722 .19983 .57871 .20745 .5729 .20589 Metetra
.613 .055 0 r
.5729 .20589 .57871 .20745 .59033 .21425 .58453 .21225 Metetra
.515 0 0 r
.58453 .21225 .59033 .21425 .60208 .22026 .59628 .21787 Metetra
0 .16 .588 r
.59628 .21787 .60208 .22026 .61394 .22549 .60815 .22276 Metetra
0 .272 .708 r
.60815 .22276 .61394 .22549 .62589 .22996 .62012 .22693 Metetra
0 .377 .806 r
.62012 .22693 .62589 .22996 .63794 .2337 .63217 .23041 Metetra
.027 .467 .877 r
.63217 .23041 .63794 .2337 .65007 .23675 .64431 .23322 Metetra
.151 .539 .923 r
.64431 .23322 .65007 .23675 .66226 .23911 .65652 .23538 Metetra
.256 .595 .95 r
.65652 .23538 .66226 .23911 .67452 .24081 .66879 .2369 Metetra
.345 .638 .963 r
.66879 .2369 .67452 .24081 .68682 .24187 .68111 .23781 Metetra
.42 .672 .966 r
.68111 .23781 .68682 .24187 .69916 .24231 .69348 .23812 Metetra
.482 .698 .964 r
.69348 .23812 .69916 .24231 .71154 .24214 .70588 .23784 Metetra
.535 .719 .958 r
.70588 .23784 .71154 .24214 .72394 .24137 .7183 .23698 Metetra
.58 .736 .949 r
.7183 .23698 .72394 .24137 .73634 .24 .73074 .23555 Metetra
.62 .751 .94 r
.73074 .23555 .73634 .24 .74875 .23805 .74318 .23353 Metetra
.656 .764 .929 r
.74318 .23353 .74875 .23805 .76115 .23549 .75562 .23094 Metetra
.687 .775 .918 r
.75562 .23094 .76115 .23549 .77353 .23235 .76803 .22776 Metetra
.716 .785 .906 r
.76803 .22776 .77353 .23235 .78587 .2286 .78042 .22399 Metetra
.743 .794 .894 r
.78042 .22399 .78587 .2286 .79817 .22424 .79276 .21962 Metetra
.767 .802 .881 r
.79276 .21962 .79817 .22424 .81042 .21928 .80505 .21464 Metetra
.399 .668 .969 r
.13677 .3428 .14394 .34646 .15346 .34681 .14631 .34312 Metetra
.479 .702 .967 r
.14631 .34312 .15346 .34681 .16315 .34659 .15602 .34288 Metetra
.544 .727 .959 r
.15602 .34288 .16315 .34659 .17298 .34581 .16587 .34209 Metetra
.596 .744 .947 r
.16587 .34209 .17298 .34581 .18296 .34447 .17586 .34074 Metetra
.638 .756 .934 r
.17586 .34074 .18296 .34447 .19307 .34258 .18599 .33886 Metetra
.674 .766 .92 r
.18599 .33886 .19307 .34258 .2033 .34014 .19624 .33644 Metetra
.704 .774 .906 r
.19624 .33644 .2033 .34014 .21365 .33715 .20661 .33348 Metetra
.73 .781 .893 r
.20661 .33348 .21365 .33715 .22411 .33361 .21709 .32999 Metetra
.753 .787 .881 r
.21709 .32999 .22411 .33361 .23467 .3295 .22767 .32596 Metetra
.774 .793 .869 r
.22767 .32596 .23467 .3295 .24533 .32481 .23835 .32138 Metetra
.793 .799 .857 r
.23835 .32138 .24533 .32481 .25609 .31954 .24912 .31623 Metetra
.811 .805 .846 r
.24912 .31623 .25609 .31954 .26692 .31367 .25998 .31051 Metetra
.828 .811 .834 r
.25998 .31051 .26692 .31367 .27784 .30716 .27091 .30418 Metetra
.844 .817 .823 r
.27091 .30418 .27784 .30716 .28882 .30001 .28192 .29724 Metetra
.859 .824 .812 r
.28192 .29724 .28882 .30001 .29987 .29219 .29299 .28965 Metetra
.874 .831 .801 r
.29299 .28965 .29987 .29219 .31098 .28366 .30412 .28141 Metetra
.889 .838 .79 r
.30412 .28141 .31098 .28366 .32214 .27442 .3153 .27248 Metetra
.903 .846 .778 r
.3153 .27248 .32214 .27442 .33333 .26443 .32652 .26286 Metetra
.916 .855 .766 r
.32652 .26286 .33333 .26443 .34456 .25368 .33777 .25254 Metetra
.929 .864 .754 r
.33777 .25254 .34456 .25368 .3558 .24217 .34904 .24152 Metetra
.942 .875 .742 r
.34904 .24152 .3558 .24217 .36705 .22991 .36031 .22983 Metetra
.953 .887 .729 r
.36031 .22983 .36705 .22991 .37828 .21694 .37158 .21753 Metetra
.962 .902 .715 r
.37158 .21753 .37828 .21694 .38949 .20334 .38281 .20473 Metetra
.968 .919 .699 r
.38281 .20473 .38949 .20334 .40064 .18926 .394 .19158 Metetra
.965 .938 .677 r
.394 .19158 .40064 .18926 .41164 .17638 .40511 .17838 Metetra
.877 .991 .745 r
.40511 .17838 .41164 .17638 .422 .17409 .41589 .16984 Metetra
0 .337 .815 r
.4897 .15345 .49563 .15782 .50632 .15545 .50033 .15735 Metetra
.772 .305 .133 r
.50033 .15735 .50632 .15545 .517 .16377 .51104 .16596 Metetra
.767 .301 .14 r
.51104 .16596 .517 .16377 .52784 .17333 .52191 .17455 Metetra
.764 .276 .073 r
.52191 .17455 .52784 .17333 .53886 .18244 .53296 .18284 Metetra
.748 .237 0 r
.53296 .18284 .53886 .18244 .55006 .19095 .54416 .19064 Metetra
.716 .182 0 r
.54416 .19064 .55006 .19095 .5614 .19878 .55553 .19786 Metetra
.664 .111 0 r
.55553 .19786 .5614 .19878 .5729 .20589 .56703 .20444 Metetra
.588 .022 0 r
.56703 .20444 .5729 .20589 .58453 .21225 .57867 .21034 Metetra
.487 0 0 r
.57867 .21034 .58453 .21225 .59628 .21787 .59044 .21555 Metetra
0 .194 .613 r
.59044 .21555 .59628 .21787 .60815 .22276 .60231 .22008 Metetra
0 .305 .731 r
.60231 .22008 .60815 .22276 .62012 .22693 .61429 .22394 Metetra
0 .406 .824 r
.61429 .22394 .62012 .22693 .63217 .23041 .62636 .22714 Metetra
.056 .491 .89 r
.62636 .22714 .63217 .23041 .64431 .23322 .63851 .2297 Metetra
.175 .558 .932 r
.63851 .2297 .64431 .23322 .65652 .23538 .65073 .23164 Metetra
.277 .609 .955 r
.65073 .23164 .65652 .23538 .66879 .2369 .66302 .23298 Metetra
.362 .649 .965 r
.66302 .23298 .66879 .2369 .68111 .23781 .67536 .23372 Metetra
.432 .679 .967 r
.67536 .23372 .68111 .23781 .69348 .23812 .68775 .23389 Metetra
.491 .702 .963 r
.68775 .23389 .69348 .23812 .70588 .23784 .70017 .2335 Metetra
.541 .721 .957 r
.70017 .2335 .70588 .23784 .7183 .23698 .71262 .23255 Metetra
.585 .737 .948 r
.71262 .23255 .7183 .23698 .73074 .23555 .72509 .23104 Metetra
.623 .751 .939 r
.72509 .23104 .73074 .23555 .74318 .23353 .73756 .22897 Metetra
.657 .763 .928 r
.73756 .22897 .74318 .23353 .75562 .23094 .75003 .22634 Metetra
.688 .774 .917 r
.75003 .22634 .75562 .23094 .76803 .22776 .76249 .22313 Metetra
.716 .785 .906 r
.76249 .22313 .76803 .22776 .78042 .22399 .77492 .21935 Metetra
.742 .794 .894 r
.77492 .21935 .78042 .22399 .79276 .21962 .7873 .21496 Metetra
.766 .802 .881 r
.7873 .21496 .79276 .21962 .80505 .21464 .79964 .20998 Metetra
.402 .67 .969 r
.12955 .33911 .13677 .3428 .14631 .34312 .13911 .33941 Metetra
.482 .703 .967 r
.13911 .33941 .14631 .34312 .15602 .34288 .14883 .33914 Metetra
.545 .727 .958 r
.14883 .33914 .15602 .34288 .16587 .34209 .1587 .33832 Metetra
.596 .743 .947 r
.1587 .33832 .16587 .34209 .17586 .34074 .16872 .33697 Metetra
.637 .755 .934 r
.16872 .33697 .17586 .34074 .18599 .33886 .17886 .33509 Metetra
.672 .765 .92 r
.17886 .33509 .18599 .33886 .19624 .33644 .18913 .33268 Metetra
.701 .772 .907 r
.18913 .33268 .19624 .33644 .20661 .33348 .19952 .32977 Metetra
.726 .779 .895 r
.19952 .32977 .20661 .33348 .21709 .32999 .21002 .32634 Metetra
.749 .786 .883 r
.21002 .32634 .21709 .32999 .22767 .32596 .22062 .32239 Metetra
.769 .792 .872 r
.22062 .32239 .22767 .32596 .23835 .32138 .23131 .31791 Metetra
.788 .799 .861 r
.23131 .31791 .23835 .32138 .24912 .31623 .2421 .3129 Metetra
.806 .806 .851 r
.2421 .3129 .24912 .31623 .25998 .31051 .25297 .30733 Metetra
.823 .813 .84 r
.25297 .30733 .25998 .31051 .27091 .30418 .26393 .3012 Metetra
.84 .82 .83 r
.26393 .3012 .27091 .30418 .28192 .29724 .27495 .29448 Metetra
.855 .828 .819 r
.27495 .29448 .28192 .29724 .29299 .28965 .28604 .28715 Metetra
.871 .836 .809 r
.28604 .28715 .29299 .28965 .30412 .28141 .29719 .2792 Metetra
.886 .844 .798 r
.29719 .2792 .30412 .28141 .3153 .27248 .30839 .27061 Metetra
.9 .853 .787 r
.30839 .27061 .3153 .27248 .32652 .26286 .31963 .26137 Metetra
.914 .863 .776 r
.31963 .26137 .32652 .26286 .33777 .25254 .3309 .25149 Metetra
.927 .874 .765 r
.3309 .25149 .33777 .25254 .34904 .24152 .3422 .24098 Metetra
.939 .886 .753 r
.3422 .24098 .34904 .24152 .36031 .22983 .35349 .22987 Metetra
.95 .9 .741 r
.35349 .22987 .36031 .22983 .37158 .21753 .36478 .21824 Metetra
.958 .916 .728 r
.36478 .21824 .37158 .21753 .38281 .20473 .37605 .20621 Metetra
.961 .934 .712 r
.37605 .20621 .38281 .20473 .394 .19158 .38726 .19396 Metetra
.953 .953 .69 r
.38726 .19396 .394 .19158 .40511 .17838 .3984 .18178 Metetra
.915 .964 .651 r
.3984 .18178 .40511 .17838 .41589 .16984 .40945 .1701 Metetra
.87 .981 .842 r
.40945 .1701 .41589 .16984 .42631 .16753 .42017 .16323 Metetra
.202 .51 .911 r
.47303 .15144 .47903 .15582 .4897 .15345 .48362 .15362 Metetra
.734 .216 0 r
.48362 .15362 .4897 .15345 .50033 .15735 .49423 .16065 Metetra
.734 .278 .169 r
.49423 .16065 .50033 .15735 .51104 .16596 .50499 .16821 Metetra
.743 .268 .116 r
.50499 .16821 .51104 .16596 .52191 .17455 .5159 .17587 Metetra
.74 .243 .05 r
.5159 .17587 .52191 .17455 .53296 .18284 .52698 .18335 Metetra
.724 .204 0 r
.52698 .18335 .53296 .18284 .54416 .19064 .5382 .19045 Metetra
.69 .148 0 r
.5382 .19045 .54416 .19064 .55553 .19786 .54958 .19706 Metetra
.636 .075 0 r
.54958 .19706 .55553 .19786 .56703 .20444 .56111 .20309 Metetra
.558 0 0 r
.56111 .20309 .56703 .20444 .57867 .21034 .57276 .20851 Metetra
.453 0 0 r
.57276 .20851 .57867 .21034 .59044 .21555 .58454 .2133 Metetra
0 .232 .641 r
.58454 .2133 .59044 .21555 .60231 .22008 .59642 .21746 Metetra
0 .341 .756 r
.59642 .21746 .60231 .22008 .61429 .22394 .60841 .22098 Metetra
0 .437 .844 r
.60841 .22098 .61429 .22394 .62636 .22714 .62049 .22388 Metetra
.089 .516 .905 r
.62049 .22388 .62636 .22714 .63851 .2297 .63266 .22618 Metetra
.203 .578 .941 r
.63266 .22618 .63851 .2297 .65073 .23164 .6449 .22789 Metetra
.299 .624 .96 r
.6449 .22789 .65073 .23164 .66302 .23298 .6572 .22902 Metetra
.379 .659 .968 r
.6572 .22902 .66302 .23298 .67536 .23372 .66956 .2296 Metetra
.445 .686 .967 r
.66956 .2296 .67536 .23372 .68775 .23389 .68197 .22962 Metetra
.501 .707 .963 r
.68197 .22962 .68775 .23389 .70017 .2335 .69442 .22911 Metetra
.548 .724 .956 r
.69442 .22911 .70017 .2335 .71262 .23255 .70689 .22806 Metetra
.589 .738 .947 r
.70689 .22806 .71262 .23255 .72509 .23104 .71939 .22647 Metetra
.625 .751 .937 r
.71939 .22647 .72509 .23104 .73756 .22897 .7319 .22435 Metetra
.658 .763 .927 r
.7319 .22435 .73756 .22897 .75003 .22634 .7444 .22168 Metetra
.688 .774 .917 r
.7444 .22168 .75003 .22634 .76249 .22313 .7569 .21845 Metetra
.715 .784 .906 r
.7569 .21845 .76249 .22313 .77492 .21935 .76937 .21465 Metetra
.741 .793 .894 r
.76937 .21465 .77492 .21935 .7873 .21496 .7818 .21026 Metetra
.765 .801 .882 r
.7818 .21026 .7873 .21496 .79964 .20998 .79419 .20527 Metetra
.406 .672 .969 r
.12228 .33541 .12955 .33911 .13911 .33941 .13186 .33567 Metetra
.485 .704 .966 r
.13186 .33567 .13911 .33941 .14883 .33914 .1416 .33536 Metetra
.547 .727 .958 r
.1416 .33536 .14883 .33914 .1587 .33832 .15149 .33452 Metetra
.596 .742 .946 r
.15149 .33452 .1587 .33832 .16872 .33697 .16152 .33315 Metetra
.636 .754 .933 r
.16152 .33315 .16872 .33697 .17886 .33509 .17169 .33127 Metetra
.669 .763 .92 r
.17169 .33127 .17886 .33509 .18913 .33268 .18198 .32888 Metetra
.698 .771 .908 r
.18198 .32888 .18913 .33268 .19952 .32977 .19238 .326 Metetra
.722 .778 .897 r
.19238 .326 .19952 .32977 .21002 .32634 .2029 .32264 Metetra
.744 .784 .886 r
.2029 .32264 .21002 .32634 .22062 .32239 .21351 .31877 Metetra
.764 .791 .875 r
.21351 .31877 .22062 .32239 .23131 .31791 .22422 .31441 Metetra
.783 .798 .865 r
.22422 .31441 .23131 .31791 .2421 .3129 .23503 .30954 Metetra
.801 .806 .856 r
.23503 .30954 .2421 .3129 .25297 .30733 .24591 .30415 Metetra
.818 .814 .846 r
.24591 .30415 .25297 .30733 .26393 .3012 .25688 .29821 Metetra
.834 .822 .837 r
.25688 .29821 .26393 .3012 .27495 .29448 .26792 .29173 Metetra
.85 .831 .827 r
.26792 .29173 .27495 .29448 .28604 .28715 .27902 .28467 Metetra
.866 .84 .817 r
.27902 .28467 .28604 .28715 .29719 .2792 .29019 .27703 Metetra
.881 .849 .808 r
.29019 .27703 .29719 .2792 .30839 .27061 .3014 .26879 Metetra
.896 .86 .798 r
.3014 .26879 .30839 .27061 .31963 .26137 .31266 .25995 Metetra
.91 .871 .787 r
.31266 .25995 .31963 .26137 .3309 .25149 .32396 .25052 Metetra
.923 .883 .777 r
.32396 .25052 .3309 .25149 .3422 .24098 .33527 .24052 Metetra
.935 .897 .766 r
.33527 .24052 .3422 .24098 .35349 .22987 .34659 .22999 Metetra
.945 .912 .754 r
.34659 .22999 .35349 .22987 .36478 .21824 .3579 .21903 Metetra
.952 .929 .741 r
.3579 .21903 .36478 .21824 .37605 .20621 .36919 .20775 Metetra
.952 .948 .726 r
.36919 .20775 .37605 .20621 .38726 .19396 .38043 .19635 Metetra
.937 .966 .703 r
.38043 .19635 .38726 .19396 .3984 .18178 .3916 .18512 Metetra
.888 .972 .662 r
.3916 .18512 .3984 .18178 .40945 .1701 .40268 .17446 Metetra
.754 .928 .573 r
.40268 .17446 .40945 .1701 .42017 .16323 .41365 .16491 Metetra
.852 .996 .769 r
.41365 .16491 .42017 .16323 .43066 .16089 .42448 .15715 Metetra
.701 .784 .915 r
.42448 .15715 .43066 .16089 .44119 .15854 .43507 .15418 Metetra
.625 .727 .92 r
.44566 .1518 .45176 .15618 .46237 .15381 .45628 .15002 Metetra
0 .408 .851 r
.45628 .15002 .46237 .15381 .47303 .15144 .4668 .15305 Metetra
.652 .131 0 r
.4668 .15305 .47303 .15144 .48362 .15362 .47737 .15789 Metetra
.683 .233 .176 r
.47737 .15789 .48362 .15362 .49423 .16065 .48805 .16388 Metetra
.707 .24 .139 r
.48805 .16388 .49423 .16065 .50499 .16821 .49886 .17046 Metetra
.717 .231 .088 r
.49886 .17046 .50499 .16821 .5159 .17587 .50981 .17724 Metetra
.714 .206 .022 r
.50981 .17724 .5159 .17587 .52698 .18335 .52092 .18394 Metetra
.696 .166 0 r
.52092 .18394 .52698 .18335 .5382 .19045 .53217 .19034 Metetra
.661 .108 0 r
.53217 .19034 .5382 .19045 .54958 .19706 .54358 .19633 Metetra
.604 .033 0 r
.54358 .19633 .54958 .19706 .56111 .20309 .55512 .20181 Metetra
.522 0 0 r
.55512 .20181 .56111 .20309 .57276 .20851 .56679 .20674 Metetra
.413 0 0 r
.56679 .20674 .57276 .20851 .58454 .2133 .57858 .2111 Metetra
0 .275 .674 r
.57858 .2111 .58454 .2133 .59642 .21746 .59048 .21486 Metetra
0 .38 .783 r
.59048 .21486 .59642 .21746 .60841 .22098 .60248 .21804 Metetra
0 .471 .865 r
.60248 .21804 .60841 .22098 .62049 .22388 .61458 .22063 Metetra
.124 .543 .919 r
.61458 .22063 .62049 .22388 .63266 .22618 .62676 .22265 Metetra
.233 .598 .95 r
.62676 .22265 .63266 .22618 .6449 .22789 .63901 .22412 Metetra
.323 .639 .965 r
.63901 .22412 .6449 .22789 .6572 .22902 .65133 .22504 Metetra
.398 .669 .969 r
.65133 .22504 .6572 .22902 .66956 .2296 .66371 .22543 Metetra
.459 .693 .967 r
.66371 .22543 .66956 .2296 .68197 .22962 .67614 .2253 Metetra
.511 .711 .962 r
.67614 .2253 .68197 .22962 .69442 .22911 .68861 .22466 Metetra
.555 .726 .954 r
.68861 .22466 .69442 .22911 .70689 .22806 .70111 .22351 Metetra
.593 .739 .945 r
.70111 .22351 .70689 .22806 .71939 .22647 .71364 .22185 Metetra
.628 .751 .936 r
.71364 .22185 .71939 .22647 .7319 .22435 .72618 .21967 Metetra
.659 .762 .926 r
.72618 .21967 .7319 .22435 .7444 .22168 .73873 .21696 Metetra
.687 .773 .916 r
.73873 .21696 .7444 .22168 .7569 .21845 .75126 .21372 Metetra
.714 .783 .906 r
.75126 .21372 .7569 .21845 .76937 .21465 .76378 .20991 Metetra
.74 .792 .894 r
.76378 .20991 .76937 .21465 .7818 .21026 .77626 .20552 Metetra
.764 .801 .882 r
.77626 .20552 .7818 .21026 .79419 .20527 .78869 .20053 Metetra
.411 .675 .969 r
.11496 .33168 .12228 .33541 .13186 .33567 .12455 .33189 Metetra
.489 .706 .966 r
.12455 .33189 .13186 .33567 .1416 .33536 .13431 .33155 Metetra
.549 .727 .957 r
.13431 .33155 .1416 .33536 .15149 .33452 .14423 .33067 Metetra
.597 .742 .945 r
.14423 .33067 .15149 .33452 .16152 .33315 .15428 .32928 Metetra
.636 .753 .933 r
.15428 .32928 .16152 .33315 .17169 .33127 .16446 .32739 Metetra
.667 .761 .92 r
.16446 .32739 .17169 .33127 .18198 .32888 .17477 .32502 Metetra
.694 .769 .909 r
.17477 .32502 .18198 .32888 .19238 .326 .1852 .32219 Metetra
.718 .776 .898 r
.1852 .32219 .19238 .326 .2029 .32264 .19573 .31888 Metetra
.739 .783 .888 r
.19573 .31888 .2029 .32264 .21351 .31877 .20636 .31511 Metetra
.759 .79 .878 r
.20636 .31511 .21351 .31877 .22422 .31441 .21708 .31087 Metetra
.777 .798 .869 r
.21708 .31087 .22422 .31441 .23503 .30954 .2279 .30614 Metetra
.795 .806 .861 r
.2279 .30614 .23503 .30954 .24591 .30415 .2388 .30093 Metetra
.812 .814 .852 r
.2388 .30093 .24591 .30415 .25688 .29821 .24977 .29521 Metetra
.828 .823 .844 r
.24977 .29521 .25688 .29821 .26792 .29173 .26082 .28897 Metetra
.845 .833 .835 r
.26082 .28897 .26792 .29173 .27902 .28467 .27194 .2822 Metetra
.86 .844 .826 r
.27194 .2822 .27902 .28467 .29019 .27703 .28312 .27488 Metetra
.876 .855 .818 r
.28312 .27488 .29019 .27703 .3014 .26879 .29435 .267 Metetra
.891 .866 .808 r
.29435 .267 .3014 .26879 .31266 .25995 .30562 .25857 Metetra
.905 .879 .799 r
.30562 .25857 .31266 .25995 .32396 .25052 .31693 .2496 Metetra
.918 .892 .789 r
.31693 .2496 .32396 .25052 .33527 .24052 .32826 .24012 Metetra
.929 .907 .779 r
.32826 .24012 .33527 .24052 .34659 .22999 .3396 .23018 Metetra
.938 .924 .768 r
.3396 .23018 .34659 .22999 .3579 .21903 .35093 .21986 Metetra
.943 .942 .756 r
.35093 .21986 .3579 .21903 .36919 .20775 .36224 .20931 Metetra
.94 .961 .74 r
.36224 .20931 .36919 .20775 .38043 .19635 .3735 .19872 Metetra
.918 .977 .717 r
.3735 .19872 .38043 .19635 .3916 .18512 .3847 .18836 Metetra
.857 .976 .673 r
.3847 .18836 .3916 .18512 .40268 .17446 .39582 .1786 Metetra
.711 .921 .58 r
.39582 .1786 .40268 .17446 .41365 .16491 .40682 .16993 Metetra
.40682 .16993 .41365 .16491 .42448 .15715 .41771 .16289 Metetra
.41771 .16289 .42448 .15715 .43507 .15418 .42848 .15801 Metetra
.077 0 0 r
.42848 .15801 .43507 .15418 .44566 .1518 .43915 .15562 Metetra
.364 0 0 r
.43915 .15562 .44566 .1518 .45628 .15002 .44976 .15573 Metetra
.54 .097 .147 r
.44976 .15573 .45628 .15002 .4668 .15305 .46037 .15802 Metetra
.61 .159 .155 r
.46037 .15802 .4668 .15305 .47737 .15789 .47102 .16196 Metetra
.653 .189 .14 r
.47102 .16196 .47737 .15789 .48805 .16388 .48177 .16701 Metetra
.678 .198 .106 r
.48177 .16701 .48805 .16388 .49886 .17046 .49264 .17269 Metetra
.688 .189 .055 r
.49264 .17269 .49886 .17046 .50981 .17724 .50364 .17864 Metetra
.684 .164 0 r
.50364 .17864 .50981 .17724 .52092 .18394 .51478 .18457 Metetra
.664 .123 0 r
.51478 .18457 .52092 .18394 .53217 .19034 .52607 .19029 Metetra
.626 .064 0 r
.52607 .19029 .53217 .19034 .54358 .19633 .5375 .19566 Metetra
.566 0 0 r
.5375 .19566 .54358 .19633 .55512 .20181 .54906 .20058 Metetra
.479 0 0 r
.54906 .20058 .55512 .20181 .56679 .20674 .56075 .20502 Metetra
.366 0 0 r
.56075 .20502 .56679 .20674 .57858 .2111 .57256 .20892 Metetra
0 .323 .71 r
.57256 .20892 .57858 .2111 .59048 .21486 .58448 .21228 Metetra
0 .422 .813 r
.58448 .21228 .59048 .21486 .60248 .21804 .5965 .21509 Metetra
.043 .506 .887 r
.5965 .21509 .60248 .21804 .61458 .22063 .60861 .21736 Metetra
.163 .571 .933 r
.60861 .21736 .61458 .22063 .62676 .22265 .6208 .21909 Metetra
.265 .619 .958 r
.6208 .21909 .62676 .22265 .63901 .22412 .63307 .22031 Metetra
.348 .654 .969 r
.63307 .22031 .63901 .22412 .65133 .22504 .64541 .22101 Metetra
.417 .679 .971 r
.64541 .22101 .65133 .22504 .66371 .22543 .65781 .22121 Metetra
.474 .699 .967 r
.65781 .22121 .66371 .22543 .67614 .2253 .67026 .22092 Metetra
.521 .715 .96 r
.67026 .22092 .67614 .2253 .68861 .22466 .68276 .22015 Metetra
.562 .728 .952 r
.68276 .22015 .68861 .22466 .70111 .22351 .69529 .2189 Metetra
.598 .74 .943 r
.69529 .2189 .70111 .22351 .71364 .22185 .70784 .21716 Metetra
.63 .75 .934 r
.70784 .21716 .71364 .22185 .72618 .21967 .72042 .21493 Metetra
.659 .761 .925 r
.72042 .21493 .72618 .21967 .73873 .21696 .733 .21219 Metetra
.687 .771 .915 r
.733 .21219 .73873 .21696 .75126 .21372 .74558 .20892 Metetra
.713 .781 .905 r
.74558 .20892 .75126 .21372 .76378 .20991 .75813 .20511 Metetra
.738 .791 .895 r
.75813 .20511 .76378 .20991 .77626 .20552 .77066 .20074 Metetra
.763 .8 .883 r
.77066 .20074 .77626 .20552 .78869 .20053 .78315 .19576 Metetra
.418 .678 .97 r
.10758 .32793 .11496 .33168 .12455 .33189 .1172 .32808 Metetra
.494 .707 .965 r
.1172 .32808 .12455 .33189 .13431 .33155 .12698 .32769 Metetra
.552 .727 .956 r
.12698 .32769 .13431 .33155 .14423 .33067 .13691 .32676 Metetra
.598 .741 .944 r
.13691 .32676 .14423 .33067 .15428 .32928 .14699 .32535 Metetra
.635 .751 .932 r
.14699 .32535 .15428 .32928 .16446 .32739 .1572 .32345 Metetra
.666 .759 .92 r
.1572 .32345 .16446 .32739 .17477 .32502 .16752 .3211 Metetra
.691 .766 .909 r
.16752 .3211 .17477 .32502 .1852 .32219 .17796 .3183 Metetra
.714 .773 .899 r
.17796 .3183 .1852 .32219 .19573 .31888 .18851 .31506 Metetra
.734 .78 .89 r
.18851 .31506 .19573 .31888 .20636 .31511 .19915 .31139 Metetra
.753 .788 .881 r
.19915 .31139 .20636 .31511 .21708 .31087 .20989 .30727 Metetra
.771 .796 .873 r
.20989 .30727 .21708 .31087 .2279 .30614 .22071 .3027 Metetra
.788 .805 .866 r
.22071 .3027 .2279 .30614 .2388 .30093 .23162 .29768 Metetra
.805 .814 .858 r
.23162 .29768 .2388 .30093 .24977 .29521 .24261 .29218 Metetra
.822 .825 .851 r
.24261 .29218 .24977 .29521 .26082 .28897 .25367 .2862 Metetra
.838 .835 .844 r
.25367 .2862 .26082 .28897 .27194 .2822 .26479 .27972 Metetra
.854 .847 .836 r
.26479 .27972 .27194 .2822 .28312 .27488 .27598 .27273 Metetra
.869 .859 .828 r
.27598 .27273 .28312 .27488 .29435 .267 .28722 .26523 Metetra
.884 .872 .82 r
.28722 .26523 .29435 .267 .30562 .25857 .2985 .25722 Metetra
.898 .886 .811 r
.2985 .25722 .30562 .25857 .31693 .2496 .30982 .24872 Metetra
.911 .901 .802 r
.30982 .24872 .31693 .2496 .32826 .24012 .32117 .23976 Metetra
.922 .917 .793 r
.32117 .23976 .32826 .24012 .3396 .23018 .33252 .23039 Metetra
.93 .935 .783 r
.33252 .23039 .3396 .23018 .35093 .21986 .34387 .22072 Metetra
.933 .954 .771 r
.34387 .22072 .35093 .21986 .36224 .20931 .3552 .21087 Metetra
.925 .972 .755 r
.3552 .21087 .36224 .20931 .3735 .19872 .36649 .20103 Metetra
.897 .986 .731 r
.36649 .20103 .3735 .19872 .3847 .18836 .37771 .19147 Metetra
.826 .978 .684 r
.37771 .19147 .3847 .18836 .39582 .1786 .38886 .18252 Metetra
.671 .913 .59 r
.38886 .18252 .39582 .1786 .40682 .16993 .39991 .17461 Metetra
.39991 .17461 .40682 .16993 .41771 .16289 .41085 .16817 Metetra
.41085 .16817 .41771 .16289 .42848 .15801 .42169 .16362 Metetra
.204 0 0 r
.42169 .16362 .42848 .15801 .43915 .15562 .43244 .16123 Metetra
.387 0 .05 r
.43244 .16123 .43915 .15562 .44976 .15573 .44314 .16098 Metetra
.502 .045 .099 r
.44314 .16098 .44976 .15573 .46037 .15802 .45384 .16264 Metetra
.574 .109 .112 r
.45384 .16264 .46037 .15802 .47102 .16196 .46458 .1658 Metetra
.619 .142 .099 r
.46458 .1658 .47102 .16196 .48177 .16701 .4754 .17002 Metetra
.645 .152 .067 r
.4754 .17002 .48177 .16701 .49264 .17269 .48633 .17487 Metetra
.655 .144 .018 r
.48633 .17487 .49264 .17269 .50364 .17864 .49738 .18002 Metetra
.649 .118 0 r
.49738 .18002 .50364 .17864 .51478 .18457 .50857 .18522 Metetra
.628 .075 0 r
.50857 .18522 .51478 .18457 .52607 .19029 .51989 .19026 Metetra
.586 .013 0 r
.51989 .19026 .52607 .19029 .5375 .19566 .53135 .19502 Metetra
.521 0 0 r
.53135 .19502 .5375 .19566 .54906 .20058 .54294 .19939 Metetra
.428 0 0 r
.54294 .19939 .54906 .20058 .56075 .20502 .55465 .20332 Metetra
.311 0 0 r
.55465 .20332 .56075 .20502 .57256 .20892 .56648 .20676 Metetra
0 .374 .749 r
.56648 .20676 .57256 .20892 .58448 .21228 .57842 .2097 Metetra
0 .467 .843 r
.57842 .2097 .58448 .21228 .5965 .21509 .59045 .21214 Metetra
.091 .542 .908 r
.59045 .21214 .5965 .21509 .60861 .21736 .60258 .21407 Metetra
.204 .598 .947 r
.60258 .21407 .60861 .21736 .6208 .21909 .61479 .21551 Metetra
.298 .639 .966 r
.61479 .21551 .6208 .21909 .63307 .22031 .62708 .21645 Metetra
.375 .668 .972 r
.62708 .21645 .63307 .22031 .64541 .22101 .63944 .21692 Metetra
.437 .689 .971 r
.63944 .21692 .64541 .22101 .65781 .22121 .65186 .21693 Metetra
.489 .705 .966 r
.65186 .21693 .65781 .22121 .67026 .22092 .66433 .21648 Metetra
.532 .718 .958 r
.66433 .21648 .67026 .22092 .68276 .22015 .67685 .21557 Metetra
.569 .729 .95 r
.67685 .21557 .68276 .22015 .69529 .2189 .68941 .21421 Metetra
.602 .74 .941 r
.68941 .21421 .69529 .2189 .70784 .21716 .702 .21239 Metetra
.632 .75 .933 r
.702 .21239 .70784 .21716 .72042 .21493 .7146 .21011 Metetra
.66 .759 .924 r
.7146 .21011 .72042 .21493 .733 .21219 .72722 .20734 Metetra
.686 .769 .915 r
.72722 .20734 .733 .21219 .74558 .20892 .73984 .20407 Metetra
.712 .78 .905 r
.73984 .20407 .74558 .20892 .75813 .20511 .75245 .20027 Metetra
.737 .79 .895 r
.75245 .20027 .75813 .20511 .77066 .20074 .76502 .19591 Metetra
.761 .799 .884 r
.76502 .19591 .77066 .20074 .78315 .19576 .77756 .19096 Metetra
.426 .682 .97 r
.10014 .32416 .10758 .32793 .1172 .32808 .10979 .32424 Metetra
.5 .709 .964 r
.10979 .32424 .1172 .32808 .12698 .32769 .11959 .32378 Metetra
.557 .728 .954 r
.11959 .32378 .12698 .32769 .13691 .32676 .12955 .32281 Metetra
.6 .74 .942 r
.12955 .32281 .13691 .32676 .14699 .32535 .13965 .32136 Metetra
.635 .749 .93 r
.13965 .32136 .14699 .32535 .1572 .32345 .14988 .31945 Metetra
.664 .757 .919 r
.14988 .31945 .1572 .32345 .16752 .3211 .16023 .31711 Metetra
.688 .764 .909 r
.16023 .31711 .16752 .3211 .17796 .3183 .17068 .31435 Metetra
.709 .77 .9 r
.17068 .31435 .17796 .3183 .18851 .31506 .18124 .31118 Metetra
.729 .778 .892 r
.18124 .31118 .18851 .31506 .19915 .31139 .1919 .3076 Metetra
.747 .786 .884 r
.1919 .3076 .19915 .31139 .20989 .30727 .20264 .30361 Metetra
.764 .794 .878 r
.20264 .30361 .20989 .30727 .22071 .3027 .21348 .2992 Metetra
.781 .804 .871 r
.21348 .2992 .22071 .3027 .23162 .29768 .22439 .29438 Metetra
.797 .814 .865 r
.22439 .29438 .23162 .29768 .24261 .29218 .23538 .28911 Metetra
.814 .825 .859 r
.23538 .28911 .24261 .29218 .25367 .2862 .24645 .2834 Metetra
.83 .837 .852 r
.24645 .2834 .25367 .2862 .26479 .27972 .25758 .27723 Metetra
.846 .85 .846 r
.25758 .27723 .26479 .27972 .27598 .27273 .26877 .27058 Metetra
.862 .863 .839 r
.26877 .27058 .27598 .27273 .28722 .26523 .28001 .26347 Metetra
.877 .878 .832 r
.28001 .26347 .28722 .26523 .2985 .25722 .29131 .25589 Metetra
.891 .893 .824 r
.29131 .25589 .2985 .25722 .30982 .24872 .30263 .24785 Metetra
.903 .909 .817 r
.30263 .24785 .30982 .24872 .32117 .23976 .31399 .23941 Metetra
.914 .927 .808 r
.31399 .23941 .32117 .23976 .33252 .23039 .32536 .23062 Metetra
.92 .945 .798 r
.32536 .23062 .33252 .23039 .34387 .22072 .33672 .22156 Metetra
.92 .964 .787 r
.33672 .22156 .34387 .22072 .3552 .21087 .34807 .21239 Metetra
.908 .982 .771 r
.34807 .21239 .3552 .21087 .36649 .20103 .35938 .20326 Metetra
.873 .992 .745 r
.35938 .20326 .36649 .20103 .37771 .19147 .37063 .19444 Metetra
.793 .978 .695 r
.37063 .19444 .37771 .19147 .38886 .18252 .38181 .18622 Metetra
.635 .906 .602 r
.38181 .18622 .38886 .18252 .39991 .17461 .39291 .17896 Metetra
.39291 .17896 .39991 .17461 .41085 .16817 .40391 .17303 Metetra
.40391 .17303 .41085 .16817 .42169 .16362 .41481 .16877 Metetra
.17 0 0 r
.41481 .16877 .42169 .16362 .43244 .16123 .42564 .16636 Metetra
.347 0 0 r
.42564 .16636 .43244 .16123 .44314 .16098 .43643 .16581 Metetra
.462 0 .047 r
.43643 .16581 .44314 .16098 .45384 .16264 .44722 .16694 Metetra
.535 .056 .064 r
.44722 .16694 .45384 .16264 .46458 .1658 .45804 .16942 Metetra
.582 .091 .054 r
.45804 .16942 .46458 .1658 .4754 .17002 .46893 .17288 Metetra
.608 .102 .024 r
.46893 .17288 .4754 .17002 .48633 .17487 .47993 .17696 Metetra
.617 .093 0 r
.47993 .17696 .48633 .17487 .49738 .18002 .49104 .18137 Metetra
.61 .066 0 r
.49104 .18137 .49738 .18002 .50857 .18522 .50227 .18586 Metetra
.585 .02 0 r
.50227 .18586 .50857 .18522 .51989 .19026 .51363 .19025 Metetra
.539 0 0 r
.51363 .19025 .51989 .19026 .53135 .19502 .52513 .1944 Metetra
.468 0 0 r
.52513 .1944 .53135 .19502 .54294 .19939 .53675 .19821 Metetra
.37 0 0 r
.53675 .19821 .54294 .19939 .55465 .20332 .54849 .20162 Metetra
0 .329 .676 r
.54849 .20162 .55465 .20332 .56648 .20676 .56034 .2046 Metetra
0 .428 .789 r
.56034 .2046 .56648 .20676 .57842 .2097 .5723 .20712 Metetra
.02 .512 .873 r
.5723 .20712 .57842 .2097 .59045 .21214 .58435 .20917 Metetra
.143 .578 .928 r
.58435 .20917 .59045 .21214 .60258 .21407 .5965 .21075 Metetra
.247 .625 .959 r
.5965 .21075 .60258 .21407 .61479 .21551 .60873 .21187 Metetra
.332 .658 .972 r
.60873 .21187 .61479 .21551 .62708 .21645 .62104 .21254 Metetra
.401 .681 .974 r
.62104 .21254 .62708 .21645 .63944 .21692 .63342 .21277 Metetra
.458 .698 .971 r
.63342 .21277 .63944 .21692 .65186 .21693 .64586 .21257 Metetra
.504 .711 .964 r
.64586 .21257 .65186 .21693 .66433 .21648 .65835 .21195 Metetra
.543 .721 .956 r
.65835 .21195 .66433 .21648 .67685 .21557 .67089 .21091 Metetra
.576 .73 .947 r
.67089 .21091 .67685 .21557 .68941 .21421 .68348 .20944 Metetra
.606 .739 .939 r
.68348 .20944 .68941 .21421 .702 .21239 .6961 .20755 Metetra
.634 .748 .931 r
.6961 .20755 .702 .21239 .7146 .21011 .70874 .20521 Metetra
.66 .758 .922 r
.70874 .20521 .7146 .21011 .72722 .20734 .7214 .20242 Metetra
.685 .767 .914 r
.7214 .20242 .72722 .20734 .73984 .20407 .73406 .19914 Metetra
.71 .777 .905 r
.73406 .19914 .73984 .20407 .75245 .20027 .74671 .19536 Metetra
.734 .788 .896 r
.74671 .19536 .75245 .20027 .76502 .19591 .75934 .19103 Metetra
.758 .798 .885 r
.75934 .19103 .76502 .19591 .77756 .19096 .77192 .18611 Metetra
.436 .686 .97 r
.09265 .32036 .10014 .32416 .10979 .32424 .10232 .32036 Metetra
.508 .712 .963 r
.10232 .32036 .10979 .32424 .11959 .32378 .11216 .31982 Metetra
.562 .728 .953 r
.11216 .31982 .11959 .32378 .12955 .32281 .12214 .31879 Metetra
.603 .739 .941 r
.12214 .31879 .12955 .32281 .13965 .32136 .13227 .3173 Metetra
.636 .747 .929 r
.13227 .3173 .13965 .32136 .14988 .31945 .14252 .31537 Metetra
.662 .754 .918 r
.14252 .31537 .14988 .31945 .16023 .31711 .15288 .31304 Metetra
.685 .761 .909 r
.15288 .31304 .16023 .31711 .17068 .31435 .16336 .31032 Metetra
.705 .767 .901 r
.16336 .31032 .17068 .31435 .18124 .31118 .17393 .30721 Metetra
.723 .774 .893 r
.17393 .30721 .18124 .31118 .1919 .3076 .1846 .30373 Metetra
.74 .783 .887 r
.1846 .30373 .1919 .3076 .20264 .30361 .19535 .29988 Metetra
.756 .792 .881 r
.19535 .29988 .20264 .30361 .21348 .2992 .20619 .29564 Metetra
.773 .802 .876 r
.20619 .29564 .21348 .2992 .22439 .29438 .21711 .29102 Metetra
.789 .813 .871 r
.21711 .29102 .22439 .29438 .23538 .28911 .2281 .28599 Metetra
.805 .825 .866 r
.2281 .28599 .23538 .28911 .24645 .2834 .23917 .28056 Metetra
.821 .838 .861 r
.23917 .28056 .24645 .2834 .25758 .27723 .2503 .2747 Metetra
.837 .852 .856 r
.2503 .2747 .25758 .27723 .26877 .27058 .26149 .26841 Metetra
.853 .867 .851 r
.26149 .26841 .26877 .27058 .28001 .26347 .27274 .26169 Metetra
.868 .882 .845 r
.27274 .26169 .28001 .26347 .29131 .25589 .28404 .25454 Metetra
.882 .899 .838 r
.28404 .25454 .29131 .25589 .30263 .24785 .29537 .24699 Metetra
.894 .917 .831 r
.29537 .24699 .30263 .24785 .31399 .23941 .30673 .23906 Metetra
.903 .935 .824 r
.30673 .23906 .31399 .23941 .32536 .23062 .31811 .23083 Metetra
.908 .955 .815 r
.31811 .23083 .32536 .23062 .33672 .22156 .32949 .22239 Metetra
.905 .974 .803 r
.32949 .22239 .33672 .22156 .34807 .21239 .34085 .21385 Metetra
.888 .99 .786 r
.34085 .21385 .34807 .21239 .35938 .20326 .35218 .2054 Metetra
.847 .995 .758 r
.35218 .2054 .35938 .20326 .37063 .19444 .36346 .19726 Metetra
.76 .975 .707 r
.36346 .19726 .37063 .19444 .38181 .18622 .37468 .1897 Metetra
.603 .9 .614 r
.37468 .1897 .38181 .18622 .39291 .17896 .38582 .18301 Metetra
.38582 .18301 .39291 .17896 .40391 .17303 .39687 .17752 Metetra
.39687 .17752 .40391 .17303 .41481 .16877 .40785 .17349 Metetra
.135 0 0 r
.40785 .17349 .41481 .16877 .42564 .16636 .41876 .17107 Metetra
.304 0 0 r
.41876 .17107 .42564 .16636 .43643 .16581 .42963 .17027 Metetra
.419 0 0 r
.42963 .17027 .43643 .16581 .44722 .16694 .4405 .17093 Metetra
.493 0 .012 r
.4405 .17093 .44722 .16694 .45804 .16942 .45141 .17281 Metetra
.54 .035 .005 r
.45141 .17281 .45804 .16942 .46893 .17288 .46238 .17559 Metetra
.566 .047 0 r
.46238 .17559 .46893 .17288 .47993 .17696 .47344 .17896 Metetra
.574 .037 0 r
.47344 .17896 .47993 .17696 .49104 .18137 .4846 .18267 Metetra
.565 .008 0 r
.4846 .18267 .49104 .18137 .50227 .18586 .49589 .18648 Metetra
.536 0 0 r
.49589 .18648 .50227 .18586 .51363 .19025 .5073 .19022 Metetra
.484 0 0 r
.5073 .19022 .51363 .19025 .52513 .1944 .51883 .19377 Metetra
.407 0 0 r
.51883 .19377 .52513 .1944 .53675 .19821 .53049 .19702 Metetra
.303 0 0 r
.53049 .19702 .53675 .19821 .54849 .20162 .54225 .19992 Metetra
0 .392 .727 r
.54225 .19992 .54849 .20162 .56034 .2046 .55413 .20242 Metetra
0 .484 .83 r
.55413 .20242 .56034 .2046 .5723 .20712 .56611 .2045 Metetra
.083 .558 .903 r
.56611 .2045 .5723 .20712 .58435 .20917 .57819 .20615 Metetra
.196 .613 .947 r
.57819 .20615 .58435 .20917 .5965 .21075 .59036 .20738 Metetra
.291 .651 .969 r
.59036 .20738 .5965 .21075 .60873 .21187 .60261 .20818 Metetra
.367 .677 .977 r
.60261 .20818 .60873 .21187 .62104 .21254 .61494 .20857 Metetra
.428 .694 .975 r
.61494 .20857 .62104 .21254 .63342 .21277 .62734 .20855 Metetra
.478 .706 .97 r
.62734 .20855 .63342 .21277 .64586 .21257 .6398 .20814 Metetra
.519 .716 .962 r
.6398 .20814 .64586 .21257 .65835 .21195 .65232 .20734 Metetra
.553 .723 .953 r
.65232 .20734 .65835 .21195 .67089 .21091 .66488 .20615 Metetra
.583 .731 .944 r
.66488 .20615 .67089 .21091 .68348 .20944 .6775 .20458 Metetra
.61 .738 .936 r
.6775 .20458 .68348 .20944 .6961 .20755 .69015 .20261 Metetra
.636 .746 .928 r
.69015 .20261 .6961 .20755 .70874 .20521 .70282 .20023 Metetra
.66 .755 .921 r
.70282 .20023 .70874 .20521 .7214 .20242 .71552 .19742 Metetra
.683 .765 .913 r
.71552 .19742 .7214 .20242 .73406 .19914 .72822 .19415 Metetra
.707 .775 .905 r
.72822 .19415 .73406 .19914 .74671 .19536 .74092 .19039 Metetra
.731 .786 .896 r
.74092 .19039 .74671 .19536 .75934 .19103 .7536 .1861 Metetra
.755 .797 .886 r
.7536 .1861 .75934 .19103 .77192 .18611 .76624 .18123 Metetra
.448 .692 .97 r
.08511 .31654 .09265 .32036 .10232 .32036 .09481 .31644 Metetra
.517 .715 .962 r
.09481 .31644 .10232 .32036 .11216 .31982 .10467 .31582 Metetra
.568 .729 .95 r
.10467 .31582 .11216 .31982 .12214 .31879 .11469 .31471 Metetra
.606 .738 .938 r
.11469 .31471 .12214 .31879 .13227 .3173 .12484 .31317 Metetra
.636 .745 .927 r
.12484 .31317 .13227 .3173 .14252 .31537 .13511 .31122 Metetra
.661 .751 .917 r
.13511 .31122 .14252 .31537 .15288 .31304 .1455 .30889 Metetra
.682 .757 .908 r
.1455 .30889 .15288 .31304 .16336 .31032 .15599 .3062 Metetra
.7 .764 .901 r
.15599 .3062 .16336 .31032 .17393 .30721 .16657 .30316 Metetra
.717 .771 .895 r
.16657 .30316 .17393 .30721 .1846 .30373 .17725 .29978 Metetra
.733 .779 .89 r
.17725 .29978 .1846 .30373 .19535 .29988 .18801 .29606 Metetra
.748 .788 .885 r
.18801 .29606 .19535 .29988 .20619 .29564 .19885 .292 Metetra
.764 .799 .881 r
.19885 .292 .20619 .29564 .21711 .29102 .20977 .28759 Metetra
.779 .811 .878 r
.20977 .28759 .21711 .29102 .2281 .28599 .22076 .28282 Metetra
.795 .824 .874 r
.22076 .28282 .2281 .28599 .23917 .28056 .23183 .27767 Metetra
.811 .838 .871 r
.23183 .27767 .23917 .28056 .2503 .2747 .24296 .27213 Metetra
.827 .853 .867 r
.24296 .27213 .2503 .2747 .26149 .26841 .25415 .26621 Metetra
.842 .869 .863 r
.25415 .26621 .26149 .26841 .27274 .26169 .26539 .25989 Metetra
.857 .887 .858 r
.26539 .25989 .27274 .26169 .28404 .25454 .27669 .25318 Metetra
.87 .905 .853 r
.27669 .25318 .28404 .25454 .29537 .24699 .28803 .2461 Metetra
.882 .924 .847 r
.28803 .2461 .29537 .24699 .30673 .23906 .29939 .2387 Metetra
.89 .943 .84 r
.29939 .2387 .30673 .23906 .31811 .23083 .31077 .23102 Metetra
.893 .963 .831 r
.31077 .23102 .31811 .23083 .32949 .22239 .32216 .22317 Metetra
.887 .981 .82 r
.32216 .22317 .32949 .22239 .34085 .21385 .33354 .21525 Metetra
.866 .995 .802 r
.33354 .21525 .34085 .21385 .35218 .2054 .34489 .20743 Metetra
.818 .997 .772 r
.34489 .20743 .35218 .2054 .36346 .19726 .3562 .19992 Metetra
.727 .971 .719 r
.3562 .19992 .36346 .19726 .37468 .1897 .36745 .19295 Metetra
.573 .893 .628 r
.36745 .19295 .37468 .1897 .38582 .18301 .37864 .18678 Metetra
.37864 .18678 .38582 .18301 .39687 .17752 .38975 .18167 Metetra
.38975 .18167 .39687 .17752 .40785 .17349 .40079 .17784 Metetra
.1 0 0 r
.40079 .17784 .40785 .17349 .41876 .17107 .41178 .17541 Metetra
.26 0 0 r
.41178 .17541 .41876 .17107 .42963 .17027 .42273 .17438 Metetra
.372 0 0 r
.42273 .17438 .42963 .17027 .4405 .17093 .43369 .17464 Metetra
.447 0 0 r
.43369 .17464 .4405 .17093 .45141 .17281 .44468 .17598 Metetra
.494 0 0 r
.44468 .17598 .45141 .17281 .46238 .17559 .45572 .17813 Metetra
.519 0 0 r
.45572 .17813 .46238 .17559 .47344 .17896 .46686 .18085 Metetra
.525 0 0 r
.46686 .18085 .47344 .17896 .4846 .18267 .47809 .18389 Metetra
.512 0 0 r
.47809 .18389 .4846 .18267 .49589 .18648 .48943 .18705 Metetra
.479 0 0 r
.48943 .18705 .49589 .18648 .5073 .19022 .50089 .19016 Metetra
.421 0 0 r
.50089 .19016 .5073 .19022 .51883 .19377 .51246 .19311 Metetra
.337 0 0 r
.51246 .19311 .51883 .19377 .53049 .19702 .52415 .19581 Metetra
.228 0 0 r
.52415 .19581 .53049 .19702 .54225 .19992 .53595 .19819 Metetra
0 .458 .778 r
.53595 .19819 .54225 .19992 .55413 .20242 .54786 .20021 Metetra
.028 .54 .869 r
.54786 .20021 .55413 .20242 .56611 .2045 .55987 .20185 Metetra
.148 .603 .929 r
.55987 .20185 .56611 .2045 .57819 .20615 .57197 .20309 Metetra
.251 .647 .963 r
.57197 .20309 .57819 .20615 .59036 .20738 .58416 .20395 Metetra
.335 .676 .977 r
.58416 .20395 .59036 .20738 .60261 .20818 .59644 .20442 Metetra
.402 .694 .98 r
.59644 .20442 .60261 .20818 .61494 .20857 .60878 .20451 Metetra
.455 .706 .975 r
.60878 .20451 .61494 .20857 .62734 .20855 .6212 .20424 Metetra
.498 .714 .967 r
.6212 .20424 .62734 .20855 .6398 .20814 .63369 .20361 Metetra
.534 .72 .959 r
.63369 .20361 .6398 .20814 .65232 .20734 .64623 .20263 Metetra
.564 .725 .95 r
.64623 .20263 .65232 .20734 .66488 .20615 .65882 .2013 Metetra
.59 .731 .941 r
.65882 .2013 .66488 .20615 .6775 .20458 .67146 .19962 Metetra
.614 .737 .933 r
.67146 .19962 .6775 .20458 .69015 .20261 .68414 .19757 Metetra
.637 .744 .926 r
.68414 .19757 .69015 .20261 .70282 .20023 .69686 .19515 Metetra
.659 .752 .919 r
.69686 .19515 .70282 .20023 .71552 .19742 .70959 .19233 Metetra
.681 .762 .912 r
.70959 .19233 .71552 .19742 .72822 .19415 .72234 .18908 Metetra
.704 .772 .905 r
.72234 .18908 .72822 .19415 .74092 .19039 .73508 .18535 Metetra
.727 .783 .897 r
.73508 .18535 .74092 .19039 .7536 .1861 .74782 .18111 Metetra
.751 .795 .888 r
.74782 .18111 .7536 .1861 .76624 .18123 .76052 .17631 Metetra
.462 .698 .969 r
.07751 .31268 .08511 .31654 .09481 .31644 .08724 .31247 Metetra
.527 .718 .96 r
.08724 .31247 .09481 .31644 .10467 .31582 .09714 .31175 Metetra
.574 .73 .948 r
.09714 .31175 .10467 .31582 .11469 .31471 .10719 .31056 Metetra
.61 .737 .936 r
.10719 .31056 .11469 .31471 .12484 .31317 .11737 .30896 Metetra
.638 .743 .925 r
.11737 .30896 .12484 .31317 .13511 .31122 .12767 .30697 Metetra
.66 .748 .915 r
.12767 .30697 .13511 .31122 .1455 .30889 .13807 .30464 Metetra
.679 .753 .907 r
.13807 .30464 .1455 .30889 .15599 .3062 .14858 .30198 Metetra
.695 .759 .901 r
.14858 .30198 .15599 .3062 .16657 .30316 .15917 .29901 Metetra
.711 .766 .896 r
.15917 .29901 .16657 .30316 .17725 .29978 .16986 .29573 Metetra
.725 .775 .892 r
.16986 .29573 .17725 .29978 .18801 .29606 .18062 .29216 Metetra
.739 .784 .889 r
.18062 .29216 .18801 .29606 .19885 .292 .19146 .28828 Metetra
.754 .795 .886 r
.19146 .28828 .19885 .292 .20977 .28759 .20238 .28408 Metetra
.769 .808 .884 r
.20238 .28408 .20977 .28759 .22076 .28282 .21337 .27956 Metetra
.784 .822 .882 r
.21337 .27956 .22076 .28282 .23183 .27767 .22443 .27471 Metetra
.799 .837 .88 r
.22443 .27471 .23183 .27767 .24296 .27213 .23555 .26951 Metetra
.815 .854 .878 r
.23555 .26951 .24296 .27213 .25415 .26621 .24674 .26395 Metetra
.83 .871 .875 r
.24674 .26395 .25415 .26621 .26539 .25989 .25798 .25804 Metetra
.844 .89 .872 r
.25798 .25804 .26539 .25989 .27669 .25318 .26927 .25178 Metetra
.857 .909 .868 r
.26927 .25178 .27669 .25318 .28803 .2461 .2806 .24518 Metetra
.868 .929 .863 r
.2806 .24518 .28803 .2461 .29939 .2387 .29197 .23829 Metetra
.875 .95 .856 r
.29197 .23829 .29939 .2387 .31077 .23102 .30336 .23117 Metetra
.876 .97 .848 r
.30336 .23117 .31077 .23102 .32216 .22317 .31475 .22389 Metetra
.866 .987 .836 r
.31475 .22389 .32216 .22317 .33354 .21525 .32614 .21656 Metetra
.841 .999 .817 r
.32614 .21656 .33354 .21525 .34489 .20743 .33751 .20935 Metetra
.788 .996 .785 r
.33751 .20935 .34489 .20743 .3562 .19992 .34885 .20242 Metetra
.694 .965 .73 r
.34885 .20242 .3562 .19992 .36745 .19295 .36014 .19598 Metetra
.545 .887 .642 r
.36014 .19598 .36745 .19295 .37864 .18678 .37136 .19027 Metetra
.37136 .19027 .37864 .18678 .38975 .18167 .38253 .1855 Metetra
.38253 .1855 .38975 .18167 .40079 .17784 .39364 .18185 Metetra
.064 0 0 r
.39364 .18185 .40079 .17784 .41178 .17541 .4047 .1794 Metetra
.215 0 0 r
.4047 .1794 .41178 .17541 .42273 .17438 .41574 .17818 Metetra
.323 0 0 r
.41574 .17818 .42273 .17438 .43369 .17464 .42678 .17808 Metetra
.396 0 0 r
.42678 .17808 .43369 .17464 .44468 .17598 .43785 .17892 Metetra
.442 0 0 r
.43785 .17892 .44468 .17598 .45572 .17813 .44898 .18051 Metetra
.466 0 0 r
.44898 .18051 .45572 .17813 .46686 .18085 .46019 .18261 Metetra
.469 0 0 r
.46019 .18261 .46686 .18085 .47809 .18389 .47148 .18502 Metetra
.452 0 0 r
.47148 .18502 .47809 .18389 .48943 .18705 .48288 .18755 Metetra
.412 0 0 r
.48288 .18755 .48943 .18705 .50089 .19016 .49439 .19006 Metetra
.348 0 0 r
.49439 .19006 .50089 .19016 .51246 .19311 .50602 .19242 Metetra
.257 0 0 r
.50602 .19242 .51246 .19311 .52415 .19581 .51775 .19456 Metetra
0 .439 .723 r
.51775 .19456 .52415 .19581 .53595 .19819 .52959 .19642 Metetra
0 .525 .828 r
.52959 .19642 .53595 .19819 .54786 .20021 .54153 .19795 Metetra
.104 .595 .905 r
.54153 .19795 .54786 .20021 .55987 .20185 .55356 .19914 Metetra
.214 .645 .952 r
.55356 .19914 .55987 .20185 .57197 .20309 .56569 .19997 Metetra
.305 .678 .976 r
.56569 .19997 .57197 .20309 .58416 .20395 .57791 .20045 Metetra
.379 .698 .983 r
.57791 .20045 .58416 .20395 .59644 .20442 .5902 .20058 Metetra
.436 .71 .981 r
.5902 .20058 .59644 .20442 .60878 .20451 .60257 .20037 Metetra
.482 .716 .974 r
.60257 .20037 .60878 .20451 .6212 .20424 .61501 .19984 Metetra
.519 .72 .964 r
.61501 .19984 .6212 .20424 .63369 .20361 .62752 .19898 Metetra
.549 .723 .955 r
.62752 .19898 .63369 .20361 .64623 .20263 .64008 .19782 Metetra
.574 .726 .946 r
.64008 .19782 .64623 .20263 .65882 .2013 .6527 .19634 Metetra
.597 .73 .938 r
.6527 .19634 .65882 .2013 .67146 .19962 .66537 .19455 Metetra
.618 .735 .93 r
.66537 .19455 .67146 .19962 .68414 .19757 .67809 .19243 Metetra
.638 .741 .923 r
.67809 .19243 .68414 .19757 .69686 .19515 .69083 .18998 Metetra
.658 .749 .917 r
.69083 .18998 .69686 .19515 .70959 .19233 .70361 .18715 Metetra
.679 .758 .911 r
.70361 .18715 .70959 .19233 .72234 .18908 .7164 .18392 Metetra
.7 .769 .905 r
.7164 .18392 .72234 .18908 .73508 .18535 .7292 .18024 Metetra
.723 .78 .898 r
.7292 .18024 .73508 .18535 .74782 .18111 .74198 .17607 Metetra
.747 .793 .89 r
.74198 .17607 .74782 .18111 .76052 .17631 .75474 .17136 Metetra
.478 .704 .968 r
.06985 .3088 .07751 .31268 .08724 .31247 .07962 .30846 Metetra
.538 .721 .957 r
.07962 .30846 .08724 .31247 .09714 .31175 .08956 .30762 Metetra
.582 .73 .945 r
.08956 .30762 .09714 .31175 .10719 .31056 .09964 .30633 Metetra
.615 .736 .933 r
.09964 .30633 .10719 .31056 .11737 .30896 .10985 .30466 Metetra
.64 .741 .922 r
.10985 .30466 .11737 .30896 .12767 .30697 .12018 .30263 Metetra
.659 .745 .913 r
.12018 .30263 .12767 .30697 .13807 .30464 .1306 .30029 Metetra
.676 .749 .906 r
.1306 .30029 .13807 .30464 .14858 .30198 .14112 .29766 Metetra
.691 .755 .901 r
.14112 .29766 .14858 .30198 .15917 .29901 .15173 .29475 Metetra
.704 .762 .897 r
.15173 .29475 .15917 .29901 .16986 .29573 .16242 .29158 Metetra
.717 .77 .894 r
.16242 .29158 .16986 .29573 .18062 .29216 .17319 .28815 Metetra
.73 .78 .892 r
.17319 .28815 .18062 .29216 .19146 .28828 .18403 .28445 Metetra
.743 .791 .891 r
.18403 .28445 .19146 .28828 .20238 .28408 .19494 .28048 Metetra
.757 .804 .891 r
.19494 .28048 .20238 .28408 .21337 .27956 .20592 .27623 Metetra
.771 .819 .89 r
.20592 .27623 .21337 .27956 .22443 .27471 .21697 .27168 Metetra
.786 .835 .89 r
.21697 .27168 .22443 .27471 .23555 .26951 .22808 .26682 Metetra
.801 .853 .889 r
.22808 .26682 .23555 .26951 .24674 .26395 .23926 .26164 Metetra
.816 .872 .888 r
.23926 .26164 .24674 .26395 .25798 .25804 .25049 .25614 Metetra
.83 .892 .886 r
.25049 .25614 .25798 .25804 .26927 .25178 .26178 .25033 Metetra
.842 .913 .883 r
.26178 .25033 .26927 .25178 .2806 .24518 .27311 .24422 Metetra
.852 .934 .879 r
.27311 .24422 .2806 .24518 .29197 .23829 .28447 .23784 Metetra
.857 .955 .873 r
.28447 .23784 .29197 .23829 .30336 .23117 .29586 .23125 Metetra
.856 .975 .865 r
.29586 .23125 .30336 .23117 .31475 .22389 .30726 .22453 Metetra
.843 .991 .852 r
.30726 .22453 .31475 .22389 .32614 .21656 .31866 .21778 Metetra
.813 1 .832 r
.31866 .21778 .32614 .21656 .33751 .20935 .33005 .21113 Metetra
.756 .992 .797 r
.33005 .21113 .33751 .20935 .34885 .20242 .34141 .20475 Metetra
.661 .957 .742 r
.34141 .20475 .34885 .20242 .36014 .19598 .35273 .19881 Metetra
.52 .881 .657 r
.35273 .19881 .36014 .19598 .37136 .19027 .364 .19352 Metetra
.364 .19352 .37136 .19027 .38253 .1855 .37522 .18905 Metetra
.37522 .18905 .38253 .1855 .39364 .18185 .3864 .18554 Metetra
.029 0 0 r
.3864 .18554 .39364 .18185 .4047 .1794 .39754 .18309 Metetra
.169 0 0 r
.39754 .18309 .4047 .1794 .41574 .17818 .40866 .18168 Metetra
.271 0 0 r
.40866 .18168 .41574 .17818 .42678 .17808 .41978 .18126 Metetra
.341 0 0 r
.41978 .18126 .42678 .17808 .43785 .17892 .43094 .18166 Metetra
.385 0 0 r
.43094 .18166 .43785 .17892 .44898 .18051 .44214 .18272 Metetra
.406 0 0 r
.44214 .18272 .44898 .18051 .46019 .18261 .45342 .18425 Metetra
.405 0 0 r
.45342 .18425 .46019 .18261 .47148 .18502 .46479 .18605 Metetra
.383 0 0 r
.46479 .18605 .47148 .18502 .48288 .18755 .47625 .18798 Metetra
.336 0 0 r
.47625 .18798 .48288 .18755 .49439 .19006 .48782 .18989 Metetra
.264 0 0 r
.48782 .18989 .49439 .19006 .50602 .19242 .49949 .19167 Metetra
.167 0 0 r
.49949 .19167 .50602 .19242 .51775 .19456 .51127 .19326 Metetra
0 .515 .783 r
.51127 .19326 .51775 .19456 .52959 .19642 .52315 .19459 Metetra
.069 .591 .875 r
.52315 .19459 .52959 .19642 .54153 .19795 .53512 .19563 Metetra
.182 .647 .937 r
.53512 .19563 .54153 .19795 .55356 .19914 .54719 .19636 Metetra
.28 .685 .971 r
.54719 .19636 .55356 .19914 .56569 .19997 .55935 .19677 Metetra
.359 .707 .985 r
.55935 .19677 .56569 .19997 .57791 .20045 .57159 .19686 Metetra
.421 .718 .986 r
.57159 .19686 .57791 .20045 .5902 .20058 .58391 .19664 Metetra
.47 .723 .98 r
.58391 .19664 .5902 .20058 .60257 .20037 .5963 .19613 Metetra
.508 .725 .971 r
.5963 .19613 .60257 .20037 .61501 .19984 .60877 .19532 Metetra
.538 .726 .961 r
.60877 .19532 .61501 .19984 .62752 .19898 .6213 .19424 Metetra
.563 .726 .951 r
.6213 .19424 .62752 .19898 .64008 .19782 .63389 .19289 Metetra
.584 .727 .941 r
.63389 .19289 .64008 .19782 .6527 .19634 .64653 .19126 Metetra
.603 .729 .934 r
.64653 .19126 .6527 .19634 .66537 .19455 .65923 .18936 Metetra
.621 .733 .927 r
.65923 .18936 .66537 .19455 .67809 .19243 .67197 .18718 Metetra
.639 .738 .921 r
.67197 .18718 .67809 .19243 .69083 .18998 .68476 .18469 Metetra
.657 .745 .915 r
.68476 .18469 .69083 .18998 .70361 .18715 .69757 .18186 Metetra
.676 .754 .91 r
.69757 .18186 .70361 .18715 .7164 .18392 .71041 .17867 Metetra
.696 .765 .905 r
.71041 .17867 .7164 .18392 .7292 .18024 .72325 .17506 Metetra
.718 .777 .899 r
.72325 .17506 .7292 .18024 .74198 .17607 .7361 .17097 Metetra
.741 .79 .892 r
.7361 .17097 .74198 .17607 .75474 .17136 .74892 .16635 Metetra
.495 .711 .967 r
.06213 .30489 .06985 .3088 .07962 .30846 .07195 .30439 Metetra
.551 .724 .954 r
.07195 .30439 .07962 .30846 .08956 .30762 .08193 .30342 Metetra
.591 .731 .941 r
.08193 .30342 .08956 .30762 .09964 .30633 .09205 .30202 Metetra
.62 .735 .929 r
.09205 .30202 .09964 .30633 .10985 .30466 .1023 .30026 Metetra
.642 .738 .919 r
.1023 .30026 .10985 .30466 .12018 .30263 .11265 .29819 Metetra
.659 .741 .911 r
.11265 .29819 .12018 .30263 .1306 .30029 .1231 .29583 Metetra
.673 .745 .904 r
.1231 .29583 .1306 .30029 .14112 .29766 .13363 .29322 Metetra
.686 .75 .9 r
.13363 .29322 .14112 .29766 .15173 .29475 .14425 .29038 Metetra
.697 .756 .897 r
.14425 .29038 .15173 .29475 .16242 .29158 .15495 .28732 Metetra
.708 .764 .896 r
.15495 .28732 .16242 .29158 .17319 .28815 .16571 .28403 Metetra
.72 .774 .895 r
.16571 .28403 .17319 .28815 .18403 .28445 .17655 .28052 Metetra
.732 .786 .896 r
.17655 .28052 .18403 .28445 .19494 .28048 .18745 .27678 Metetra
.744 .8 .897 r
.18745 .27678 .19494 .28048 .20592 .27623 .19842 .2728 Metetra
.758 .815 .898 r
.19842 .2728 .20592 .27623 .21697 .27168 .20946 .26856 Metetra
.772 .832 .899 r
.20946 .26856 .21697 .27168 .22808 .26682 .22056 .26405 Metetra
.786 .851 .9 r
.22056 .26405 .22808 .26682 .23926 .26164 .23172 .25925 Metetra
.8 .871 .9 r
.23172 .25925 .23926 .26164 .25049 .25614 .24294 .25418 Metetra
.813 .893 .9 r
.24294 .25418 .25049 .25614 .26178 .25033 .25421 .24882 Metetra
.824 .915 .899 r
.25421 .24882 .26178 .25033 .27311 .24422 .26553 .24319 Metetra
.833 .937 .896 r
.26553 .24319 .27311 .24422 .28447 .23784 .27689 .23732 Metetra
.836 .958 .89 r
.27689 .23732 .28447 .23784 .29586 .23125 .28827 .23127 Metetra
.832 .978 .882 r
.28827 .23127 .29586 .23125 .30726 .22453 .29968 .22509 Metetra
.816 .993 .868 r
.29968 .22509 .30726 .22453 .31866 .21778 .31109 .21889 Metetra
.783 .998 .845 r
.31109 .21889 .31866 .21778 .33005 .21113 .32249 .21278 Metetra
.723 .987 .809 r
.32249 .21278 .33005 .21113 .34141 .20475 .33388 .20691 Metetra
.629 .949 .752 r
.33388 .20691 .34141 .20475 .35273 .19881 .34523 .20144 Metetra
.496 .874 .671 r
.34523 .20144 .35273 .19881 .364 .19352 .35655 .19652 Metetra
.35655 .19652 .364 .19352 .37522 .18905 .36783 .19232 Metetra
.36783 .19232 .37522 .18905 .3864 .18554 .37907 .18895 Metetra
.37907 .18895 .3864 .18554 .39754 .18309 .39028 .18649 Metetra
.122 0 0 r
.39028 .18649 .39754 .18309 .40866 .18168 .40148 .18492 Metetra
.217 0 0 r
.40148 .18492 .40866 .18168 .41978 .18126 .41269 .1842 Metetra
.282 0 0 r
.41269 .1842 .41978 .18126 .43094 .18166 .42393 .1842 Metetra
.322 0 0 r
.42393 .1842 .43094 .18166 .44214 .18272 .43521 .18477 Metetra
.338 0 0 r
.43521 .18477 .44214 .18272 .45342 .18425 .44657 .18575 Metetra
.333 0 0 r
.44657 .18575 .45342 .18425 .46479 .18605 .45801 .18698 Metetra
.304 0 0 r
.45801 .18698 .46479 .18605 .47625 .18798 .46954 .18832 Metetra
.25 0 0 r
.46954 .18832 .47625 .18798 .48782 .18989 .48117 .18964 Metetra
.17 0 0 r
.48117 .18964 .48782 .18989 .49949 .19167 .49289 .19086 Metetra
0 .513 .738 r
.49289 .19086 .49949 .19167 .51127 .19326 .50472 .19189 Metetra
.045 .59 .84 r
.50472 .19189 .51127 .19326 .52315 .19459 .51664 .1927 Metetra
.158 .652 .916 r
.51664 .1927 .52315 .19459 .53512 .19563 .52865 .19324 Metetra
.26 .695 .963 r
.52865 .19324 .53512 .19563 .54719 .19636 .54076 .1935 Metetra
.344 .72 .985 r
.54076 .1935 .54719 .19636 .55935 .19677 .55294 .19348 Metetra
.411 .732 .991 r
.55294 .19348 .55935 .19677 .57159 .19686 .56521 .19318 Metetra
.463 .736 .987 r
.56521 .19318 .57159 .19686 .58391 .19664 .57756 .1926 Metetra
.502 .735 .977 r
.57756 .1926 .58391 .19664 .5963 .19613 .58998 .19177 Metetra
.533 .733 .967 r
.58998 .19177 .5963 .19613 .60877 .19532 .60247 .19069 Metetra
.557 .73 .956 r
.60247 .19069 .60877 .19532 .6213 .19424 .61502 .18937 Metetra
.577 .728 .946 r
.61502 .18937 .6213 .19424 .63389 .19289 .62763 .18783 Metetra
.594 .727 .937 r
.62763 .18783 .63389 .19289 .64653 .19126 .6403 .18605 Metetra
.609 .727 .929 r
.6403 .18605 .64653 .19126 .65923 .18936 .65303 .18405 Metetra
.624 .73 .923 r
.65303 .18405 .65923 .18936 .67197 .18718 .66581 .1818 Metetra
.639 .734 .918 r
.66581 .1818 .67197 .18718 .68476 .18469 .67863 .17928 Metetra
.655 .741 .913 r
.67863 .17928 .68476 .18469 .69757 .18186 .69148 .17647 Metetra
.672 .749 .909 r
.69148 .17647 .69757 .18186 .71041 .17867 .70436 .17332 Metetra
.691 .76 .905 r
.70436 .17332 .71041 .17867 .72325 .17506 .71726 .16979 Metetra
.712 .773 .9 r
.71726 .16979 .72325 .17506 .7361 .17097 .73016 .16581 Metetra
.735 .787 .894 r
.73016 .16581 .7361 .17097 .74892 .16635 .74304 .16131 Metetra
.514 .718 .965 r
.05436 .30094 .06213 .30489 .07195 .30439 .06423 .30027 Metetra
.565 .728 .951 r
.06423 .30027 .07195 .30439 .08193 .30342 .07426 .29914 Metetra
.601 .732 .937 r
.07426 .29914 .08193 .30342 .09205 .30202 .08442 .29762 Metetra
.626 .734 .925 r
.08442 .29762 .09205 .30202 .1023 .30026 .0947 .29577 Metetra
.645 .735 .915 r
.0947 .29577 .1023 .30026 .11265 .29819 .10508 .29363 Metetra
.659 .737 .908 r
.10508 .29363 .11265 .29819 .1231 .29583 .11556 .29125 Metetra
.671 .74 .902 r
.11556 .29125 .1231 .29583 .13363 .29322 .12611 .28866 Metetra
.681 .744 .899 r
.12611 .28866 .13363 .29322 .14425 .29038 .13674 .28588 Metetra
.69 .75 .897 r
.13674 .28588 .14425 .29038 .15495 .28732 .14743 .28292 Metetra
.7 .758 .897 r
.14743 .28292 .15495 .28732 .16571 .28403 .1582 .27978 Metetra
.709 .768 .898 r
.1582 .27978 .16571 .28403 .17655 .28052 .16903 .27647 Metetra
.719 .78 .9 r
.16903 .27647 .17655 .28052 .18745 .27678 .17992 .27296 Metetra
.73 .794 .903 r
.17992 .27296 .18745 .27678 .19842 .2728 .19087 .26926 Metetra
.742 .81 .905 r
.19087 .26926 .19842 .2728 .20946 .26856 .20189 .26533 Metetra
.755 .828 .908 r
.20189 .26533 .20946 .26856 .22056 .26405 .21298 .26118 Metetra
.768 .848 .911 r
.21298 .26118 .22056 .26405 .23172 .25925 .22412 .25678 Metetra
.781 .869 .913 r
.22412 .25678 .23172 .25925 .24294 .25418 .23532 .25213 Metetra
.793 .892 .915 r
.23532 .25213 .24294 .25418 .25421 .24882 .24658 .24723 Metetra
.804 .915 .915 r
.24658 .24723 .25421 .24882 .26553 .24319 .25788 .24209 Metetra
.811 .938 .912 r
.25788 .24209 .26553 .24319 .27689 .23732 .26923 .23673 Metetra
.812 .96 .907 r
.26923 .23673 .27689 .23732 .28827 .23127 .28061 .2312 Metetra
.806 .979 .898 r
.28061 .2312 .28827 .23127 .29968 .22509 .29201 .22556 Metetra
.787 .992 .883 r
.29201 .22556 .29968 .22509 .31109 .21889 .30343 .21989 Metetra
.75 .994 .858 r
.30343 .21989 .31109 .21889 .32249 .21278 .31485 .2143 Metetra
.688 .979 .819 r
.31485 .2143 .32249 .21278 .33388 .20691 .32626 .20891 Metetra
.596 .939 .762 r
.32626 .20891 .33388 .20691 .34523 .20144 .33764 .20387 Metetra
.473 .868 .685 r
.33764 .20387 .34523 .20144 .35655 .19652 .34901 .1993 Metetra
.34901 .1993 .35655 .19652 .36783 .19232 .36034 .19535 Metetra
.36034 .19535 .36783 .19232 .37907 .18895 .37164 .1921 Metetra
.37164 .1921 .37907 .18895 .39028 .18649 .38292 .18962 Metetra
.074 0 0 r
.38292 .18962 .39028 .18649 .40148 .18492 .3942 .18791 Metetra
.16 0 0 r
.3942 .18791 .40148 .18492 .41269 .1842 .4055 .18691 Metetra
.219 0 0 r
.4055 .18691 .41269 .1842 .42393 .1842 .41682 .18653 Metetra
.253 0 0 r
.41682 .18653 .42393 .1842 .43521 .18477 .42819 .18664 Metetra
.264 0 0 r
.42819 .18664 .43521 .18477 .44657 .18575 .43963 .18711 Metetra
.252 0 0 r
.43963 .18711 .44657 .18575 .45801 .18698 .45114 .18779 Metetra
.215 0 0 r
.45114 .18779 .45801 .18698 .46954 .18832 .46274 .18855 Metetra
.153 0 0 r
.46274 .18855 .46954 .18832 .48117 .18964 .47443 .18931 Metetra
.068 0 0 r
.47443 .18931 .48117 .18964 .49289 .19086 .48621 .18996 Metetra
.035 .596 .803 r
.48621 .18996 .49289 .19086 .50472 .19189 .49809 .19045 Metetra
.144 .661 .89 r
.49809 .19045 .50472 .19189 .51664 .1927 .51006 .19072 Metetra
.246 .708 .949 r
.51006 .19072 .51664 .1927 .52865 .19324 .52211 .19076 Metetra
.335 .737 .982 r
.52211 .19076 .52865 .19324 .54076 .1935 .53425 .19055 Metetra
.406 .75 .994 r
.53425 .19055 .54076 .1935 .55294 .19348 .54648 .19009 Metetra
.46 .753 .993 r
.54648 .19009 .55294 .19348 .56521 .19318 .55878 .18938 Metetra
.502 .75 .984 r
.55878 .18938 .56521 .19318 .57756 .1926 .57115 .18844 Metetra
.533 .745 .973 r
.57115 .18844 .57756 .1926 .58998 .19177 .58359 .18729 Metetra
.557 .739 .961 r
.58359 .18729 .58998 .19177 .60247 .19069 .59611 .18592 Metetra
.575 .733 .95 r
.59611 .18592 .60247 .19069 .61502 .18937 .60868 .18437 Metetra
.59 .729 .94 r
.60868 .18437 .61502 .18937 .62763 .18783 .62132 .18262 Metetra
.603 .726 .931 r
.62132 .18262 .62763 .18783 .6403 .18605 .63402 .1807 Metetra
.615 .725 .924 r
.63402 .1807 .6403 .18605 .65303 .18405 .64678 .17859 Metetra
.626 .726 .919 r
.64678 .17859 .65303 .18405 .66581 .1818 .65959 .17628 Metetra
.639 .73 .914 r
.65959 .17628 .66581 .1818 .67863 .17928 .67244 .17375 Metetra
.652 .736 .911 r
.67244 .17375 .67863 .17928 .69148 .17647 .68534 .17096 Metetra
.667 .744 .908 r
.68534 .17096 .69148 .17647 .70436 .17332 .69826 .16787 Metetra
.685 .755 .905 r
.69826 .16787 .70436 .17332 .71726 .16979 .71121 .16443 Metetra
.705 .768 .901 r
.71121 .16443 .71726 .16979 .73016 .16581 .72417 .16057 Metetra
.728 .783 .897 r
.72417 .16057 .73016 .16581 .74304 .16131 .73712 .15621 Metetra
.534 .725 .961 r
.04653 .29695 .05436 .30094 .06423 .30027 .05646 .29609 Metetra
.58 .731 .946 r
.05646 .29609 .06423 .30027 .07426 .29914 .06654 .29478 Metetra
.611 .732 .932 r
.06654 .29478 .07426 .29914 .08442 .29762 .07675 .29312 Metetra
.633 .733 .92 r
.07675 .29312 .08442 .29762 .0947 .29577 .08707 .29116 Metetra
.648 .732 .911 r
.08707 .29116 .0947 .29577 .10508 .29363 .09749 .28895 Metetra
.66 .733 .904 r
.09749 .28895 .10508 .29363 .11556 .29125 .10798 .28654 Metetra
.669 .735 .9 r
.10798 .28654 .11556 .29125 .12611 .28866 .11855 .28396 Metetra
.676 .738 .897 r
.11855 .28396 .12611 .28866 .13674 .28588 .12919 .28124 Metetra
.683 .744 .897 r
.12919 .28124 .13674 .28588 .14743 .28292 .13989 .27839 Metetra
.69 .751 .898 r
.13989 .27839 .14743 .28292 .1582 .27978 .15064 .2754 Metetra
.698 .761 .9 r
.15064 .2754 .1582 .27978 .16903 .27647 .16146 .27228 Metetra
.706 .772 .904 r
.16146 .27228 .16903 .27647 .17992 .27296 .17234 .26902 Metetra
.715 .787 .908 r
.17234 .26902 .17992 .27296 .19087 .26926 .18328 .2656 Metetra
.725 .803 .913 r
.18328 .2656 .19087 .26926 .20189 .26533 .19428 .262 Metetra
.737 .822 .918 r
.19428 .262 .20189 .26533 .21298 .26118 .20534 .25821 Metetra
.748 .843 .922 r
.20534 .25821 .21298 .26118 .22412 .25678 .21645 .25421 Metetra
.76 .866 .926 r
.21645 .25421 .22412 .25678 .23532 .25213 .22763 .24999 Metetra
.771 .889 .929 r
.22763 .24999 .23532 .25213 .24658 .24723 .23887 .24555 Metetra
.78 .914 .93 r
.23887 .24555 .24658 .24723 .25788 .24209 .25016 .2409 Metetra
.785 .937 .929 r
.25016 .2409 .25788 .24209 .26923 .23673 .26149 .23605 Metetra
.784 .959 .924 r
.26149 .23605 .26923 .23673 .28061 .2312 .27286 .23103 Metetra
.775 .977 .914 r
.27286 .23103 .28061 .2312 .29201 .22556 .28427 .22592 Metetra
.753 .987 .897 r
.28427 .22592 .29201 .22556 .30343 .21989 .29569 .22077 Metetra
.713 .987 .87 r
.29569 .22077 .30343 .21989 .31485 .2143 .30712 .21568 Metetra
.651 .968 .829 r
.30712 .21568 .31485 .2143 .32626 .20891 .31855 .21075 Metetra
.563 .927 .771 r
.31855 .21075 .32626 .20891 .33764 .20387 .32997 .20611 Metetra
.451 .861 .698 r
.32997 .20611 .33764 .20387 .34901 .1993 .34137 .20187 Metetra
.34137 .20187 .34901 .1993 .36034 .19535 .35275 .19814 Metetra
.35275 .19814 .36034 .19535 .37164 .1921 .36412 .19501 Metetra
.36412 .19501 .37164 .1921 .38292 .18962 .37548 .19252 Metetra
.027 0 0 r
.37548 .19252 .38292 .18962 .3942 .18791 .38684 .19067 Metetra
.102 0 0 r
.38684 .19067 .3942 .18791 .4055 .18691 .39821 .18941 Metetra
.152 0 0 r
.39821 .18941 .4055 .18691 .41682 .18653 .40962 .18868 Metetra
.179 0 0 r
.40962 .18868 .41682 .18653 .42819 .18664 .42107 .18835 Metetra
.183 0 0 r
.42107 .18835 .42819 .18664 .43963 .18711 .43259 .18833 Metetra
.162 0 0 r
.43259 .18833 .43963 .18711 .45114 .18779 .44418 .18847 Metetra
.118 0 0 r
.44418 .18847 .45114 .18779 .46274 .18855 .45585 .18869 Metetra
.049 0 0 r
.45585 .18869 .46274 .18855 .47443 .18931 .46761 .18888 Metetra
.04 .607 .768 r
.46761 .18888 .47443 .18931 .48621 .18996 .47945 .18897 Metetra
.141 .673 .861 r
.47945 .18897 .48621 .18996 .49809 .19045 .49138 .18891 Metetra
.242 .724 .931 r
.49138 .18891 .49809 .19045 .51006 .19072 .5034 .18865 Metetra
.332 .757 .974 r
.5034 .18865 .51006 .19072 .52211 .19076 .5155 .18818 Metetra
.406 .772 .994 r
.5155 .18818 .52211 .19076 .53425 .19055 .52769 .18749 Metetra
.463 .775 .997 r
.52769 .18749 .53425 .19055 .54648 .19009 .53994 .18659 Metetra
.506 .77 .991 r
.53994 .18659 .54648 .19009 .55878 .18938 .55228 .18547 Metetra
.538 .762 .98 r
.55228 .18547 .55878 .18938 .57115 .18844 .56468 .18416 Metetra
.562 .753 .967 r
.56468 .18416 .57115 .18844 .58359 .18729 .57715 .18266 Metetra
.579 .744 .955 r
.57715 .18266 .58359 .18729 .59611 .18592 .58969 .18101 Metetra
.593 .736 .943 r
.58969 .18101 .59611 .18592 .60868 .18437 .60229 .17921 Metetra
.603 .729 .934 r
.60229 .17921 .60868 .18437 .62132 .18262 .61496 .17727 Metetra
.612 .725 .926 r
.61496 .17727 .62132 .18262 .63402 .1807 .62768 .1752 Metetra
.62 .722 .919 r
.62768 .1752 .63402 .1807 .64678 .17859 .64047 .17298 Metetra
.629 .722 .915 r
.64047 .17298 .64678 .17859 .65959 .17628 .65331 .17062 Metetra
.638 .725 .911 r
.65331 .17062 .65959 .17628 .67244 .17375 .6662 .16807 Metetra
.649 .73 .908 r
.6662 .16807 .67244 .17375 .68534 .17096 .67914 .16532 Metetra
.662 .738 .907 r
.67914 .16532 .68534 .17096 .69826 .16787 .69211 .1623 Metetra
.678 .749 .905 r
.69211 .1623 .69826 .16787 .71121 .16443 .70511 .15897 Metetra
.697 .763 .903 r
.70511 .15897 .71121 .16443 .72417 .16057 .71813 .15525 Metetra
.719 .778 .899 r
.71813 .15525 .72417 .16057 .73712 .15621 .73114 .15106 Metetra
.556 .732 .957 r
.03865 .29292 .04653 .29695 .05646 .29609 .04864 .29183 Metetra
.596 .734 .94 r
.04864 .29183 .05646 .29609 .06654 .29478 .05878 .29034 Metetra
.622 .733 .926 r
.05878 .29034 .06654 .29478 .07675 .29312 .06904 .28851 Metetra
.64 .731 .914 r
.06904 .28851 .07675 .29312 .08707 .29116 .07941 .28642 Metetra
.652 .729 .906 r
.07941 .28642 .08707 .29116 .09749 .28895 .08986 .28413 Metetra
.66 .729 .9 r
.08986 .28413 .09749 .28895 .10798 .28654 .10038 .28168 Metetra
.666 .729 .897 r
.10038 .28168 .10798 .28654 .11855 .28396 .11096 .27912 Metetra
.671 .732 .895 r
.11096 .27912 .11855 .28396 .12919 .28124 .12161 .27645 Metetra
.676 .737 .896 r
.12161 .27645 .12919 .28124 .13989 .27839 .13231 .2737 Metetra
.68 .743 .898 r
.13231 .2737 .13989 .27839 .15064 .2754 .14306 .27087 Metetra
.686 .752 .902 r
.14306 .27087 .15064 .2754 .16146 .27228 .15386 .26795 Metetra
.692 .764 .907 r
.15386 .26795 .16146 .27228 .17234 .26902 .16472 .26494 Metetra
.699 .778 .913 r
.16472 .26494 .17234 .26902 .18328 .2656 .17564 .2618 Metetra
.707 .795 .92 r
.17564 .2618 .18328 .2656 .19428 .262 .18661 .25854 Metetra
.716 .815 .926 r
.18661 .25854 .19428 .262 .20534 .25821 .19764 .25512 Metetra
.726 .836 .933 r
.19764 .25512 .20534 .25821 .21645 .25421 .20873 .25153 Metetra
.736 .86 .939 r
.20873 .25153 .21645 .25421 .22763 .24999 .21988 .24775 Metetra
.745 .885 .943 r
.21988 .24775 .22763 .24999 .23887 .24555 .23109 .24378 Metetra
.752 .91 .946 r
.23109 .24378 .23887 .24555 .25016 .2409 .24236 .23961 Metetra
.755 .934 .945 r
.24236 .23961 .25016 .2409 .26149 .23605 .25368 .23527 Metetra
.752 .955 .94 r
.25368 .23527 .26149 .23605 .27286 .23103 .26504 .23077 Metetra
.74 .972 .929 r
.26504 .23077 .27286 .23103 .28427 .22592 .27643 .22617 Metetra
.715 .98 .909 r
.27643 .22617 .28427 .22592 .29569 .22077 .28785 .22153 Metetra
.674 .976 .879 r
.28785 .22153 .29569 .22077 .30712 .21568 .2993 .21691 Metetra
.612 .955 .836 r
.2993 .21691 .30712 .21568 .31855 .21075 .31074 .21243 Metetra
.53 .914 .779 r
.31074 .21243 .31855 .21075 .32997 .20611 .32219 .20817 Metetra
.428 .853 .71 r
.32219 .20817 .32997 .20611 .34137 .20187 .33364 .20424 Metetra
.317 .775 .634 r
.33364 .20424 .34137 .20187 .35275 .19814 .34507 .20072 Metetra
.34507 .20072 .35275 .19814 .36412 .19501 .3565 .19769 Metetra
.3565 .19769 .36412 .19501 .37548 .19252 .36793 .19519 Metetra
.36793 .19519 .37548 .19252 .38684 .19067 .37937 .1932 Metetra
.043 0 0 r
.37937 .1932 .38684 .19067 .39821 .18941 .39083 .19171 Metetra
.083 0 0 r
.39083 .19171 .39821 .18941 .40962 .18868 .40232 .19064 Metetra
.101 0 0 r
.40232 .19064 .40962 .18868 .42107 .18835 .41386 .1899 Metetra
.096 0 0 r
.41386 .1899 .42107 .18835 .43259 .18833 .42546 .1894 Metetra
.066 0 0 r
.42546 .1894 .43259 .18833 .44418 .18847 .43713 .18903 Metetra
.014 0 0 r
.43713 .18903 .44418 .18847 .45585 .18869 .44888 .18871 Metetra
.061 .626 .739 r
.44888 .18871 .45585 .18869 .46761 .18888 .46071 .18834 Metetra
.151 .689 .831 r
.46071 .18834 .46761 .18888 .47945 .18897 .47262 .18788 Metetra
.246 .742 .908 r
.47262 .18788 .47945 .18897 .49138 .18891 .48461 .18726 Metetra
.335 .778 .961 r
.48461 .18726 .49138 .18891 .5034 .18865 .49668 .18647 Metetra
.411 .797 .99 r
.49668 .18647 .5034 .18865 .5155 .18818 .50883 .18549 Metetra
.471 .8 .999 r
.50883 .18549 .5155 .18818 .52769 .18749 .52105 .18432 Metetra
.516 .795 .996 r
.52105 .18432 .52769 .18749 .53994 .18659 .53335 .18295 Metetra
.549 .784 .986 r
.53335 .18295 .53994 .18659 .55228 .18547 .54572 .18142 Metetra
.572 .772 .973 r
.54572 .18142 .55228 .18547 .56468 .18416 .55815 .17972 Metetra
.589 .759 .96 r
.55815 .17972 .56468 .18416 .57715 .18266 .57065 .17789 Metetra
.601 .747 .947 r
.57065 .17789 .57715 .18266 .58969 .18101 .58322 .17594 Metetra
.609 .737 .936 r
.58322 .17594 .58969 .18101 .60229 .17921 .59584 .17389 Metetra
.615 .729 .927 r
.59584 .17389 .60229 .17921 .61496 .17727 .60854 .17175 Metetra
.62 .723 .92 r
.60854 .17175 .61496 .17727 .62768 .1752 .62129 .16953 Metetra
.625 .719 .914 r
.62129 .16953 .62768 .1752 .64047 .17298 .6341 .16721 Metetra
.63 .718 .91 r
.6341 .16721 .64047 .17298 .65331 .17062 .64697 .16479 Metetra
.637 .719 .907 r
.64697 .16479 .65331 .17062 .6662 .16807 .6599 .16225 Metetra
.645 .724 .906 r
.6599 .16225 .6662 .16807 .67914 .16532 .67288 .15954 Metetra
.656 .731 .905 r
.67288 .15954 .67914 .16532 .69211 .1623 .6859 .15661 Metetra
.67 .742 .905 r
.6859 .15661 .69211 .1623 .70511 .15897 .69895 .1534 Metetra
.687 .756 .904 r
.69895 .1534 .70511 .15897 .71813 .15525 .71203 .14985 Metetra
.709 .773 .902 r
.71203 .14985 .71813 .15525 .73114 .15106 .72511 .14585 Metetra
.579 .738 .951 r
.03071 .28883 .03865 .29292 .04864 .29183 .04078 .2875 Metetra
.613 .737 .934 r
.04078 .2875 .04864 .29183 .05878 .29034 .05098 .28579 Metetra
.634 .733 .919 r
.05098 .28579 .05878 .29034 .06904 .28851 .0613 .28378 Metetra
.648 .729 .908 r
.0613 .28378 .06904 .28851 .07941 .28642 .07171 .28155 Metetra
.656 .726 .9 r
.07171 .28155 .07941 .28642 .08986 .28413 .0822 .27917 Metetra
.661 .724 .895 r
.0822 .27917 .08986 .28413 .10038 .28168 .09275 .27667 Metetra
.665 .724 .893 r
.09275 .27667 .10038 .28168 .11096 .27912 .10335 .27411 Metetra
.667 .725 .893 r
.10335 .27411 .11096 .27912 .12161 .27645 .114 .2715 Metetra
.668 .729 .895 r
.114 .2715 .12161 .27645 .13231 .2737 .1247 .26886 Metetra
.67 .735 .898 r
.1247 .26886 .13231 .2737 .14306 .27087 .13544 .26618 Metetra
.673 .743 .904 r
.13544 .26618 .14306 .27087 .15386 .26795 .14623 .26347 Metetra
.676 .755 .91 r
.14623 .26347 .15386 .26795 .16472 .26494 .15706 .2607 Metetra
.68 .769 .918 r
.15706 .2607 .16472 .26494 .17564 .2618 .16795 .25787 Metetra
.686 .786 .926 r
.16795 .25787 .17564 .2618 .18661 .25854 .17889 .25494 Metetra
.693 .805 .935 r
.17889 .25494 .18661 .25854 .19764 .25512 .18989 .2519 Metetra
.7 .827 .943 r
.18989 .2519 .19764 .25512 .20873 .25153 .20095 .24873 Metetra
.708 .852 .951 r
.20095 .24873 .20873 .25153 .21988 .24775 .21207 .24539 Metetra
.715 .877 .957 r
.21207 .24539 .21988 .24775 .23109 .24378 .22325 .24189 Metetra
.72 .903 .96 r
.22325 .24189 .23109 .24378 .24236 .23961 .23449 .23822 Metetra
.721 .927 .96 r
.23449 .23822 .24236 .23961 .25368 .23527 .24578 .23438 Metetra
.715 .948 .954 r
.24578 .23438 .25368 .23527 .26504 .23077 .25713 .2304 Metetra
.701 .963 .941 r
.25713 .2304 .26504 .23077 .27643 .22617 .26851 .22631 Metetra
.674 .969 .92 r
.26851 .22631 .27643 .22617 .28785 .22153 .27994 .22216 Metetra
.631 .962 .887 r
.27994 .22216 .28785 .22153 .2993 .21691 .29138 .21801 Metetra
.572 .94 .842 r
.29138 .21801 .2993 .21691 .31074 .21243 .30285 .21395 Metetra
.496 .9 .786 r
.30285 .21395 .31074 .21243 .32219 .20817 .31433 .21006 Metetra
.406 .844 .721 r
.31433 .21006 .32219 .20817 .33364 .20424 .32581 .20642 Metetra
.311 .777 .653 r
.32581 .20642 .33364 .20424 .34507 .20072 .3373 .2031 Metetra
.3373 .2031 .34507 .20072 .3565 .19769 .34879 .20017 Metetra
.34879 .20017 .3565 .19769 .36793 .19519 .36029 .19765 Metetra
.36029 .19765 .36793 .19519 .37937 .1932 .37181 .19554 Metetra
.37181 .19554 .37937 .1932 .39083 .19171 .38335 .19382 Metetra
.012 0 0 r
.38335 .19382 .39083 .19171 .40232 .19064 .39493 .19243 Metetra
.02 0 0 r
.39493 .19243 .40232 .19064 .41386 .1899 .40656 .1913 Metetra
.004 0 0 r
.40656 .1913 .41386 .1899 .42546 .1894 .41825 .19034 Metetra
.41825 .19034 .42546 .1894 .43713 .18903 .43 .18946 Metetra
.094 .65 .717 r
.43 .18946 .43713 .18903 .44888 .18871 .44182 .1886 Metetra
.172 .708 .804 r
.44182 .1886 .44888 .18871 .46071 .18834 .45372 .18769 Metetra
.259 .761 .883 r
.45372 .18769 .46071 .18834 .47262 .18788 .4657 .18667 Metetra
.345 .801 .944 r
.4657 .18667 .47262 .18788 .48461 .18726 .47775 .18551 Metetra
.422 .822 .981 r
.47775 .18551 .48461 .18726 .49668 .18647 .48988 .18418 Metetra
.484 .828 .998 r
.48988 .18418 .49668 .18647 .50883 .18549 .50208 .18268 Metetra
.531 .822 .999 r
.50208 .18268 .50883 .18549 .52105 .18432 .51435 .18101 Metetra
.564 .81 .991 r
.51435 .18101 .52105 .18432 .53335 .18295 .52669 .17918 Metetra
.588 .795 .978 r
.52669 .17918 .53335 .18295 .54572 .18142 .53909 .17722 Metetra
.604 .779 .964 r
.53909 .17722 .54572 .18142 .55815 .17972 .55156 .17513 Metetra
.614 .763 .951 r
.55156 .17513 .55815 .17972 .57065 .17789 .56409 .17295 Metetra
.62 .749 .939 r
.56409 .17295 .57065 .17789 .58322 .17594 .57669 .1707 Metetra
.624 .737 .928 r
.57669 .1707 .58322 .17594 .59584 .17389 .58934 .1684 Metetra
.626 .727 .92 r
.58934 .1684 .59584 .17389 .60854 .17175 .60206 .16606 Metetra
.628 .72 .913 r
.60206 .16606 .60854 .17175 .62129 .16953 .61484 .16368 Metetra
.629 .715 .908 r
.61484 .16368 .62129 .16953 .6341 .16721 .62768 .16127 Metetra
.631 .712 .905 r
.62768 .16127 .6341 .16721 .64697 .16479 .64058 .1588 Metetra
.635 .713 .903 r
.64058 .1588 .64697 .16479 .6599 .16225 .65354 .15626 Metetra
.64 .717 .903 r
.65354 .15626 .6599 .16225 .67288 .15954 .66656 .1536 Metetra
.649 .724 .904 r
.66656 .1536 .67288 .15954 .6859 .15661 .67963 .15078 Metetra
.66 .734 .905 r
.67963 .15078 .6859 .15661 .69895 .1534 .69274 .14772 Metetra
.676 .749 .905 r
.69274 .14772 .69895 .1534 .71203 .14985 .70588 .14435 Metetra
.697 .766 .905 r
.70588 .14435 .71203 .14985 .72511 .14585 .71903 .14057 Metetra
.602 .744 .944 r
.02272 .28469 .03071 .28883 .04078 .2875 .03287 .28309 Metetra
.63 .739 .926 r
.03287 .28309 .04078 .2875 .05098 .28579 .04315 .28113 Metetra
.646 .733 .912 r
.04315 .28113 .05098 .28579 .0613 .28378 .05353 .27892 Metetra
.656 .727 .902 r
.05353 .27892 .0613 .28378 .07171 .28155 .06399 .27654 Metetra
.661 .722 .894 r
.06399 .27654 .07171 .28155 .0822 .27917 .07451 .27405 Metetra
.663 .719 .89 r
.07451 .27405 .0822 .27917 .09275 .27667 .08509 .2715 Metetra
.663 .717 .889 r
.08509 .2715 .09275 .27667 .10335 .27411 .09571 .26893 Metetra
.662 .718 .89 r
.09571 .26893 .10335 .27411 .114 .2715 .10637 .26637 Metetra
.661 .72 .893 r
.10637 .26637 .114 .2715 .1247 .26886 .11706 .26383 Metetra
.66 .726 .898 r
.11706 .26383 .1247 .26886 .13544 .26618 .12779 .26131 Metetra
.659 .733 .904 r
.12779 .26131 .13544 .26618 .14623 .26347 .13856 .25881 Metetra
.659 .744 .912 r
.13856 .25881 .14623 .26347 .15706 .2607 .14937 .2563 Metetra
.661 .757 .922 r
.14937 .2563 .15706 .2607 .16795 .25787 .16023 .25377 Metetra
.663 .774 .932 r
.16023 .25377 .16795 .25787 .17889 .25494 .17113 .2512 Metetra
.667 .794 .942 r
.17113 .2512 .17889 .25494 .18989 .2519 .1821 .24854 Metetra
.672 .816 .952 r
.1821 .24854 .18989 .2519 .20095 .24873 .19312 .24579 Metetra
.677 .841 .962 r
.19312 .24579 .20095 .24873 .21207 .24539 .2042 .24291 Metetra
.681 .866 .969 r
.2042 .24291 .21207 .24539 .22325 .24189 .21534 .23989 Metetra
.683 .892 .974 r
.21534 .23989 .22325 .24189 .23449 .23822 .22655 .23671 Metetra
.681 .917 .973 r
.22655 .23671 .23449 .23822 .24578 .23438 .23782 .23338 Metetra
.673 .937 .967 r
.23782 .23338 .24578 .23438 .25713 .2304 .24914 .22991 Metetra
.656 .95 .952 r
.24914 .22991 .25713 .2304 .26851 .22631 .26051 .22633 Metetra
.627 .954 .928 r
.26051 .22633 .26851 .22631 .27994 .22216 .27193 .22266 Metetra
.585 .945 .892 r
.27193 .22266 .27994 .22216 .29138 .21801 .28338 .21898 Metetra
.529 .922 .846 r
.28338 .21898 .29138 .21801 .30285 .21395 .29487 .21533 Metetra
.461 .884 .791 r
.29487 .21533 .30285 .21395 .31433 .21006 .30637 .21179 Metetra
.384 .834 .73 r
.30637 .21179 .31433 .21006 .32581 .20642 .31789 .20842 Metetra
.304 .777 .67 r
.31789 .20842 .32581 .20642 .3373 .2031 .32943 .20529 Metetra
.32943 .20529 .3373 .2031 .34879 .20017 .34099 .20245 Metetra
.34099 .20245 .34879 .20017 .36029 .19765 .35256 .19991 Metetra
.35256 .19991 .36029 .19765 .37181 .19554 .36415 .19769 Metetra
.36415 .19769 .37181 .19554 .38335 .19382 .37578 .19575 Metetra
.37578 .19575 .38335 .19382 .39493 .19243 .38744 .19405 Metetra
.38744 .19405 .39493 .19243 .40656 .1913 .39916 .19253 Metetra
.39916 .19253 .40656 .1913 .41825 .19034 .41093 .19113 Metetra
.136 .679 .703 r
.41093 .19113 .41825 .19034 .43 .18946 .42277 .18976 Metetra
.202 .73 .781 r
.42277 .18976 .43 .18946 .44182 .1886 .43468 .18838 Metetra
.28 .781 .857 r
.43468 .18838 .44182 .1886 .45372 .18769 .44665 .18692 Metetra
.361 .822 .922 r
.44665 .18692 .45372 .18769 .4657 .18667 .4587 .18535 Metetra
.437 .847 .967 r
.4587 .18535 .4657 .18667 .47775 .18551 .47082 .18363 Metetra
.5 .856 .991 r
.47082 .18363 .47775 .18551 .48988 .18418 .48301 .18176 Metetra
.548 .851 .998 r
.48301 .18176 .48988 .18418 .50208 .18268 .49527 .17974 Metetra
.583 .838 .993 r
.49527 .17974 .50208 .18268 .51435 .18101 .50759 .17756 Metetra
.607 .821 .982 r
.50759 .17756 .51435 .18101 .52669 .17918 .51997 .17526 Metetra
.623 .802 .968 r
.51997 .17526 .52669 .17918 .53909 .17722 .53241 .17286 Metetra
.632 .783 .954 r
.53241 .17286 .53909 .17722 .55156 .17513 .54491 .17038 Metetra
.637 .766 .941 r
.54491 .17038 .55156 .17513 .56409 .17295 .55748 .16784 Metetra
.639 .75 .929 r
.55748 .16784 .56409 .17295 .57669 .1707 .5701 .16528 Metetra
.639 .737 .92 r
.5701 .16528 .57669 .1707 .58934 .1684 .58278 .16272 Metetra
.637 .725 .912 r
.58278 .16272 .58934 .1684 .60206 .16606 .59552 .16017 Metetra
.635 .716 .906 r
.59552 .16017 .60206 .16606 .61484 .16368 .60833 .15764 Metetra
.633 .71 .902 r
.60833 .15764 .61484 .16368 .62768 .16127 .6212 .15513 Metetra
.632 .707 .9 r
.6212 .15513 .62768 .16127 .64058 .1588 .63414 .15262 Metetra
.632 .706 .899 r
.63414 .15262 .64058 .1588 .65354 .15626 .64713 .1501 Metetra
.635 .709 .9 r
.64713 .1501 .65354 .15626 .66656 .1536 .66019 .14751 Metetra
.641 .715 .902 r
.66019 .14751 .66656 .1536 .67963 .15078 .67331 .14481 Metetra
.65 .726 .904 r
.67331 .14481 .67963 .15078 .69274 .14772 .68647 .14192 Metetra
.664 .74 .907 r
.68647 .14192 .69274 .14772 .70588 .14435 .69967 .13876 Metetra
.683 .758 .908 r
.69967 .13876 .70588 .14435 .71903 .14057 .71289 .13522 Metetra
.625 .749 .936 r
.01468 .28049 .02272 .28469 .03287 .28309 .02491 .27858 Metetra
.647 .741 .918 r
.02491 .27858 .03287 .28309 .04315 .28113 .03527 .27636 Metetra
.658 .732 .904 r
.03527 .27636 .04315 .28113 .05353 .27892 .04572 .27393 Metetra
.664 .725 .894 r
.04572 .27393 .05353 .27892 .06399 .27654 .05624 .27137 Metetra
.666 .718 .888 r
.05624 .27137 .06399 .27654 .07451 .27405 .06681 .26876 Metetra
.664 .714 .885 r
.06681 .26876 .07451 .27405 .08509 .2715 .07742 .26614 Metetra
.662 .711 .884 r
.07742 .26614 .08509 .2715 .09571 .26893 .08805 .26357 Metetra
.658 .71 .886 r
.08805 .26357 .09571 .26893 .10637 .26637 .09872 .26106 Metetra
.653 .712 .891 r
.09872 .26106 .10637 .26637 .11706 .26383 .10941 .25862 Metetra
.649 .716 .897 r
.10941 .25862 .11706 .26383 .12779 .26131 .12012 .25626 Metetra
.645 .722 .905 r
.12012 .25626 .12779 .26131 .13856 .25881 .13087 .25397 Metetra
.642 .732 .914 r
.13087 .25397 .13856 .25881 .14937 .2563 .14165 .25173 Metetra
.64 .745 .925 r
.14165 .25173 .14937 .2563 .16023 .25377 .15247 .24951 Metetra
.639 .761 .936 r
.15247 .24951 .16023 .25377 .17113 .2512 .16333 .24729 Metetra
.639 .78 .949 r
.16333 .24729 .17113 .2512 .1821 .24854 .17425 .24503 Metetra
.64 .802 .961 r
.17425 .24503 .1821 .24854 .19312 .24579 .18523 .24271 Metetra
.641 .826 .972 r
.18523 .24271 .19312 .24579 .2042 .24291 .19627 .24029 Metetra
.642 .852 .98 r
.19627 .24029 .2042 .24291 .21534 .23989 .20737 .23776 Metetra
.64 .878 .985 r
.20737 .23776 .21534 .23989 .22655 .23671 .21854 .23508 Metetra
.635 .901 .984 r
.21854 .23508 .22655 .23671 .23782 .23338 .22977 .23226 Metetra
.624 .92 .977 r
.22977 .23226 .23782 .23338 .24914 .22991 .24107 .22931 Metetra
.605 .932 .96 r
.24107 .22931 .24914 .22991 .26051 .22633 .25243 .22622 Metetra
.576 .934 .932 r
.25243 .22622 .26051 .22633 .27193 .22266 .26384 .22304 Metetra
.535 .923 .895 r
.26384 .22304 .27193 .22266 .28338 .21898 .27529 .2198 Metetra
.484 .9 .848 r
.27529 .2198 .28338 .21898 .29487 .21533 .28679 .21656 Metetra
.425 .866 .794 r
.28679 .21656 .29487 .21533 .30637 .21179 .29832 .21336 Metetra
.361 .823 .739 r
.29832 .21336 .30637 .21179 .31789 .20842 .30988 .21026 Metetra
.297 .777 .685 r
.30988 .21026 .31789 .20842 .32943 .20529 .32147 .20731 Metetra
.32147 .20731 .32943 .20529 .34099 .20245 .33308 .20455 Metetra
.33308 .20455 .34099 .20245 .35256 .19991 .34472 .202 Metetra
.34472 .202 .35256 .19991 .36415 .19769 .35639 .19966 Metetra
.35639 .19966 .36415 .19769 .37578 .19575 .3681 .19751 Metetra
.3681 .19751 .37578 .19575 .38744 .19405 .37986 .19552 Metetra
.37986 .19552 .38744 .19405 .39916 .19253 .39166 .19362 Metetra
.183 .709 .698 r
.39166 .19362 .39916 .19253 .41093 .19113 .40353 .19178 Metetra
.237 .753 .764 r
.40353 .19178 .41093 .19113 .42277 .18976 .41545 .18993 Metetra
.305 .799 .834 r
.41545 .18993 .42277 .18976 .43468 .18838 .42745 .18803 Metetra
.38 .84 .898 r
.42745 .18803 .43468 .18838 .44665 .18692 .4395 .18602 Metetra
.454 .869 .948 r
.4395 .18602 .44665 .18692 .4587 .18535 .45163 .18389 Metetra
.517 .882 .979 r
.45163 .18389 .4587 .18535 .47082 .18363 .46382 .18162 Metetra
.568 .88 .992 r
.46382 .18162 .47082 .18363 .48301 .18176 .47607 .1792 Metetra
.605 .867 .992 r
.47607 .1792 .48301 .18176 .49527 .17974 .48838 .17664 Metetra
.63 .849 .983 r
.48838 .17664 .49527 .17974 .50759 .17756 .50075 .17396 Metetra
.645 .828 .97 r
.50075 .17396 .50759 .17756 .51997 .17526 .51318 .17118 Metetra
.654 .806 .956 r
.51318 .17118 .51997 .17526 .53241 .17286 .52567 .16833 Metetra
.658 .786 .942 r
.52567 .16833 .53241 .17286 .54491 .17038 .53821 .16544 Metetra
.658 .767 .93 r
.53821 .16544 .54491 .17038 .55748 .16784 .5508 .16254 Metetra
.656 .75 .919 r
.5508 .16254 .55748 .16784 .5701 .16528 .56346 .15966 Metetra
.652 .735 .91 r
.56346 .15966 .5701 .16528 .58278 .16272 .57617 .15684 Metetra
.647 .723 .904 r
.57617 .15684 .58278 .16272 .59552 .16017 .58894 .15408 Metetra
.642 .713 .899 r
.58894 .15408 .59552 .16017 .60833 .15764 .60177 .1514 Metetra
.636 .705 .896 r
.60177 .1514 .60833 .15764 .6212 .15513 .61467 .14879 Metetra
.632 .7 .895 r
.61467 .14879 .6212 .15513 .63414 .15262 .62763 .14625 Metetra
.63 .699 .895 r
.62763 .14625 .63414 .15262 .64713 .1501 .64066 .14375 Metetra
.629 .7 .897 r
.64066 .14375 .64713 .1501 .66019 .14751 .65376 .14124 Metetra
.632 .706 .9 r
.65376 .14124 .66019 .14751 .67331 .14481 .66692 .13868 Metetra
.639 .716 .903 r
.66692 .13868 .67331 .14481 .68647 .14192 .68014 .13598 Metetra
.65 .73 .908 r
.68014 .13598 .68647 .14192 .69967 .13876 .6934 .13305 Metetra
.668 .749 .911 r
.6934 .13305 .69967 .13876 .71289 .13522 .70669 .1298 Metetra
.648 .753 .926 r
.00658 .27622 .01468 .28049 .02491 .27858 .01692 .27397 Metetra
.664 .742 .908 r
.01692 .27397 .02491 .27858 .03527 .27636 .02737 .27146 Metetra
.671 .731 .895 r
.02737 .27146 .03527 .27636 .04572 .27393 .03789 .26878 Metetra
.673 .722 .886 r
.03789 .26878 .04572 .27393 .05624 .27137 .04847 .26603 Metetra
.671 .714 .881 r
.04847 .26603 .05624 .27137 .06681 .26876 .05909 .26328 Metetra
.666 .708 .879 r
.05909 .26328 .06681 .26876 .07742 .26614 .06973 .26059 Metetra
.66 .704 .879 r
.06973 .26059 .07742 .26614 .08805 .26357 .08038 .258 Metetra
.653 .702 .882 r
.08038 .258 .08805 .26357 .09872 .26106 .09105 .25554 Metetra
.646 .702 .888 r
.09105 .25554 .09872 .26106 .10941 .25862 .10173 .2532 Metetra
.638 .705 .895 r
.10173 .2532 .10941 .25862 .12012 .25626 .11243 .25101 Metetra
.63 .71 .904 r
.11243 .25101 .12012 .25626 .13087 .25397 .12315 .24893 Metetra
.623 .718 .915 r
.12315 .24893 .13087 .25397 .14165 .25173 .13389 .24696 Metetra
.617 .73 .927 r
.13389 .24696 .14165 .25173 .15247 .24951 .14467 .24507 Metetra
.611 .745 .94 r
.14467 .24507 .15247 .24951 .16333 .24729 .15549 .24321 Metetra
.607 .763 .954 r
.15549 .24321 .16333 .24729 .17425 .24503 .16636 .24136 Metetra
.604 .784 .967 r
.16636 .24136 .17425 .24503 .18523 .24271 .17729 .23948 Metetra
.601 .808 .98 r
.17729 .23948 .18523 .24271 .19627 .24029 .18828 .23753 Metetra
.597 .833 .989 r
.18828 .23753 .19627 .24029 .20737 .23776 .19933 .23549 Metetra
.592 .858 .994 r
.19933 .23549 .20737 .23776 .21854 .23508 .21046 .23332 Metetra
.583 .881 .993 r
.21046 .23332 .21854 .23508 .22977 .23226 .22166 .23102 Metetra
.569 .898 .983 r
.22166 .23102 .22977 .23226 .24107 .22931 .23292 .22857 Metetra
.548 .908 .963 r
.23292 .22857 .24107 .22931 .25243 .22622 .24426 .22599 Metetra
.519 .908 .933 r
.24426 .22599 .25243 .22622 .26384 .22304 .25565 .22329 Metetra
.481 .897 .894 r
.25565 .22329 .26384 .22304 .27529 .2198 .26711 .22049 Metetra
.437 .876 .847 r
.26711 .22049 .27529 .2198 .28679 .21656 .27862 .21764 Metetra
.387 .846 .796 r
.27862 .21764 .28679 .21656 .29832 .21336 .29017 .21478 Metetra
.337 .811 .745 r
.29017 .21478 .29832 .21336 .30988 .21026 .30177 .21194 Metetra
.288 .774 .699 r
.30177 .21194 .30988 .21026 .32147 .20731 .3134 .20917 Metetra
.3134 .20917 .32147 .20731 .33308 .20455 .32507 .20649 Metetra
.32507 .20649 .33308 .20455 .34472 .202 .33678 .20392 Metetra
.33678 .20392 .34472 .202 .35639 .19966 .34853 .20147 Metetra
.34853 .20147 .35639 .19966 .3681 .19751 .36033 .19912 Metetra
.36033 .19912 .3681 .19751 .37986 .19552 .37217 .19683 Metetra
.227 .738 .699 r
.37217 .19683 .37986 .19552 .39166 .19362 .38407 .19457 Metetra
.273 .774 .752 r
.38407 .19457 .39166 .19362 .40353 .19178 .39603 .1923 Metetra
.333 .816 .813 r
.39603 .1923 .40353 .19178 .41545 .18993 .40805 .18997 Metetra
.401 .856 .874 r
.40805 .18997 .41545 .18993 .42745 .18803 .42013 .18754 Metetra
.471 .887 .926 r
.42013 .18754 .42745 .18803 .4395 .18602 .43227 .185 Metetra
.535 .903 .962 r
.43227 .185 .4395 .18602 .45163 .18389 .44447 .18231 Metetra
.588 .905 .982 r
.44447 .18231 .45163 .18389 .46382 .18162 .45673 .17948 Metetra
.627 .895 .987 r
.45673 .17948 .46382 .18162 .47607 .1792 .46905 .1765 Metetra
.653 .877 .982 r
.46905 .1765 .47607 .1792 .48838 .17664 .48143 .1734 Metetra
.67 .855 .97 r
.48143 .1734 .48838 .17664 .50075 .17396 .49386 .1702 Metetra
.679 .832 .957 r
.49386 .1702 .50075 .17396 .51318 .17118 .50634 .16692 Metetra
.682 .809 .943 r
.50634 .16692 .51318 .17118 .52567 .16833 .51887 .16361 Metetra
.681 .787 .93 r
.51887 .16361 .52567 .16833 .53821 .16544 .53144 .1603 Metetra
.677 .767 .918 r
.53144 .1603 .53821 .16544 .5508 .16254 .54407 .15703 Metetra
.671 .749 .909 r
.54407 .15703 .5508 .16254 .56346 .15966 .55676 .15384 Metetra
.664 .733 .901 r
.55676 .15384 .56346 .15966 .57617 .15684 .56949 .15074 Metetra
.656 .719 .895 r
.56949 .15074 .57617 .15684 .58894 .15408 .58229 .14777 Metetra
.648 .708 .891 r
.58229 .14777 .58894 .15408 .60177 .1514 .59515 .14493 Metetra
.639 .699 .889 r
.59515 .14493 .60177 .1514 .61467 .14879 .60808 .14224 Metetra
.632 .693 .889 r
.60808 .14224 .61467 .14879 .62763 .14625 .62107 .13967 Metetra
.626 .691 .89 r
.62107 .13967 .62763 .14625 .64066 .14375 .63414 .1372 Metetra
.623 .691 .893 r
.63414 .1372 .64066 .14375 .65376 .14124 .64728 .13479 Metetra
.622 .696 .897 r
.64728 .13479 .65376 .14124 .66692 .13868 .66048 .13238 Metetra
.626 .705 .902 r
.66048 .13238 .66692 .13868 .68014 .13598 .67375 .12989 Metetra
.635 .719 .908 r
.67375 .12989 .68014 .13598 .6934 .13305 .68708 .12723 Metetra
.65 .738 .914 r
.68708 .12723 .6934 .13305 .70669 .1298 .70044 .12428 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .26459 L
s
.96935 .26459 m
1 .40283 L
s
1 .40283 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.03716 .15727 m
0 .30182 L
s
0 .30182 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.68874 0 m
.03716 .15727 L
s
.03716 .15727 m
.68874 0 L
s
.03716 .15727 m
.04196 .16003 L
s
[(-2)] .02757 .15175 1 .93395 Mshowa
.18558 .12145 m
.19014 .12435 L
s
[(-1)] .17646 .11563 .96648 1 Mshowa
.34306 .08344 m
.34735 .0865 L
s
[(0)] .3345 .07731 .86223 1 Mshowa
.51046 .04303 m
.51442 .04625 L
s
[(1)] .50253 .03658 .75799 1 Mshowa
.68874 0 m
.69233 .00339 L
s
[(2)] .68156 -0.00677 .65374 1 Mshowa
.125 Mabswid
.06616 .15027 m
.06901 .15195 L
s
.09549 .14319 m
.09832 .14488 L
s
.12517 .13603 m
.12797 .13774 L
s
.1552 .12878 m
.15797 .13051 L
s
.21633 .11403 m
.21903 .11579 L
s
.24744 .10652 m
.25012 .1083 L
s
.27893 .09891 m
.28157 .10071 L
s
.3108 .09122 m
.31341 .09304 L
s
.37572 .07555 m
.37826 .07741 L
s
.40878 .06757 m
.41128 .06945 L
s
.44225 .05949 m
.44471 .06139 L
s
.47614 .05131 m
.47856 .05323 L
s
.54521 .03464 m
.54755 .0366 L
s
.58041 .02615 m
.5827 .02812 L
s
.61605 .01754 m
.6183 .01954 L
s
.65216 .00883 m
.65436 .01084 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00<KG101Fe`00
a]L00`3Ge`1Ge`00amL00`3Ge`1Fe`00b=L00`3Ge`1Ee`00bML00`3Ge`0:e`@0A]L00<KG00@0emL0
3]L00`3Ge`15e`00amL200oG00<0emL0AML00=3G1004e`030=OG04GG003He`030=OG04GG003:e`<0
2ML304OG0036e`@00]L200[G00<0emL0AML009KG100Xe`@01]L00`3G001Ae`00V=L00`3Ge`0Se`@0
00?G0=L01mL0103Ge`1@e`00V=L00`3Ge`0Ne`D03]L00`3Ge`0204oG002He`030=OG01_G100Be`03
0=OG00;G00<0emL0C=L009SG00<0emL05]L501KG00<0emL00mL00`3Ge`1;e`00U]L301CG100Le`03
0=OG00?G00<0emL0B]L009SG00<0emL03]L4023G00<0emL01=L204[G002Ue`@09=L00`3Ge`05e`80
BML00:7G100Xe`030=OG00OG00<0emL0A]L009gG100/e`030=OG00SG00<0emL0AML009SG1@000mL0
e`0]e`030=OG00SG0P16e`00JmL202OG100ee`030=OG00[G00<0emL0@mL006[G00@0emL08]L503SG
00<0emL02mL00`3Ge`12e`00J]L0103Ge`0Me`D0?ML00`3Ge`0<e`030=OG047G001Ze`040=OG01[G
1@10e`030=OG00cG0P0>e`801=L00`3Ge`02e`<09]L006[G00@0emL05]L404GG00<0emL03]L00`3G
e`0:e`040=OG00_G00<0emL08mL006[G00@0emL04ML504WG00<0emL03mL00`3Ge`09e`040=OG00_G
00<0emL08mL006_G0P0>e`@0C]L00`3Ge`0@e`030=OG00;G1002e`040=OG00SG0`0Ve`00MmL405?G
00<0emL03mL200WG00@0emL02=L00`3Ge`0Ve`00LmL405OG00<0emL04ML00`3Ge`06e`040=OG00SG
00<0emL09]L006oG101Ke`030=OG01;G00<0emL01]L200WG100Ue`00@=L402KG1@1Oe`030=OG01?G
00<0emL0>ML004;G00<0emL08ML406CG00<0emL04mL203[G0012e`030=OG01gG101Xe`030=OG01GG
00<0emL0=mL003[G1004e`030=OG01WG101/e`030=OG01KG0P0ge`00@]L00`3Ge`0Ee`@0L=L00`3G
e`0He`030=OG03CG0010e`<04mL407CG00<0emL05mL303GG0012e`030=OG00cG1@1he`030=OG01[G
00<0emL0<]L004gG101me`030=OG01_G00<0emL0<ML004WG1021e`030=OG01_G0P0be`00AML508CG
0P0Ne`030=OG02oG000Ie`@09=L408GG10000jd0e`0Ne`030=OG02kG000Ie`030=OG027G1026e`<0
00F2R@29PP0201oG00<0emL01mL202CG000Je`030=OG01_G1@23e`L000>200001P000jd0000Me`80
1mL0103Ge`0Se`004mL400CG00<0emL05]L5083G1`001H80PXV200<000F2R@29PP040003[H8001kG
00<0emL01=L0103Ge`0Se`007=L00`3Ge`0Ae`@0PML40008PZd0[H80PZd40005PZd0[HP00`001XV]
0:f9[@807]L00`3Ge`03e`040=OG02?G000Ie`040=OG00oG10000mL0e`1oe`<000J9PP22RH860003
RH8000H000F2R@29PP040003[@0001kG00<0emL00]L0103Ge`0Se`006]L200cG101Re`806mL70005
[H80PZd010001H80PZf200<000F2[@2]R0080006[@000:f80P0Ke`030=L000?G00@0emL08mL002CG
10000mL0e`1Me`L000=c00001`0?e`<000F9PP22R@070003RH8000H000F208:9PP030003PP0000H0
00B]0:f80`0Ne`040=OGe`809=L0027G0`1Re`/00W<30003U`0000@02=L30005[HT0R:d00`001Jf8
08:]00@000F2[@2]PP0;0008R00008V]0:d40004[:d001kG00<0emL09]L001WG0P06e`<0H=L30003
900000H000E/0000K0020004Ug80LPX000>]00001@000hV200050006RH80PXV20`000h8000090003
PP0000X000B]R0007=L202OG000He`040=OG00CG00@0emOG0P1Me`P000E8K01cK0050008LYL00780
Uid40003RJd0008000F]R@29[@040005RJd0[HT02`002H<00029[@2]R@030005RJd0[HT02@000jb]
000Me`809ML001SG00@0emL01=L200CG00<0emL0FML700981P02K0/000>8[@000P000hV800050006
RH80PXV20`000h:900090005PP22RH800`001H:908V200<000>2[@000`000hP0R0020003[@3G01gG
00<0emL08]L001SG00@0emL01=L00`3Ge`04e`80F=L70003B00000@00V`60003RK<000H000>]R@00
0P001HV]0:f900L000>900001@001HV]0:f900L000>900001@000hV]00020004[HT0R0<000>/[J`0
0P0Le`<08mL001SG00@0emL01=L00`3Ge`06e`80E=L>0003K4P000@000>9S`000P02R@L000>90000
1@000hR900050005PXT0RH801`001H:908V200<000F2R@29PP040005[@2]PZd010001HP000280080
7]L00`3Ge`0Pe`006=L0103Ge`03e`802]L2053G7P000hV?000500:92@03R@H00XT00`29R@070003
RJd000D000F9[@2]R@040003[@0000H000B/[@007ML00`3Ge`0Oe`006ML200CG0P0<e`030=OG04_G
=P001HT0RH:900H000F2R@29PP040005R@29PXT01P000h:]00020003[HP000<000>]0:d00`0Me`80
8=L000KG0P04e`030=OG00;G1002e`<01ML00`3Ge`0<e`80BML^0003I@0000`000>900002002R@L0
00B]0:f910000jd000020004R@2/[@<000B][0007]L00`3Ge`0Me`001ML0103Ge`08e`030=OG00KG
00@0emOG0P0@e`80A=LD00[G50000emU000<0005REl0PXT01`001HT0RH:900H000>2R@000P001Jf8
08R]00P000B8[@007ML00`3Ge`07e`801=L00`3Ge`02e`<01mL000GG00@0emL02ML00`3Ge`05e`04
0=OGe`804]L00`3Ge`0oe`d000G?0000eP0200kG1@000mL0000N00:900<0RHT01`001HT0[HV]00<0
00F]R@29[@030003[HT000<000F]0000[@0201gG00<0emL01ML0103Ge`0;e`030=OG00CG0005e`04
0=OG00[G00@0emOG0`04e`030=OG01;G0P0ke`/000GF0=H0eP060003[00000SG1@0:eb4000F9PP22
R@070003R@0000D000>]00000P000hP000020006[HP00:f/0P0Je`030=L000KG00@0emL02mL00`3G
e`04e`001ML0103Ge`0;e`040=OG00KG0P0Ee`80=]L=0003eP0000D000?F0=H00P06e`@02]L5009k
00@0emOG8002R@H000F]R@29[@030003[HT0008000B9[@2]0P000j`0[00301gG00<0emL00mL0103G
e`08e`<01mL000GG00@0emL02=L0103Ge`02e`030=OG00CG00<0emL05]L2033G50000mH0eP020004
c`00d0L03=L20007R@1k07]@N`0300CG3`001UmU08UOR@X000F208:9PP060003RH80008000F8[@2]
R0020003[HP0008000B/[@007ML00`3Ge`02e`040=OG00SG00<0emL01mL000KG0P0:e`800mL400;G
00<0emL06ML00`3Ge`0Yea<000OF0000eP3F008000??0<l01P0@e`0508T0N`000g/010380006ea80
00F908UUR@0:0004R@29[@@000>900001@000hT000060004[J`001[G0`03e`040=OG00SG00<0emL0
1mL001gG0P0Ke`809]LE0008eP00c`3?0<l50003c`2[008000?@0=L03]L02P2907/0Ne1k0<l300SG
500018T0REl:0003RH80008000F2R@2]R0030003R:d000L000>/00007=L0103GemL200WG1006e`00
2]L200CG00<0emL00]L300GG00<0emL07=L2023G:@001=000=H200gG00D0R@1k0003N`060<P00<l0
2]LE00:900<0RHT01`000hT000050003R@00008000>]00000P001Z`0002/[@806mL00`3Ge`0Ee`00
2ML0103Ge`0;e`040=OGe`808=L00`3Ge`0HeaX000?F0=H010000ll0c`020003d03@008000>[0:/0
10000j`0000<e`0:08T0N`1kD7/0c`8000?800002mLH0003GXT000D000F2R@29R0030003R:d00080
00B]R0280`000jb]000201_G0P0Fe`002ML0103Ge`0;e`040=OGe`808ML201GG8@001M00d03?0080
00?F0=H00P001lo@003?0<l00P001:f/000:e`0508T0N`000g/01P38003?00oG5`000hT0R@02R@H0
00>9[@000P000jd0[@02[@8000>/[@000P001:f/000Le`030=OG01?G0009e`040=OG00SG0`04e`03
0=OG02;G0P0=ebd000C@c`2[0P001m00d03?0<l010000j`00009e`0:08T0N`1kD7/0c`8000?80=L0
4=LJ0003R@0000D000>900001@001Jd0002]00@000>/00007=L201?G0009e`040=OG00SG00<0emL0
1=L202GG0P08e``000Jc002c0;<?0005eP3F0=H00P001M00d03@008000?F00000`002m3?003@0=00
d03@008000B/[@001mL01@2907/000=k0P001<l0c`0CeaT00XT00`29[@030005[HT0RJd00`000jd0
00060004[:d001[G0`0Be`002ML0103Ge`08e`030=OG00?G0P0Xe`030=L000L000>?R@0010000hVc
000@0009eP3F0=H0eP3F008000F[0:/0Z`020004d:/0Z`8000?@00000P001j/0Z`2U0:D010000j`0
0007e`8000Ek07]@N`020004b03801CG7@000hT000050006[@000:f820000jd0000Le`030=OG00oG
000:e`802ML400;G00<0emL09=L:0003/hT000@000>]/`001`000k<000050003/P0000d000C@eP3F
0P000ll0c`02000@d<l0c`3?0<l0c`3?0<l0c`8000B/YP001ML2009k00T0N`3?0<l0c`004]L20003
[@0001/00XT60003[HT0008000>]00000P001jd0002][0007=L00`3Ge`0>e`006mL201oG1P02R@<0
0XT80003/hT000@000>/000020000mJ/00070003eP3F008000>[0:/01`002:_@002[0:_@0P002Z/0
0<l0c`3?0<l20005YP00[0001=L20008Ne00D0380<P201CG8@001880R8T40006R00008R]1@001:d0
0:`201WG0`0?e`000]L200CG00<0emL00mL00`3Ge`02e`<01ML00`3Ge`0He`H00XT60003[HT00080
00>9/`000P000k>900040003[@0000H000GG0000e`080006d=H0eP3F0P001=3F0=H20003d03?00<0
00C?d03@0P003lo@0=00d03@0=00d:/0YP020003d03G00;G0P02N`0407/0c`8000?80=L04]LG0006
GhUO05n92@000jf900020003R@00008000B]0:f/0P000jf/000201cG00<0emL01]L400;G00001ML0
emL000WG00<0emL01ML01@3GemL001KG1@000h:900050003PXT000D000>8[@000P000jf8000;0004
/`00[0<000>/eP001@000j`0[0070006Zm00d03@0P001J_@002[008000W@Z`00d03@0=000P003:D0
Y@2U0:D0YJ`0[0D000IkD01@0<P20003c`3G01?G700018T0REh70009R00008R]0:f800<000J80000
[:d201cG00<0emL01mL00`3Ge`01e`0000GG0=OG000:e`030=OG00CG00@0emOG0P0?e`H000B2[@2]
0`001Jf908V]00<000>]R@001@000jf900090004/`00[0D000>/0:`01P001=N/0=040004eP00d0H0
00WF0=H0d03@0=000`003m3?003@c`3?0<l0Z`2[d0020005YP2U0:D00`02N`0407/0c`8000?80=L0
4ML20003R@00008000<:00006002R@H000>9[@001@000jd000060003[@0001[G00<0e`002=L00`3G
e`01e`0000GG0=OG000:e`040=OGe`<01=L00`3Ge`0;e`<000F9PP22R@060003PP0000@000>9PP00
0P000hR]000<0003[J`000@000B/002c10000j`000020003eP0000@000b/eP00Zm00d03@0=030006
d03@0=2[0P002]000:/0Y@2U0:D2000;c`3?0<nU0:D0YM000`001W]@0500b08000??0=L03mL60003
F000018000<k000020000hT000050004R@2]R0<000>8[@001P001:f/000Ke`030=OG00GG00<0emL0
0ML00005e`3Ge`002mL0103Ge`05e`802mL20005[H80PZd00`001Jf208:]00<000B]0:f80`000hV]
000<0003/jd0008000B/002c0P000jcG00020003e`00008000>/e`000`000j`0[003000<d=H0eP3F
0=H0eP3@0P000ll0c`020007d<l0c`3?d0020009Zm00d03@Z`2U008000G@0=00d002009k00@0N`3?
0P001<P00008e`800]L20005R@2205P00P000eP0000M00:900<0RHT01P000hV]00020003[@0000H0
00>/00006ML300KG00<0emL00ML00005e`3Ge`002=L0103Ge`02e`030=OG00?G0P05e`H000>20000
10000hV200050003RH8000@000>2[@001`000hR]00020003[HP0008000J/[@00[:d20003[0000080
00>b00000P000j`000020004eZ`0[0<000>/00000P002]2[003@0=2[0:/30007Z`2[0:/0Y@020007
d03@0=00d0020009Y@2Uc`3@Y@2U008000IkD01@0<P20004c`22N`P000>9PP0020001EL000090080
00<900000P000`<0000500034000010000>900001@001Jd0002]00P000>/00004mL50003e`0000CG
0`03e`000]L200WG1002e`@00]L0103GemL30005[HP0R:d00`001:d0[H830005R:d0[HP00`000hR]
00050006R00008R]0`000jf/00020003[;<0008000>c[00010001:`00=L30003ej`000<000?F0000
0P000j`0d0020003eP3F00<001KFd03@0=00c`3?0<o@0=00d03@0=2[0P002M2[d03@0=00d0020004
YM00009k00@0N`3?0P000lP000020006YP000:J20`0027/0N`1kPP1l10000bd0000R00:91P001Zd0
002]R@L000B/[@002mL600OG00<0emL01=L00`3Ge`01e`006ML40003RH8000D000>9PP0010000h:9
00050003PP0000D000J20000PZd30003[HP0008000>8[@000P000jf/00020004[000[@8000>/0000
0P000j`000020007[=000:`0[0030004Zm00d0<000?@00000P001j/0Z`2[0:/00P001m00d03@0=00
0P003ZD0YM00d03?Y@2Ud03?0`001W]@0500b08000W?0:J1YP2VNjH0100037^2089k07^207`0F0<0
00<^02h00P0010<000<L0003PP0000@000>]R0000P000hP000020007[@000:f/0005e`D03]L00`3G
e`07e`004=L400GG1P001HV]0:f800<000B8[@2]0`000jf800050005[HP0R:d00`001Zd0002]R0<0
00>/[@000P000jf/00020003[;<000@000?G[0000P000jcG00030005[000eZ`00`000j`0[004000A
eP3Fd03@0:`0cm00d03@0=000P003/l0Z`2[0:/0Zm00d03@0P001JG@002U008000F]07/0N`020003
b038008000fV0:H0YX40PJH0YW^V00P000=G05L00P000c@0000R0004R@29[@@000N90000R@2/0080
00>]0:d00P000j`0000301?G00<0emL01mL001;G00<0emL00mL200;G20000h:9000<0003RH8000D0
00>]PP000P001X800028[@<000>]R0000P000jb]00020004[@00[0D000>/00000P001M2/003@00<0
00C@[02/0P003=00d03@Z`2[0:/0Z`8001;@0=00d:/0Z`2U0:D0Y@2U0:D2000;d:G@0=00d:D0YJ/0
0P000e00D0020003c`3?008000Z10:D0N`2107^V10001W^207`0O08000=A02d00`000bd02@0T0003
RH80008000>800000`000hR]00020005[@00[0005]L00`3Ge`07e`004]L00`3Ge`03e`801=L00`29
R@050003[HT000D000B]0:f80`001HR]0:f800<000>8[@000P001Zd0002][0<000>/[@000P001[>/
002c[08000CG0=N/10001ML00:cF00<000?F00000P001ZcF0=H0d0@000J/0:c@0=030006d:/0Z`2[
0P002m00d03@Z`2[0:G@008000FU0:D0Y@040003N`1k008001[80<P0Y@2UYZD0YJH0YX40PJH0PW/0
Nh80O0@000=G02d020000`X0000N0006R@0008V]2@001Jd00:`001GG00<0emL01mL001;G00<0emL0
0mL00`3Ge`04e`8000>9PP0010001H:908V200D000>2R@001@000h:]00020003[H80008000J80000
R:d30003[J`0008000>/[@0010000j`0000200:/0P000j`000020006d000[02/0P000m2[00020009
Z`2[0:_@0=2[008001c@002[0:G@0=00d03@Y@2U0:G@0=2U0:D0YJbU0`000e00D0020004c`00Y@80
00NVY@00YX6V008000Ik07^208850003O01H00<000EH0000;P0200032@0000d000<d00004@000h80
00020004[@2]R0<000J8002][:d201GG00<0emL01]L001;G00<0emL00]L200GG1@02R@P000>9[@00
10000jf900050003[HP0008000J8[@00[:d30003[J`0008000>/[@000P001;<00:`20004e`00[080
00oG[000e`3F0=J/0:cF0=H00`001]2/0:`0[08000o@[000d:`0[02[d03@0=000P003j/0Z`2[0:D0
Y@2U0:G@Y@040003N`1k008000K80000YJ`20003YJH000<000F1YP2VP@020005PP2208801002F0@0
00<^00009@000hV]00050005[@000:`010000jd0000De`030=OG00KG000@e`<01=L00`3Ge`0400CG
0`0018UO08860004RH80PP<000F2R@2]PP030003PZd0008000J]0000[HP30003R:d0008000R][000
[J`0[0800Z`20005[000[=000`001m000:c@0=000`002M000:_@0=00d0020007Z`2[0:/0Y@02000G
d03@Y@2U0:G@0=2U0:D0Y@2U0:D0YJ`00P000e00D002000@c`00YJJU0:FVY@21YX40N`<000Uk07/0
Eg`0O5L01@000bd0000300042@002PP000<@000030001XUN05j9GPH000>9000010000hR]00060003
[@0001?G00<0emL01]L001;G00<0emL00]L300[G1P000hT000070003[@0000@000>9[@000P000jf8
00020006[0000:b]0`000jf/00020005[:d00:`00P001ML00:cG008000J/0000[=H20003[0000080
00K@0=2/0:`2000Fd03@[02/0:c@0=00d03@0=2[0:/0Z`8000g@Z`2[0:G@0=2U0:G@00<000=k07/0
0P003/P0002U0:D0Y@2U0:FV0P004840PJH0PW/0N`1GPP1l05P30003F00000l000<e000020000el0
00050003R@0000@000>]00001@000jd000050003[@0001;G00<0emL01]L001SG0P0<e`H000AO08:9
1P000h8000040003[H80008000>8[@000P001Zd0002]R0<000>/[@000P000jf/000300:/1@000j`0
[002000Fd:`00=00d03@[02[d03@0=2[0:/0Z`@000O@0=00d03@008000VUd:D0Y@2U0:D00P001jbU
002/0:`00P000e00D002000=c`000:H0YP2V0:H0YP020005NjIk07/02P000eP0F0030003F00000<0
00<^000070000eh000040003RH8000D000>]00001@000jd0000Ae`030=OG00KG000Je`803=L800:9
1P000jd000040003RJd0008000J]R000[J`30003[:d0008000>][00010001J`0002/008000CA002/
0P001M000:c@00<000G@002/d0030005d000[=000`007]000:`0[02[d03@0=2[0:/0Zm00d:D0Y@2U
d03@Y@8000=k07/00P004LP00:`0[:F/0:JUYP2VY@2100<000V107^V0880PW/010000eP0F0030003
F000020000>900001@0018T0RJd30005[@000:d00`001:f/000@e`030=OG00GG000Le`803=L80003
PXT000D000B208:90`000jf200020006R00008R]0`000jf800020003[:d000:/0P000j`00002[080
00B/0:b/0P001Z`0002/d08000J/0000Zm02000GZ`000:_@0=2[0:D0YM00d03@Y@2U0:D00P002m2U
002/0:`0[02/008000I@N`3?0<l40005Y@0008400`004h6V001k07^2N`1k07^207aG05L01@001Bd0
000]00X000<d00001@000el000020003GP0000L000ENR@29PP060005[@000:d00`000jd000020003
[00000oG00<0emL01ML001kG0P0<e`P00XT80003[HT0008000>9[@000P001Zd0002][0<000>/[@00
0P001Jd00:cA008000N/003A[02/008000?@[0000P001J`00=2/00<000F/003@[0030004[000d080
00R/003@0=00d080012[0:_@Z`2U0:G@0=2U0:G@0`02N`040<P0b08000Z/Y@2UYZD0YJJU0P001ZH0
YX40P@`000=l05P04`000c/0000F0003R@0000@000B]00000Zd70003[00000kG00<0emL01ML0023G
0P0<e`P000=OR@001`000h:900020006[HP00:f80`000hR]00020004[J`000:/1@02[08000B/002/
10001:`00:`20006[=00d03@0P002J/0Zm00d03@Y@02000Cd03@Y@2U0:D0YM2U0:D0YJ`0[0020003
YJ`000<000A@N`3?0P000lP0Y@02000=YZD00:J1YP2VP@1kYP02000;N`1kPP22N`1G05L01P001EP0
001H008000<^00000P000c@000050003>`0001@000>2000010000jf800020003R00000D000>/0000
3ML00`3Ge`05e`008]L200cG2002R@0308V900D000>]R@000P001XT0002/[@<000>][0000P001J`0
002/008000F]0000d@050007d@00[02/d002000@[000d03@[02/0:c@0=00d08000B/003@0P003j`0
[02/0:/0Z`2U0:D0Y@020004d03@Y@800W/01@38003?008000JU[000YJH40003YJJU0080016V0:J1
07^V0880PW`0F01HPP0A0003=@0001X00XT60005R@000:d01`000j`0000=e`030=OG00CG000Te`80
3=L;0003R@0000@000>2[@000P001Zd0002]R0<000J8[@00[:d200:/0P001:`00:`20003[00000:/
00@0[0000Z`20008[03@[02/0:/2000Ud:/0Z`2U0:G@Y@2U0:G@0=2U0:D0YJbU0:D0YJ`0[:D0Y@1@
N`02000?b0380:FVY@2UYZD0PJJ100@000FVN`1kPP0>0003EeP000H000=H00001`000c@000020003
=00000<000=N00003P000hT000040005R00008P01`001:b]000;e`030=OG00CG000Ve`803=L;0003
R@0000@000>]R@000P001XT0002/[@<000J]0000[J`20004[J`0[08000GA[000d@020004[000d080
00B/003@10001:`00=02000;[02/0:`0[02/0:`00P005=2/0:`0YM2U0:D0YM00d03@0=000W/20003
c`3?0080012U0:D0Y@2U0:FV0:J1YP2V0`003JH0YP22O01lPP22088010000eP0F0050003=00000P0
00=O00005`000jd000040005R@000:d00`000j`000020003[@0000[G00<0emL01=L002SG0P0<e`/0
00>9000010001XR]0028[@<000>]R0000P001XP0002/[@8000B/002/0P02[08000B/0:b/0P001:`0
[:`20006[02/0:_@0P003:/0YM00d:D0YM00d08000VU0:D0Y@2U0:D00P002j`0[:F/0:bU051k0080
01?8002VY@2UYZD0PJH0YP2V0:J1008001>V089k07^2089k05L0Eg`0O01H008000EG05P0=0050003
=00000P000=O00005@000hT000040006R00008R]1`000jd00009e`030=OG00CG000Ze`803=L;0003
R@0000@000J]0000[HT30006[:d00:b]0`000jf/00030005dJ`00=400P001j`00=2/0:`00P001]2/
0:`0[08000C@002/0P001=000:`2000Bd03@[02/d03@[02U0:K@0=2U0`000jD00002N`8000??0000
0`004j`0002VYJH0YZD0P@21086V0:H03@000h80PP040005F01H05P01@000c@0000;0003G`000100
00>]000010000hV]00020003[@0000D000>]00002=L00`3Ge`04e`00;=L200cG2P000h:900050006
R00008R]0`001Zd0002][0D000B/00000Z`00`2/[0020004[000[08000F/002/0002[0050:`0[:/0
0P001:`0d:D20006[02/Y@2U0P002J`00:D0YJ`0[0020008YJbU0:D0D7/2000:b000YZFV0:JUYP@0
00V1YP00PJH0YW/00P003880PW/0Nh80PP1lE`/000Dd03@0=00T0003RH8000T000>]00001@000jd0
0008e`030=OG00?G000^e`803=LA0003RJd0008000J]R000[J`30005[:d0[J`00P001Jd0003A0080
00R/d@00[02/d08000R/0:c@0=00d08000B/d03@0P001:`00=020009[000d03@[02/008000G@YP00
d0020004YP00N`<000k?0000[02/0:bU0:FVY@8000FV0:J1YP02000EP@21YP2V089l07b20880PUP0
F01H00l000=H00000P000el0000L0003R@0000@000>]00001@000jd00007e`030=OG00?G000`e`80
3=L80003G`0000H000>]R0000P001XP00028[@<000>]00000Z`20003[00000:/1@000j`00002[004
0:`000:/00@0[02/0P001j`00:D0YJ`00P002ZD0YJ`0[02/0:`20009Y@2U[02/Y@2U008000C>0038
0`003ZD0Y@2U0840P@21086V10001G^V089k00l000EG05L0F003009H00<0F0001`000c@000050003
GP00010000>9000010000hP000040005[@000:d00`000jd00006e`030=OG00?G000be`803=L700:9
3@001Zd0002][08000R][000[J`0[0<000B/003A0P000jc@0003000?[=000:`0[=00d03@[02/0080
01c@[02/0:`0[=00d03@YP2Vd03@0=00d:H0b0380`005JD0YJbU0:F/Y@2UYP2VY@21YX40P@03000>
PP2207b2089l07`0O88?0003G`0000T000=O00004`000hT000040003R@0000P000F]0000[@0200GG
00<0emL00mL003CG0P0;e`P000>9G`0010000h:900040003[HP0008000J80000[:d400:/0P001:`0
0:`30003[02/00<000>/00000Z`0202/0:`0[02/0P001jD0YJbU0:D00P001Z`0[:D0Y@8000F/YJ`0
[0050003cP1k00<000FV0000YP030003YX6V00<000>VP@000P002G/0Nh80PW/0N`080006O01l07aH
1@02F0P000=H00006P000hT000040006R00008R]2@000jf80005e`030=OG00;G000fe`803ML=0003
[HT000@000>/[@000P001jd0002]0:d00`001Jf/0:cA008000B/003@0P001J`00=2/008000g@0=2/
d03@0=2/0:c@008000J/0:c@0=020005Y]000:H00P001m00[:J/0:`00`002:bV[02/YZ`00jH4000;
PJH00880PZJ208801@001g`0O880PW`020000h80PP070003P`2300L000>300008@001Jd0002]00T0
0mL00`3Ge`02e`00>=L200gG3@000h8000040006[HP00:f80P001:d00:`30003[00000:/0P001Z`0
[:`0[0<00Z`00`2/YP020006[02/YP2V0P001:`00:D2000G[0000:`0[:D0YJ`0[02/0:`0YP2V0:H0
0P001ZD00021YP8000>1YX400P001ZH0YX40N`<001=k07^2089k07^20880PP22E`1H00T000=H0000
1`000eh0000F0003R@0000@000>9000010001Jd0002]00<000>]000010000mL0e`03e`00>]L200gG
3@000jd000080003[:d000<000J/[@00[:d20004[000[@8000B/003@0`001=000:`20004d000[080
00C@0=2/0P007]00d:c@0=2V0:H0YP2V[02/YZ`0[:J/0:bV0:J/YP8000>V0:H00`001JJ208:V0080
00N208:VPP22014000EHPP22F0080003Peh0028000>9000020000jd000050004[@0000CG000le`80
3=L=0003RH80008000>800001@000hR]00020004[00000:/00<0[:`00P001:`0[:`20008[000[:H0
YZ`20006YP2V[02/0P001JD0002U008000R/002U[:D0Y@<000FU0000Y@03000@Y@2U0840P@21YP2V
PJH0YP<000BV0:Ik1@003g/0Nh80PP22N`1GPP22E`0:0004PUP0F1d000>300002`000hT0000<0003
[@0000CG000ne`803=L=0006RJd008V]0`001Zd0002][08000>][0000P001j`00:f/0:`00P001=2/
0:`30007[000d:`0[002000;d000[02/d:`0[=000`002m000:H0YZbV0:J/008000^V[000YZbV0:J/
YP020004YP2VYP8000BV0:J20`007880PP22YX80O01lPP22O01l07b20880PW`0F8910003[@0000?G
0010e`803=LA0006[HP00:f80`0018P00002[0800Z`400:/0P001:`00:`20005YZ`00:H00P002Z`0
[:H0YP2U0:H20005[:D00:`00`001:`00:D20007[:D00:H0YP030007YP000:J1YP020004P@21YP80
00Mk07^2089k01h00162F01NPP23GP1NP`23GP1NR@0;0003R@0000@000>9000020000hT0000;0003
e`3G00;G0012e`803=L:00:91@001XT0002/[@8000>/[@000P001jd0002]0:d00`001jd00:c@0:d0
0`001m000:c@0=000P001Jc@002/008001f/002V[02/YZ`0[:H0YP2V0:H0YZ`0[:J/0:bV[0040003
PZJ2008000JV0:J208830004PP2200:20140PW`0O01lPP22O01lPP220002PP0308:201<000>90000
7`06e`050=OGe`000mL004CG0P0;e`/000>2000010001Jd0002]00<000B]R0000Z`20004[000[080
0Z`20004[000YP8000F/YP00[002000>YP00[:H0YZ`0[02/0:`3000:[000YJbU0:F/Y@8000bV0000
YP2VP@21YX440005YX40NjH00P002G/0Nh80PW/0N`0Z0003R@0001P03ML20003e`3G00;G0016e`80
2mLE0003[J`0008000^/0000[:d0[J`0[0030007[:d0[J`0[00300:/00T0d:`0[02/0:`00P02[080
00F/0000[0030005[0000:`00`001Z`0002/YP<000ZV0:JV0:J2YP2V0`001ZH0YX80PPD000f208:2
089l07b2088000:200@0PX800X803P2208:308>208:308V220000hT000040003R@0000P05mL00`3G
0002e`00B=L200gG30000hV200040006R:d008R]0`001:d00:`20005[0000:`00P001JH0002V0080
00F/002V[0020004YP00[08001JV[02/YZ`0[:J/0:bU[02VYJH0YX6V0P001840PJH40003PJH00080
00BV0:Ik1@0037/0Nh80PW/0Nh80PQ`000>200001P000hV2000801kG0P02e`00B]L200cG3@000hV]
00080006[J`00:f/10002jf/002][02/[J`000:/0P000j`00002[0090:b/0:`0[02/00<000F/0000
[0030003[000008000JV0000YZ`30004[02VPP8000BV0:J20`002H80PZH0YX80PP080005PP22PP00
0X800`220002PP0408:200:200<0PX<020001880PZd60003R@0002;G1002e`00C=L200cG3@001HT0
002]00/000>]R0000P001J`0002/00<000BV002/0P001JH0002V008000F/YP00[0030005[0000:`0
0`002Z`0002VP@21YX420004YP2VP@<000B1086V0P001h40NjIk07/01@003g/0Nh80PW/0Nh80PW/0
N`0>0004PP2200:21P000hT0000401kG1P06e`00C]L200cG40000jf900020005R0000:`00`001Zb]
002/[@8000V/[@00[:d0[J`00P001:d00:`30003[00000:/0P001ZbV002/YP8000>/YP000P002:H0
002V0:J/0P001880PZH30006YP2VPP220`002H80PZH0YX80PP0;0007PP22PP220002PP0308:200P0
00>2[@00100Ne`H03=L0053G0P0;e`X000>9PP0010001XR]0028[@8000>8[@000P001Jd0002/00<0
00F/0000[0020004YP00[08000JV[000YZ`20006YZ`00:J/0P001h:/002208800`000h:V00020004
YP2VP@8000BV0:J11@001g/0Nh9k07/01@003g/0Nh80PW/0N`1lPW`0O0080004PP22PPH07ML601;G
001Be`802mLA0005[@000:d00`001Zd0002][08000J][000[J`20007[J`0[:d0[@030005[@000:d0
0`001J`0002/00<000R/0:bV0:J/YP8000B/0:bV0`001880PZH20007PP22YP2VPP050009PP22YP2V
PP2200/000N208:20:J200D07ML601SG001De`803=LC0006[HP00:f80`001HP0002800<000F/0000
YP020004[000YP8000J/YP00[:H20003[02/00<000>/PP000P002880002208:V0P001880PJH30006
YP2VP@210`002G/0N`1kPW/0N`05000<N`1kPP22N`1l07b21P0Le`H07]L005KG0P0<e``000>]R@00
20001Zb]002/[@8000J/[@00[:d20007[:d0[J`0[003000<[02/0:`0[:d0[:J/0P002:J/002V0:J/
10000h:/00020004YP2VPPD000N208:V0:J200D000V208:V0:J20880200Le`H09=L005SG0P0;ea40
00>8000020001Jd0002]00<000F]0000[0040003PZ`000<000>2[0000P001J`0002/00@000>2[000
0P000jH000030004YP2VPP<000N2086V08:100D000Ik07/0Nh8801kG1P0Ze`00F]L200_G4@001Jd0
002]01<000F]0000[@050005[J`00:d00`000jd000030008[8800:`0[8850004PP22YPL000FVPP22
YP05023G1P0`e`00G=L200cG4`001Zf8002]R08000J]R000[HP20006[HP00:f80P000jf200040005
PP00[8800P001:`0[8830004PP22YP8000N208:V0:J2008000N208:1086200D07mL603KG001Ne`80
3=L<0003[HT000P000F90000[0030005[0000:`00`001J`0002/00D000F/0000R0050003PZd000@0
00B]0:b21@001880PZH501kG1P0le`00H=L200_G4@000hP0000;0005R:d008P00`001HP0002800D0
00J2[@00PZd50004[02VPPD000B208:21@0Me`H0@]L006;G0P0;ea@000J9[@00RJd@0003RJd000T0
00>2[@001P000jf2000501cG1P18e`00I=L200cG7P001XR]0028[@T000>900001@000hV2000601_G
1`1>e`00I]L200_G5@001Jd008V]00d000>]0000300Le`H0EML006SG0P0;ebX08=L605_G001Ze`80
2]LQ02;G1P1Qe`00K=L200_G6P0Pe`H0ImL006kG0P0;ea<07mL606gG001`e`802]L=01kG1P1ce`00
L]L200_G1@0Me`H0NML007CG0P09e`030=OG01WG1P1oe`00M]L200OG00<0emL04mL608GG001he`80
1ML00`3Ge`0=e`H0RmL007[G0P03e`030=OG00OG1P2Ae`00O=L20003e`3G00;G1P2Ge`00O]L509gG
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.0850106, -0.00185705, \
0.00363122, 0.0058908}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[p3, ViewPoint -> {0. , \(-2.0\), 0. }]\)], "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 -0.375 1.25 [
[-0.01161 -0.0058 -12 -6.3 ]
[-0.01161 -0.0058 0 2.7 ]
[.24024 -0.00976 -12 -8.1 ]
[.24024 -0.00976 0 .9 ]
[.5 -0.01562 -3 -9 ]
[.5 -0.01562 3 0 ]
[.75976 -0.00976 0 -8.1 ]
[.75976 -0.00976 6 .9 ]
[1.01161 -0.0058 0 -6.3 ]
[1.01161 -0.0058 6 2.7 ]
[0 .01563 -6 0 ]
[0 .01563 6 9 ]
[.07143 .05134 -12 0 ]
[.07143 .05134 12 9 ]
[.125 .07813 -3 0 ]
[.125 .07813 3 9 ]
[.16667 .09896 -9 0 ]
[.16667 .09896 9 9 ]
[.2 .11563 -3 0 ]
[.2 .11563 3 9 ]
[-0.0125 0 -6 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10417 -24 -4.5 ]
[-0.0125 .10417 0 4.5 ]
[-0.0125 .20833 -18 -4.5 ]
[-0.0125 .20833 0 4.5 ]
[-0.0125 .3125 -24 -4.5 ]
[-0.0125 .3125 0 4.5 ]
[-0.0125 .41667 -6 -4.5 ]
[-0.0125 .41667 0 4.5 ]
[ 0 -0.00781 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
.0058 .0029 L
s
[(-2)] -0.01161 -0.0058 1 .4 Mshowa
.25 0 m
.25488 .00488 L
s
[(-1)] .24024 -0.00976 1 .8 Mshowa
.5 0 m
.5 .00781 L
s
[(0)] .5 -0.01562 0 1 Mshowa
.75 0 m
.74512 .00488 L
s
[(1)] .75976 -0.00976 -1 .8 Mshowa
1 0 m
.9942 .0029 L
s
[(2)] 1.01161 -0.0058 -1 .4 Mshowa
.125 Mabswid
.05 0 m
.05343 .0019 L
s
.1 0 m
.10335 .0021 L
s
.15 0 m
.15326 .00233 L
s
.2 0 m
.20312 .0026 L
s
.3 0 m
.30265 .00331 L
s
.35 0 m
.35225 .00375 L
s
.4 0 m
.40168 .00419 L
s
.45 0 m
.45091 .00455 L
s
.55 0 m
.54909 .00455 L
s
.6 0 m
.59832 .00419 L
s
.65 0 m
.64775 .00375 L
s
.7 0 m
.69735 .00331 L
s
.8 0 m
.79688 .0026 L
s
.85 0 m
.84674 .00233 L
s
.9 0 m
.89665 .0021 L
s
.95 0 m
.94657 .0019 L
s
.25 Mabswid
0 0 m
.2 .1 L
s
0 0 m
0 -0.00781 L
s
[(-1)] 0 .01563 0 -1 Mshowa
.07143 .03571 m
.07143 .0279 L
s
[(-0.5)] .07143 .05134 0 -1 Mshowa
.125 .0625 m
.125 .05469 L
s
[(0)] .125 .07813 0 -1 Mshowa
.16667 .08333 m
.16667 .07552 L
s
[(0.5)] .16667 .09896 0 -1 Mshowa
.2 .1 m
.2 .09219 L
s
[(1)] .2 .11563 0 -1 Mshowa
.125 Mabswid
.01613 .00806 m
.01613 .00338 L
s
.03125 .01562 m
.03125 .01094 L
s
.04545 .02273 m
.04545 .01804 L
s
.05882 .02941 m
.05882 .02472 L
s
.08333 .04167 m
.08333 .03698 L
s
.09459 .0473 m
.09459 .04261 L
s
.10526 .05263 m
.10526 .04794 L
s
.11538 .05769 m
.11538 .053 L
s
.13415 .06707 m
.13415 .06239 L
s
.14286 .07143 m
.14286 .06674 L
s
.15116 .07558 m
.15116 .07089 L
s
.15909 .07955 m
.15909 .07486 L
s
.17391 .08696 m
.17391 .08227 L
s
.18085 .09043 m
.18085 .08574 L
s
.1875 .09375 m
.1875 .08906 L
s
.19388 .09694 m
.19388 .09225 L
s
.25 Mabswid
0 0 m
0 .5 L
s
0 0 m
.00625 0 L
s
[(0)] -0.0125 0 1 0 Mshowa
0 .10417 m
.00625 .10417 L
s
[(0.25)] -0.0125 .10417 1 0 Mshowa
0 .20833 m
.00625 .20833 L
s
[(0.5)] -0.0125 .20833 1 0 Mshowa
0 .3125 m
.00625 .3125 L
s
[(0.75)] -0.0125 .3125 1 0 Mshowa
0 .41667 m
.00625 .41667 L
s
[(1)] -0.0125 .41667 1 0 Mshowa
.125 Mabswid
0 .02083 m
.00375 .02083 L
s
0 .04167 m
.00375 .04167 L
s
0 .0625 m
.00375 .0625 L
s
0 .08333 m
.00375 .08333 L
s
0 .125 m
.00375 .125 L
s
0 .14583 m
.00375 .14583 L
s
0 .16667 m
.00375 .16667 L
s
0 .1875 m
.00375 .1875 L
s
0 .22917 m
.00375 .22917 L
s
0 .25 m
.00375 .25 L
s
0 .27083 m
.00375 .27083 L
s
0 .29167 m
.00375 .29167 L
s
0 .33333 m
.00375 .33333 L
s
0 .35417 m
.00375 .35417 L
s
0 .375 m
.00375 .375 L
s
0 .39583 m
.00375 .39583 L
s
0 .4375 m
.00375 .4375 L
s
0 .45833 m
.00375 .45833 L
s
0 .47917 m
.00375 .47917 L
s
.25 Mabswid
0 0 m
0 .5 L
s
0 .5 m
.2 .4 L
s
.2 .4 m
.2 .1 L
s
.2 .1 m
0 0 L
s
1 0 m
.8 .1 L
s
.8 .1 m
.8 .4 L
s
.8 .4 m
1 .5 L
s
1 .5 m
1 0 L
s
0 0 m
0 .5 L
s
0 .5 m
1 .5 L
s
1 .5 m
1 0 L
s
1 0 m
0 0 L
s
.2 .1 m
.8 .1 L
s
.8 .1 m
.8 .4 L
s
.8 .4 m
.2 .4 L
s
.2 .4 m
.2 .1 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.179 0 0 r
.19795 .35092 .2 .35 .21017 .35004 .20819 .35159 Metetra
.211 0 0 r
.20819 .35159 .21017 .35004 .22034 .34957 .21843 .35166 Metetra
.244 0 0 r
.21843 .35166 .22034 .34957 .23051 .34879 .22867 .35133 Metetra
.276 0 0 r
.22867 .35133 .23051 .34879 .24068 .3479 .23891 .35077 Metetra
.304 0 0 r
.23891 .35077 .24068 .3479 .25085 .34702 .24915 .35012 Metetra
.327 0 0 r
.24915 .35012 .25085 .34702 .26102 .34628 .25939 .34949 Metetra
.342 0 0 r
.25939 .34949 .26102 .34628 .27119 .34576 .26962 .34895 Metetra
.351 0 0 r
.26962 .34895 .27119 .34576 .28136 .3455 .27986 .34856 Metetra
.35 0 0 r
.27986 .34856 .28136 .3455 .29153 .34552 .2901 .34834 Metetra
.338 0 0 r
.2901 .34834 .29153 .34552 .30169 .34583 .30034 .3483 Metetra
.313 0 0 r
.30034 .3483 .30169 .34583 .31186 .3464 .31058 .3484 Metetra
.272 0 0 r
.31058 .3484 .31186 .3464 .32203 .34719 .32082 .34862 Metetra
.21 0 0 r
.32082 .34862 .32203 .34719 .3322 .34814 .33106 .34891 Metetra
.127 0 0 r
.33106 .34891 .3322 .34814 .34237 .34919 .3413 .34922 Metetra
.021 0 0 r
.3413 .34922 .34237 .34919 .35254 .35027 .35154 .34947 Metetra
.099 .652 .806 r
.35154 .34947 .35254 .35027 .36271 .3513 .36177 .34961 Metetra
.223 .731 .893 r
.36177 .34961 .36271 .3513 .37288 .35223 .37201 .34959 Metetra
.338 .788 .953 r
.37201 .34959 .37288 .35223 .38305 .35298 .38225 .34935 Metetra
.434 .823 .986 r
.38225 .34935 .38305 .35298 .39322 .35352 .39249 .34886 Metetra
.509 .84 .998 r
.39249 .34886 .39322 .35352 .40339 .35381 .40273 .34811 Metetra
.565 .844 .997 r
.40273 .34811 .40339 .35381 .41356 .35385 .41297 .34711 Metetra
.605 .84 .988 r
.41297 .34711 .41356 .35385 .42373 .35364 .42321 .34588 Metetra
.633 .832 .977 r
.42321 .34588 .42373 .35364 .4339 .35322 .43345 .34449 Metetra
.651 .822 .965 r
.43345 .34449 .4339 .35322 .44407 .35264 .44369 .343 Metetra
.662 .81 .954 r
.44369 .343 .44407 .35264 .45424 .35198 .45392 .34153 Metetra
.668 .798 .945 r
.45392 .34153 .45424 .35198 .46441 .35131 .46416 .34017 Metetra
.669 .786 .937 r
.46416 .34017 .46441 .35131 .47458 .35071 .4744 .33902 Metetra
.666 .775 .931 r
.4744 .33902 .47458 .35071 .48475 .35027 .48464 .3382 Metetra
.66 .764 .927 r
.48464 .3382 .48475 .35027 .49492 .35003 .49488 .33777 Metetra
.652 .755 .925 r
.49488 .33777 .49492 .35003 .50508 .35003 .50512 .33777 Metetra
.185 0 0 r
.79181 .35159 .78983 .35004 .8 .35 .80205 .35092 Metetra
.266 0 0 r
.78157 .35166 .77966 .34957 .78983 .35004 .79181 .35159 Metetra
.325 0 0 r
.77133 .35133 .76949 .34879 .77966 .34957 .78157 .35166 Metetra
.364 0 0 r
.76109 .35077 .75932 .3479 .76949 .34879 .77133 .35133 Metetra
.387 0 0 r
.75085 .35012 .74915 .34702 .75932 .3479 .76109 .35077 Metetra
.396 0 0 r
.74061 .34949 .73898 .34628 .74915 .34702 .75085 .35012 Metetra
.392 0 0 r
.73038 .34895 .72881 .34576 .73898 .34628 .74061 .34949 Metetra
.377 0 0 r
.72014 .34856 .71864 .3455 .72881 .34576 .73038 .34895 Metetra
.349 0 0 r
.7099 .34834 .70847 .34552 .71864 .3455 .72014 .34856 Metetra
.308 0 0 r
.69966 .3483 .69831 .34583 .70847 .34552 .7099 .34834 Metetra
.253 0 0 r
.68942 .3484 .68814 .3464 .69831 .34583 .69966 .3483 Metetra
.182 0 0 r
.67918 .34862 .67797 .34719 .68814 .3464 .68942 .3484 Metetra
.094 0 0 r
.66894 .34891 .6678 .34814 .67797 .34719 .67918 .34862 Metetra
.6587 .34922 .65763 .34919 .6678 .34814 .66894 .34891 Metetra
.119 .668 .805 r
.64846 .34947 .64746 .35027 .65763 .34919 .6587 .34922 Metetra
.228 .734 .892 r
.63823 .34961 .63729 .3513 .64746 .35027 .64846 .34947 Metetra
.323 .777 .953 r
.62799 .34959 .62712 .35223 .63729 .3513 .63823 .34961 Metetra
.4 .796 .986 r
.61775 .34935 .61695 .35298 .62712 .35223 .62799 .34959 Metetra
.458 .799 .999 r
.60751 .34886 .60678 .35352 .61695 .35298 .61775 .34935 Metetra
.5 .792 .998 r
.59727 .34811 .59661 .35381 .60678 .35352 .60751 .34886 Metetra
.531 .78 .989 r
.58703 .34711 .58644 .35385 .59661 .35381 .59727 .34811 Metetra
.554 .768 .978 r
.57679 .34588 .57627 .35364 .58644 .35385 .58703 .34711 Metetra
.571 .757 .965 r
.56655 .34449 .5661 .35322 .57627 .35364 .57679 .34588 Metetra
.586 .748 .954 r
.55631 .343 .55593 .35264 .5661 .35322 .56655 .34449 Metetra
.599 .742 .944 r
.54608 .34153 .54576 .35198 .55593 .35264 .55631 .343 Metetra
.611 .739 .936 r
.53584 .34017 .53559 .35131 .54576 .35198 .54608 .34153 Metetra
.622 .739 .931 r
.5256 .33902 .52542 .35071 .53559 .35131 .53584 .34017 Metetra
.633 .742 .927 r
.51536 .3382 .51525 .35027 .52542 .35071 .5256 .33902 Metetra
.643 .748 .925 r
.50512 .33777 .50508 .35003 .51525 .35027 .51536 .3382 Metetra
.214 0 0 r
.19588 .35177 .19795 .35092 .20819 .35159 .20619 .35303 Metetra
.231 0 0 r
.20619 .35303 .20819 .35159 .21843 .35166 .21649 .3536 Metetra
.252 0 0 r
.21649 .3536 .21843 .35166 .22867 .35133 .2268 .35367 Metetra
.273 0 0 r
.2268 .35367 .22867 .35133 .23891 .35077 .23711 .35342 Metetra
.291 0 0 r
.23711 .35342 .23891 .35077 .24915 .35012 .24742 .35297 Metetra
.305 0 0 r
.24742 .35297 .24915 .35012 .25939 .34949 .25773 .35242 Metetra
.313 0 0 r
.25773 .35242 .25939 .34949 .26962 .34895 .26804 .35186 Metetra
.313 0 0 r
.26804 .35186 .26962 .34895 .27986 .34856 .27835 .35134 Metetra
.304 0 0 r
.27835 .35134 .27986 .34856 .2901 .34834 .28866 .35087 Metetra
.284 0 0 r
.28866 .35087 .2901 .34834 .30034 .3483 .29897 .35047 Metetra
.25 0 0 r
.29897 .35047 .30034 .3483 .31058 .3484 .30928 .35011 Metetra
.198 0 0 r
.30928 .35011 .31058 .3484 .32082 .34862 .31959 .34977 Metetra
.128 0 0 r
.31959 .34977 .32082 .34862 .33106 .34891 .3299 .34941 Metetra
.036 0 0 r
.3299 .34941 .33106 .34891 .3413 .34922 .34021 .34897 Metetra
.073 .635 .747 r
.34021 .34897 .3413 .34922 .35154 .34947 .35052 .3484 Metetra
.192 .72 .841 r
.35052 .3484 .35154 .34947 .36177 .34961 .36082 .34765 Metetra
.309 .788 .915 r
.36082 .34765 .36177 .34961 .37201 .34959 .37113 .34668 Metetra
.413 .834 .963 r
.37113 .34668 .37201 .34959 .38225 .34935 .38144 .34544 Metetra
.498 .86 .988 r
.38144 .34544 .38225 .34935 .39249 .34886 .39175 .34391 Metetra
.562 .87 .995 r
.39175 .34391 .39249 .34886 .40273 .34811 .40206 .34211 Metetra
.61 .869 .991 r
.40206 .34211 .40273 .34811 .41297 .34711 .41237 .34005 Metetra
.643 .861 .982 r
.41237 .34005 .41297 .34711 .42321 .34588 .42268 .33778 Metetra
.665 .849 .971 r
.42268 .33778 .42321 .34588 .43345 .34449 .43299 .33538 Metetra
.679 .836 .959 r
.43299 .33538 .43345 .34449 .44369 .343 .4433 .33295 Metetra
.685 .822 .948 r
.4433 .33295 .44369 .343 .45392 .34153 .45361 .33063 Metetra
.687 .807 .939 r
.45361 .33063 .45392 .34153 .46416 .34017 .46392 .32854 Metetra
.683 .792 .932 r
.46392 .32854 .46416 .34017 .4744 .33902 .47423 .32682 Metetra
.677 .778 .927 r
.47423 .32682 .4744 .33902 .48464 .3382 .48454 .3256 Metetra
.667 .764 .923 r
.48454 .3256 .48464 .3382 .49488 .33777 .49485 .32496 Metetra
.655 .752 .921 r
.49485 .32496 .49488 .33777 .50512 .33777 .50515 .32496 Metetra
.151 0 0 r
.79381 .35303 .79181 .35159 .80205 .35092 .80412 .35177 Metetra
.229 0 0 r
.78351 .3536 .78157 .35166 .79181 .35159 .79381 .35303 Metetra
.288 0 0 r
.7732 .35367 .77133 .35133 .78157 .35166 .78351 .3536 Metetra
.329 0 0 r
.76289 .35342 .76109 .35077 .77133 .35133 .7732 .35367 Metetra
.355 0 0 r
.75258 .35297 .75085 .35012 .76109 .35077 .76289 .35342 Metetra
.366 0 0 r
.74227 .35242 .74061 .34949 .75085 .35012 .75258 .35297 Metetra
.365 0 0 r
.73196 .35186 .73038 .34895 .74061 .34949 .74227 .35242 Metetra
.352 0 0 r
.72165 .35134 .72014 .34856 .73038 .34895 .73196 .35186 Metetra
.326 0 0 r
.71134 .35087 .7099 .34834 .72014 .34856 .72165 .35134 Metetra
.288 0 0 r
.70103 .35047 .69966 .3483 .7099 .34834 .71134 .35087 Metetra
.234 0 0 r
.69072 .35011 .68942 .3484 .69966 .3483 .70103 .35047 Metetra
.166 0 0 r
.68041 .34977 .67918 .34862 .68942 .3484 .69072 .35011 Metetra
.081 0 0 r
.6701 .34941 .66894 .34891 .67918 .34862 .68041 .34977 Metetra
.016 .589 .746 r
.65979 .34897 .6587 .34922 .66894 .34891 .6701 .34941 Metetra
.119 .661 .84 r
.64948 .3484 .64846 .34947 .6587 .34922 .65979 .34897 Metetra
.219 .716 .915 r
.63918 .34765 .63823 .34961 .64846 .34947 .64948 .3484 Metetra
.306 .749 .964 r
.62887 .34668 .62799 .34959 .63823 .34961 .63918 .34765 Metetra
.377 .764 .989 r
.61856 .34544 .61775 .34935 .62799 .34959 .62887 .34668 Metetra
.432 .765 .996 r
.60825 .34391 .60751 .34886 .61775 .34935 .61856 .34544 Metetra
.473 .758 .993 r
.59794 .34211 .59727 .34811 .60751 .34886 .60825 .34391 Metetra
.505 .749 .983 r
.58763 .34005 .58703 .34711 .59727 .34811 .59794 .34211 Metetra
.529 .739 .971 r
.57732 .33778 .57679 .34588 .58703 .34711 .58763 .34005 Metetra
.549 .731 .959 r
.56701 .33538 .56655 .34449 .57679 .34588 .57732 .33778 Metetra
.567 .725 .948 r
.5567 .33295 .55631 .343 .56655 .34449 .56701 .33538 Metetra
.583 .722 .939 r
.54639 .33063 .54608 .34153 .55631 .343 .5567 .33295 Metetra
.598 .722 .931 r
.53608 .32854 .53584 .34017 .54608 .34153 .54639 .33063 Metetra
.613 .726 .926 r
.52577 .32682 .5256 .33902 .53584 .34017 .53608 .32854 Metetra
.628 .732 .922 r
.51546 .3256 .51536 .3382 .5256 .33902 .52577 .32682 Metetra
.642 .741 .921 r
.50515 .32496 .50512 .33777 .51536 .3382 .51546 .3256 Metetra
.245 0 0 r
.19377 .35257 .19588 .35177 .20619 .35303 .20415 .35436 Metetra
.251 0 0 r
.20415 .35436 .20619 .35303 .21649 .3536 .21453 .35538 Metetra
.26 0 0 r
.21453 .35538 .21649 .3536 .2268 .35367 .22491 .35583 Metetra
.27 0 0 r
.22491 .35583 .2268 .35367 .23711 .35342 .23529 .35585 Metetra
.279 0 0 r
.23529 .35585 .23711 .35342 .24742 .35297 .24567 .35558 Metetra
.283 0 0 r
.24567 .35558 .24742 .35297 .25773 .35242 .25606 .35511 Metetra
.283 0 0 r
.25606 .35511 .25773 .35242 .26804 .35186 .26644 .35451 Metetra
.275 0 0 r
.26644 .35451 .26804 .35186 .27835 .35134 .27682 .35384 Metetra
.257 0 0 r
.27682 .35384 .27835 .35134 .28866 .35087 .2872 .35312 Metetra
.228 0 0 r
.2872 .35312 .28866 .35087 .29897 .35047 .29758 .35236 Metetra
.185 0 0 r
.29758 .35236 .29897 .35047 .30928 .35011 .30796 .35155 Metetra
.125 0 0 r
.30796 .35155 .30928 .35011 .31959 .34977 .31834 .35065 Metetra
.046 0 0 r
.31834 .35065 .31959 .34977 .3299 .34941 .32872 .34963 Metetra
.32872 .34963 .3299 .34941 .34021 .34897 .3391 .34846 Metetra
.162 .702 .785 r
.3391 .34846 .34021 .34897 .35052 .3484 .34948 .34707 Metetra
.277 .777 .867 r
.34948 .34707 .35052 .3484 .36082 .34765 .35986 .34543 Metetra
.386 .835 .928 r
.35986 .34543 .36082 .34765 .37113 .34668 .37024 .3435 Metetra
.479 .872 .967 r
.37024 .3435 .37113 .34668 .38144 .34544 .38062 .34126 Metetra
.554 .891 .985 r
.38062 .34126 .38144 .34544 .39175 .34391 .391 .33869 Metetra
.61 .895 .988 r
.391 .33869 .39175 .34391 .40206 .34211 .40138 .33581 Metetra
.65 .89 .983 r
.40138 .33581 .40206 .34211 .41237 .34005 .41176 .33266 Metetra
.678 .879 .974 r
.41176 .33266 .41237 .34005 .42268 .33778 .42215 .32931 Metetra
.695 .865 .963 r
.42215 .32931 .42268 .33778 .43299 .33538 .43253 .32587 Metetra
.704 .849 .952 r
.43253 .32587 .43299 .33538 .4433 .33295 .44291 .32246 Metetra
.707 .832 .942 r
.44291 .32246 .4433 .33295 .45361 .33063 .45329 .31924 Metetra
.705 .815 .934 r
.45329 .31924 .45361 .33063 .46392 .32854 .46367 .31638 Metetra
.698 .798 .927 r
.46367 .31638 .46392 .32854 .47423 .32682 .47405 .31405 Metetra
.687 .781 .922 r
.47405 .31405 .47423 .32682 .48454 .3256 .48443 .3124 Metetra
.674 .764 .918 r
.48443 .3124 .48454 .3256 .49485 .32496 .49481 .31155 Metetra
.658 .748 .916 r
.49481 .31155 .49485 .32496 .50515 .32496 .50519 .31155 Metetra
.121 0 0 r
.79585 .35436 .79381 .35303 .80412 .35177 .80623 .35257 Metetra
.196 0 0 r
.78547 .35538 .78351 .3536 .79381 .35303 .79585 .35436 Metetra
.254 0 0 r
.77509 .35583 .7732 .35367 .78351 .3536 .78547 .35538 Metetra
.296 0 0 r
.76471 .35585 .76289 .35342 .7732 .35367 .77509 .35583 Metetra
.323 0 0 r
.75433 .35558 .75258 .35297 .76289 .35342 .76471 .35585 Metetra
.337 0 0 r
.74394 .35511 .74227 .35242 .75258 .35297 .75433 .35558 Metetra
.338 0 0 r
.73356 .35451 .73196 .35186 .74227 .35242 .74394 .35511 Metetra
.327 0 0 r
.72318 .35384 .72165 .35134 .73196 .35186 .73356 .35451 Metetra
.304 0 0 r
.7128 .35312 .71134 .35087 .72165 .35134 .72318 .35384 Metetra
.267 0 0 r
.70242 .35236 .70103 .35047 .71134 .35087 .7128 .35312 Metetra
.216 0 0 r
.69204 .35155 .69072 .35011 .70103 .35047 .70242 .35236 Metetra
.15 0 0 r
.68166 .35065 .68041 .34977 .69072 .35011 .69204 .35155 Metetra
.07 0 0 r
.67128 .34963 .6701 .34941 .68041 .34977 .68166 .35065 Metetra
.021 .588 .784 r
.6609 .34846 .65979 .34897 .6701 .34941 .67128 .34963 Metetra
.117 .648 .866 r
.65052 .34707 .64948 .3484 .65979 .34897 .6609 .34846 Metetra
.208 .693 .929 r
.64014 .34543 .63918 .34765 .64948 .3484 .65052 .34707 Metetra
.288 .719 .968 r
.62976 .3435 .62887 .34668 .63918 .34765 .64014 .34543 Metetra
.354 .73 .987 r
.61938 .34126 .61856 .34544 .62887 .34668 .62976 .3435 Metetra
.406 .73 .991 r
.609 .33869 .60825 .34391 .61856 .34544 .61938 .34126 Metetra
.446 .724 .985 r
.59862 .33581 .59794 .34211 .60825 .34391 .609 .33869 Metetra
.478 .717 .975 r
.58824 .33266 .58763 .34005 .59794 .34211 .59862 .33581 Metetra
.504 .71 .963 r
.57785 .32931 .57732 .33778 .58763 .34005 .58824 .33266 Metetra
.527 .704 .952 r
.56747 .32587 .56701 .33538 .57732 .33778 .57785 .32931 Metetra
.547 .702 .941 r
.55709 .32246 .5567 .33295 .56701 .33538 .56747 .32587 Metetra
.567 .702 .932 r
.54671 .31924 .54639 .33063 .5567 .33295 .55709 .32246 Metetra
.586 .706 .926 r
.53633 .31638 .53608 .32854 .54639 .33063 .54671 .31924 Metetra
.604 .712 .921 r
.52595 .31405 .52577 .32682 .53608 .32854 .53633 .31638 Metetra
.623 .722 .918 r
.51557 .3124 .51546 .3256 .52577 .32682 .52595 .31405 Metetra
.641 .734 .916 r
.50519 .31155 .50515 .32496 .51546 .3256 .51557 .3124 Metetra
.274 0 0 r
.19164 .35332 .19377 .35257 .20415 .35436 .20209 .3556 Metetra
.268 0 0 r
.20209 .3556 .20415 .35436 .21453 .35538 .21254 .35704 Metetra
.267 0 0 r
.21254 .35704 .21453 .35538 .22491 .35583 .223 .35783 Metetra
.267 0 0 r
.223 .35783 .22491 .35583 .23529 .35585 .23345 .3581 Metetra
.266 0 0 r
.23345 .3581 .23529 .35585 .24567 .35558 .2439 .35798 Metetra
.262 0 0 r
.2439 .35798 .24567 .35558 .25606 .35511 .25436 .35756 Metetra
.253 0 0 r
.25436 .35756 .25606 .35511 .26644 .35451 .26481 .35692 Metetra
.236 0 0 r
.26481 .35692 .26644 .35451 .27682 .35384 .27526 .3561 Metetra
.21 0 0 r
.27526 .3561 .27682 .35384 .2872 .35312 .28571 .35512 Metetra
.173 0 0 r
.28571 .35512 .2872 .35312 .29758 .35236 .29617 .354 Metetra
.121 0 0 r
.29617 .354 .29758 .35236 .30796 .35155 .30662 .35273 Metetra
.052 0 0 r
.30662 .35273 .30796 .35155 .31834 .35065 .31707 .35128 Metetra
.31707 .35128 .31834 .35065 .32872 .34963 .32753 .34961 Metetra
.134 .68 .73 r
.32753 .34961 .32872 .34963 .3391 .34846 .33798 .3477 Metetra
.243 .759 .813 r
.33798 .3477 .3391 .34846 .34948 .34707 .34843 .3455 Metetra
.353 .825 .883 r
.34843 .3455 .34948 .34707 .35986 .34543 .35889 .34297 Metetra
.453 .874 .934 r
.35889 .34297 .35986 .34543 .37024 .3435 .36934 .34008 Metetra
.537 .903 .964 r
.36934 .34008 .37024 .3435 .38062 .34126 .37979 .33682 Metetra
.603 .916 .977 r
.37979 .33682 .38062 .34126 .391 .33869 .39024 .33318 Metetra
.652 .916 .979 r
.39024 .33318 .391 .33869 .40138 .33581 .4007 .32921 Metetra
.687 .908 .973 r
.4007 .32921 .40138 .33581 .41176 .33266 .41115 .32495 Metetra
.709 .894 .964 r
.41115 .32495 .41176 .33266 .42215 .32931 .4216 .32049 Metetra
.723 .879 .953 r
.4216 .32049 .42215 .32931 .43253 .32587 .43206 .31596 Metetra
.728 .861 .944 r
.43206 .31596 .43253 .32587 .44291 .32246 .44251 .31152 Metetra
.728 .842 .935 r
.44251 .31152 .44291 .32246 .45329 .31924 .45296 .30736 Metetra
.722 .823 .927 r
.45296 .30736 .45329 .31924 .46367 .31638 .46341 .30368 Metetra
.712 .803 .921 r
.46341 .30368 .46367 .31638 .47405 .31405 .47387 .30069 Metetra
.698 .783 .917 r
.47387 .30069 .47405 .31405 .48443 .3124 .48432 .29857 Metetra
.681 .763 .914 r
.48432 .29857 .48443 .3124 .49481 .31155 .49477 .29748 Metetra
.661 .745 .912 r
.49477 .29748 .49481 .31155 .50519 .31155 .50523 .29748 Metetra
.095 0 0 r
.79791 .3556 .79585 .35436 .80623 .35257 .80836 .35332 Metetra
.167 0 0 r
.78746 .35704 .78547 .35538 .79585 .35436 .79791 .3556 Metetra
.223 0 0 r
.777 .35783 .77509 .35583 .78547 .35538 .78746 .35704 Metetra
.266 0 0 r
.76655 .3581 .76471 .35585 .77509 .35583 .777 .35783 Metetra
.294 0 0 r
.7561 .35798 .75433 .35558 .76471 .35585 .76655 .3581 Metetra
.309 0 0 r
.74564 .35756 .74394 .35511 .75433 .35558 .7561 .35798 Metetra
.312 0 0 r
.73519 .35692 .73356 .35451 .74394 .35511 .74564 .35756 Metetra
.303 0 0 r
.72474 .3561 .72318 .35384 .73356 .35451 .73519 .35692 Metetra
.282 0 0 r
.71429 .35512 .7128 .35312 .72318 .35384 .72474 .3561 Metetra
.248 0 0 r
.70383 .354 .70242 .35236 .7128 .35312 .71429 .35512 Metetra
.199 0 0 r
.69338 .35273 .69204 .35155 .70242 .35236 .70383 .354 Metetra
.137 0 0 r
.68293 .35128 .68166 .35065 .69204 .35155 .69338 .35273 Metetra
0 .522 .729 r
.67247 .34961 .67128 .34963 .68166 .35065 .68293 .35128 Metetra
.023 .581 .813 r
.66202 .3477 .6609 .34846 .67128 .34963 .67247 .34961 Metetra
.111 .631 .884 r
.65157 .3455 .65052 .34707 .6609 .34846 .66202 .3477 Metetra
.194 .666 .936 r
.64111 .34297 .64014 .34543 .65052 .34707 .65157 .3455 Metetra
.268 .687 .968 r
.63066 .34008 .62976 .3435 .64014 .34543 .64111 .34297 Metetra
.329 .695 .981 r
.62021 .33682 .61938 .34126 .62976 .3435 .63066 .34008 Metetra
.379 .695 .982 r
.60976 .33318 .609 .33869 .61938 .34126 .62021 .33682 Metetra
.419 .69 .975 r
.5993 .32921 .59862 .33581 .609 .33869 .60976 .33318 Metetra
.452 .685 .965 r
.58885 .32495 .58824 .33266 .59862 .33581 .5993 .32921 Metetra
.48 .68 .954 r
.5784 .32049 .57785 .32931 .58824 .33266 .58885 .32495 Metetra
.505 .678 .943 r
.56794 .31596 .56747 .32587 .57785 .32931 .5784 .32049 Metetra
.528 .678 .933 r
.55749 .31152 .55709 .32246 .56747 .32587 .56794 .31596 Metetra
.55 .682 .925 r
.54704 .30736 .54671 .31924 .55709 .32246 .55749 .31152 Metetra
.573 .688 .919 r
.53659 .30368 .53633 .31638 .54671 .31924 .54704 .30736 Metetra
.595 .699 .915 r
.52613 .30069 .52595 .31405 .53633 .31638 .53659 .30368 Metetra
.618 .712 .912 r
.51568 .29857 .51557 .3124 .52595 .31405 .52613 .30069 Metetra
.64 .727 .911 r
.50523 .29748 .50519 .31155 .51557 .3124 .51568 .29857 Metetra
.299 0 0 r
.18947 .35405 .19164 .35332 .20209 .3556 .2 .35676 Metetra
.284 0 0 r
.2 .35676 .20209 .3556 .21254 .35704 .21053 .35859 Metetra
.273 0 0 r
.21053 .35859 .21254 .35704 .223 .35783 .22105 .35968 Metetra
.264 0 0 r
.22105 .35968 .223 .35783 .23345 .3581 .23158 .36017 Metetra
.254 0 0 r
.23158 .36017 .23345 .3581 .2439 .35798 .24211 .36018 Metetra
.241 0 0 r
.24211 .36018 .2439 .35798 .25436 .35756 .25263 .3598 Metetra
.223 0 0 r
.25263 .3598 .25436 .35756 .26481 .35692 .26316 .3591 Metetra
.198 0 0 r
.26316 .3591 .26481 .35692 .27526 .3561 .27368 .35812 Metetra
.164 0 0 r
.27368 .35812 .27526 .3561 .28571 .35512 .28421 .35689 Metetra
.118 0 0 r
.28421 .35689 .28571 .35512 .29617 .354 .29474 .35541 Metetra
.058 0 0 r
.29474 .35541 .29617 .354 .30662 .35273 .30526 .35367 Metetra
.30526 .35367 .30662 .35273 .31707 .35128 .31579 .35167 Metetra
.31579 .35167 .31707 .35128 .32753 .34961 .32632 .34936 Metetra
.21 .734 .761 r
.32632 .34936 .32753 .34961 .33798 .3477 .33684 .34672 Metetra
.317 .806 .833 r
.33684 .34672 .33798 .3477 .34843 .3455 .34737 .3437 Metetra
.42 .864 .892 r
.34737 .3437 .34843 .3455 .35889 .34297 .35789 .34027 Metetra
.512 .905 .934 r
.35789 .34027 .35889 .34297 .36934 .34008 .36842 .33642 Metetra
.588 .928 .957 r
.36842 .33642 .36934 .34008 .37979 .33682 .37895 .33213 Metetra
.646 .936 .967 r
.37895 .33213 .37979 .33682 .39024 .33318 .38947 .32742 Metetra
.689 .933 .967 r
.38947 .32742 .39024 .33318 .4007 .32921 .4 .32232 Metetra
.719 .923 .961 r
.4 .32232 .4007 .32921 .41115 .32495 .41053 .31691 Metetra
.738 .908 .953 r
.41053 .31691 .41115 .32495 .4216 .32049 .42105 .3113 Metetra
.748 .891 .943 r
.42105 .3113 .4216 .32049 .43206 .31596 .43158 .30563 Metetra
.751 .872 .935 r
.43158 .30563 .43206 .31596 .44251 .31152 .44211 .3001 Metetra
.748 .851 .927 r
.44211 .3001 .44251 .31152 .45296 .30736 .45263 .29494 Metetra
.739 .83 .921 r
.45263 .29494 .45296 .30736 .46341 .30368 .46316 .29038 Metetra
.726 .808 .915 r
.46316 .29038 .46341 .30368 .47387 .30069 .47368 .28667 Metetra
.709 .785 .912 r
.47368 .28667 .47387 .30069 .48432 .29857 .48421 .28406 Metetra
.688 .763 .909 r
.48421 .28406 .48432 .29857 .49477 .29748 .49474 .2827 Metetra
.664 .741 .907 r
.49474 .2827 .49477 .29748 .50523 .29748 .50526 .2827 Metetra
.072 0 0 r
.8 .35676 .79791 .3556 .80836 .35332 .81053 .35405 Metetra
.14 0 0 r
.78947 .35859 .78746 .35704 .79791 .3556 .8 .35676 Metetra
.195 0 0 r
.77895 .35968 .777 .35783 .78746 .35704 .78947 .35859 Metetra
.237 0 0 r
.76842 .36017 .76655 .3581 .777 .35783 .77895 .35968 Metetra
.266 0 0 r
.75789 .36018 .7561 .35798 .76655 .3581 .76842 .36017 Metetra
.283 0 0 r
.74737 .3598 .74564 .35756 .7561 .35798 .75789 .36018 Metetra
.288 0 0 r
.73684 .3591 .73519 .35692 .74564 .35756 .74737 .3598 Metetra
.281 0 0 r
.72632 .35812 .72474 .3561 .73519 .35692 .73684 .3591 Metetra
.262 0 0 r
.71579 .35689 .71429 .35512 .72474 .3561 .72632 .35812 Metetra
.23 0 0 r
.70526 .35541 .70383 .354 .71429 .35512 .71579 .35689 Metetra
.184 0 0 r
.69474 .35367 .69338 .35273 .70383 .354 .70526 .35541 Metetra
.126 0 0 r
.68421 .35167 .68293 .35128 .69338 .35273 .69474 .35367 Metetra
0 .521 .76 r
.67368 .34936 .67247 .34961 .68293 .35128 .68421 .35167 Metetra
.023 .57 .834 r
.66316 .34672 .66202 .3477 .67247 .34961 .67368 .34936 Metetra
.103 .61 .895 r
.65263 .3437 .65157 .3455 .66202 .3477 .66316 .34672 Metetra
.179 .638 .938 r
.64211 .34027 .64111 .34297 .65157 .3455 .65263 .3437 Metetra
.247 .654 .963 r
.63158 .33642 .63066 .34008 .64111 .34297 .64211 .34027 Metetra
.304 .66 .972 r
.62105 .33213 .62021 .33682 .63066 .34008 .63158 .33642 Metetra
.352 .66 .971 r
.61053 .32742 .60976 .33318 .62021 .33682 .62105 .33213 Metetra
.391 .657 .964 r
.6 .32232 .5993 .32921 .60976 .33318 .61053 .32742 Metetra
.425 .653 .954 r
.58947 .31691 .58885 .32495 .5993 .32921 .6 .32232 Metetra
.455 .651 .944 r
.57895 .3113 .5784 .32049 .58885 .32495 .58947 .31691 Metetra
.482 .651 .934 r
.56842 .30563 .56794 .31596 .5784 .32049 .57895 .3113 Metetra
.508 .654 .925 r
.55789 .3001 .55749 .31152 .56794 .31596 .56842 .30563 Metetra
.534 .661 .918 r
.54737 .29494 .54704 .30736 .55749 .31152 .55789 .3001 Metetra
.559 .671 .913 r
.53684 .29038 .53659 .30368 .54704 .30736 .54737 .29494 Metetra
.586 .684 .909 r
.52632 .28667 .52613 .30069 .53659 .30368 .53684 .29038 Metetra
.612 .701 .907 r
.51579 .28406 .51568 .29857 .52613 .30069 .52632 .28667 Metetra
.639 .72 .907 r
.50526 .2827 .50523 .29748 .51568 .29857 .51579 .28406 Metetra
.322 0 0 r
.18728 .35476 .18947 .35405 .2 .35676 .19788 .35787 Metetra
.298 0 0 r
.19788 .35787 .2 .35676 .21053 .35859 .20848 .36003 Metetra
.278 0 0 r
.20848 .36003 .21053 .35859 .22105 .35968 .21908 .36139 Metetra
.26 0 0 r
.21908 .36139 .22105 .35968 .23158 .36017 .22968 .36208 Metetra
.242 0 0 r
.22968 .36208 .23158 .36017 .24211 .36018 .24028 .36221 Metetra
.22 0 0 r
.24028 .36221 .24211 .36018 .25263 .3598 .25088 .36185 Metetra
.194 0 0 r
.25088 .36185 .25263 .3598 .26316 .3591 .26148 .36108 Metetra
.161 0 0 r
.26148 .36108 .26316 .3591 .27368 .35812 .27208 .35993 Metetra
.119 0 0 r
.27208 .35993 .27368 .35812 .28421 .35689 .28269 .35843 Metetra
.065 0 0 r
.28269 .35843 .28421 .35689 .29474 .35541 .29329 .35659 Metetra
.29329 .35659 .29474 .35541 .30526 .35367 .30389 .3544 Metetra
.30389 .3544 .30526 .35367 .31579 .35167 .31449 .35185 Metetra
.177 .708 .713 r
.31449 .35185 .31579 .35167 .32632 .34936 .32509 .3489 Metetra
.278 .781 .783 r
.32509 .3489 .32632 .34936 .33684 .34672 .33569 .34552 Metetra
.381 .845 .846 r
.33569 .34552 .33684 .34672 .34737 .3437 .34629 .34168 Metetra
.478 .896 .895 r
.34629 .34168 .34737 .3437 .35789 .34027 .35689 .33736 Metetra
.563 .929 .929 r
.35689 .33736 .35789 .34027 .36842 .33642 .36749 .33254 Metetra
.631 .947 .947 r
.36749 .33254 .36842 .33642 .37895 .33213 .37809 .32721 Metetra
.684 .952 .954 r
.37809 .32721 .37895 .33213 .38947 .32742 .38869 .3214 Metetra
.722 .947 .953 r
.38869 .3214 .38947 .32742 .4 .32232 .39929 .31515 Metetra
.748 .935 .948 r
.39929 .31515 .4 .32232 .41053 .31691 .40989 .30856 Metetra
.764 .92 .94 r
.40989 .30856 .41053 .31691 .42105 .3113 .42049 .30174 Metetra
.772 .901 .932 r
.42049 .30174 .42105 .3113 .43158 .30563 .4311 .29488 Metetra
.773 .881 .925 r
.4311 .29488 .43158 .30563 .44211 .3001 .4417 .2882 Metetra
.767 .86 .918 r
.4417 .2882 .44211 .3001 .45263 .29494 .4523 .28196 Metetra
.756 .837 .913 r
.4523 .28196 .45263 .29494 .46316 .29038 .4629 .27644 Metetra
.74 .813 .909 r
.4629 .27644 .46316 .29038 .47368 .28667 .4735 .27197 Metetra
.719 .788 .906 r
.4735 .27197 .47368 .28667 .48421 .28406 .4841 .2688 Metetra
.694 .762 .904 r
.4841 .2688 .48421 .28406 .49474 .2827 .4947 .26716 Metetra
.667 .737 .902 r
.4947 .26716 .49474 .2827 .50526 .2827 .5053 .26716 Metetra
.053 0 0 r
.80212 .35787 .8 .35676 .81053 .35405 .81272 .35476 Metetra
.117 0 0 r
.79152 .36003 .78947 .35859 .8 .35676 .80212 .35787 Metetra
.17 0 0 r
.78092 .36139 .77895 .35968 .78947 .35859 .79152 .36003 Metetra
.211 0 0 r
.77032 .36208 .76842 .36017 .77895 .35968 .78092 .36139 Metetra
.241 0 0 r
.75972 .36221 .75789 .36018 .76842 .36017 .77032 .36208 Metetra
.259 0 0 r
.74912 .36185 .74737 .3598 .75789 .36018 .75972 .36221 Metetra
.265 0 0 r
.73852 .36108 .73684 .3591 .74737 .3598 .74912 .36185 Metetra
.26 0 0 r
.72792 .35993 .72632 .35812 .73684 .3591 .73852 .36108 Metetra
.243 0 0 r
.71731 .35843 .71579 .35689 .72632 .35812 .72792 .35993 Metetra
.213 0 0 r
.70671 .35659 .70526 .35541 .71579 .35689 .71731 .35843 Metetra
.171 0 0 r
.69611 .3544 .69474 .35367 .70526 .35541 .70671 .35659 Metetra
0 .472 .711 r
.68551 .35185 .68421 .35167 .69474 .35367 .69611 .3544 Metetra
0 .516 .784 r
.67491 .3489 .67368 .34936 .68421 .35167 .68551 .35185 Metetra
.02 .556 .849 r
.66431 .34552 .66316 .34672 .67368 .34936 .67491 .3489 Metetra
.093 .587 .9 r
.65371 .34168 .65263 .3437 .66316 .34672 .66431 .34552 Metetra
.162 .608 .935 r
.64311 .33736 .64211 .34027 .65263 .3437 .65371 .34168 Metetra
.225 .62 .954 r
.63251 .33254 .63158 .33642 .64211 .34027 .64311 .33736 Metetra
.279 .625 .961 r
.62191 .32721 .62105 .33213 .63158 .33642 .63251 .33254 Metetra
.325 .625 .959 r
.61131 .3214 .61053 .32742 .62105 .33213 .62191 .32721 Metetra
.364 .623 .952 r
.60071 .31515 .6 .32232 .61053 .32742 .61131 .3214 Metetra
.398 .622 .942 r
.59011 .30856 .58947 .31691 .6 .32232 .60071 .31515 Metetra
.43 .622 .933 r
.57951 .30174 .57895 .3113 .58947 .31691 .59011 .30856 Metetra
.459 .625 .924 r
.5689 .29488 .56842 .30563 .57895 .3113 .57951 .30174 Metetra
.488 .631 .916 r
.5583 .2882 .55789 .3001 .56842 .30563 .5689 .29488 Metetra
.516 .64 .91 r
.5477 .28196 .54737 .29494 .55789 .3001 .5583 .2882 Metetra
.546 .653 .905 r
.5371 .27644 .53684 .29038 .54737 .29494 .5477 .28196 Metetra
.576 .67 .903 r
.5265 .27197 .52632 .28667 .53684 .29038 .5371 .27644 Metetra
.607 .69 .901 r
.5159 .2688 .51579 .28406 .52632 .28667 .5265 .27197 Metetra
.637 .712 .901 r
.5053 .26716 .50526 .2827 .51579 .28406 .5159 .2688 Metetra
.342 0 0 r
.18505 .35545 .18728 .35476 .19788 .35787 .19573 .35892 Metetra
.311 0 0 r
.19573 .35892 .19788 .35787 .20848 .36003 .20641 .36139 Metetra
.283 0 0 r
.20641 .36139 .20848 .36003 .21908 .36139 .21708 .363 Metetra
.256 0 0 r
.21708 .363 .21908 .36139 .22968 .36208 .22776 .36386 Metetra
.23 0 0 r
.22776 .36386 .22968 .36208 .24028 .36221 .23843 .36407 Metetra
.2 0 0 r
.23843 .36407 .24028 .36221 .25088 .36185 .24911 .36372 Metetra
.166 0 0 r
.24911 .36372 .25088 .36185 .26148 .36108 .25979 .36287 Metetra
.125 0 0 r
.25979 .36287 .26148 .36108 .27208 .35993 .27046 .36154 Metetra
.075 0 0 r
.27046 .36154 .27208 .35993 .28269 .35843 .28114 .35978 Metetra
.014 0 0 r
.28114 .35978 .28269 .35843 .29329 .35659 .29181 .35758 Metetra
.29181 .35758 .29329 .35659 .30389 .3544 .30249 .35493 Metetra
.30249 .35493 .30389 .3544 .31449 .35185 .31317 .35183 Metetra
.24 .752 .737 r
.31317 .35183 .31449 .35185 .32509 .3489 .32384 .34824 Metetra
.34 .819 .799 r
.32384 .34824 .32509 .3489 .33569 .34552 .33452 .34413 Metetra
.438 .877 .852 r
.33452 .34413 .33569 .34552 .34629 .34168 .3452 .33948 Metetra
.529 .921 .893 r
.3452 .33948 .34629 .34168 .35689 .33736 .35587 .33426 Metetra
.607 .949 .92 r
.35587 .33426 .35689 .33736 .36749 .33254 .36655 .32845 Metetra
.669 .962 .935 r
.36655 .32845 .36749 .33254 .37809 .32721 .37722 .32207 Metetra
.717 .964 .94 r
.37722 .32207 .37809 .32721 .38869 .3214 .3879 .31514 Metetra
.751 .958 .939 r
.3879 .31514 .38869 .3214 .39929 .31515 .39858 .30771 Metetra
.774 .946 .933 r
.39858 .30771 .39929 .31515 .40989 .30856 .40925 .29989 Metetra
.788 .93 .927 r
.40925 .29989 .40989 .30856 .42049 .30174 .41993 .29182 Metetra
.794 .911 .92 r
.41993 .29182 .42049 .30174 .4311 .29488 .4306 .28371 Metetra
.793 .89 .914 r
.4306 .28371 .4311 .29488 .4417 .2882 .44128 .27579 Metetra
.786 .868 .909 r
.44128 .27579 .4417 .2882 .4523 .28196 .45196 .26839 Metetra
.773 .844 .905 r
.45196 .26839 .4523 .28196 .4629 .27644 .46263 .26184 Metetra
.754 .817 .902 r
.46263 .26184 .4629 .27644 .4735 .27197 .47331 .25651 Metetra
.73 .79 .9 r
.47331 .25651 .4735 .27197 .4841 .2688 .48399 .25274 Metetra
.701 .761 .898 r
.48399 .25274 .4841 .2688 .4947 .26716 .49466 .25078 Metetra
.67 .732 .897 r
.49466 .25078 .4947 .26716 .5053 .26716 .50534 .25078 Metetra
.036 0 0 r
.80427 .35892 .80212 .35787 .81272 .35476 .81495 .35545 Metetra
.096 0 0 r
.79359 .36139 .79152 .36003 .80212 .35787 .80427 .35892 Metetra
.147 0 0 r
.78292 .363 .78092 .36139 .79152 .36003 .79359 .36139 Metetra
.188 0 0 r
.77224 .36386 .77032 .36208 .78092 .36139 .78292 .363 Metetra
.218 0 0 r
.76157 .36407 .75972 .36221 .77032 .36208 .77224 .36386 Metetra
.237 0 0 r
.75089 .36372 .74912 .36185 .75972 .36221 .76157 .36407 Metetra
.244 0 0 r
.74021 .36287 .73852 .36108 .74912 .36185 .75089 .36372 Metetra
.241 0 0 r
.72954 .36154 .72792 .35993 .73852 .36108 .74021 .36287 Metetra
.226 0 0 r
.71886 .35978 .71731 .35843 .72792 .35993 .72954 .36154 Metetra
.199 0 0 r
.70819 .35758 .70671 .35659 .71731 .35843 .71886 .35978 Metetra
.16 0 0 r
.69751 .35493 .69611 .3544 .70671 .35659 .70819 .35758 Metetra
0 .471 .737 r
.68683 .35183 .68551 .35185 .69611 .3544 .69751 .35493 Metetra
0 .507 .801 r
.67616 .34824 .67491 .3489 .68551 .35185 .68683 .35183 Metetra
.015 .538 .857 r
.66548 .34413 .66431 .34552 .67491 .3489 .67616 .34824 Metetra
.081 .562 .901 r
.6548 .33948 .65371 .34168 .66431 .34552 .66548 .34413 Metetra
.145 .578 .929 r
.64413 .33426 .64311 .33736 .65371 .34168 .6548 .33948 Metetra
.202 .587 .944 r
.63345 .32845 .63251 .33254 .64311 .33736 .64413 .33426 Metetra
.253 .591 .948 r
.62278 .32207 .62191 .32721 .63251 .33254 .63345 .32845 Metetra
.297 .591 .945 r
.6121 .31514 .61131 .3214 .62191 .32721 .62278 .32207 Metetra
.336 .59 .938 r
.60142 .30771 .60071 .31515 .61131 .3214 .6121 .31514 Metetra
.371 .591 .93 r
.59075 .29989 .59011 .30856 .60071 .31515 .60142 .30771 Metetra
.404 .593 .921 r
.58007 .29182 .57951 .30174 .59011 .30856 .59075 .29989 Metetra
.435 .598 .913 r
.5694 .28371 .5689 .29488 .57951 .30174 .58007 .29182 Metetra
.467 .606 .906 r
.55872 .27579 .5583 .2882 .5689 .29488 .5694 .28371 Metetra
.499 .618 .901 r
.54804 .26839 .5477 .28196 .5583 .2882 .55872 .27579 Metetra
.531 .635 .898 r
.53737 .26184 .5371 .27644 .5477 .28196 .54804 .26839 Metetra
.566 .655 .896 r
.52669 .25651 .5265 .27197 .5371 .27644 .53737 .26184 Metetra
.6 .678 .895 r
.51601 .25274 .5159 .2688 .5265 .27197 .52669 .25651 Metetra
.635 .704 .896 r
.50534 .25078 .5053 .26716 .5159 .2688 .51601 .25274 Metetra
.36 0 0 r
.1828 .35615 .18505 .35545 .19573 .35892 .19355 .35993 Metetra
.322 0 0 r
.19355 .35993 .19573 .35892 .20641 .36139 .2043 .36267 Metetra
.287 0 0 r
.2043 .36267 .20641 .36139 .21708 .363 .21505 .36449 Metetra
.253 0 0 r
.21505 .36449 .21708 .363 .22776 .36386 .22581 .3655 Metetra
.218 0 0 r
.22581 .3655 .22776 .36386 .23843 .36407 .23656 .36579 Metetra
.181 0 0 r
.23656 .36579 .23843 .36407 .24911 .36372 .24731 .36543 Metetra
.139 0 0 r
.24731 .36543 .24911 .36372 .25979 .36287 .25806 .36448 Metetra
.09 0 0 r
.25806 .36448 .25979 .36287 .27046 .36154 .26882 .36298 Metetra
.033 0 0 r
.26882 .36298 .27046 .36154 .28114 .35978 .27957 .36095 Metetra
.27957 .36095 .28114 .35978 .29181 .35758 .29032 .35838 Metetra
.29032 .35838 .29181 .35758 .30249 .35493 .30108 .35528 Metetra
.201 .721 .698 r
.30108 .35528 .30249 .35493 .31317 .35183 .31183 .35163 Metetra
.297 .789 .755 r
.31183 .35163 .31317 .35183 .32384 .34824 .32258 .3474 Metetra
.394 .851 .809 r
.32258 .3474 .32384 .34824 .33452 .34413 .33333 .34256 Metetra
.488 .902 .854 r
.33333 .34256 .33452 .34413 .3452 .33948 .34409 .3371 Metetra
.573 .94 .888 r
.34409 .3371 .3452 .33948 .35587 .33426 .35484 .33097 Metetra
.644 .964 .909 r
.35484 .33097 .35587 .33426 .36655 .32845 .36559 .32418 Metetra
.702 .974 .921 r
.36559 .32418 .36655 .32845 .37722 .32207 .37634 .31673 Metetra
.745 .974 .924 r
.37634 .31673 .37722 .32207 .3879 .31514 .3871 .30866 Metetra
.777 .967 .923 r
.3871 .30866 .3879 .31514 .39858 .30771 .39785 .30002 Metetra
.798 .955 .918 r
.39785 .30002 .39858 .30771 .40925 .29989 .4086 .29093 Metetra
.81 .939 .913 r
.4086 .29093 .40925 .29989 .41993 .29182 .41935 .28155 Metetra
.815 .92 .907 r
.41935 .28155 .41993 .29182 .4306 .28371 .43011 .2721 Metetra
.813 .899 .903 r
.43011 .2721 .4306 .28371 .44128 .27579 .44086 .26286 Metetra
.804 .875 .899 r
.44086 .26286 .44128 .27579 .45196 .26839 .45161 .25421 Metetra
.789 .85 .897 r
.45161 .25421 .45196 .26839 .46263 .26184 .46237 .24653 Metetra
.768 .822 .895 r
.46237 .24653 .46263 .26184 .47331 .25651 .47312 .24025 Metetra
.741 .792 .894 r
.47312 .24025 .47331 .25651 .48399 .25274 .48387 .2358 Metetra
.708 .76 .893 r
.48387 .2358 .48399 .25274 .49466 .25078 .49462 .23348 Metetra
.672 .728 .892 r
.49462 .23348 .49466 .25078 .50534 .25078 .50538 .23348 Metetra
.022 0 0 r
.80645 .35993 .80427 .35892 .81495 .35545 .8172 .35615 Metetra
.078 0 0 r
.7957 .36267 .79359 .36139 .80427 .35892 .80645 .35993 Metetra
.127 0 0 r
.78495 .36449 .78292 .363 .79359 .36139 .7957 .36267 Metetra
.167 0 0 r
.77419 .3655 .77224 .36386 .78292 .363 .78495 .36449 Metetra
.197 0 0 r
.76344 .36579 .76157 .36407 .77224 .36386 .77419 .3655 Metetra
.217 0 0 r
.75269 .36543 .75089 .36372 .76157 .36407 .76344 .36579 Metetra
.226 0 0 r
.74194 .36448 .74021 .36287 .75089 .36372 .75269 .36543 Metetra
.224 0 0 r
.73118 .36298 .72954 .36154 .74021 .36287 .74194 .36448 Metetra
.211 0 0 r
.72043 .36095 .71886 .35978 .72954 .36154 .73118 .36298 Metetra
.187 0 0 r
.70968 .35838 .70819 .35758 .71886 .35978 .72043 .36095 Metetra
0 .439 .696 r
.69892 .35528 .69751 .35493 .70819 .35758 .70968 .35838 Metetra
0 .467 .757 r
.68817 .35163 .68683 .35183 .69751 .35493 .69892 .35528 Metetra
0 .495 .813 r
.67742 .3474 .67616 .34824 .68683 .35183 .68817 .35163 Metetra
.007 .519 .861 r
.66667 .34256 .66548 .34413 .67616 .34824 .67742 .3474 Metetra
.068 .537 .897 r
.65591 .3371 .6548 .33948 .66548 .34413 .66667 .34256 Metetra
.126 .548 .92 r
.64516 .33097 .64413 .33426 .6548 .33948 .65591 .3371 Metetra
.179 .554 .932 r
.63441 .32418 .63345 .32845 .64413 .33426 .64516 .33097 Metetra
.227 .557 .934 r
.62366 .31673 .62278 .32207 .63345 .32845 .63441 .32418 Metetra
.27 .557 .931 r
.6129 .30866 .6121 .31514 .62278 .32207 .62366 .31673 Metetra
.309 .558 .924 r
.60215 .30002 .60142 .30771 .6121 .31514 .6129 .30866 Metetra
.344 .56 .916 r
.5914 .29093 .59075 .29989 .60142 .30771 .60215 .30002 Metetra
.378 .564 .908 r
.58065 .28155 .58007 .29182 .59075 .29989 .5914 .29093 Metetra
.411 .571 .901 r
.56989 .2721 .5694 .28371 .58007 .29182 .58065 .28155 Metetra
.445 .582 .896 r
.55914 .26286 .55872 .27579 .5694 .28371 .56989 .2721 Metetra
.48 .596 .892 r
.54839 .25421 .54804 .26839 .55872 .27579 .55914 .26286 Metetra
.516 .616 .889 r
.53763 .24653 .53737 .26184 .54804 .26839 .54839 .25421 Metetra
.555 .639 .889 r
.52688 .24025 .52669 .25651 .53737 .26184 .53763 .24653 Metetra
.594 .666 .889 r
.51613 .2358 .51601 .25274 .52669 .25651 .52688 .24025 Metetra
.634 .696 .89 r
.50538 .23348 .50534 .25078 .51601 .25274 .51613 .2358 Metetra
.375 0 0 r
.18051 .35684 .1828 .35615 .19355 .35993 .19134 .36091 Metetra
.332 0 0 r
.19134 .36091 .19355 .35993 .2043 .36267 .20217 .36389 Metetra
.29 0 0 r
.20217 .36389 .2043 .36267 .21505 .36449 .213 .3659 Metetra
.249 0 0 r
.213 .3659 .21505 .36449 .22581 .3655 .22383 .36703 Metetra
.207 0 0 r
.22383 .36703 .22581 .3655 .23656 .36579 .23466 .36738 Metetra
.162 0 0 r
.23466 .36738 .23656 .36579 .24731 .36543 .24549 .367 Metetra
.113 0 0 r
.24549 .367 .24731 .36543 .25806 .36448 .25632 .36595 Metetra
.057 0 0 r
.25632 .36595 .25806 .36448 .26882 .36298 .26715 .36426 Metetra
.26715 .36426 .26882 .36298 .27957 .36095 .27798 .36195 Metetra
.27798 .36195 .27957 .36095 .29032 .35838 .28881 .35902 Metetra
.28881 .35902 .29032 .35838 .30108 .35528 .29964 .35547 Metetra
.252 .757 .718 r
.29964 .35547 .30108 .35528 .31183 .35163 .31047 .35127 Metetra
.347 .82 .768 r
.31047 .35127 .31183 .35163 .32258 .3474 .3213 .34641 Metetra
.442 .877 .814 r
.3213 .34641 .32258 .3474 .33333 .34256 .33213 .34085 Metetra
.531 .922 .852 r
.33213 .34085 .33333 .34256 .34409 .3371 .34296 .33456 Metetra
.61 .955 .879 r
.34296 .33456 .34409 .3371 .35484 .33097 .35379 .32753 Metetra
.677 .975 .896 r
.35379 .32753 .35484 .33097 .36559 .32418 .36462 .31975 Metetra
.73 .983 .905 r
.36462 .31975 .36559 .32418 .37634 .31673 .37545 .31122 Metetra
.77 .982 .907 r
.37545 .31122 .37634 .31673 .3871 .30866 .38628 .30197 Metetra
.799 .975 .906 r
.38628 .30197 .3871 .30866 .39785 .30002 .39711 .29209 Metetra
.819 .962 .902 r
.39711 .29209 .39785 .30002 .4086 .29093 .40794 .28168 Metetra
.83 .946 .898 r
.40794 .28168 .4086 .29093 .41935 .28155 .41877 .27092 Metetra
.834 .928 .894 r
.41877 .27092 .41935 .28155 .43011 .2721 .4296 .26005 Metetra
.831 .906 .891 r
.4296 .26005 .43011 .2721 .44086 .26286 .44043 .24941 Metetra
.821 .883 .889 r
.44043 .24941 .44086 .26286 .45161 .25421 .45126 .23939 Metetra
.805 .856 .888 r
.45126 .23939 .45161 .25421 .46237 .24653 .46209 .23045 Metetra
.782 .827 .888 r
.46209 .23045 .46237 .24653 .47312 .24025 .47292 .22313 Metetra
.752 .794 .888 r
.47292 .22313 .47312 .24025 .48387 .2358 .48375 .2179 Metetra
.716 .76 .887 r
.48375 .2179 .48387 .2358 .49462 .23348 .49458 .21517 Metetra
.675 .723 .886 r
.49458 .21517 .49462 .23348 .50538 .23348 .50542 .21517 Metetra
.01 0 0 r
.80866 .36091 .80645 .35993 .8172 .35615 .81949 .35684 Metetra
.063 0 0 r
.79783 .36389 .7957 .36267 .80645 .35993 .80866 .36091 Metetra
.11 0 0 r
.787 .3659 .78495 .36449 .7957 .36267 .79783 .36389 Metetra
.148 0 0 r
.77617 .36703 .77419 .3655 .78495 .36449 .787 .3659 Metetra
.178 0 0 r
.76534 .36738 .76344 .36579 .77419 .3655 .77617 .36703 Metetra
.199 0 0 r
.75451 .367 .75269 .36543 .76344 .36579 .76534 .36738 Metetra
.209 0 0 r
.74368 .36595 .74194 .36448 .75269 .36543 .75451 .367 Metetra
.209 0 0 r
.73285 .36426 .73118 .36298 .74194 .36448 .74368 .36595 Metetra
.199 0 0 r
.72202 .36195 .72043 .36095 .73118 .36298 .73285 .36426 Metetra
.177 0 0 r
.71119 .35902 .70968 .35838 .72043 .36095 .72202 .36195 Metetra
0 .439 .717 r
.70036 .35547 .69892 .35528 .70968 .35838 .71119 .35902 Metetra
0 .461 .771 r
.68953 .35127 .68817 .35163 .69892 .35528 .70036 .35547 Metetra
0 .481 .821 r
.6787 .34641 .67742 .3474 .68817 .35163 .68953 .35127 Metetra
0 .498 .862 r
.66787 .34085 .66667 .34256 .67742 .3474 .6787 .34641 Metetra
.053 .511 .891 r
.65704 .33456 .65591 .3371 .66667 .34256 .66787 .34085 Metetra
.106 .518 .909 r
.64621 .32753 .64516 .33097 .65591 .3371 .65704 .33456 Metetra
.155 .522 .918 r
.63538 .31975 .63441 .32418 .64516 .33097 .64621 .32753 Metetra
.201 .524 .919 r
.62455 .31122 .62366 .31673 .63441 .32418 .63538 .31975 Metetra
.242 .524 .915 r
.61372 .30197 .6129 .30866 .62366 .31673 .62455 .31122 Metetra
.281 .526 .909 r
.60289 .29209 .60215 .30002 .6129 .30866 .61372 .30197 Metetra
.317 .529 .902 r
.59206 .28168 .5914 .29093 .60215 .30002 .60289 .29209 Metetra
.352 .534 .895 r
.58123 .27092 .58065 .28155 .5914 .29093 .59206 .28168 Metetra
.387 .543 .889 r
.5704 .26005 .56989 .2721 .58065 .28155 .58123 .27092 Metetra
.423 .556 .884 r
.55957 .24941 .55914 .26286 .56989 .2721 .5704 .26005 Metetra
.461 .574 .882 r
.54874 .23939 .54839 .25421 .55914 .26286 .55957 .24941 Metetra
.501 .596 .881 r
.53791 .23045 .53763 .24653 .54839 .25421 .54874 .23939 Metetra
.543 .622 .881 r
.52708 .22313 .52688 .24025 .53763 .24653 .53791 .23045 Metetra
.587 .653 .882 r
.51625 .2179 .51613 .2358 .52688 .24025 .52708 .22313 Metetra
.631 .687 .884 r
.50542 .21517 .50538 .23348 .51613 .2358 .51625 .2179 Metetra
.388 0 0 r
.17818 .35755 .18051 .35684 .19134 .36091 .18909 .36187 Metetra
.34 0 0 r
.18909 .36187 .19134 .36091 .20217 .36389 .2 .36506 Metetra
.292 0 0 r
.2 .36506 .20217 .36389 .213 .3659 .21091 .36723 Metetra
.245 0 0 r
.21091 .36723 .213 .3659 .22383 .36703 .22182 .36847 Metetra
.196 0 0 r
.22182 .36847 .22383 .36703 .23466 .36738 .23273 .36885 Metetra
.145 0 0 r
.23273 .36885 .23466 .36738 .24549 .367 .24364 .36844 Metetra
.089 0 0 r
.24364 .36844 .24549 .367 .25632 .36595 .25455 .36728 Metetra
.026 0 0 r
.25455 .36728 .25632 .36595 .26715 .36426 .26545 .3654 Metetra
.26545 .3654 .26715 .36426 .27798 .36195 .27636 .36281 Metetra
.27636 .36281 .27798 .36195 .28881 .35902 .28727 .35952 Metetra
.207 .723 .686 r
.28727 .35952 .28881 .35902 .29964 .35547 .29818 .35551 Metetra
.298 .786 .732 r
.29818 .35551 .29964 .35547 .31047 .35127 .30909 .35078 Metetra
.392 .846 .776 r
.30909 .35078 .31047 .35127 .3213 .34641 .32 .34528 Metetra
.483 .897 .815 r
.32 .34528 .3213 .34641 .33213 .34085 .33091 .339 Metetra
.568 .938 .846 r
.33091 .339 .33213 .34085 .34296 .33456 .34182 .3319 Metetra
.642 .967 .868 r
.34182 .3319 .34296 .33456 .35379 .32753 .35273 .32396 Metetra
.704 .983 .882 r
.35273 .32396 .35379 .32753 .36462 .31975 .36364 .31517 Metetra
.754 .99 .888 r
.36364 .31517 .36462 .31975 .37545 .31122 .37455 .30554 Metetra
.792 .988 .89 r
.37455 .30554 .37545 .31122 .38628 .30197 .38545 .29511 Metetra
.819 .98 .888 r
.38545 .29511 .38628 .30197 .39711 .29209 .39636 .28394 Metetra
.838 .968 .885 r
.39636 .28394 .39711 .29209 .40794 .28168 .40727 .27216 Metetra
.848 .953 .882 r
.40727 .27216 .40794 .28168 .41877 .27092 .41818 .25995 Metetra
.852 .935 .879 r
.41818 .25995 .41877 .27092 .4296 .26005 .42909 .24759 Metetra
.848 .914 .878 r
.42909 .24759 .4296 .26005 .44043 .24941 .44 .23542 Metetra
.838 .89 .877 r
.44 .23542 .44043 .24941 .45126 .23939 .45091 .2239 Metetra
.821 .863 .878 r
.45091 .2239 .45126 .23939 .46209 .23045 .46182 .21358 Metetra
.796 .832 .879 r
.46182 .21358 .46209 .23045 .47292 .22313 .47273 .20507 Metetra
.763 .797 .881 r
.47273 .20507 .47292 .22313 .48375 .2179 .48364 .19896 Metetra
.723 .759 .881 r
.48364 .19896 .48375 .2179 .49458 .21517 .49455 .19577 Metetra
.677 .719 .88 r
.49455 .19577 .49458 .21517 .50542 .21517 .50545 .19577 Metetra
.81091 .36187 .80866 .36091 .81949 .35684 .82182 .35755 Metetra
.05 0 0 r
.8 .36506 .79783 .36389 .80866 .36091 .81091 .36187 Metetra
.094 0 0 r
.78909 .36723 .787 .3659 .79783 .36389 .8 .36506 Metetra
.132 0 0 r
.77818 .36847 .77617 .36703 .787 .3659 .78909 .36723 Metetra
.162 0 0 r
.76727 .36885 .76534 .36738 .77617 .36703 .77818 .36847 Metetra
.183 0 0 r
.75636 .36844 .75451 .367 .76534 .36738 .76727 .36885 Metetra
.194 0 0 r
.74545 .36728 .74368 .36595 .75451 .367 .75636 .36844 Metetra
.196 0 0 r
.73455 .3654 .73285 .36426 .74368 .36595 .74545 .36728 Metetra
.188 0 0 r
.72364 .36281 .72202 .36195 .73285 .36426 .73455 .3654 Metetra
.17 0 0 r
.71273 .35952 .71119 .35902 .72202 .36195 .72364 .36281 Metetra
0 .437 .733 r
.70182 .35551 .70036 .35547 .71119 .35902 .71273 .35952 Metetra
0 .452 .782 r
.69091 .35078 .68953 .35127 .70036 .35547 .70182 .35551 Metetra
0 .465 .824 r
.68 .34528 .6787 .34641 .68953 .35127 .69091 .35078 Metetra
0 .477 .859 r
.66909 .339 .66787 .34085 .6787 .34641 .68 .34528 Metetra
.037 .484 .883 r
.65818 .3319 .65704 .33456 .66787 .34085 .66909 .339 Metetra
.085 .489 .897 r
.64727 .32396 .64621 .32753 .65704 .33456 .65818 .3319 Metetra
.131 .49 .903 r
.63636 .31517 .63538 .31975 .64621 .32753 .64727 .32396 Metetra
.174 .491 .903 r
.62545 .30554 .62455 .31122 .63538 .31975 .63636 .31517 Metetra
.214 .492 .899 r
.61455 .29511 .61372 .30197 .62455 .31122 .62545 .30554 Metetra
.252 .494 .893 r
.60364 .28394 .60289 .29209 .61372 .30197 .61455 .29511 Metetra
.289 .498 .887 r
.59273 .27216 .59206 .28168 .60289 .29209 .60364 .28394 Metetra
.325 .505 .881 r
.58182 .25995 .58123 .27092 .59206 .28168 .59273 .27216 Metetra
.361 .515 .876 r
.57091 .24759 .5704 .26005 .58123 .27092 .58182 .25995 Metetra
.4 .53 .873 r
.56 .23542 .55957 .24941 .5704 .26005 .57091 .24759 Metetra
.44 .55 .871 r
.54909 .2239 .54874 .23939 .55957 .24941 .56 .23542 Metetra
.484 .575 .871 r
.53818 .21358 .53791 .23045 .54874 .23939 .54909 .2239 Metetra
.53 .605 .873 r
.52727 .20507 .52708 .22313 .53791 .23045 .53818 .21358 Metetra
.579 .64 .875 r
.51636 .19896 .51625 .2179 .52708 .22313 .52727 .20507 Metetra
.629 .678 .878 r
.50545 .19577 .50542 .21517 .51625 .2179 .51636 .19896 Metetra
.4 0 0 r
.17582 .35827 .17818 .35755 .18909 .36187 .18681 .3628 Metetra
.347 0 0 r
.18681 .3628 .18909 .36187 .2 .36506 .1978 .36618 Metetra
.294 0 0 r
.1978 .36618 .2 .36506 .21091 .36723 .20879 .36849 Metetra
.241 0 0 r
.20879 .36849 .21091 .36723 .22182 .36847 .21978 .36981 Metetra
.186 0 0 r
.21978 .36981 .22182 .36847 .23273 .36885 .23077 .37022 Metetra
.128 0 0 r
.23077 .37022 .23273 .36885 .24364 .36844 .24176 .36976 Metetra
.065 0 0 r
.24176 .36976 .24364 .36844 .25455 .36728 .25275 .36848 Metetra
.25275 .36848 .25455 .36728 .26545 .3654 .26374 .36641 Metetra
.26374 .36641 .26545 .3654 .27636 .36281 .27473 .36354 Metetra
.27473 .36354 .27636 .36281 .28727 .35952 .28571 .35989 Metetra
.248 .751 .702 r
.28571 .35989 .28727 .35952 .29818 .35551 .2967 .35544 Metetra
.339 .812 .743 r
.2967 .35544 .29818 .35551 .30909 .35078 .30769 .35016 Metetra
.431 .867 .781 r
.30769 .35016 .30909 .35078 .32 .34528 .31868 .34404 Metetra
.519 .914 .813 r
.31868 .34404 .32 .34528 .33091 .339 .32967 .33704 Metetra
.599 .95 .839 r
.32967 .33704 .33091 .339 .34182 .3319 .34066 .32912 Metetra
.669 .975 .856 r
.34066 .32912 .34182 .3319 .35273 .32396 .35165 .32028 Metetra
.727 .99 .866 r
.35165 .32028 .35273 .32396 .36364 .31517 .36264 .31048 Metetra
.774 .995 .871 r
.36264 .31048 .36364 .31517 .37455 .30554 .37363 .29974 Metetra
.81 .992 .872 r
.37363 .29974 .37455 .30554 .38545 .29511 .38462 .28809 Metetra
.836 .985 .87 r
.38462 .28809 .38545 .29511 .39636 .28394 .3956 .2756 Metetra
.854 .973 .867 r
.3956 .2756 .39636 .28394 .40727 .27216 .40659 .2624 Metetra
.865 .958 .865 r
.40659 .2624 .40727 .27216 .41818 .25995 .41758 .24868 Metetra
.868 .941 .864 r
.41758 .24868 .41818 .25995 .42909 .24759 .42857 .23471 Metetra
.865 .92 .864 r
.42857 .23471 .42909 .24759 .44 .23542 .43956 .2209 Metetra
.855 .897 .865 r
.43956 .2209 .44 .23542 .45091 .2239 .45055 .20774 Metetra
.837 .869 .868 r
.45055 .20774 .45091 .2239 .46182 .21358 .46154 .19587 Metetra
.81 .837 .871 r
.46154 .19587 .46182 .21358 .47273 .20507 .47253 .186 Metetra
.775 .8 .873 r
.47253 .186 .47273 .20507 .48364 .19896 .48352 .17888 Metetra
.731 .758 .875 r
.48352 .17888 .48364 .19896 .49455 .19577 .49451 .17514 Metetra
.68 .714 .874 r
.49451 .17514 .49455 .19577 .50545 .19577 .50549 .17514 Metetra
.81319 .3628 .81091 .36187 .82182 .35755 .82418 .35827 Metetra
.039 0 0 r
.8022 .36618 .8 .36506 .81091 .36187 .81319 .3628 Metetra
.081 0 0 r
.79121 .36849 .78909 .36723 .8 .36506 .8022 .36618 Metetra
.118 0 0 r
.78022 .36981 .77818 .36847 .78909 .36723 .79121 .36849 Metetra
.148 0 0 r
.76923 .37022 .76727 .36885 .77818 .36847 .78022 .36981 Metetra
.169 0 0 r
.75824 .36976 .75636 .36844 .76727 .36885 .76923 .37022 Metetra
.182 0 0 r
.74725 .36848 .74545 .36728 .75636 .36844 .75824 .36976 Metetra
.186 0 0 r
.73626 .36641 .73455 .3654 .74545 .36728 .74725 .36848 Metetra
.18 0 0 r
.72527 .36354 .72364 .36281 .73455 .3654 .73626 .36641 Metetra
0 .423 .7 r
.71429 .35989 .71273 .35952 .72364 .36281 .72527 .36354 Metetra
0 .432 .746 r
.7033 .35544 .70182 .35551 .71273 .35952 .71429 .35989 Metetra
0 .441 .788 r
.69231 .35016 .69091 .35078 .70182 .35551 .7033 .35544 Metetra
0 .449 .825 r
.68132 .34404 .68 .34528 .69091 .35078 .69231 .35016 Metetra
0 .454 .853 r
.67033 .33704 .66909 .339 .68 .34528 .68132 .34404 Metetra
.02 .458 .873 r
.65934 .32912 .65818 .3319 .66909 .339 .67033 .33704 Metetra
.064 .459 .884 r
.64835 .32028 .64727 .32396 .65818 .3319 .65934 .32912 Metetra
.107 .459 .888 r
.63736 .31048 .63636 .31517 .64727 .32396 .64835 .32028 Metetra
.147 .459 .887 r
.62637 .29974 .62545 .30554 .63636 .31517 .63736 .31048 Metetra
.186 .46 .883 r
.61538 .28809 .61455 .29511 .62545 .30554 .62637 .29974 Metetra
.223 .462 .877 r
.6044 .2756 .60364 .28394 .61455 .29511 .61538 .28809 Metetra
.26 .467 .871 r
.59341 .2624 .59273 .27216 .60364 .28394 .6044 .2756 Metetra
.297 .475 .866 r
.58242 .24868 .58182 .25995 .59273 .27216 .59341 .2624 Metetra
.335 .487 .862 r
.57143 .23471 .57091 .24759 .58182 .25995 .58242 .24868 Metetra
.375 .504 .86 r
.56044 .2209 .56 .23542 .57091 .24759 .57143 .23471 Metetra
.419 .526 .86 r
.54945 .20774 .54909 .2239 .56 .23542 .56044 .2209 Metetra
.466 .553 .861 r
.53846 .19587 .53818 .21358 .54909 .2239 .54945 .20774 Metetra
.516 .587 .864 r
.52747 .186 .52727 .20507 .53818 .21358 .53846 .19587 Metetra
.57 .626 .868 r
.51648 .17888 .51636 .19896 .52727 .20507 .52747 .186 Metetra
.625 .669 .872 r
.50549 .17514 .50545 .19577 .51636 .19896 .51648 .17888 Metetra
.409 0 0 r
.17343 .359 .17582 .35827 .18681 .3628 .1845 .36372 Metetra
.353 0 0 r
.1845 .36372 .18681 .3628 .1978 .36618 .19557 .36726 Metetra
.295 0 0 r
.19557 .36726 .1978 .36618 .20879 .36849 .20664 .36969 Metetra
.237 0 0 r
.20664 .36969 .20879 .36849 .21978 .36981 .21771 .37108 Metetra
.176 0 0 r
.21771 .37108 .21978 .36981 .23077 .37022 .22878 .3715 Metetra
.112 0 0 r
.22878 .3715 .23077 .37022 .24176 .36976 .23985 .37099 Metetra
.044 0 0 r
.23985 .37099 .24176 .36976 .25275 .36848 .25092 .36958 Metetra
.25092 .36958 .25275 .36848 .26374 .36641 .26199 .36731 Metetra
.26199 .36731 .26374 .36641 .27473 .36354 .27306 .36416 Metetra
.27306 .36416 .27473 .36354 .28571 .35989 .28413 .36015 Metetra
.284 .775 .714 r
.28413 .36015 .28571 .35989 .2967 .35544 .2952 .35525 Metetra
.375 .833 .749 r
.2952 .35525 .2967 .35544 .30769 .35016 .30627 .34945 Metetra
.465 .884 .782 r
.30627 .34945 .30769 .35016 .31868 .34404 .31734 .3427 Metetra
.549 .927 .809 r
.31734 .3427 .31868 .34404 .32967 .33704 .32841 .33499 Metetra
.626 .96 .829 r
.32841 .33499 .32967 .33704 .34066 .32912 .33948 .32627 Metetra
.692 .981 .842 r
.33948 .32627 .34066 .32912 .35165 .32028 .35055 .31651 Metetra
.747 .994 .85 r
.35055 .31651 .35165 .32028 .36264 .31048 .36162 .3057 Metetra
.791 .998 .853 r
.36162 .3057 .36264 .31048 .37363 .29974 .37269 .29384 Metetra
.826 .995 .853 r
.37269 .29384 .37363 .29974 .38462 .28809 .38376 .28095 Metetra
.851 .988 .851 r
.38376 .28095 .38462 .28809 .3956 .2756 .39483 .26711 Metetra
.869 .977 .849 r
.39483 .26711 .3956 .2756 .40659 .2624 .4059 .25243 Metetra
.88 .963 .847 r
.4059 .25243 .40659 .2624 .41758 .24868 .41697 .23711 Metetra
.884 .946 .847 r
.41697 .23711 .41758 .24868 .42857 .23471 .42804 .22144 Metetra
.881 .926 .849 r
.42804 .22144 .42857 .23471 .43956 .2209 .43911 .20584 Metetra
.871 .903 .852 r
.43911 .20584 .43956 .2209 .45055 .20774 .45018 .19087 Metetra
.853 .876 .856 r
.45018 .19087 .45055 .20774 .46154 .19587 .46125 .17726 Metetra
.825 .843 .861 r
.46125 .17726 .46154 .19587 .47253 .186 .47232 .16584 Metetra
.787 .803 .866 r
.47232 .16584 .47253 .186 .48352 .17888 .48339 .15755 Metetra
.739 .758 .868 r
.48339 .15755 .48352 .17888 .49451 .17514 .49446 .15316 Metetra
.682 .709 .868 r
.49446 .15316 .49451 .17514 .50549 .17514 .50554 .15316 Metetra
.8155 .36372 .81319 .3628 .82418 .35827 .82657 .359 Metetra
.029 0 0 r
.80443 .36726 .8022 .36618 .81319 .3628 .8155 .36372 Metetra
.07 0 0 r
.79336 .36969 .79121 .36849 .8022 .36618 .80443 .36726 Metetra
.106 0 0 r
.78229 .37108 .78022 .36981 .79121 .36849 .79336 .36969 Metetra
.135 0 0 r
.77122 .3715 .76923 .37022 .78022 .36981 .78229 .37108 Metetra
.158 0 0 r
.76015 .37099 .75824 .36976 .76923 .37022 .77122 .3715 Metetra
.172 0 0 r
.74908 .36958 .74725 .36848 .75824 .36976 .76015 .37099 Metetra
.177 0 0 r
.73801 .36731 .73626 .36641 .74725 .36848 .74908 .36958 Metetra
.174 0 0 r
.72694 .36416 .72527 .36354 .73626 .36641 .73801 .36731 Metetra
0 .422 .714 r
.71587 .36015 .71429 .35989 .72527 .36354 .72694 .36416 Metetra
0 .425 .754 r
.7048 .35525 .7033 .35544 .71429 .35989 .71587 .36015 Metetra
0 .428 .791 r
.69373 .34945 .69231 .35016 .7033 .35544 .7048 .35525 Metetra
0 .431 .822 r
.68266 .3427 .68132 .34404 .69231 .35016 .69373 .34945 Metetra
0 .432 .846 r
.67159 .33499 .67033 .33704 .68132 .34404 .68266 .3427 Metetra
.001 .432 .861 r
.66052 .32627 .65934 .32912 .67033 .33704 .67159 .33499 Metetra
.042 .43 .869 r
.64945 .31651 .64835 .32028 .65934 .32912 .66052 .32627 Metetra
.081 .429 .872 r
.63838 .3057 .63736 .31048 .64835 .32028 .64945 .31651 Metetra
.12 .428 .87 r
.62731 .29384 .62637 .29974 .63736 .31048 .63838 .3057 Metetra
.157 .428 .866 r
.61624 .28095 .61538 .28809 .62637 .29974 .62731 .29384 Metetra
.194 .43 .86 r
.60517 .26711 .6044 .2756 .61538 .28809 .61624 .28095 Metetra
.23 .436 .855 r
.5941 .25243 .59341 .2624 .6044 .2756 .60517 .26711 Metetra
.268 .445 .851 r
.58303 .23711 .58242 .24868 .59341 .2624 .5941 .25243 Metetra
.307 .458 .848 r
.57196 .22144 .57143 .23471 .58242 .24868 .58303 .23711 Metetra
.35 .476 .847 r
.56089 .20584 .56044 .2209 .57143 .23471 .57196 .22144 Metetra
.396 .5 .848 r
.54982 .19087 .54945 .20774 .56044 .2209 .56089 .20584 Metetra
.446 .531 .851 r
.53875 .17726 .53846 .19587 .54945 .20774 .54982 .19087 Metetra
.501 .567 .855 r
.52768 .16584 .52747 .186 .53846 .19587 .53875 .17726 Metetra
.56 .61 .86 r
.51661 .15755 .51648 .17888 .52747 .186 .52768 .16584 Metetra
.621 .658 .865 r
.50554 .15316 .50549 .17514 .51648 .17888 .51661 .15755 Metetra
.417 0 0 r
.171 .35975 .17343 .359 .1845 .36372 .18216 .36464 Metetra
.358 0 0 r
.18216 .36464 .1845 .36372 .19557 .36726 .19331 .36831 Metetra
.296 0 0 r
.19331 .36831 .19557 .36726 .20664 .36969 .20446 .37084 Metetra
.233 0 0 r
.20446 .37084 .20664 .36969 .21771 .37108 .21561 .37229 Metetra
.167 0 0 r
.21561 .37229 .21771 .37108 .22878 .3715 .22677 .3727 Metetra
.097 0 0 r
.22677 .3727 .22878 .3715 .23985 .37099 .23792 .37213 Metetra
.023 0 0 r
.23792 .37213 .23985 .37099 .25092 .36958 .24907 .37059 Metetra
.24907 .37059 .25092 .36958 .26199 .36731 .26022 .36811 Metetra
.26022 .36811 .26199 .36731 .27306 .36416 .27138 .36469 Metetra
.226 .735 .689 r
.27138 .36469 .27306 .36416 .28413 .36015 .28253 .36032 Metetra
.316 .795 .722 r
.28253 .36032 .28413 .36015 .2952 .35525 .29368 .35498 Metetra
.407 .85 .753 r
.29368 .35498 .2952 .35525 .30627 .34945 .30483 .34865 Metetra
.494 .898 .78 r
.30483 .34865 .30627 .34945 .31734 .3427 .31599 .3413 Metetra
.575 .937 .802 r
.31599 .3413 .31734 .3427 .32841 .33499 .32714 .33287 Metetra
.648 .966 .818 r
.32714 .33287 .32841 .33499 .33948 .32627 .33829 .32335 Metetra
.711 .986 .828 r
.33829 .32335 .33948 .32627 .35055 .31651 .34944 .31269 Metetra
.764 .996 .833 r
.34944 .31269 .35055 .31651 .36162 .3057 .36059 .30086 Metetra
.806 1 .834 r
.36059 .30086 .36162 .3057 .37269 .29384 .37175 .28787 Metetra
.839 .997 .833 r
.37175 .28787 .37269 .29384 .38376 .28095 .3829 .27373 Metetra
.864 .99 .832 r
.3829 .27373 .38376 .28095 .39483 .26711 .39405 .25849 Metetra
.882 .98 .83 r
.39405 .25849 .39483 .26711 .4059 .25243 .4052 .24228 Metetra
.893 .967 .829 r
.4052 .24228 .4059 .25243 .41697 .23711 .41636 .22528 Metetra
.897 .951 .83 r
.41636 .22528 .41697 .23711 .42804 .22144 .42751 .2078 Metetra
.896 .932 .832 r
.42751 .2078 .42804 .22144 .43911 .20584 .43866 .19027 Metetra
.886 .91 .837 r
.43866 .19027 .43911 .20584 .45018 .19087 .44981 .1733 Metetra
.869 .882 .844 r
.44981 .1733 .45018 .19087 .46125 .17726 .46097 .15771 Metetra
.84 .849 .851 r
.46097 .15771 .46125 .17726 .47232 .16584 .47212 .14451 Metetra
.8 .807 .857 r
.47212 .14451 .47232 .16584 .48339 .15755 .48327 .13482 Metetra
.747 .758 .861 r
.48327 .13482 .48339 .15755 .49446 .15316 .49442 .12965 Metetra
.685 .703 .861 r
.49442 .12965 .49446 .15316 .50554 .15316 .50558 .12965 Metetra
.81784 .36464 .8155 .36372 .82657 .359 .829 .35975 Metetra
.021 0 0 r
.80669 .36831 .80443 .36726 .8155 .36372 .81784 .36464 Metetra
.06 0 0 r
.79554 .37084 .79336 .36969 .80443 .36726 .80669 .36831 Metetra
.095 0 0 r
.78439 .37229 .78229 .37108 .79336 .36969 .79554 .37084 Metetra
.125 0 0 r
.77323 .3727 .77122 .3715 .78229 .37108 .78439 .37229 Metetra
.148 0 0 r
.76208 .37213 .76015 .37099 .77122 .3715 .77323 .3727 Metetra
.163 0 0 r
.75093 .37059 .74908 .36958 .76015 .37099 .76208 .37213 Metetra
.171 0 0 r
.73978 .36811 .73801 .36731 .74908 .36958 .75093 .37059 Metetra
.17 0 0 r
.72862 .36469 .72694 .36416 .73801 .36731 .73978 .36811 Metetra
0 .419 .724 r
.71747 .36032 .71587 .36015 .72694 .36416 .72862 .36469 Metetra
0 .416 .76 r
.70632 .35498 .7048 .35525 .71587 .36015 .71747 .36032 Metetra
0 .415 .792 r
.69517 .34865 .69373 .34945 .7048 .35525 .70632 .35498 Metetra
0 .412 .818 r
.68401 .3413 .68266 .3427 .69373 .34945 .69517 .34865 Metetra
0 .409 .837 r
.67286 .33287 .67159 .33499 .68266 .3427 .68401 .3413 Metetra
0 .406 .848 r
.66171 .32335 .66052 .32627 .67159 .33499 .67286 .33287 Metetra
.019 .402 .854 r
.65056 .31269 .64945 .31651 .66052 .32627 .66171 .32335 Metetra
.056 .399 .855 r
.63941 .30086 .63838 .3057 .64945 .31651 .65056 .31269 Metetra
.092 .396 .852 r
.62825 .28787 .62731 .29384 .63838 .3057 .63941 .30086 Metetra
.128 .396 .848 r
.6171 .27373 .61624 .28095 .62731 .29384 .62825 .28787 Metetra
.163 .399 .843 r
.60595 .25849 .60517 .26711 .61624 .28095 .6171 .27373 Metetra
.2 .404 .838 r
.5948 .24228 .5941 .25243 .60517 .26711 .60595 .25849 Metetra
.238 .414 .835 r
.58364 .22528 .58303 .23711 .5941 .25243 .5948 .24228 Metetra
.278 .428 .833 r
.57249 .2078 .57196 .22144 .58303 .23711 .58364 .22528 Metetra
.322 .448 .833 r
.56134 .19027 .56089 .20584 .57196 .22144 .57249 .2078 Metetra
.371 .474 .835 r
.55019 .1733 .54982 .19087 .56089 .20584 .56134 .19027 Metetra
.424 .506 .839 r
.53903 .15771 .53875 .17726 .54982 .19087 .55019 .1733 Metetra
.484 .546 .845 r
.52788 .14451 .52768 .16584 .53875 .17726 .53903 .15771 Metetra
.548 .594 .852 r
.51673 .13482 .51661 .15755 .52768 .16584 .52788 .14451 Metetra
.617 .647 .858 r
.50558 .12965 .50554 .15316 .51661 .15755 .51673 .13482 Metetra
.424 0 0 r
.16854 .36052 .171 .35975 .18216 .36464 .17978 .36555 Metetra
.361 0 0 r
.17978 .36555 .18216 .36464 .19331 .36831 .19101 .36934 Metetra
.296 0 0 r
.19101 .36934 .19331 .36831 .20446 .37084 .20225 .37195 Metetra
.229 0 0 r
.20225 .37195 .20446 .37084 .21561 .37229 .21348 .37343 Metetra
.158 0 0 r
.21348 .37343 .21561 .37229 .22677 .3727 .22472 .37384 Metetra
.083 0 0 r
.22472 .37384 .22677 .3727 .23792 .37213 .23596 .37319 Metetra
.005 0 0 r
.23596 .37319 .23792 .37213 .24907 .37059 .24719 .37152 Metetra
.24719 .37152 .24907 .37059 .26022 .36811 .25843 .36884 Metetra
.25843 .36884 .26022 .36811 .27138 .36469 .26966 .36514 Metetra
.254 .754 .699 r
.26966 .36514 .27138 .36469 .28253 .36032 .2809 .36042 Metetra
.345 .812 .728 r
.2809 .36042 .28253 .36032 .29368 .35498 .29213 .35465 Metetra
.434 .865 .754 r
.29213 .35465 .29368 .35498 .30483 .34865 .30337 .3478 Metetra
.519 .909 .776 r
.30337 .3478 .30483 .34865 .31599 .3413 .31461 .33984 Metetra
.597 .945 .794 r
.31461 .33984 .31599 .3413 .32714 .33287 .32584 .33072 Metetra
.667 .971 .805 r
.32584 .33072 .32714 .33287 .33829 .32335 .33708 .3204 Metetra
.727 .988 .812 r
.33708 .3204 .33829 .32335 .34944 .31269 .34831 .30884 Metetra
.777 .997 .815 r
.34831 .30884 .34944 .31269 .36059 .30086 .35955 .296 Metetra
.818 1 .815 r
.35955 .296 .36059 .30086 .37175 .28787 .37079 .28186 Metetra
.85 .998 .814 r
.37079 .28186 .37175 .28787 .3829 .27373 .38202 .26645 Metetra
.875 .991 .812 r
.38202 .26645 .3829 .27373 .39405 .25849 .39326 .24979 Metetra
.893 .982 .81 r
.39326 .24979 .39405 .25849 .4052 .24228 .40449 .232 Metetra
.904 .969 .81 r
.40449 .232 .4052 .24228 .41636 .22528 .41573 .21325 Metetra
.91 .955 .811 r
.41573 .21325 .41636 .22528 .42751 .2078 .42697 .19383 Metetra
.909 .937 .815 r
.42697 .19383 .42751 .2078 .43866 .19027 .4382 .17421 Metetra
.902 .916 .821 r
.4382 .17421 .43866 .19027 .44981 .1733 .44944 .15503 Metetra
.885 .889 .83 r
.44944 .15503 .44981 .1733 .46097 .15771 .46067 .13719 Metetra
.856 .855 .839 r
.46067 .13719 .46097 .15771 .47212 .14451 .47191 .1219 Metetra
.814 .812 .848 r
.47191 .1219 .47212 .14451 .48327 .13482 .48315 .11053 Metetra
.757 .759 .854 r
.48315 .11053 .48327 .13482 .49442 .12965 .49438 .10443 Metetra
.687 .698 .855 r
.49438 .10443 .49442 .12965 .50558 .12965 .50562 .10443 Metetra
.82022 .36555 .81784 .36464 .829 .35975 .83146 .36052 Metetra
.015 0 0 r
.80899 .36934 .80669 .36831 .81784 .36464 .82022 .36555 Metetra
.052 0 0 r
.79775 .37195 .79554 .37084 .80669 .36831 .80899 .36934 Metetra
.087 0 0 r
.78652 .37343 .78439 .37229 .79554 .37084 .79775 .37195 Metetra
.116 0 0 r
.77528 .37384 .77323 .3727 .78439 .37229 .78652 .37343 Metetra
.14 0 0 r
.76404 .37319 .76208 .37213 .77323 .3727 .77528 .37384 Metetra
.157 0 0 r
.75281 .37152 .75093 .37059 .76208 .37213 .76404 .37319 Metetra
.166 0 0 r
.74157 .36884 .73978 .36811 .75093 .37059 .75281 .37152 Metetra
0 .421 .696 r
.73034 .36514 .72862 .36469 .73978 .36811 .74157 .36884 Metetra
0 .414 .731 r
.7191 .36042 .71747 .36032 .72862 .36469 .73034 .36514 Metetra
0 .407 .763 r
.70787 .35465 .70632 .35498 .71747 .36032 .7191 .36042 Metetra
0 .4 .79 r
.69663 .3478 .69517 .34865 .70632 .35498 .70787 .35465 Metetra
0 .393 .811 r
.68539 .33984 .68401 .3413 .69517 .34865 .69663 .3478 Metetra
0 .386 .826 r
.67416 .33072 .67286 .33287 .68401 .3413 .68539 .33984 Metetra
0 .38 .835 r
.66292 .3204 .66171 .32335 .67286 .33287 .67416 .33072 Metetra
0 .374 .838 r
.65169 .30884 .65056 .31269 .66171 .32335 .66292 .3204 Metetra
.029 .369 .838 r
.64045 .296 .63941 .30086 .65056 .31269 .65169 .30884 Metetra
.063 .366 .835 r
.62921 .28186 .62825 .28787 .63941 .30086 .64045 .296 Metetra
.097 .365 .83 r
.61798 .26645 .6171 .27373 .62825 .28787 .62921 .28186 Metetra
.132 .367 .825 r
.60674 .24979 .60595 .25849 .6171 .27373 .61798 .26645 Metetra
.168 .372 .821 r
.59551 .232 .5948 .24228 .60595 .25849 .60674 .24979 Metetra
.206 .382 .818 r
.58427 .21325 .58364 .22528 .5948 .24228 .59551 .232 Metetra
.248 .397 .817 r
.57303 .19383 .57249 .2078 .58364 .22528 .58427 .21325 Metetra
.293 .418 .818 r
.5618 .17421 .56134 .19027 .57249 .2078 .57303 .19383 Metetra
.344 .445 .821 r
.55056 .15503 .55019 .1733 .56134 .19027 .5618 .17421 Metetra
.401 .48 .826 r
.53933 .13719 .53903 .15771 .55019 .1733 .55056 .15503 Metetra
.464 .524 .834 r
.52809 .1219 .52788 .14451 .53903 .15771 .53933 .13719 Metetra
.535 .576 .842 r
.51685 .11053 .51673 .13482 .52788 .14451 .52809 .1219 Metetra
.611 .635 .85 r
.50562 .10443 .50558 .12965 .51673 .13482 .51685 .11053 Metetra
.429 0 0 r
.16604 .36131 .16854 .36052 .17978 .36555 .17736 .36646 Metetra
.364 0 0 r
.17736 .36646 .17978 .36555 .19101 .36934 .18868 .37035 Metetra
.296 0 0 r
.18868 .37035 .19101 .36934 .20225 .37195 .2 .37303 Metetra
.225 0 0 r
.2 .37303 .20225 .37195 .21348 .37343 .21132 .37454 Metetra
.149 0 0 r
.21132 .37454 .21348 .37343 .22472 .37384 .22264 .37492 Metetra
.07 0 0 r
.22264 .37492 .22472 .37384 .23596 .37319 .23396 .3742 Metetra
.23396 .3742 .23596 .37319 .24719 .37152 .24528 .37239 Metetra
.24528 .37239 .24719 .37152 .25843 .36884 .2566 .3695 Metetra
.2566 .3695 .25843 .36884 .26966 .36514 .26792 .36553 Metetra
.279 .771 .706 r
.26792 .36553 .26966 .36514 .2809 .36042 .27925 .36047 Metetra
.37 .827 .731 r
.27925 .36047 .2809 .36042 .29213 .35465 .29057 .35427 Metetra
.458 .876 .753 r
.29057 .35427 .29213 .35465 .30337 .3478 .30189 .34692 Metetra
.54 .917 .771 r
.30189 .34692 .30337 .3478 .31461 .33984 .31321 .33836 Metetra
.616 .95 .784 r
.31321 .33836 .31461 .33984 .32584 .33072 .32453 .32855 Metetra
.682 .974 .792 r
.32453 .32855 .32584 .33072 .33708 .3204 .33585 .31745 Metetra
.74 .989 .796 r
.33585 .31745 .33708 .3204 .34831 .30884 .34717 .30499 Metetra
.788 .997 .797 r
.34717 .30499 .34831 .30884 .35955 .296 .35849 .29114 Metetra
.827 .999 .796 r
.35849 .29114 .35955 .296 .37079 .28186 .36981 .27587 Metetra
.859 .997 .793 r
.36981 .27587 .37079 .28186 .38202 .26645 .38113 .25916 Metetra
.883 .991 .791 r
.38113 .25916 .38202 .26645 .39326 .24979 .39245 .24106 Metetra
.902 .982 .789 r
.39245 .24106 .39326 .24979 .40449 .232 .40377 .22163 Metetra
.914 .971 .789 r
.40377 .22163 .40449 .232 .41573 .21325 .41509 .20105 Metetra
.921 .958 .791 r
.41509 .20105 .41573 .21325 .42697 .19383 .42642 .17959 Metetra
.922 .941 .796 r
.42642 .17959 .42697 .19383 .4382 .17421 .43774 .1577 Metetra
.916 .921 .803 r
.43774 .1577 .4382 .17421 .44944 .15503 .44906 .13606 Metetra
.901 .896 .814 r
.44906 .13606 .44944 .15503 .46067 .13719 .46038 .11567 Metetra
.873 .862 .826 r
.46038 .11567 .46067 .13719 .47191 .1219 .4717 .09792 Metetra
.829 .817 .838 r
.4717 .09792 .47191 .1219 .48315 .11053 .48302 .08452 Metetra
.705 .71 .852 r
.48302 .08452 .48315 .11053 .49438 .10443 .49434 .08302 Metetra
.679 .716 .877 r
.49434 .08302 .49438 .10443 .50562 .10443 .50566 .08302 Metetra
.82264 .36646 .82022 .36555 .83146 .36052 .83396 .36131 Metetra
.01 0 0 r
.81132 .37035 .80899 .36934 .82022 .36555 .82264 .36646 Metetra
.046 0 0 r
.8 .37303 .79775 .37195 .80899 .36934 .81132 .37035 Metetra
.08 0 0 r
.78868 .37454 .78652 .37343 .79775 .37195 .8 .37303 Metetra
.109 0 0 r
.77736 .37492 .77528 .37384 .78652 .37343 .78868 .37454 Metetra
.134 0 0 r
.76604 .3742 .76404 .37319 .77528 .37384 .77736 .37492 Metetra
.152 0 0 r
.75472 .37239 .75281 .37152 .76404 .37319 .76604 .3742 Metetra
.163 0 0 r
.7434 .3695 .74157 .36884 .75281 .37152 .75472 .37239 Metetra
0 .419 .704 r
.73208 .36553 .73034 .36514 .74157 .36884 .7434 .3695 Metetra
0 .407 .736 r
.72075 .36047 .7191 .36042 .73034 .36514 .73208 .36553 Metetra
0 .396 .764 r
.70943 .35427 .70787 .35465 .7191 .36042 .72075 .36047 Metetra
0 .385 .787 r
.69811 .34692 .69663 .3478 .70787 .35465 .70943 .35427 Metetra
0 .374 .804 r
.68679 .33836 .68539 .33984 .69663 .3478 .69811 .34692 Metetra
0 .364 .815 r
.67547 .32855 .67416 .33072 .68539 .33984 .68679 .33836 Metetra
0 .354 .821 r
.66415 .31745 .66292 .3204 .67416 .33072 .67547 .32855 Metetra
0 .346 .822 r
.65283 .30499 .65169 .30884 .66292 .3204 .66415 .31745 Metetra
.002 .339 .82 r
.64151 .29114 .64045 .296 .65169 .30884 .65283 .30499 Metetra
.034 .335 .816 r
.63019 .27587 .62921 .28186 .64045 .296 .64151 .29114 Metetra
.066 .333 .811 r
.61887 .25916 .61798 .26645 .62921 .28186 .63019 .27587 Metetra
.1 .335 .807 r
.60755 .24106 .60674 .24979 .61798 .26645 .61887 .25916 Metetra
.136 .34 .803 r
.59623 .22163 .59551 .232 .60674 .24979 .60755 .24106 Metetra
.174 .35 .8 r
.58491 .20105 .58427 .21325 .59551 .232 .59623 .22163 Metetra
.216 .366 .8 r
.57358 .17959 .57303 .19383 .58427 .21325 .58491 .20105 Metetra
.262 .387 .802 r
.56226 .1577 .5618 .17421 .57303 .19383 .57358 .17959 Metetra
.315 .416 .806 r
.55094 .13606 .55056 .15503 .5618 .17421 .56226 .1577 Metetra
.375 .452 .813 r
.53962 .11567 .53933 .13719 .55056 .15503 .55094 .13606 Metetra
.443 .499 .822 r
.5283 .09792 .52809 .1219 .53933 .13719 .53962 .11567 Metetra
.52 .555 .832 r
.51698 .08452 .51685 .11053 .52809 .1219 .5283 .09792 Metetra
.657 .699 .877 r
.50566 .08302 .50562 .10443 .51685 .11053 .51698 .08452 Metetra
.434 0 0 r
.1635 .36213 .16604 .36131 .17736 .36646 .1749 .36738 Metetra
.367 0 0 r
.1749 .36738 .17736 .36646 .18868 .37035 .18631 .37135 Metetra
.296 0 0 r
.18631 .37135 .18868 .37035 .2 .37303 .19772 .37408 Metetra
.221 0 0 r
.19772 .37408 .2 .37303 .21132 .37454 .20913 .37561 Metetra
.142 0 0 r
.20913 .37561 .21132 .37454 .22264 .37492 .22053 .37596 Metetra
.059 0 0 r
.22053 .37596 .22264 .37492 .23396 .3742 .23194 .37515 Metetra
.23194 .37515 .23396 .3742 .24528 .37239 .24335 .37321 Metetra
.24335 .37321 .24528 .37239 .2566 .3695 .25475 .37012 Metetra
.209 .724 .685 r
.25475 .37012 .2566 .3695 .26792 .36553 .26616 .36588 Metetra
.301 .784 .71 r
.26616 .36588 .26792 .36553 .27925 .36047 .27757 .36047 Metetra
.391 .838 .732 r
.27757 .36047 .27925 .36047 .29057 .35427 .28897 .35386 Metetra
.478 .885 .75 r
.28897 .35386 .29057 .35427 .30189 .34692 .30038 .34601 Metetra
.558 .924 .764 r
.30038 .34601 .30189 .34692 .31321 .33836 .31179 .33687 Metetra
.631 .954 .773 r
.31179 .33687 .31321 .33836 .32453 .32855 .32319 .32639 Metetra
.695 .975 .778 r
.32319 .32639 .32453 .32855 .33585 .31745 .3346 .31451 Metetra
.75 .989 .78 r
.3346 .31451 .33585 .31745 .34717 .30499 .34601 .30118 Metetra
.796 .996 .779 r
.34601 .30118 .34717 .30499 .35849 .29114 .35741 .28632 Metetra
.834 .998 .776 r
.35741 .28632 .35849 .29114 .36981 .27587 .36882 .26991 Metetra
.865 .995 .773 r
.36882 .26991 .36981 .27587 .38113 .25916 .38023 .25192 Metetra
.89 .99 .77 r
.38023 .25192 .38113 .25916 .39245 .24106 .39163 .23234 Metetra
.909 .982 .768 r
.39163 .23234 .39245 .24106 .40377 .22163 .40304 .21124 Metetra
.922 .972 .767 r
.40304 .21124 .40377 .22163 .41509 .20105 .41445 .18876 Metetra
.931 .96 .77 r
.41445 .18876 .41509 .20105 .42642 .17959 .42586 .16513 Metetra
.933 .945 .775 r
.42586 .16513 .42642 .17959 .43774 .1577 .43726 .14079 Metetra
.929 .926 .784 r
.43726 .14079 .43774 .1577 .44906 .13606 .44867 .11644 Metetra
.916 .902 .796 r
.44867 .11644 .44906 .13606 .46038 .11567 .46008 .09313 Metetra
.814 .816 .851 r
.46008 .09313 .46038 .11567 .4717 .09792 .47148 .08175 Metetra
.658 .748 .917 r
.47148 .08175 .4717 .09792 .48302 .08452 .48289 .08175 Metetra
.283 .76 .931 r
.48289 .08175 .48302 .08452 .49434 .08302 .4943 .08175 Metetra
.8251 .36738 .82264 .36646 .83396 .36131 .8365 .36213 Metetra
.006 0 0 r
.81369 .37135 .81132 .37035 .82264 .36646 .8251 .36738 Metetra
.041 0 0 r
.80228 .37408 .8 .37303 .81132 .37035 .81369 .37135 Metetra
.074 0 0 r
.79087 .37561 .78868 .37454 .8 .37303 .80228 .37408 Metetra
.104 0 0 r
.77947 .37596 .77736 .37492 .78868 .37454 .79087 .37561 Metetra
.129 0 0 r
.76806 .37515 .76604 .3742 .77736 .37492 .77947 .37596 Metetra
.149 0 0 r
.75665 .37321 .75472 .37239 .76604 .3742 .76806 .37515 Metetra
.162 0 0 r
.74525 .37012 .7434 .3695 .75472 .37239 .75665 .37321 Metetra
0 .415 .71 r
.73384 .36588 .73208 .36553 .7434 .3695 .74525 .37012 Metetra
0 .399 .738 r
.72243 .36047 .72075 .36047 .73208 .36553 .73384 .36588 Metetra
0 .384 .762 r
.71103 .35386 .70943 .35427 .72075 .36047 .72243 .36047 Metetra
0 .369 .781 r
.69962 .34601 .69811 .34692 .70943 .35427 .71103 .35386 Metetra
0 .355 .795 r
.68821 .33687 .68679 .33836 .69811 .34692 .69962 .34601 Metetra
0 .341 .803 r
.67681 .32639 .67547 .32855 .68679 .33836 .68821 .33687 Metetra
0 .329 .806 r
.6654 .31451 .66415 .31745 .67547 .32855 .67681 .32639 Metetra
0 .319 .805 r
.65399 .30118 .65283 .30499 .66415 .31745 .6654 .31451 Metetra
0 .31 .802 r
.64259 .28632 .64151 .29114 .65283 .30499 .65399 .30118 Metetra
.004 .304 .797 r
.63118 .26991 .63019 .27587 .64151 .29114 .64259 .28632 Metetra
.035 .302 .792 r
.61977 .25192 .61887 .25916 .63019 .27587 .63118 .26991 Metetra
.067 .303 .787 r
.60837 .23234 .60755 .24106 .61887 .25916 .61977 .25192 Metetra
.102 .308 .784 r
.59696 .21124 .59623 .22163 .60755 .24106 .60837 .23234 Metetra
.139 .317 .782 r
.58555 .18876 .58491 .20105 .59623 .22163 .59696 .21124 Metetra
.181 .333 .782 r
.57414 .16513 .57358 .17959 .58491 .20105 .58555 .18876 Metetra
.229 .354 .784 r
.56274 .14079 .56226 .1577 .57358 .17959 .57414 .16513 Metetra
.283 .384 .789 r
.55133 .11644 .55094 .13606 .56226 .1577 .56274 .14079 Metetra
.345 .422 .798 r
.53992 .09313 .53962 .11567 .55094 .13606 .55133 .11644 Metetra
.438 .558 .879 r
.52852 .08175 .5283 .09792 .53962 .11567 .53992 .09313 Metetra
.283 .76 .931 r
.51711 .08175 .51698 .08452 .5283 .09792 .52852 .08175 Metetra
.139 .679 .832 r
.5057 .08175 .50566 .08302 .51698 .08452 .51711 .08175 Metetra
.437 0 0 r
.16092 .36296 .1635 .36213 .1749 .36738 .17241 .3683 Metetra
.368 0 0 r
.17241 .3683 .1749 .36738 .18631 .37135 .18391 .37234 Metetra
.295 0 0 r
.18391 .37234 .18631 .37135 .19772 .37408 .1954 .37511 Metetra
.217 0 0 r
.1954 .37511 .19772 .37408 .20913 .37561 .2069 .37665 Metetra
.134 0 0 r
.2069 .37665 .20913 .37561 .22053 .37596 .21839 .37696 Metetra
.048 0 0 r
.21839 .37696 .22053 .37596 .23194 .37515 .22989 .37607 Metetra
.22989 .37607 .23194 .37515 .24335 .37321 .24138 .37399 Metetra
.24138 .37399 .24335 .37321 .25475 .37012 .25287 .3707 Metetra
.228 .737 .691 r
.25287 .3707 .25475 .37012 .26616 .36588 .26437 .3662 Metetra
.32 .796 .713 r
.26437 .3662 .26616 .36588 .27757 .36047 .27586 .36046 Metetra
.41 .848 .731 r
.27586 .36046 .27757 .36047 .28897 .35386 .28736 .35345 Metetra
.494 .892 .746 r
.28736 .35345 .28897 .35386 .30038 .34601 .29885 .34511 Metetra
.573 .928 .756 r
.29885 .34511 .30038 .34601 .31179 .33687 .31034 .33541 Metetra
.643 .956 .762 r
.31034 .33541 .31179 .33687 .32319 .32639 .32184 .32427 Metetra
.705 .975 .764 r
.32184 .32427 .32319 .32639 .3346 .31451 .33333 .31164 Metetra
.758 .987 .763 r
.33333 .31164 .3346 .31451 .34601 .30118 .34483 .29743 Metetra
.802 .994 .76 r
.34483 .29743 .34601 .30118 .35741 .28632 .35632 .28159 Metetra
.84 .995 .756 r
.35632 .28159 .35741 .28632 .36882 .26991 .36782 .26405 Metetra
.87 .993 .751 r
.36782 .26405 .36882 .26991 .38023 .25192 .37931 .24476 Metetra
.895 .988 .748 r
.37931 .24476 .38023 .25192 .39163 .23234 .3908 .22371 Metetra
.914 .981 .745 r
.3908 .22371 .39163 .23234 .40304 .21124 .4023 .2009 Metetra
.928 .971 .745 r
.4023 .2009 .40304 .21124 .41445 .18876 .41379 .17644 Metetra
.938 .96 .747 r
.41379 .17644 .41445 .18876 .42586 .16513 .42529 .15054 Metetra
.943 .947 .753 r
.42529 .15054 .42586 .16513 .43726 .14079 .43678 .12357 Metetra
.942 .931 .762 r
.43678 .12357 .43726 .14079 .44867 .11644 .44828 .09622 Metetra
.861 .866 .842 r
.44828 .09622 .44867 .11644 .46008 .09313 .45977 .08046 Metetra
.63 .776 .951 r
.45977 .08046 .46008 .09313 .47148 .08175 .47126 .08046 Metetra
.82759 .3683 .8251 .36738 .8365 .36213 .83908 .36296 Metetra
.002 0 0 r
.81609 .37234 .81369 .37135 .8251 .36738 .82759 .3683 Metetra
.036 0 0 r
.8046 .37511 .80228 .37408 .81369 .37135 .81609 .37234 Metetra
.069 0 0 r
.7931 .37665 .79087 .37561 .80228 .37408 .8046 .37511 Metetra
.1 0 0 r
.78161 .37696 .77947 .37596 .79087 .37561 .7931 .37665 Metetra
.126 0 0 r
.77011 .37607 .76806 .37515 .77947 .37596 .78161 .37696 Metetra
.147 0 0 r
.75862 .37399 .75665 .37321 .76806 .37515 .77011 .37607 Metetra
.162 0 0 r
.74713 .3707 .74525 .37012 .75665 .37321 .75862 .37399 Metetra
0 .41 .714 r
.73563 .3662 .73384 .36588 .74525 .37012 .74713 .3707 Metetra
0 .391 .739 r
.72414 .36046 .72243 .36047 .73384 .36588 .73563 .3662 Metetra
0 .372 .759 r
.71264 .35345 .71103 .35386 .72243 .36047 .72414 .36046 Metetra
0 .353 .775 r
.70115 .34511 .69962 .34601 .71103 .35386 .71264 .35345 Metetra
0 .335 .785 r
.68966 .33541 .68821 .33687 .69962 .34601 .70115 .34511 Metetra
0 .319 .79 r
.67816 .32427 .67681 .32639 .68821 .33687 .68966 .33541 Metetra
0 .304 .79 r
.66667 .31164 .6654 .31451 .67681 .32639 .67816 .32427 Metetra
0 .291 .788 r
.65517 .29743 .65399 .30118 .6654 .31451 .66667 .31164 Metetra
0 .281 .784 r
.64368 .28159 .64259 .28632 .65399 .30118 .65517 .29743 Metetra
0 .274 .778 r
.63218 .26405 .63118 .26991 .64259 .28632 .64368 .28159 Metetra
.002 .27 .773 r
.62069 .24476 .61977 .25192 .63118 .26991 .63218 .26405 Metetra
.033 .27 .768 r
.6092 .22371 .60837 .23234 .61977 .25192 .62069 .24476 Metetra
.066 .274 .764 r
.5977 .2009 .59696 .21124 .60837 .23234 .6092 .22371 Metetra
.103 .283 .762 r
.58621 .17644 .58555 .18876 .59696 .21124 .5977 .2009 Metetra
.145 .298 .762 r
.57471 .15054 .57414 .16513 .58555 .18876 .58621 .17644 Metetra
.193 .32 .765 r
.56322 .12357 .56274 .14079 .57414 .16513 .57471 .15054 Metetra
.248 .35 .772 r
.55172 .09622 .55133 .11644 .56274 .14079 .56322 .12357 Metetra
.263 .444 .852 r
.54023 .08046 .53992 .09313 .55133 .11644 .55172 .09622 Metetra
.139 .679 .832 r
.52874 .08046 .52852 .08175 .53992 .09313 .54023 .08046 Metetra
.439 0 0 r
.1583 .36382 .16092 .36296 .17241 .3683 .16988 .36923 Metetra
.369 0 0 r
.16988 .36923 .17241 .3683 .18391 .37234 .18147 .37333 Metetra
.294 0 0 r
.18147 .37333 .18391 .37234 .1954 .37511 .19305 .37614 Metetra
.213 0 0 r
.19305 .37614 .1954 .37511 .2069 .37665 .20463 .37767 Metetra
.128 0 0 r
.20463 .37767 .2069 .37665 .21839 .37696 .21622 .37794 Metetra
.038 0 0 r
.21622 .37794 .21839 .37696 .22989 .37607 .2278 .37696 Metetra
.2278 .37696 .22989 .37607 .24138 .37399 .23938 .37474 Metetra
.23938 .37474 .24138 .37399 .25287 .3707 .25097 .37126 Metetra
.244 .747 .694 r
.25097 .37126 .25287 .3707 .26437 .3662 .26255 .3665 Metetra
.336 .805 .714 r
.26255 .3665 .26437 .3662 .27586 .36046 .27413 .36044 Metetra
.425 .855 .729 r
.27413 .36044 .27586 .36046 .28736 .35345 .28571 .35304 Metetra
.508 .897 .74 r
.28571 .35304 .28736 .35345 .29885 .34511 .2973 .34424 Metetra
.584 .931 .747 r
.2973 .34424 .29885 .34511 .31034 .33541 .30888 .33399 Metetra
.652 .956 .749 r
.30888 .33399 .31034 .33541 .32184 .32427 .32046 .32221 Metetra
.712 .974 .749 r
.32046 .32221 .32184 .32427 .33333 .31164 .33205 .30884 Metetra
.763 .985 .746 r
.33205 .30884 .33333 .31164 .34483 .29743 .34363 .29379 Metetra
.806 .99 .741 r
.34363 .29379 .34483 .29743 .35632 .28159 .35521 .27698 Metetra
.843 .992 .735 r
.35521 .27698 .35632 .28159 .36782 .26405 .3668 .25833 Metetra
.873 .989 .73 r
.3668 .25833 .36782 .26405 .37931 .24476 .37838 .23776 Metetra
.897 .985 .725 r
.37838 .23776 .37931 .24476 .3908 .22371 .38996 .21521 Metetra
.917 .978 .722 r
.38996 .21521 .3908 .22371 .4023 .2009 .40154 .19068 Metetra
.933 .97 .721 r
.40154 .19068 .4023 .2009 .41379 .17644 .41313 .16419 Metetra
.944 .96 .723 r
.41313 .16419 .41379 .17644 .42529 .15054 .42471 .13591 Metetra
.951 .948 .729 r
.42471 .13591 .42529 .15054 .43678 .12357 .43629 .10615 Metetra
.939 .93 .767 r
.43629 .10615 .43678 .12357 .44828 .09622 .44788 .07915 Metetra
.66 .746 .913 r
.44788 .07915 .44828 .09622 .45977 .08046 .45946 .07915 Metetra
.83012 .36923 .82759 .3683 .83908 .36296 .8417 .36382 Metetra
.81853 .37333 .81609 .37234 .82759 .3683 .83012 .36923 Metetra
.033 0 0 r
.80695 .37614 .8046 .37511 .81609 .37234 .81853 .37333 Metetra
.066 0 0 r
.79537 .37767 .7931 .37665 .8046 .37511 .80695 .37614 Metetra
.097 0 0 r
.78378 .37794 .78161 .37696 .7931 .37665 .79537 .37767 Metetra
.124 0 0 r
.7722 .37696 .77011 .37607 .78161 .37696 .78378 .37794 Metetra
.147 0 0 r
.76062 .37474 .75862 .37399 .77011 .37607 .7722 .37696 Metetra
0 .428 .689 r
.74903 .37126 .74713 .3707 .75862 .37399 .76062 .37474 Metetra
0 .405 .716 r
.73745 .3665 .73563 .3662 .74713 .3707 .74903 .37126 Metetra
0 .381 .738 r
.72587 .36044 .72414 .36046 .73563 .3662 .73745 .3665 Metetra
0 .359 .755 r
.71429 .35304 .71264 .35345 .72414 .36046 .72587 .36044 Metetra
0 .337 .767 r
.7027 .34424 .70115 .34511 .71264 .35345 .71429 .35304 Metetra
0 .316 .774 r
.69112 .33399 .68966 .33541 .70115 .34511 .7027 .34424 Metetra
0 .296 .776 r
.67954 .32221 .67816 .32427 .68966 .33541 .69112 .33399 Metetra
0 .279 .774 r
.66795 .30884 .66667 .31164 .67816 .32427 .67954 .32221 Metetra
0 .265 .77 r
.65637 .29379 .65517 .29743 .66667 .31164 .66795 .30884 Metetra
0 .253 .765 r
.64479 .27698 .64368 .28159 .65517 .29743 .65637 .29379 Metetra
0 .244 .758 r
.6332 .25833 .63218 .26405 .64368 .28159 .64479 .27698 Metetra
0 .239 .752 r
.62162 .23776 .62069 .24476 .63218 .26405 .6332 .25833 Metetra
0 .237 .747 r
.61004 .21521 .6092 .22371 .62069 .24476 .62162 .23776 Metetra
.029 .24 .743 r
.59846 .19068 .5977 .2009 .6092 .22371 .61004 .21521 Metetra
.066 .248 .741 r
.58687 .16419 .58621 .17644 .5977 .2009 .59846 .19068 Metetra
.107 .263 .742 r
.57529 .13591 .57471 .15054 .58621 .17644 .58687 .16419 Metetra
.154 .284 .745 r
.56371 .10615 .56322 .12357 .57471 .15054 .57529 .13591 Metetra
.18 .314 .764 r
.55212 .07915 .55172 .09622 .56322 .12357 .56371 .10615 Metetra
.139 .679 .832 r
.54054 .07915 .54023 .08046 .55172 .09622 .55212 .07915 Metetra
.441 0 0 r
.15564 .3647 .1583 .36382 .16988 .36923 .16732 .37017 Metetra
.37 0 0 r
.16732 .37017 .16988 .36923 .18147 .37333 .17899 .37432 Metetra
.293 0 0 r
.17899 .37432 .18147 .37333 .19305 .37614 .19066 .37715 Metetra
.21 0 0 r
.19066 .37715 .19305 .37614 .20463 .37767 .20233 .37867 Metetra
.121 0 0 r
.20233 .37867 .20463 .37767 .21622 .37794 .21401 .3789 Metetra
.029 0 0 r
.21401 .3789 .21622 .37794 .2278 .37696 .22568 .37784 Metetra
.22568 .37784 .2278 .37696 .23938 .37474 .23735 .37548 Metetra
.23735 .37548 .23938 .37474 .25097 .37126 .24903 .37181 Metetra
.257 .756 .696 r
.24903 .37181 .25097 .37126 .26255 .3665 .2607 .36681 Metetra
.35 .812 .713 r
.2607 .36681 .26255 .3665 .27413 .36044 .27237 .36044 Metetra
.438 .861 .726 r
.27237 .36044 .27413 .36044 .28571 .35304 .28405 .35266 Metetra
.519 .901 .733 r
.28405 .35266 .28571 .35304 .2973 .34424 .29572 .34341 Metetra
.593 .932 .737 r
.29572 .34341 .2973 .34424 .30888 .33399 .30739 .33263 Metetra
.659 .955 .736 r
.30739 .33263 .30888 .33399 .32046 .32221 .31907 .32024 Metetra
.717 .972 .733 r
.31907 .32024 .32046 .32221 .33205 .30884 .33074 .30616 Metetra
.766 .981 .728 r
.33074 .30616 .33205 .30884 .34363 .29379 .34241 .29029 Metetra
.808 .986 .722 r
.34241 .29029 .34363 .29379 .35521 .27698 .35409 .27254 Metetra
.844 .987 .715 r
.35409 .27254 .35521 .27698 .3668 .25833 .36576 .25279 Metetra
.873 .985 .708 r
.36576 .25279 .3668 .25833 .37838 .23776 .37743 .23095 Metetra
.898 .981 .702 r
.37743 .23095 .37838 .23776 .38996 .21521 .38911 .20693 Metetra
.918 .974 .698 r
.38911 .20693 .38996 .21521 .40154 .19068 .40078 .18066 Metetra
.935 .967 .696 r
.40078 .18066 .40154 .19068 .41313 .16419 .41245 .15212 Metetra
.948 .958 .697 r
.41245 .15212 .41313 .16419 .42471 .13591 .42412 .12137 Metetra
.956 .948 .702 r
.42412 .12137 .42471 .13591 .43629 .10615 .4358 .08865 Metetra
.819 .863 .88 r
.4358 .08865 .43629 .10615 .44788 .07915 .44747 .07782 Metetra
.83268 .37017 .83012 .36923 .8417 .36382 .84436 .3647 Metetra
.82101 .37432 .81853 .37333 .83012 .36923 .83268 .37017 Metetra
.031 0 0 r
.80934 .37715 .80695 .37614 .81853 .37333 .82101 .37432 Metetra
.064 0 0 r
.79767 .37867 .79537 .37767 .80695 .37614 .80934 .37715 Metetra
.095 0 0 r
.78599 .3789 .78378 .37794 .79537 .37767 .79767 .37867 Metetra
.123 0 0 r
.77432 .37784 .7722 .37696 .78378 .37794 .78599 .3789 Metetra
.147 0 0 r
.76265 .37548 .76062 .37474 .7722 .37696 .77432 .37784 Metetra
0 .424 .692 r
.75097 .37181 .74903 .37126 .76062 .37474 .76265 .37548 Metetra
0 .398 .716 r
.7393 .36681 .73745 .3665 .74903 .37126 .75097 .37181 Metetra
0 .372 .736 r
.72763 .36044 .72587 .36044 .73745 .3665 .7393 .36681 Metetra
0 .345 .749 r
.71595 .35266 .71429 .35304 .72587 .36044 .72763 .36044 Metetra
0 .32 .758 r
.70428 .34341 .7027 .34424 .71429 .35304 .71595 .35266 Metetra
0 .296 .762 r
.69261 .33263 .69112 .33399 .7027 .34424 .70428 .34341 Metetra
0 .274 .762 r
.68093 .32024 .67954 .32221 .69112 .33399 .69261 .33263 Metetra
0 .255 .758 r
.66926 .30616 .66795 .30884 .67954 .32221 .68093 .32024 Metetra
0 .238 .752 r
.65759 .29029 .65637 .29379 .66795 .30884 .66926 .30616 Metetra
0 .224 .745 r
.64591 .27254 .64479 .27698 .65637 .29379 .65759 .29029 Metetra
0 .214 .738 r
.63424 .25279 .6332 .25833 .64479 .27698 .64591 .27254 Metetra
0 .207 .731 r
.62257 .23095 .62162 .23776 .6332 .25833 .63424 .25279 Metetra
0 .204 .725 r
.61089 .20693 .61004 .21521 .62162 .23776 .62257 .23095 Metetra
0 .206 .721 r
.59922 .18066 .59846 .19068 .61004 .21521 .61089 .20693 Metetra
.026 .212 .719 r
.58755 .15212 .58687 .16419 .59846 .19068 .59922 .18066 Metetra
.066 .225 .719 r
.57588 .12137 .57529 .13591 .58687 .16419 .58755 .15212 Metetra
.113 .246 .723 r
.5642 .08865 .56371 .10615 .57529 .13591 .57588 .12137 Metetra
0 .234 .699 r
.55253 .07782 .55212 .07915 .56371 .10615 .5642 .08865 Metetra
.442 0 0 r
.15294 .3656 .15564 .3647 .16732 .37017 .16471 .37113 Metetra
.37 0 0 r
.16471 .37113 .16732 .37017 .17899 .37432 .17647 .37531 Metetra
.291 0 0 r
.17647 .37531 .17899 .37432 .19066 .37715 .18824 .37816 Metetra
.206 0 0 r
.18824 .37816 .19066 .37715 .20233 .37867 .2 .37967 Metetra
.116 0 0 r
.2 .37967 .20233 .37867 .21401 .3789 .21176 .37986 Metetra
.022 0 0 r
.21176 .37986 .21401 .3789 .22568 .37784 .22353 .37871 Metetra
.22353 .37871 .22568 .37784 .23735 .37548 .23529 .37622 Metetra
.23529 .37622 .23735 .37548 .24903 .37181 .24706 .37236 Metetra
.269 .763 .697 r
.24706 .37236 .24903 .37181 .2607 .36681 .25882 .36713 Metetra
.361 .818 .712 r
.25882 .36713 .2607 .36681 .27237 .36044 .27059 .36046 Metetra
.448 .865 .721 r
.27059 .36046 .27237 .36044 .28405 .35266 .28235 .35232 Metetra
.528 .903 .726 r
.28235 .35232 .28405 .35266 .29572 .34341 .29412 .34265 Metetra
.6 .932 .726 r
.29412 .34265 .29572 .34341 .30739 .33263 .30588 .33136 Metetra
.664 .954 .723 r
.30588 .33136 .30739 .33263 .31907 .32024 .31765 .31839 Metetra
.72 .968 .718 r
.31765 .31839 .31907 .32024 .33074 .30616 .32941 .30362 Metetra
.767 .977 .71 r
.32941 .30362 .33074 .30616 .34241 .29029 .34118 .28697 Metetra
.808 .981 .702 r
.34118 .28697 .34241 .29029 .35409 .27254 .35294 .2683 Metetra
.843 .982 .694 r
.35294 .2683 .35409 .27254 .36576 .25279 .36471 .24749 Metetra
.872 .98 .685 r
.36471 .24749 .36576 .25279 .37743 .23095 .37647 .22442 Metetra
.897 .975 .678 r
.37647 .22442 .37743 .23095 .38911 .20693 .38824 .19894 Metetra
.917 .97 .673 r
.38824 .19894 .38911 .20693 .40078 .18066 .4 .17094 Metetra
.935 .963 .67 r
.4 .17094 .40078 .18066 .41245 .15212 .41176 .14032 Metetra
.949 .955 .67 r
.41176 .14032 .41245 .15212 .42412 .12137 .42353 .10706 Metetra
.951 .952 .719 r
.42353 .10706 .42412 .12137 .4358 .08865 .43529 .07647 Metetra
.618 .785 .961 r
.43529 .07647 .4358 .08865 .44747 .07782 .44706 .07647 Metetra
.83529 .37113 .83268 .37017 .84436 .3647 .84706 .3656 Metetra
.82353 .37531 .82101 .37432 .83268 .37017 .83529 .37113 Metetra
.029 0 0 r
.81176 .37816 .80934 .37715 .82101 .37432 .82353 .37531 Metetra
.062 0 0 r
.8 .37967 .79767 .37867 .80934 .37715 .81176 .37816 Metetra
.094 0 0 r
.78824 .37986 .78599 .3789 .79767 .37867 .8 .37967 Metetra
.123 0 0 r
.77647 .37871 .77432 .37784 .78599 .3789 .78824 .37986 Metetra
.149 0 0 r
.76471 .37622 .76265 .37548 .77432 .37784 .77647 .37871 Metetra
0 .42 .693 r
.75294 .37236 .75097 .37181 .76265 .37548 .76471 .37622 Metetra
0 .391 .715 r
.74118 .36713 .7393 .36681 .75097 .37181 .75294 .37236 Metetra
0 .361 .732 r
.72941 .36046 .72763 .36044 .7393 .36681 .74118 .36713 Metetra
0 .332 .743 r
.71765 .35232 .71595 .35266 .72763 .36044 .72941 .36046 Metetra
0 .304 .748 r
.70588 .34265 .70428 .34341 .71595 .35266 .71765 .35232 Metetra
0 .277 .749 r
.69412 .33136 .69261 .33263 .70428 .34341 .70588 .34265 Metetra
0 .253 .747 r
.68235 .31839 .68093 .32024 .69261 .33263 .69412 .33136 Metetra
0 .231 .741 r
.67059 .30362 .66926 .30616 .68093 .32024 .68235 .31839 Metetra
0 .212 .734 r
.65882 .28697 .65759 .29029 .66926 .30616 .67059 .30362 Metetra
0 .196 .726 r
.64706 .2683 .64591 .27254 .65759 .29029 .65882 .28697 Metetra
0 .184 .717 r
.63529 .24749 .63424 .25279 .64591 .27254 .64706 .2683 Metetra
0 .175 .709 r
.62353 .22442 .62257 .23095 .63424 .25279 .63529 .24749 Metetra
0 .17 .703 r
.61176 .19894 .61089 .20693 .62257 .23095 .62353 .22442 Metetra
0 .17 .698 r
.6 .17094 .59922 .18066 .61089 .20693 .61176 .19894 Metetra
0 .175 .695 r
.58824 .14032 .58755 .15212 .59922 .18066 .6 .17094 Metetra
.022 .187 .696 r
.57647 .10706 .57588 .12137 .58755 .15212 .58824 .14032 Metetra
0 .174 .694 r
.56471 .07647 .5642 .08865 .57588 .12137 .57647 .10706 Metetra
.139 .679 .832 r
.55294 .07647 .55253 .07782 .5642 .08865 .56471 .07647 Metetra
.443 0 0 r
.1502 .36652 .15294 .3656 .16471 .37113 .16206 .37209 Metetra
.37 0 0 r
.16206 .37209 .16471 .37113 .17647 .37531 .17391 .37631 Metetra
.29 0 0 r
.17391 .37631 .17647 .37531 .18824 .37816 .18577 .37917 Metetra
.203 0 0 r
.18577 .37917 .18824 .37816 .2 .37967 .19763 .38067 Metetra
.111 0 0 r
.19763 .38067 .2 .37967 .21176 .37986 .20949 .38081 Metetra
.015 0 0 r
.20949 .38081 .21176 .37986 .22353 .37871 .22134 .37958 Metetra
.22134 .37958 .22353 .37871 .23529 .37622 .2332 .37696 Metetra
.2332 .37696 .23529 .37622 .24706 .37236 .24506 .37293 Metetra
.278 .768 .697 r
.24506 .37293 .24706 .37236 .25882 .36713 .25692 .36747 Metetra
.37 .822 .709 r
.25692 .36747 .25882 .36713 .27059 .36046 .26877 .36053 Metetra
.456 .867 .715 r
.26877 .36053 .27059 .36046 .28235 .35232 .28063 .35205 Metetra
.534 .903 .717 r
.28063 .35205 .28235 .35232 .29412 .34265 .29249 .34197 Metetra
.604 .931 .715 r
.29249 .34197 .29412 .34265 .30588 .33136 .30435 .3302 Metetra
.666 .951 .71 r
.30435 .3302 .30588 .33136 .31765 .31839 .31621 .31667 Metetra
.72 .964 .702 r
.31621 .31667 .31765 .31839 .32941 .30362 .32806 .30126 Metetra
.767 .972 .693 r
.32806 .30126 .32941 .30362 .34118 .28697 .33992 .28385 Metetra
.806 .976 .683 r
.33992 .28385 .34118 .28697 .35294 .2683 .35178 .26431 Metetra
.84 .976 .672 r
.35178 .26431 .35294 .2683 .36471 .24749 .36364 .24248 Metetra
.869 .973 .663 r
.36364 .24248 .36471 .24749 .37647 .22442 .37549 .21821 Metetra
.893 .969 .654 r
.37549 .21821 .37647 .22442 .38824 .19894 .38735 .19132 Metetra
.914 .963 .647 r
.38735 .19132 .38824 .19894 .4 .17094 .39921 .16162 Metetra
.932 .957 .643 r
.39921 .16162 .4 .17094 .41176 .14032 .41107 .12893 Metetra
.947 .95 .641 r
.41107 .12893 .41176 .14032 .42353 .10706 .42292 .09313 Metetra
.893 .945 .836 r
.42292 .09313 .42353 .10706 .43529 .07647 .43478 .0751 Metetra
.83794 .37209 .83529 .37113 .84706 .3656 .8498 .36652 Metetra
.82609 .37631 .82353 .37531 .83529 .37113 .83794 .37209 Metetra
.028 0 0 r
.81423 .37917 .81176 .37816 .82353 .37531 .82609 .37631 Metetra
.061 0 0 r
.80237 .38067 .8 .37967 .81176 .37816 .81423 .37917 Metetra
.093 0 0 r
.79051 .38081 .78824 .37986 .8 .37967 .80237 .38067 Metetra
.124 0 0 r
.77866 .37958 .77647 .37871 .78824 .37986 .79051 .38081 Metetra
.151 0 0 r
.7668 .37696 .76471 .37622 .77647 .37871 .77866 .37958 Metetra
0 .415 .693 r
.75494 .37293 .75294 .37236 .76471 .37622 .7668 .37696 Metetra
0 .383 .713 r
.74308 .36747 .74118 .36713 .75294 .37236 .75494 .37293 Metetra
0 .351 .727 r
.73123 .36053 .72941 .36046 .74118 .36713 .74308 .36747 Metetra
0 .319 .735 r
.71937 .35205 .71765 .35232 .72941 .36046 .73123 .36053 Metetra
0 .288 .738 r
.70751 .34197 .70588 .34265 .71765 .35232 .71937 .35205 Metetra
0 .258 .737 r
.69565 .3302 .69412 .33136 .70588 .34265 .70751 .34197 Metetra
0 .231 .732 r
.68379 .31667 .68235 .31839 .69412 .33136 .69565 .3302 Metetra
0 .207 .724 r
.67194 .30126 .67059 .30362 .68235 .31839 .68379 .31667 Metetra
0 .186 .715 r
.66008 .28385 .65882 .28697 .67059 .30362 .67194 .30126 Metetra
0 .168 .705 r
.64822 .26431 .64706 .2683 .65882 .28697 .66008 .28385 Metetra
0 .153 .696 r
.63636 .24248 .63529 .24749 .64706 .2683 .64822 .26431 Metetra
0 .143 .687 r
.62451 .21821 .62353 .22442 .63529 .24749 .63636 .24248 Metetra
0 .136 .679 r
.61265 .19132 .61176 .19894 .62353 .22442 .62451 .21821 Metetra
0 .134 .673 r
.60079 .16162 .6 .17094 .61176 .19894 .61265 .19132 Metetra
0 .137 .67 r
.58893 .12893 .58824 .14032 .6 .17094 .60079 .16162 Metetra
0 .146 .67 r
.57708 .09313 .57647 .10706 .58824 .14032 .58893 .12893 Metetra
0 .035 .578 r
.56522 .0751 .56471 .07647 .57647 .10706 .57708 .09313 Metetra
.443 0 0 r
.14741 .36746 .1502 .36652 .16206 .37209 .15936 .37307 Metetra
.369 0 0 r
.15936 .37307 .16206 .37209 .17391 .37631 .17131 .37732 Metetra
.289 0 0 r
.17131 .37732 .17391 .37631 .18577 .37917 .18327 .38019 Metetra
.201 0 0 r
.18327 .38019 .18577 .37917 .19763 .38067 .19522 .38168 Metetra
.107 0 0 r
.19522 .38168 .19763 .38067 .20949 .38081 .20717 .38177 Metetra
.009 0 0 r
.20717 .38177 .20949 .38081 .22134 .37958 .21912 .38046 Metetra
.21912 .38046 .22134 .37958 .2332 .37696 .23108 .37772 Metetra
.23108 .37772 .2332 .37696 .24506 .37293 .24303 .37353 Metetra
.286 .772 .695 r
.24303 .37353 .24506 .37293 .25692 .36747 .25498 .36786 Metetra
.377 .825 .705 r
.25498 .36786 .25692 .36747 .26877 .36053 .26693 .36065 Metetra
.461 .868 .709 r
.26693 .36065 .26877 .36053 .28063 .35205 .27888 .35185 Metetra
.538 .903 .708 r
.27888 .35185 .28063 .35205 .29249 .34197 .29084 .34139 Metetra
.607 .929 .704 r
.29084 .34139 .29249 .34197 .30435 .3302 .30279 .32918 Metetra
.667 .947 .696 r
.30279 .32918 .30435 .3302 .31621 .31667 .31474 .31512 Metetra
.719 .959 .686 r
.31474 .31512 .31621 .31667 .32806 .30126 .32669 .2991 Metetra
.764 .966 .675 r
.32669 .2991 .32806 .30126 .33992 .28385 .33865 .28098 Metetra
.802 .969 .663 r
.33865 .28098 .33992 .28385 .35178 .26431 .3506 .26061 Metetra
.835 .969 .651 r
.3506 .26061 .35178 .26431 .36364 .24248 .36255 .23782 Metetra
.864 .966 .64 r
.36255 .23782 .36364 .24248 .37549 .21821 .3745 .2124 Metetra
.888 .962 .629 r
.3745 .2124 .37549 .21821 .38735 .19132 .38645 .18414 Metetra
.909 .956 .621 r
.38645 .18414 .38735 .19132 .39921 .16162 .39841 .1528 Metetra
.927 .95 .614 r
.39841 .1528 .39921 .16162 .41107 .12893 .41036 .11809 Metetra
.943 .943 .611 r
.41036 .11809 .41107 .12893 .42292 .09313 .42231 .07976 Metetra
.748 .868 .935 r
.42231 .07976 .42292 .09313 .43478 .0751 .43426 .07371 Metetra
.84064 .37307 .83794 .37209 .8498 .36652 .85259 .36746 Metetra
.82869 .37732 .82609 .37631 .83794 .37209 .84064 .37307 Metetra
.027 0 0 r
.81673 .38019 .81423 .37917 .82609 .37631 .82869 .37732 Metetra
.061 0 0 r
.80478 .38168 .80237 .38067 .81423 .37917 .81673 .38019 Metetra
.094 0 0 r
.79283 .38177 .79051 .38081 .80237 .38067 .80478 .38168 Metetra
.126 0 0 r
.78088 .38046 .77866 .37958 .79051 .38081 .79283 .38177 Metetra
.155 0 0 r
.76892 .37772 .7668 .37696 .77866 .37958 .78088 .38046 Metetra
0 .409 .692 r
.75697 .37353 .75494 .37293 .7668 .37696 .76892 .37772 Metetra
0 .375 .71 r
.74502 .36786 .74308 .36747 .75494 .37293 .75697 .37353 Metetra
0 .34 .721 r
.73307 .36065 .73123 .36053 .74308 .36747 .74502 .36786 Metetra
0 .305 .727 r
.72112 .35185 .71937 .35205 .73123 .36053 .73307 .36065 Metetra
0 .272 .727 r
.70916 .34139 .70751 .34197 .71937 .35205 .72112 .35185 Metetra
0 .24 .723 r
.69721 .32918 .69565 .3302 .70751 .34197 .70916 .34139 Metetra
0 .21 .716 r
.68526 .31512 .68379 .31667 .69565 .3302 .69721 .32918 Metetra
0 .184 .707 r
.67331 .2991 .67194 .30126 .68379 .31667 .68526 .31512 Metetra
0 .16 .696 r
.66135 .28098 .66008 .28385 .67194 .30126 .67331 .2991 Metetra
0 .14 .685 r
.6494 .26061 .64822 .26431 .66008 .28385 .66135 .28098 Metetra
0 .123 .674 r
.63745 .23782 .63636 .24248 .64822 .26431 .6494 .26061 Metetra
0 .11 .663 r
.6255 .2124 .62451 .21821 .63636 .24248 .63745 .23782 Metetra
0 .101 .655 r
.61355 .18414 .61265 .19132 .62451 .21821 .6255 .2124 Metetra
0 .097 .648 r
.60159 .1528 .60079 .16162 .61265 .19132 .61355 .18414 Metetra
0 .097 .643 r
.58964 .11809 .58893 .12893 .60079 .16162 .60159 .1528 Metetra
0 .104 .642 r
.57769 .07976 .57708 .09313 .58893 .12893 .58964 .11809 Metetra
0 .435 .792 r
.56574 .07371 .56522 .0751 .57708 .09313 .57769 .07976 Metetra
.443 0 0 r
.14458 .36841 .14741 .36746 .15936 .37307 .15663 .37407 Metetra
.369 0 0 r
.15663 .37407 .15936 .37307 .17131 .37732 .16867 .37834 Metetra
.287 0 0 r
.16867 .37834 .17131 .37732 .18327 .38019 .18072 .38122 Metetra
.198 0 0 r
.18072 .38122 .18327 .38019 .19522 .38168 .19277 .38269 Metetra
.104 0 0 r
.19277 .38269 .19522 .38168 .20717 .38177 .20482 .38274 Metetra
.005 0 0 r
.20482 .38274 .20717 .38177 .21912 .38046 .21687 .38135 Metetra
.21687 .38135 .21912 .38046 .23108 .37772 .22892 .3785 Metetra
.22892 .3785 .23108 .37772 .24303 .37353 .24096 .37416 Metetra
.291 .775 .693 r
.24096 .37416 .24303 .37353 .25498 .36786 .25301 .36829 Metetra
.382 .826 .7 r
.25301 .36829 .25498 .36786 .26693 .36065 .26506 .36084 Metetra
.465 .868 .702 r
.26506 .36084 .26693 .36065 .27888 .35185 .27711 .35175 Metetra
.54 .901 .699 r
.27711 .35175 .27888 .35185 .29084 .34139 .28916 .34093 Metetra
.607 .926 .692 r
.28916 .34093 .29084 .34139 .30279 .32918 .3012 .32831 Metetra
.665 .943 .682 r
.3012 .32831 .30279 .32918 .31474 .31512 .31325 .31376 Metetra
.716 .954 .67 r
.31325 .31376 .31474 .31512 .32669 .2991 .3253 .29717 Metetra
.759 .96 .657 r
.3253 .29717 .32669 .2991 .33865 .28098 .33735 .27839 Metetra
.797 .962 .643 r
.33735 .27839 .33865 .28098 .3506 .26061 .3494 .25725 Metetra
.829 .961 .629 r
.3494 .25725 .3506 .26061 .36255 .23782 .36145 .23355 Metetra
.856 .958 .616 r
.36145 .23355 .36255 .23782 .3745 .2124 .37349 .20706 Metetra
.88 .953 .604 r
.37349 .20706 .3745 .2124 .38645 .18414 .38554 .17751 Metetra
.901 .947 .593 r
.38554 .17751 .38645 .18414 .39841 .1528 .39759 .14459 Metetra
.919 .941 .585 r
.39759 .14459 .39841 .1528 .41036 .11809 .40964 .10794 Metetra
.936 .95 .624 r
.40964 .10794 .41036 .11809 .42231 .07976 .42169 .07229 Metetra
.513 .816 1 r
.42169 .07229 .42231 .07976 .43426 .07371 .43373 .07229 Metetra
.84337 .37407 .84064 .37307 .85259 .36746 .85542 .36841 Metetra
.83133 .37834 .82869 .37732 .84064 .37307 .84337 .37407 Metetra
.027 0 0 r
.81928 .38122 .81673 .38019 .82869 .37732 .83133 .37834 Metetra
.061 0 0 r
.80723 .38269 .80478 .38168 .81673 .38019 .81928 .38122 Metetra
.095 0 0 r
.79518 .38274 .79283 .38177 .80478 .38168 .80723 .38269 Metetra
.128 0 0 r
.78313 .38135 .78088 .38046 .79283 .38177 .79518 .38274 Metetra
.158 0 0 r
.77108 .3785 .76892 .37772 .78088 .38046 .78313 .38135 Metetra
0 .404 .69 r
.75904 .37416 .75697 .37353 .76892 .37772 .77108 .3785 Metetra
0 .367 .706 r
.74699 .36829 .74502 .36786 .75697 .37353 .75904 .37416 Metetra
0 .329 .715 r
.73494 .36084 .73307 .36065 .74502 .36786 .74699 .36829 Metetra
0 .292 .718 r
.72289 .35175 .72112 .35185 .73307 .36065 .73494 .36084 Metetra
0 .256 .716 r
.71084 .34093 .70916 .34139 .72112 .35185 .72289 .35175 Metetra
0 .222 .71 r
.6988 .32831 .69721 .32918 .70916 .34139 .71084 .34093 Metetra
0 .19 .7 r
.68675 .31376 .68526 .31512 .69721 .32918 .6988 .32831 Metetra
0 .161 .689 r
.6747 .29717 .67331 .2991 .68526 .31512 .68675 .31376 Metetra
0 .135 .676 r
.66265 .27839 .66135 .28098 .67331 .2991 .6747 .29717 Metetra
0 .113 .664 r
.6506 .25725 .6494 .26061 .66135 .28098 .66265 .27839 Metetra
0 .094 .651 r
.63855 .23355 .63745 .23782 .6494 .26061 .6506 .25725 Metetra
0 .078 .639 r
.62651 .20706 .6255 .2124 .63745 .23782 .63855 .23355 Metetra
0 .066 .629 r
.61446 .17751 .61355 .18414 .6255 .2124 .62651 .20706 Metetra
0 .059 .62 r
.60241 .14459 .60159 .1528 .61355 .18414 .61446 .17751 Metetra
0 .057 .615 r
.59036 .10794 .58964 .11809 .60159 .1528 .60241 .14459 Metetra
0 0 .567 r
.57831 .07229 .57769 .07976 .58964 .11809 .59036 .10794 Metetra
.139 .679 .832 r
.56627 .07229 .56574 .07371 .57769 .07976 .57831 .07229 Metetra
.442 0 0 r
.1417 .36938 .14458 .36841 .15663 .37407 .15385 .37508 Metetra
.368 0 0 r
.15385 .37508 .15663 .37407 .16867 .37834 .16599 .37938 Metetra
.286 0 0 r
.16599 .37938 .16867 .37834 .18072 .38122 .17814 .38226 Metetra
.196 0 0 r
.17814 .38226 .18072 .38122 .19277 .38269 .19028 .38372 Metetra
.101 0 0 r
.19028 .38372 .19277 .38269 .20482 .38274 .20243 .38373 Metetra
.001 0 0 r
.20243 .38373 .20482 .38274 .21687 .38135 .21457 .38227 Metetra
.21457 .38227 .21687 .38135 .22892 .3785 .22672 .37932 Metetra
.22672 .37932 .22892 .3785 .24096 .37416 .23887 .37484 Metetra
.295 .776 .689 r
.23887 .37484 .24096 .37416 .25301 .36829 .25101 .36879 Metetra
.384 .827 .695 r
.25101 .36879 .25301 .36829 .26506 .36084 .26316 .36112 Metetra
.466 .867 .695 r
.26316 .36112 .26506 .36084 .27711 .35175 .2753 .35175 Metetra
.54 .899 .689 r
.2753 .35175 .27711 .35175 .28916 .34093 .28745 .34061 Metetra
.605 .922 .68 r
.28745 .34061 .28916 .34093 .3012 .32831 .2996 .32761 Metetra
.662 .937 .668 r
.2996 .32761 .3012 .32831 .31325 .31376 .31174 .31261 Metetra
.711 .947 .654 r
.31174 .31261 .31325 .31376 .3253 .29717 .32389 .2955 Metetra
.753 .952 .639 r
.32389 .2955 .3253 .29717 .33735 .27839 .33603 .27611 Metetra
.789 .954 .623 r
.33603 .27611 .33735 .27839 .3494 .25725 .34818 .25426 Metetra
.82 .952 .607 r
.34818 .25426 .3494 .25725 .36145 .23355 .36032 .22972 Metetra
.847 .948 .592 r
.36032 .22972 .36145 .23355 .37349 .20706 .37247 .20223 Metetra
.87 .943 .578 r
.37247 .20223 .37349 .20706 .38554 .17751 .38462 .17149 Metetra
.891 .937 .566 r
.38462 .17149 .38554 .17751 .39759 .14459 .39676 .1371 Metetra
.909 .93 .555 r
.39676 .1371 .39759 .14459 .40964 .10794 .40891 .09862 Metetra
.918 .973 .692 r
.40891 .09862 .40964 .10794 .42169 .07229 .42105 .07085 Metetra
.84615 .37508 .84337 .37407 .85542 .36841 .8583 .36938 Metetra
.83401 .37938 .83133 .37834 .84337 .37407 .84615 .37508 Metetra
.027 0 0 r
.82186 .38226 .81928 .38122 .83133 .37834 .83401 .37938 Metetra
.061 0 0 r
.80972 .38372 .80723 .38269 .81928 .38122 .82186 .38226 Metetra
.096 0 0 r
.79757 .38373 .79518 .38274 .80723 .38269 .80972 .38372 Metetra
.13 0 0 r
.78543 .38227 .78313 .38135 .79518 .38274 .79757 .38373 Metetra
.162 0 0 r
.77328 .37932 .77108 .3785 .78313 .38135 .78543 .38227 Metetra
0 .398 .687 r
.76113 .37484 .75904 .37416 .77108 .3785 .77328 .37932 Metetra
0 .359 .701 r
.74899 .36879 .74699 .36829 .75904 .37416 .76113 .37484 Metetra
0 .319 .708 r
.73684 .36112 .73494 .36084 .74699 .36829 .74899 .36879 Metetra
0 .279 .708 r
.7247 .35175 .72289 .35175 .73494 .36084 .73684 .36112 Metetra
0 .241 .704 r
.71255 .34061 .71084 .34093 .72289 .35175 .7247 .35175 Metetra
0 .204 .695 r
.7004 .32761 .6988 .32831 .71084 .34093 .71255 .34061 Metetra
0 .17 .684 r
.68826 .31261 .68675 .31376 .6988 .32831 .7004 .32761 Metetra
0 .139 .671 r
.67611 .2955 .6747 .29717 .68675 .31376 .68826 .31261 Metetra
0 .111 .657 r
.66397 .27611 .66265 .27839 .6747 .29717 .67611 .2955 Metetra
0 .086 .642 r
.65182 .25426 .6506 .25725 .66265 .27839 .66397 .27611 Metetra
0 .064 .628 r
.63968 .22972 .63855 .23355 .6506 .25725 .65182 .25426 Metetra
0 .046 .614 r
.62753 .20223 .62651 .20706 .63855 .23355 .63968 .22972 Metetra
0 .031 .602 r
.61538 .17149 .61446 .17751 .62651 .20706 .62753 .20223 Metetra
0 .021 .592 r
.60324 .1371 .60241 .14459 .61446 .17751 .61538 .17149 Metetra
0 .015 .584 r
.59109 .09862 .59036 .10794 .60241 .14459 .60324 .1371 Metetra
0 0 .467 r
.57895 .07085 .57831 .07229 .59036 .10794 .59109 .09862 Metetra
.442 0 0 r
.13878 .37037 .1417 .36938 .15385 .37508 .15102 .3761 Metetra
.368 0 0 r
.15102 .3761 .15385 .37508 .16599 .37938 .16327 .38043 Metetra
.285 0 0 r
.16327 .38043 .16599 .37938 .17814 .38226 .17551 .38332 Metetra
.195 0 0 r
.17551 .38332 .17814 .38226 .19028 .38372 .18776 .38477 Metetra
.099 0 0 r
.18776 .38477 .19028 .38372 .20243 .38373 .2 .38474 Metetra
.2 .38474 .20243 .38373 .21457 .38227 .21224 .38322 Metetra
.21224 .38322 .21457 .38227 .22672 .37932 .22449 .38018 Metetra
.22449 .38018 .22672 .37932 .23887 .37484 .23673 .37558 Metetra
.297 .777 .686 r
.23673 .37558 .23887 .37484 .25101 .36879 .24898 .36937 Metetra
.385 .826 .689 r
.24898 .36937 .25101 .36879 .26316 .36112 .26122 .36149 Metetra
.466 .865 .687 r
.26122 .36149 .26316 .36112 .2753 .35175 .27347 .35188 Metetra
.538 .895 .679 r
.27347 .35188 .2753 .35175 .28745 .34061 .28571 .34045 Metetra
.601 .917 .668 r
.28571 .34045 .28745 .34061 .2996 .32761 .29796 .3271 Metetra
.657 .931 .654 r
.29796 .3271 .2996 .32761 .31174 .31261 .3102 .3117 Metetra
.704 .94 .638 r
.3102 .3117 .31174 .31261 .32389 .2955 .32245 .29412 Metetra
.745 .944 .621 r
.32245 .29412 .32389 .2955 .33603 .27611 .33469 .27418 Metetra
.78 .945 .603 r
.33469 .27418 .33603 .27611 .34818 .25426 .34694 .25169 Metetra
.81 .942 .586 r
.34694 .25169 .34818 .25426 .36032 .22972 .35918 .22639 Metetra
.836 .938 .569 r
.35918 .22639 .36032 .22972 .37247 .20223 .37143 .198 Metetra
.858 .932 .552 r
.37143 .198 .37247 .20223 .38462 .17149 .38367 .16617 Metetra
.878 .925 .537 r
.38367 .16617 .38462 .17149 .39676 .1371 .39592 .13045 Metetra
.895 .918 .524 r
.39592 .13045 .39676 .1371 .40891 .09862 .40816 .09029 Metetra
.884 .991 .764 r
.40816 .09029 .40891 .09862 .42105 .07085 .42041 .06939 Metetra
.84898 .3761 .84615 .37508 .8583 .36938 .86122 .37037 Metetra
.83673 .38043 .83401 .37938 .84615 .37508 .84898 .3761 Metetra
.028 0 0 r
.82449 .38332 .82186 .38226 .83401 .37938 .83673 .38043 Metetra
.062 0 0 r
.81224 .38477 .80972 .38372 .82186 .38226 .82449 .38332 Metetra
.098 0 0 r
.8 .38474 .79757 .38373 .80972 .38372 .81224 .38477 Metetra
.133 0 0 r
.78776 .38322 .78543 .38227 .79757 .38373 .8 .38474 Metetra
.167 0 0 r
.77551 .38018 .77328 .37932 .78543 .38227 .78776 .38322 Metetra
0 .392 .683 r
.76327 .37558 .76113 .37484 .77328 .37932 .77551 .38018 Metetra
0 .351 .695 r
.75102 .36937 .74899 .36879 .76113 .37484 .76327 .37558 Metetra
0 .309 .7 r
.73878 .36149 .73684 .36112 .74899 .36879 .75102 .36937 Metetra
0 .267 .698 r
.72653 .35188 .7247 .35175 .73684 .36112 .73878 .36149 Metetra
0 .226 .692 r
.71429 .34045 .71255 .34061 .7247 .35175 .72653 .35188 Metetra
0 .187 .681 r
.70204 .3271 .7004 .32761 .71255 .34061 .71429 .34045 Metetra
0 .15 .668 r
.6898 .3117 .68826 .31261 .7004 .32761 .70204 .3271 Metetra
0 .117 .653 r
.67755 .29412 .67611 .2955 .68826 .31261 .6898 .3117 Metetra
0 .086 .636 r
.66531 .27418 .66397 .27611 .67611 .2955 .67755 .29412 Metetra
0 .059 .62 r
.65306 .25169 .65182 .25426 .66397 .27611 .66531 .27418 Metetra
0 .035 .604 r
.64082 .22639 .63968 .22972 .65182 .25426 .65306 .25169 Metetra
0 .014 .588 r
.62857 .198 .62753 .20223 .63968 .22972 .64082 .22639 Metetra
0 0 .574 r
.61633 .16617 .61538 .17149 .62753 .20223 .62857 .198 Metetra
0 0 .562 r
.60408 .13045 .60324 .1371 .61538 .17149 .61633 .16617 Metetra
0 0 .552 r
.59184 .09029 .59109 .09862 .60324 .1371 .60408 .13045 Metetra
0 0 .552 r
.57959 .06939 .57895 .07085 .59109 .09862 .59184 .09029 Metetra
.441 0 0 r
.1358 .37138 .13878 .37037 .15102 .3761 .14815 .37714 Metetra
.367 0 0 r
.14815 .37714 .15102 .3761 .16327 .38043 .16049 .38149 Metetra
.284 0 0 r
.16049 .38149 .16327 .38043 .17551 .38332 .17284 .3844 Metetra
.194 0 0 r
.17284 .3844 .17551 .38332 .18776 .38477 .18519 .38584 Metetra
.097 0 0 r
.18519 .38584 .18776 .38477 .2 .38474 .19753 .38578 Metetra
.19753 .38578 .2 .38474 .21224 .38322 .20988 .38421 Metetra
.20988 .38421 .21224 .38322 .22449 .38018 .22222 .38109 Metetra
.22222 .38109 .22449 .38018 .23673 .37558 .23457 .37637 Metetra
.297 .776 .681 r
.23457 .37637 .23673 .37558 .24898 .36937 .24691 .37002 Metetra
.384 .824 .683 r
.24691 .37002 .24898 .36937 .26122 .36149 .25926 .36197 Metetra
.464 .862 .679 r
.25926 .36197 .26122 .36149 .27347 .35188 .2716 .35214 Metetra
.534 .891 .669 r
.2716 .35214 .27347 .35188 .28571 .34045 .28395 .34045 Metetra
.596 .911 .656 r
.28395 .34045 .28571 .34045 .29796 .3271 .2963 .32679 Metetra
.65 .924 .64 r
.2963 .32679 .29796 .3271 .3102 .3117 .30864 .31104 Metetra
.696 .932 .622 r
.30864 .31104 .3102 .3117 .32245 .29412 .32099 .29305 Metetra
.735 .935 .603 r
.32099 .29305 .32245 .29412 .33469 .27418 .33333 .27262 Metetra
.769 .935 .583 r
.33333 .27262 .33469 .27418 .34694 .25169 .34568 .24956 Metetra
.798 .932 .564 r
.34568 .24956 .34694 .25169 .35918 .22639 .35802 .2236 Metetra
.823 .927 .545 r
.35802 .2236 .35918 .22639 .37143 .198 .37037 .19442 Metetra
.844 .92 .526 r
.37037 .19442 .37143 .198 .38367 .16617 .38272 .16163 Metetra
.863 .912 .508 r
.38272 .16163 .38367 .16617 .39592 .13045 .39506 .12473 Metetra
.879 .904 .492 r
.39506 .12473 .39592 .13045 .40816 .09029 .40741 .08308 Metetra
.826 .999 .832 r
.40741 .08308 .40816 .09029 .42041 .06939 .41975 .0679 Metetra
.85185 .37714 .84898 .3761 .86122 .37037 .8642 .37138 Metetra
.83951 .38149 .83673 .38043 .84898 .3761 .85185 .37714 Metetra
.028 0 0 r
.82716 .3844 .82449 .38332 .83673 .38043 .83951 .38149 Metetra
.063 0 0 r
.81481 .38584 .81224 .38477 .82449 .38332 .82716 .3844 Metetra
.1 0 0 r
.80247 .38578 .8 .38474 .81224 .38477 .81481 .38584 Metetra
.136 0 0 r
.79012 .38421 .78776 .38322 .8 .38474 .80247 .38578 Metetra
.171 0 0 r
.77778 .38109 .77551 .38018 .78776 .38322 .79012 .38421 Metetra
0 .386 .679 r
.76543 .37637 .76327 .37558 .77551 .38018 .77778 .38109 Metetra
0 .343 .689 r
.75309 .37002 .75102 .36937 .76327 .37558 .76543 .37637 Metetra
0 .299 .692 r
.74074 .36197 .73878 .36149 .75102 .36937 .75309 .37002 Metetra
0 .255 .688 r
.7284 .35214 .72653 .35188 .73878 .36149 .74074 .36197 Metetra
0 .212 .679 r
.71605 .34045 .71429 .34045 .72653 .35188 .7284 .35214 Metetra
0 .17 .667 r
.7037 .32679 .70204 .3271 .71429 .34045 .71605 .34045 Metetra
0 .132 .651 r
.69136 .31104 .6898 .3117 .70204 .3271 .7037 .32679 Metetra
0 .096 .634 r
.67901 .29305 .67755 .29412 .6898 .3117 .69136 .31104 Metetra
0 .063 .616 r
.66667 .27262 .66531 .27418 .67755 .29412 .67901 .29305 Metetra
0 .033 .597 r
.65432 .24956 .65306 .25169 .66531 .27418 .66667 .27262 Metetra
0 .006 .579 r
.64198 .2236 .64082 .22639 .65306 .25169 .65432 .24956 Metetra
0 0 .561 r
.62963 .19442 .62857 .198 .64082 .22639 .64198 .2236 Metetra
0 0 .545 r
.61728 .16163 .61633 .16617 .62857 .198 .62963 .19442 Metetra
0 0 .53 r
.60494 .12473 .60408 .13045 .61633 .16617 .61728 .16163 Metetra
0 0 .517 r
.59259 .08308 .59184 .09029 .60408 .13045 .60494 .12473 Metetra
0 .131 .644 r
.58025 .0679 .57959 .06939 .59184 .09029 .59259 .08308 Metetra
.441 0 0 r
.13278 .37239 .1358 .37138 .14815 .37714 .14523 .3782 Metetra
.367 0 0 r
.14523 .3782 .14815 .37714 .16049 .38149 .15768 .38258 Metetra
.284 0 0 r
.15768 .38258 .16049 .38149 .17284 .3844 .17012 .3855 Metetra
.193 0 0 r
.17012 .3855 .17284 .3844 .18519 .38584 .18257 .38693 Metetra
.097 0 0 r
.18257 .38693 .18519 .38584 .19753 .38578 .19502 .38686 Metetra
.19502 .38686 .19753 .38578 .20988 .38421 .20747 .38524 Metetra
.20747 .38524 .20988 .38421 .22222 .38109 .21992 .38205 Metetra
.21992 .38205 .22222 .38109 .23457 .37637 .23237 .37724 Metetra
.296 .774 .677 r
.23237 .37724 .23457 .37637 .24691 .37002 .24481 .37076 Metetra
.382 .821 .677 r
.24481 .37076 .24691 .37002 .25926 .36197 .25726 .36255 Metetra
.46 .858 .67 r
.25726 .36255 .25926 .36197 .2716 .35214 .26971 .35254 Metetra
.529 .885 .659 r
.26971 .35254 .2716 .35214 .28395 .34045 .28216 .34063 Metetra
.589 .905 .644 r
.28216 .34063 .28395 .34045 .2963 .32679 .29461 .32671 Metetra
.641 .917 .626 r
.29461 .32671 .2963 .32679 .30864 .31104 .30705 .31066 Metetra
.686 .924 .606 r
.30705 .31066 .30864 .31104 .32099 .29305 .3195 .2923 Metetra
.724 .926 .585 r
.3195 .2923 .32099 .29305 .33333 .27262 .33195 .27147 Metetra
.756 .925 .564 r
.33195 .27147 .33333 .27262 .34568 .24956 .3444 .24792 Metetra
.784 .92 .542 r
.3444 .24792 .34568 .24956 .35802 .2236 .35685 .22139 Metetra
.807 .914 .52 r
.35685 .22139 .35802 .2236 .37037 .19442 .36929 .19154 Metetra
.827 .907 .499 r
.36929 .19154 .37037 .19442 .38272 .16163 .38174 .15793 Metetra
.845 .898 .479 r
.38174 .15793 .38272 .16163 .39506 .12473 .39419 .12004 Metetra
.86 .888 .46 r
.39419 .12004 .39506 .12473 .40741 .08308 .40664 .07714 Metetra
.739 .989 .885 r
.40664 .07714 .40741 .08308 .41975 .0679 .41909 .06639 Metetra
.85477 .3782 .85185 .37714 .8642 .37138 .86722 .37239 Metetra
.84232 .38258 .83951 .38149 .85185 .37714 .85477 .3782 Metetra
.029 0 0 r
.82988 .3855 .82716 .3844 .83951 .38149 .84232 .38258 Metetra
.064 0 0 r
.81743 .38693 .81481 .38584 .82716 .3844 .82988 .3855 Metetra
.101 0 0 r
.80498 .38686 .80247 .38578 .81481 .38584 .81743 .38693 Metetra
.139 0 0 r
.79253 .38524 .79012 .38421 .80247 .38578 .80498 .38686 Metetra
.176 0 0 r
.78008 .38205 .77778 .38109 .79012 .38421 .79253 .38524 Metetra
.21 0 0 r
.76763 .37724 .76543 .37637 .77778 .38109 .78008 .38205 Metetra
0 .336 .683 r
.75519 .37076 .75309 .37002 .76543 .37637 .76763 .37724 Metetra
0 .29 .683 r
.74274 .36255 .74074 .36197 .75309 .37002 .75519 .37076 Metetra
0 .243 .678 r
.73029 .35254 .7284 .35214 .74074 .36197 .74274 .36255 Metetra
0 .198 .667 r
.71784 .34063 .71605 .34045 .7284 .35214 .73029 .35254 Metetra
0 .155 .652 r
.70539 .32671 .7037 .32679 .71605 .34045 .71784 .34063 Metetra
0 .114 .635 r
.69295 .31066 .69136 .31104 .7037 .32679 .70539 .32671 Metetra
0 .076 .616 r
.6805 .2923 .67901 .29305 .69136 .31104 .69295 .31066 Metetra
0 .04 .595 r
.66805 .27147 .66667 .27262 .67901 .29305 .6805 .2923 Metetra
0 .007 .575 r
.6556 .24792 .65432 .24956 .66667 .27262 .66805 .27147 Metetra
0 0 .554 r
.64315 .22139 .64198 .2236 .65432 .24956 .6556 .24792 Metetra
0 0 .534 r
.63071 .19154 .62963 .19442 .64198 .2236 .64315 .22139 Metetra
0 0 .515 r
.61826 .15793 .61728 .16163 .62963 .19442 .63071 .19154 Metetra
0 0 .497 r
.60581 .12004 .60494 .12473 .61728 .16163 .61826 .15793 Metetra
0 0 .48 r
.59336 .07714 .59259 .08308 .60494 .12473 .60581 .12004 Metetra
0 .271 .724 r
.58091 .06639 .58025 .0679 .59259 .08308 .59336 .07714 Metetra
.44 0 0 r
.12971 .37343 .13278 .37239 .14523 .3782 .14226 .37928 Metetra
.366 0 0 r
.14226 .37928 .14523 .3782 .15768 .38258 .15481 .38369 Metetra
.283 0 0 r
.15481 .38369 .15768 .38258 .17012 .3855 .16736 .38662 Metetra
.193 0 0 r
.16736 .38662 .17012 .3855 .18257 .38693 .17992 .38806 Metetra
.096 0 0 r
.17992 .38806 .18257 .38693 .19502 .38686 .19247 .38796 Metetra
.19247 .38796 .19502 .38686 .20747 .38524 .20502 .38631 Metetra
.20502 .38631 .20747 .38524 .21992 .38205 .21757 .38306 Metetra
.21757 .38306 .21992 .38205 .23237 .37724 .23013 .37818 Metetra
.293 .772 .672 r
.23013 .37818 .23237 .37724 .24481 .37076 .24268 .3716 Metetra
.378 .817 .67 r
.24268 .3716 .24481 .37076 .25726 .36255 .25523 .36326 Metetra
.454 .853 .662 r
.25523 .36326 .25726 .36255 .26971 .35254 .26778 .3531 Metetra
.522 .879 .649 r
.26778 .3531 .26971 .35254 .28216 .34063 .28033 .341 Metetra
.581 .897 .632 r
.28033 .341 .28216 .34063 .29461 .32671 .29289 .32687 Metetra
.631 .909 .612 r
.29289 .32687 .29461 .32671 .30705 .31066 .30544 .31056 Metetra
.674 .914 .59 r
.30544 .31056 .30705 .31066 .3195 .2923 .31799 .29191 Metetra
.711 .916 .567 r
.31799 .29191 .3195 .2923 .33195 .27147 .33054 .27074 Metetra
.742 .913 .544 r
.33054 .27074 .33195 .27147 .3444 .24792 .3431 .2468 Metetra
.768 .908 .52 r
.3431 .2468 .3444 .24792 .35685 .22139 .35565 .2198 Metetra
.79 .901 .496 r
.35565 .2198 .35685 .22139 .36929 .19154 .3682 .1894 Metetra
.809 .892 .473 r
.3682 .1894 .36929 .19154 .38174 .15793 .38075 .15515 Metetra
.824 .882 .45 r
.38075 .15515 .38174 .15793 .39419 .12004 .39331 .11646 Metetra
.837 .87 .427 r
.39331 .11646 .39419 .12004 .40664 .07714 .40586 .07258 Metetra
.628 .959 .905 r
.40586 .07258 .40664 .07714 .41909 .06639 .41841 .06485 Metetra
.718 .562 0 r
.48117 .06485 .48133 .06639 .49378 .06639 .49372 .43515 Metetra
.707 .565 .692 r
.49372 .43515 .49378 .06639 .50622 .06639 .50628 .43515 Metetra
.85774 .37928 .85477 .3782 .86722 .37239 .87029 .37343 Metetra
.84519 .38369 .84232 .38258 .85477 .3782 .85774 .37928 Metetra
.029 0 0 r
.83264 .38662 .82988 .3855 .84232 .38258 .84519 .38369 Metetra
.065 0 0 r
.82008 .38806 .81743 .38693 .82988 .3855 .83264 .38662 Metetra
.103 0 0 r
.80753 .38796 .80498 .38686 .81743 .38693 .82008 .38806 Metetra
.142 0 0 r
.79498 .38631 .79253 .38524 .80498 .38686 .80753 .38796 Metetra
.18 0 0 r
.78243 .38306 .78008 .38205 .79253 .38524 .79498 .38631 Metetra
.216 0 0 r
.76987 .37818 .76763 .37724 .78008 .38205 .78243 .38306 Metetra
0 .329 .676 r
.75732 .3716 .75519 .37076 .76763 .37724 .76987 .37818 Metetra
0 .281 .675 r
.74477 .36326 .74274 .36255 .75519 .37076 .75732 .3716 Metetra
0 .233 .667 r
.73222 .3531 .73029 .35254 .74274 .36255 .74477 .36326 Metetra
0 .185 .654 r
.71967 .341 .71784 .34063 .73029 .35254 .73222 .3531 Metetra
0 .14 .638 r
.70711 .32687 .70539 .32671 .71784 .34063 .71967 .341 Metetra
0 .097 .618 r
.69456 .31056 .69295 .31066 .70539 .32671 .70711 .32687 Metetra
0 .056 .597 r
.68201 .29191 .6805 .2923 .69295 .31066 .69456 .31056 Metetra
0 .018 .575 r
.66946 .27074 .66805 .27147 .6805 .2923 .68201 .29191 Metetra
0 0 .552 r
.6569 .2468 .6556 .24792 .66805 .27147 .66946 .27074 Metetra
0 0 .529 r
.64435 .2198 .64315 .22139 .6556 .24792 .6569 .2468 Metetra
0 0 .506 r
.6318 .1894 .63071 .19154 .64315 .22139 .64435 .2198 Metetra
0 0 .484 r
.61925 .15515 .61826 .15793 .63071 .19154 .6318 .1894 Metetra
0 0 .462 r
.60669 .11646 .60581 .12004 .61826 .15793 .61925 .15515 Metetra
0 0 .442 r
.59414 .07258 .59336 .07714 .60581 .12004 .60669 .11646 Metetra
0 .385 .776 r
.58159 .06485 .58091 .06639 .59336 .07714 .59414 .07258 Metetra
.324 .254 .622 r
.50628 .43515 .50622 .06639 .51867 .06639 .51883 .06485 Metetra
.44 0 0 r
.12658 .37447 .12971 .37343 .14226 .37928 .13924 .38037 Metetra
.366 0 0 r
.13924 .38037 .14226 .37928 .15481 .38369 .1519 .38481 Metetra
.283 0 0 r
.1519 .38481 .15481 .38369 .16736 .38662 .16456 .38777 Metetra
.193 0 0 r
.16456 .38777 .16736 .38662 .17992 .38806 .17722 .38921 Metetra
.097 0 0 r
.17722 .38921 .17992 .38806 .19247 .38796 .18987 .38911 Metetra
.18987 .38911 .19247 .38796 .20502 .38631 .20253 .38743 Metetra
.20253 .38743 .20502 .38631 .21757 .38306 .21519 .38414 Metetra
.21519 .38414 .21757 .38306 .23013 .37818 .22785 .37919 Metetra
.289 .768 .667 r
.22785 .37919 .23013 .37818 .24268 .3716 .24051 .37254 Metetra
.373 .813 .664 r
.24051 .37254 .24268 .3716 .25523 .36326 .25316 .3641 Metetra
.447 .847 .654 r
.25316 .3641 .25523 .36326 .26778 .3531 .26582 .35381 Metetra
.513 .873 .639 r
.26582 .35381 .26778 .3531 .28033 .341 .27848 .34158 Metetra
.571 .89 .62 r
.27848 .34158 .28033 .341 .29289 .32687 .29114 .32727 Metetra
.62 .9 .599 r
.29114 .32727 .29289 .32687 .30544 .31056 .3038 .31076 Metetra
.661 .905 .575 r
.3038 .31076 .30544 .31056 .31799 .29191 .31646 .29189 Metetra
.696 .905 .55 r
.31646 .29189 .31799 .29191 .33054 .27074 .32911 .27045 Metetra
.726 .901 .525 r
.32911 .27045 .33054 .27074 .3431 .2468 .34177 .24621 Metetra
.75 .895 .499 r
.34177 .24621 .3431 .2468 .35565 .2198 .35443 .21886 Metetra
.771 .886 .472 r
.35443 .21886 .35565 .2198 .3682 .1894 .36709 .18806 Metetra
.787 .876 .446 r
.36709 .18806 .3682 .1894 .38075 .15515 .37975 .15333 Metetra
.801 .864 .42 r
.37975 .15333 .38075 .15515 .39331 .11646 .39241 .11407 Metetra
.812 .851 .394 r
.39241 .11407 .39331 .11646 .40586 .07258 .40506 .06949 Metetra
.509 .912 .879 r
.40506 .06949 .40586 .07258 .41841 .06485 .41772 .06329 Metetra
.718 .562 0 r
.48101 .06329 .48117 .06485 .49372 .43515 .49367 .43671 Metetra
.86076 .38037 .85774 .37928 .87029 .37343 .87342 .37447 Metetra
.8481 .38481 .84519 .38369 .85774 .37928 .86076 .38037 Metetra
.03 0 0 r
.83544 .38777 .83264 .38662 .84519 .38369 .8481 .38481 Metetra
.066 0 0 r
.82278 .38921 .82008 .38806 .83264 .38662 .83544 .38777 Metetra
.105 0 0 r
.81013 .38911 .80753 .38796 .82008 .38806 .82278 .38921 Metetra
.145 0 0 r
.79747 .38743 .79498 .38631 .80753 .38796 .81013 .38911 Metetra
.184 0 0 r
.78481 .38414 .78243 .38306 .79498 .38631 .79747 .38743 Metetra
.222 0 0 r
.77215 .37919 .76987 .37818 .78243 .38306 .78481 .38414 Metetra
0 .322 .669 r
.75949 .37254 .75732 .3716 .76987 .37818 .77215 .37919 Metetra
0 .273 .666 r
.74684 .3641 .74477 .36326 .75732 .3716 .75949 .37254 Metetra
0 .223 .656 r
.73418 .35381 .73222 .3531 .74477 .36326 .74684 .3641 Metetra
0 .173 .642 r
.72152 .34158 .71967 .341 .73222 .3531 .73418 .35381 Metetra
0 .126 .623 r
.70886 .32727 .70711 .32687 .71967 .341 .72152 .34158 Metetra
0 .081 .602 r
.6962 .31076 .69456 .31056 .70711 .32687 .70886 .32727 Metetra
0 .038 .578 r
.68354 .29189 .68201 .29191 .69456 .31056 .6962 .31076 Metetra
0 0 .554 r
.67089 .27045 .66946 .27074 .68201 .29191 .68354 .29189 Metetra
0 0 .529 r
.65823 .24621 .6569 .2468 .66946 .27074 .67089 .27045 Metetra
0 0 .503 r
.64557 .21886 .64435 .2198 .6569 .2468 .65823 .24621 Metetra
0 0 .477 r
.63291 .18806 .6318 .1894 .64435 .2198 .64557 .21886 Metetra
0 0 .452 r
.62025 .15333 .61925 .15515 .6318 .1894 .63291 .18806 Metetra
0 0 .427 r
.60759 .11407 .60669 .11646 .61925 .15515 .62025 .15333 Metetra
0 0 .402 r
.59494 .06949 .59414 .07258 .60669 .11646 .60759 .11407 Metetra
0 .446 .798 r
.58228 .06329 .58159 .06485 .59414 .07258 .59494 .06949 Metetra
.50633 .43671 .50628 .43515 .51883 .06485 .51899 .06329 Metetra
.439 0 0 r
.1234 .37553 .12658 .37447 .13924 .38037 .13617 .38148 Metetra
.366 0 0 r
.13617 .38148 .13924 .38037 .1519 .38481 .14894 .38596 Metetra
.284 0 0 r
.14894 .38596 .1519 .38481 .16456 .38777 .1617 .38894 Metetra
.194 0 0 r
.1617 .38894 .16456 .38777 .17722 .38921 .17447 .3904 Metetra
.098 0 0 r
.17447 .3904 .17722 .38921 .18987 .38911 .18723 .39029 Metetra
.18723 .39029 .18987 .38911 .20253 .38743 .2 .3886 Metetra
.2 .3886 .20253 .38743 .21519 .38414 .21277 .38528 Metetra
.21277 .38528 .21519 .38414 .22785 .37919 .22553 .38029 Metetra
.284 .764 .661 r
.22553 .38029 .22785 .37919 .24051 .37254 .2383 .37358 Metetra
.366 .808 .657 r
.2383 .37358 .24051 .37254 .25316 .3641 .25106 .36507 Metetra
.439 .841 .646 r
.25106 .36507 .25316 .3641 .26582 .35381 .26383 .3547 Metetra
.503 .865 .629 r
.26383 .3547 .26582 .35381 .27848 .34158 .2766 .34235 Metetra
.559 .881 .609 r
.2766 .34235 .27848 .34158 .29114 .32727 .28936 .32793 Metetra
.606 .891 .585 r
.28936 .32793 .29114 .32727 .3038 .31076 .30213 .31128 Metetra
.647 .894 .56 r
.30213 .31128 .3038 .31076 .31646 .29189 .31489 .29225 Metetra
.68 .893 .533 r
.31489 .29225 .31646 .29189 .32911 .27045 .32766 .27062 Metetra
.708 .889 .505 r
.32766 .27062 .32911 .27045 .34177 .24621 .34043 .24617 Metetra
.731 .881 .477 r
.34043 .24617 .34177 .24621 .35443 .21886 .35319 .2186 Metetra
.749 .871 .449 r
.35319 .2186 .35443 .21886 .36709 .18806 .36596 .18753 Metetra
.764 .859 .42 r
.36596 .18753 .36709 .18806 .37975 .15333 .37872 .1525 Metetra
.775 .845 .39 r
.37872 .1525 .37975 .15333 .39241 .11407 .39149 .11292 Metetra
.784 .83 .361 r
.39149 .11292 .39241 .11407 .40506 .06949 .40426 .06796 Metetra
.408 .857 .798 r
.40426 .06796 .40506 .06949 .41772 .06329 .41702 .0617 Metetra
.718 .562 0 r
.48085 .0617 .48101 .06329 .49367 .43671 .49362 .4383 Metetra
.86383 .38148 .86076 .38037 .87342 .37447 .8766 .37553 Metetra
.85106 .38596 .8481 .38481 .86076 .38037 .86383 .38148 Metetra
.03 0 0 r
.8383 .38894 .83544 .38777 .8481 .38481 .85106 .38596 Metetra
.067 0 0 r
.82553 .3904 .82278 .38921 .83544 .38777 .8383 .38894 Metetra
.107 0 0 r
.81277 .39029 .81013 .38911 .82278 .38921 .82553 .3904 Metetra
.148 0 0 r
.8 .3886 .79747 .38743 .81013 .38911 .81277 .39029 Metetra
.188 0 0 r
.78723 .38528 .78481 .38414 .79747 .38743 .8 .3886 Metetra
.227 0 0 r
.77447 .38029 .77215 .37919 .78481 .38414 .78723 .38528 Metetra
0 .316 .661 r
.7617 .37358 .75949 .37254 .77215 .37919 .77447 .38029 Metetra
0 .265 .657 r
.74894 .36507 .74684 .3641 .75949 .37254 .7617 .37358 Metetra
0 .214 .646 r
.73617 .3547 .73418 .35381 .74684 .3641 .74894 .36507 Metetra
0 .163 .629 r
.7234 .34235 .72152 .34158 .73418 .35381 .73617 .3547 Metetra
0 .113 .609 r
.71064 .32793 .70886 .32727 .72152 .34158 .7234 .34235 Metetra
0 .066 .585 r
.69787 .31128 .6962 .31076 .70886 .32727 .71064 .32793 Metetra
0 .02 .56 r
.68511 .29225 .68354 .29189 .6962 .31076 .69787 .31128 Metetra
0 0 .533 r
.67234 .27062 .67089 .27045 .68354 .29189 .68511 .29225 Metetra
0 0 .505 r
.65957 .24617 .65823 .24621 .67089 .27045 .67234 .27062 Metetra
0 0 .477 r
.64681 .2186 .64557 .21886 .65823 .24621 .65957 .24617 Metetra
0 0 .449 r
.63404 .18753 .63291 .18806 .64557 .21886 .64681 .2186 Metetra
0 0 .42 r
.62128 .1525 .62025 .15333 .63291 .18806 .63404 .18753 Metetra
0 0 .39 r
.60851 .11292 .60759 .11407 .62025 .15333 .62128 .1525 Metetra
0 0 .361 r
.59574 .06796 .59494 .06949 .60759 .11407 .60851 .11292 Metetra
0 .446 .798 r
.58298 .0617 .58228 .06329 .59494 .06949 .59574 .06796 Metetra
.50638 .4383 .50633 .43671 .51899 .06329 .51915 .0617 Metetra
.439 0 0 r
.12017 .3766 .1234 .37553 .13617 .38148 .13305 .38261 Metetra
.366 0 0 r
.13305 .38261 .13617 .38148 .14894 .38596 .14592 .38713 Metetra
.284 0 0 r
.14592 .38713 .14894 .38596 .1617 .38894 .1588 .39014 Metetra
.194 0 0 r
.1588 .39014 .1617 .38894 .17447 .3904 .17167 .39161 Metetra
.099 0 0 r
.17167 .39161 .17447 .3904 .18723 .39029 .18455 .39152 Metetra
.002 0 0 r
.18455 .39152 .18723 .39029 .2 .3886 .19742 .38982 Metetra
.19742 .38982 .2 .3886 .21277 .38528 .2103 .38649 Metetra
.2103 .38649 .21277 .38528 .22553 .38029 .22318 .38148 Metetra
.277 .759 .656 r
.22318 .38148 .22553 .38029 .2383 .37358 .23605 .37473 Metetra
.358 .802 .65 r
.23605 .37473 .2383 .37358 .25106 .36507 .24893 .36618 Metetra
.429 .834 .638 r
.24893 .36618 .25106 .36507 .26383 .3547 .2618 .35575 Metetra
.492 .857 .62 r
.2618 .35575 .26383 .3547 .2766 .34235 .27468 .34335 Metetra
.546 .872 .598 r
.27468 .34335 .2766 .34235 .28936 .32793 .28755 .32885 Metetra
.592 .881 .573 r
.28755 .32885 .28936 .32793 .30213 .31128 .30043 .31212 Metetra
.63 .883 .545 r
.30043 .31212 .30213 .31128 .31489 .29225 .3133 .29299 Metetra
.662 .881 .516 r
.3133 .29299 .31489 .29225 .32766 .27062 .32618 .27127 Metetra
.688 .875 .487 r
.32618 .27127 .32766 .27062 .34043 .24617 .33906 .24671 Metetra
.709 .866 .456 r
.33906 .24671 .34043 .24617 .35319 .2186 .35193 .21903 Metetra
.726 .854 .425 r
.35193 .21903 .35319 .2186 .36596 .18753 .36481 .18784 Metetra
.738 .841 .393 r
.36481 .18784 .36596 .18753 .37872 .1525 .37768 .15271 Metetra
.747 .825 .361 r
.37768 .15271 .37872 .1525 .39149 .11292 .39056 .11303 Metetra
.752 .807 .328 r
.39056 .11303 .39149 .11292 .40426 .06796 .40343 .06801 Metetra
.348 .801 .669 r
.40343 .06801 .40426 .06796 .41702 .0617 .41631 .06009 Metetra
.718 .562 0 r
.48069 .06009 .48085 .0617 .49362 .4383 .49356 .43991 Metetra
.86695 .38261 .86383 .38148 .8766 .37553 .87983 .3766 Metetra
.85408 .38713 .85106 .38596 .86383 .38148 .86695 .38261 Metetra
.031 0 0 r
.8412 .39014 .8383 .38894 .85106 .38596 .85408 .38713 Metetra
.068 0 0 r
.82833 .39161 .82553 .3904 .8383 .38894 .8412 .39014 Metetra
.108 0 0 r
.81545 .39152 .81277 .39029 .82553 .3904 .82833 .39161 Metetra
.15 0 0 r
.80258 .38982 .8 .3886 .81277 .39029 .81545 .39152 Metetra
.192 0 0 r
.7897 .38649 .78723 .38528 .8 .3886 .80258 .38982 Metetra
.232 0 0 r
.77682 .38148 .77447 .38029 .78723 .38528 .7897 .38649 Metetra
0 .311 .654 r
.76395 .37473 .7617 .37358 .77447 .38029 .77682 .38148 Metetra
0 .259 .648 r
.75107 .36618 .74894 .36507 .7617 .37358 .76395 .37473 Metetra
0 .205 .635 r
.7382 .35575 .73617 .3547 .74894 .36507 .75107 .36618 Metetra
0 .153 .617 r
.72532 .34335 .7234 .34235 .73617 .3547 .7382 .35575 Metetra
0 .101 .595 r
.71245 .32885 .71064 .32793 .7234 .34235 .72532 .34335 Metetra
0 .052 .569 r
.69957 .31212 .69787 .31128 .71064 .32793 .71245 .32885 Metetra
0 .004 .542 r
.6867 .29299 .68511 .29225 .69787 .31128 .69957 .31212 Metetra
0 0 .513 r
.67382 .27127 .67234 .27062 .68511 .29225 .6867 .29299 Metetra
0 0 .482 r
.66094 .24671 .65957 .24617 .67234 .27062 .67382 .27127 Metetra
0 0 .451 r
.64807 .21903 .64681 .2186 .65957 .24617 .66094 .24671 Metetra
0 0 .419 r
.63519 .18784 .63404 .18753 .64681 .2186 .64807 .21903 Metetra
0 0 .387 r
.62232 .15271 .62128 .1525 .63404 .18753 .63519 .18784 Metetra
0 0 .354 r
.60944 .11303 .60851 .11292 .62128 .1525 .62232 .15271 Metetra
0 0 .319 r
.59657 .06801 .59574 .06796 .60851 .11292 .60944 .11303 Metetra
0 .385 .776 r
.58369 .06009 .58298 .0617 .59574 .06796 .59657 .06801 Metetra
.50644 .43991 .50638 .4383 .51915 .0617 .51931 .06009 Metetra
.439 0 0 r
.11688 .37769 .12017 .3766 .13305 .38261 .12987 .38375 Metetra
.366 0 0 r
.12987 .38375 .13305 .38261 .14592 .38713 .14286 .38832 Metetra
.285 0 0 r
.14286 .38832 .14592 .38713 .1588 .39014 .15584 .39137 Metetra
.195 0 0 r
.15584 .39137 .1588 .39014 .17167 .39161 .16883 .39286 Metetra
.101 0 0 r
.16883 .39286 .17167 .39161 .18455 .39152 .18182 .39278 Metetra
.005 0 0 r
.18182 .39278 .18455 .39152 .19742 .38982 .19481 .39109 Metetra
.19481 .39109 .19742 .38982 .2103 .38649 .20779 .38776 Metetra
.20779 .38776 .2103 .38649 .22318 .38148 .22078 .38275 Metetra
.22078 .38275 .22318 .38148 .23605 .37473 .23377 .37599 Metetra
.349 .795 .644 r
.23377 .37599 .23605 .37473 .24893 .36618 .24675 .36743 Metetra
.418 .827 .63 r
.24675 .36743 .24893 .36618 .2618 .35575 .25974 .35698 Metetra
.479 .849 .611 r
.25974 .35698 .2618 .35575 .27468 .34335 .27273 .34456 Metetra
.532 .863 .587 r
.27273 .34456 .27468 .34335 .28755 .32885 .28571 .33003 Metetra
.576 .87 .56 r
.28571 .33003 .28755 .32885 .30043 .31212 .2987 .31328 Metetra
.613 .871 .531 r
.2987 .31328 .30043 .31212 .3133 .29299 .31169 .29414 Metetra
.643 .868 .5 r
.31169 .29414 .3133 .29299 .32618 .27127 .32468 .2724 Metetra
.667 .861 .468 r
.32468 .2724 .32618 .27127 .33906 .24671 .33766 .24783 Metetra
.686 .85 .435 r
.33766 .24783 .33906 .24671 .35193 .21903 .35065 .22015 Metetra
.7 .837 .402 r
.35065 .22015 .35193 .21903 .36481 .18784 .36364 .18901 Metetra
.71 .821 .367 r
.36364 .18901 .36481 .18784 .37768 .15271 .37662 .15395 Metetra
.716 .803 .332 r
.37662 .15395 .37768 .15271 .39056 .11303 .38961 .11441 Metetra
.718 .782 .295 r
.38961 .11441 .39056 .11303 .40343 .06801 .4026 .06966 Metetra
.4026 .06966 .40343 .06801 .41631 .06009 .41558 .05844 Metetra
.139 .679 .832 r
.48052 .05844 .48069 .06009 .49356 .43991 .49351 .05844 Metetra
.707 .59 .722 r
.49351 .05844 .49356 .43991 .50644 .43991 .50649 .05844 Metetra
.87013 .38375 .86695 .38261 .87983 .3766 .88312 .37769 Metetra
.85714 .38832 .85408 .38713 .86695 .38261 .87013 .38375 Metetra
.031 0 0 r
.84416 .39137 .8412 .39014 .85408 .38713 .85714 .38832 Metetra
.069 0 0 r
.83117 .39286 .82833 .39161 .8412 .39014 .84416 .39137 Metetra
.11 0 0 r
.81818 .39278 .81545 .39152 .82833 .39161 .83117 .39286 Metetra
.152 0 0 r
.80519 .39109 .80258 .38982 .81545 .39152 .81818 .39278 Metetra
.195 0 0 r
.79221 .38776 .7897 .38649 .80258 .38982 .80519 .39109 Metetra
.237 0 0 r
.77922 .38275 .77682 .38148 .7897 .38649 .79221 .38776 Metetra
.277 0 0 r
.76623 .37599 .76395 .37473 .77682 .38148 .77922 .38275 Metetra
0 .253 .64 r
.75325 .36743 .75107 .36618 .76395 .37473 .76623 .37599 Metetra
0 .198 .625 r
.74026 .35698 .7382 .35575 .75107 .36618 .75325 .36743 Metetra
0 .144 .605 r
.72727 .34456 .72532 .34335 .7382 .35575 .74026 .35698 Metetra
0 .091 .581 r
.71429 .33003 .71245 .32885 .72532 .34335 .72727 .34456 Metetra
0 .039 .554 r
.7013 .31328 .69957 .31212 .71245 .32885 .71429 .33003 Metetra
0 0 .524 r
.68831 .29414 .6867 .29299 .69957 .31212 .7013 .31328 Metetra
0 0 .492 r
.67532 .2724 .67382 .27127 .6867 .29299 .68831 .29414 Metetra
0 0 .459 r
.66234 .24783 .66094 .24671 .67382 .27127 .67532 .2724 Metetra
0 0 .425 r
.64935 .22015 .64807 .21903 .66094 .24671 .66234 .24783 Metetra
0 0 .391 r
.63636 .18901 .63519 .18784 .64807 .21903 .64935 .22015 Metetra
0 0 .354 r
.62338 .15395 .62232 .15271 .63519 .18784 .63636 .18901 Metetra
0 0 .317 r
.61039 .11441 .60944 .11303 .62232 .15271 .62338 .15395 Metetra
0 0 .277 r
.5974 .06966 .59657 .06801 .60944 .11303 .61039 .11441 Metetra
0 .271 .724 r
.58442 .05844 .58369 .06009 .59657 .06801 .5974 .06966 Metetra
.707 .59 .722 r
.50649 .05844 .50644 .43991 .51931 .06009 .51948 .05844 Metetra
.44 0 0 r
.11354 .3788 .11688 .37769 .12987 .38375 .12664 .38492 Metetra
.367 0 0 r
.12664 .38492 .12987 .38375 .14286 .38832 .13974 .38953 Metetra
.285 0 0 r
.13974 .38953 .14286 .38832 .15584 .39137 .15284 .39262 Metetra
.197 0 0 r
.15284 .39262 .15584 .39137 .16883 .39286 .16594 .39414 Metetra
.104 0 0 r
.16594 .39414 .16883 .39286 .18182 .39278 .17904 .39409 Metetra
.008 0 0 r
.17904 .39409 .18182 .39278 .19481 .39109 .19214 .39242 Metetra
.19214 .39242 .19481 .39109 .20779 .38776 .20524 .3891 Metetra
.20524 .3891 .20779 .38776 .22078 .38275 .21834 .3841 Metetra
.21834 .3841 .22078 .38275 .23377 .37599 .23144 .37736 Metetra
.338 .788 .638 r
.23144 .37736 .23377 .37599 .24675 .36743 .24454 .36881 Metetra
.406 .818 .623 r
.24454 .36881 .24675 .36743 .25974 .35698 .25764 .35838 Metetra
.466 .84 .602 r
.25764 .35838 .25974 .35698 .27273 .34456 .27074 .34598 Metetra
.516 .853 .577 r
.27074 .34598 .27273 .34456 .28571 .33003 .28384 .33149 Metetra
.559 .859 .548 r
.28384 .33149 .28571 .33003 .2987 .31328 .29694 .31477 Metetra
.594 .859 .517 r
.29694 .31477 .2987 .31328 .31169 .29414 .31004 .29568 Metetra
.622 .855 .485 r
.31004 .29568 .31169 .29414 .32468 .2724 .32314 .27401 Metetra
.644 .846 .45 r
.32314 .27401 .32468 .2724 .33766 .24783 .33624 .24953 Metetra
.661 .834 .415 r
.33624 .24953 .33766 .24783 .35065 .22015 .34934 .22199 Metetra
.673 .819 .379 r
.34934 .22199 .35065 .22015 .36364 .18901 .36245 .19102 Metetra
.68 .801 .342 r
.36245 .19102 .36364 .18901 .37662 .15395 .37555 .15623 Metetra
.682 .78 .303 r
.37555 .15623 .37662 .15395 .38961 .11441 .38865 .11707 Metetra
.68 .756 .263 r
.38865 .11707 .38961 .11441 .4026 .06966 .40175 .07288 Metetra
.40175 .07288 .4026 .06966 .41558 .05844 .41485 .05677 Metetra
.87336 .38492 .87013 .38375 .88312 .37769 .88646 .3788 Metetra
.86026 .38953 .85714 .38832 .87013 .38375 .87336 .38492 Metetra
.031 0 0 r
.84716 .39262 .84416 .39137 .85714 .38832 .86026 .38953 Metetra
.069 0 0 r
.83406 .39414 .83117 .39286 .84416 .39137 .84716 .39262 Metetra
.11 0 0 r
.82096 .39409 .81818 .39278 .83117 .39286 .83406 .39414 Metetra
.153 0 0 r
.80786 .39242 .80519 .39109 .81818 .39278 .82096 .39409 Metetra
.197 0 0 r
.79476 .3891 .79221 .38776 .80519 .39109 .80786 .39242 Metetra
.24 0 0 r
.78166 .3841 .77922 .38275 .79221 .38776 .79476 .3891 Metetra
.283 0 0 r
.76856 .37736 .76623 .37599 .77922 .38275 .78166 .3841 Metetra
0 .248 .631 r
.75546 .36881 .75325 .36743 .76623 .37599 .76856 .37736 Metetra
0 .192 .615 r
.74236 .35838 .74026 .35698 .75325 .36743 .75546 .36881 Metetra
0 .137 .594 r
.72926 .34598 .72727 .34456 .74026 .35698 .74236 .35838 Metetra
0 .081 .568 r
.71616 .33149 .71429 .33003 .72727 .34456 .72926 .34598 Metetra
0 .028 .538 r
.70306 .31477 .7013 .31328 .71429 .33003 .71616 .33149 Metetra
0 0 .506 r
.68996 .29568 .68831 .29414 .7013 .31328 .70306 .31477 Metetra
0 0 .472 r
.67686 .27401 .67532 .2724 .68831 .29414 .68996 .29568 Metetra
0 0 .437 r
.66376 .24953 .66234 .24783 .67532 .2724 .67686 .27401 Metetra
0 0 .4 r
.65066 .22199 .64935 .22015 .66234 .24783 .66376 .24953 Metetra
0 0 .362 r
.63755 .19102 .63636 .18901 .64935 .22015 .65066 .22199 Metetra
0 0 .322 r
.62445 .15623 .62338 .15395 .63636 .18901 .63755 .19102 Metetra
0 0 .28 r
.61135 .11707 .61039 .11441 .62338 .15395 .62445 .15623 Metetra
.673 .349 0 r
.59825 .07288 .5974 .06966 .61039 .11441 .61135 .11707 Metetra
0 .131 .644 r
.58515 .05677 .58442 .05844 .5974 .06966 .59825 .07288 Metetra
.44 0 0 r
.11013 .37992 .11354 .3788 .12664 .38492 .12335 .3861 Metetra
.367 0 0 r
.12335 .3861 .12664 .38492 .13974 .38953 .13656 .39077 Metetra
.286 0 0 r
.13656 .39077 .13974 .38953 .15284 .39262 .14978 .39389 Metetra
.198 0 0 r
.14978 .39389 .15284 .39262 .16594 .39414 .163 .39545 Metetra
.106 0 0 r
.163 .39545 .16594 .39414 .17904 .39409 .17621 .39543 Metetra
.012 0 0 r
.17621 .39543 .17904 .39409 .19214 .39242 .18943 .39379 Metetra
.18943 .39379 .19214 .39242 .20524 .3891 .20264 .3905 Metetra
.20264 .3905 .20524 .3891 .21834 .3841 .21586 .38553 Metetra
.21586 .38553 .21834 .3841 .23144 .37736 .22907 .37883 Metetra
.327 .78 .632 r
.22907 .37883 .23144 .37736 .24454 .36881 .24229 .37033 Metetra
.393 .81 .616 r
.24229 .37033 .24454 .36881 .25764 .35838 .25551 .35996 Metetra
.451 .83 .594 r
.25551 .35996 .25764 .35838 .27074 .34598 .26872 .34762 Metetra
.499 .842 .567 r
.26872 .34762 .27074 .34598 .28384 .33149 .28194 .33321 Metetra
.54 .847 .537 r
.28194 .33321 .28384 .33149 .29694 .31477 .29515 .31659 Metetra
.573 .847 .504 r
.29515 .31659 .29694 .31477 .31004 .29568 .30837 .29762 Metetra
.6 .841 .47 r
.30837 .29762 .31004 .29568 .32314 .27401 .32159 .2761 Metetra
.62 .83 .433 r
.32159 .2761 .32314 .27401 .33624 .24953 .3348 .25182 Metetra
.634 .817 .396 r
.3348 .25182 .33624 .24953 .34934 .22199 .34802 .22452 Metetra
.644 .799 .357 r
.34802 .22452 .34934 .22199 .36245 .19102 .36123 .19388 Metetra
.648 .779 .317 r
.36123 .19388 .36245 .19102 .37555 .15623 .37445 .15952 Metetra
.37445 .15952 .37555 .15623 .38865 .11707 .38767 .12097 Metetra
.38767 .12097 .38865 .11707 .40175 .07288 .40088 .07762 Metetra
.40088 .07762 .40175 .07288 .41485 .05677 .4141 .05507 Metetra
.87665 .3861 .87336 .38492 .88646 .3788 .88987 .37992 Metetra
.86344 .39077 .86026 .38953 .87336 .38492 .87665 .3861 Metetra
.031 0 0 r
.85022 .39389 .84716 .39262 .86026 .38953 .86344 .39077 Metetra
.069 0 0 r
.837 .39545 .83406 .39414 .84716 .39262 .85022 .39389 Metetra
.111 0 0 r
.82379 .39543 .82096 .39409 .83406 .39414 .837 .39545 Metetra
.154 0 0 r
.81057 .39379 .80786 .39242 .82096 .39409 .82379 .39543 Metetra
.199 0 0 r
.79736 .3905 .79476 .3891 .80786 .39242 .81057 .39379 Metetra
.243 0 0 r
.78414 .38553 .78166 .3841 .79476 .3891 .79736 .3905 Metetra
.287 0 0 r
.77093 .37883 .76856 .37736 .78166 .3841 .78414 .38553 Metetra
.329 0 0 r
.75771 .37033 .75546 .36881 .76856 .37736 .77093 .37883 Metetra
0 .188 .606 r
.74449 .35996 .74236 .35838 .75546 .36881 .75771 .37033 Metetra
0 .13 .583 r
.73128 .34762 .72926 .34598 .74236 .35838 .74449 .35996 Metetra
0 .074 .555 r
.71806 .33321 .71616 .33149 .72926 .34598 .73128 .34762 Metetra
0 .018 .523 r
.70485 .31659 .70306 .31477 .71616 .33149 .71806 .33321 Metetra
0 0 .489 r
.69163 .29762 .68996 .29568 .70306 .31477 .70485 .31659 Metetra
0 0 .453 r
.67841 .2761 .67686 .27401 .68996 .29568 .69163 .29762 Metetra
0 0 .415 r
.6652 .25182 .66376 .24953 .67686 .27401 .67841 .2761 Metetra
0 0 .375 r
.65198 .22452 .65066 .22199 .66376 .24953 .6652 .25182 Metetra
.624 .236 0 r
.63877 .19388 .63755 .19102 .65066 .22199 .65198 .22452 Metetra
.653 .283 0 r
.62555 .15952 .62445 .15623 .63755 .19102 .63877 .19388 Metetra
.683 .331 0 r
.61233 .12097 .61135 .11707 .62445 .15623 .62555 .15952 Metetra
.715 .379 0 r
.59912 .07762 .59825 .07288 .61135 .11707 .61233 .12097 Metetra
0 0 .552 r
.5859 .05507 .58515 .05677 .59825 .07288 .59912 .07762 Metetra
.44 0 0 r
.10667 .38106 .11013 .37992 .12335 .3861 .12 .38731 Metetra
.368 0 0 r
.12 .38731 .12335 .3861 .13656 .39077 .13333 .39203 Metetra
.287 0 0 r
.13333 .39203 .13656 .39077 .14978 .39389 .14667 .3952 Metetra
.2 0 0 r
.14667 .3952 .14978 .39389 .163 .39545 .16 .39679 Metetra
.109 0 0 r
.16 .39679 .163 .39545 .17621 .39543 .17333 .39681 Metetra
.016 0 0 r
.17333 .39681 .17621 .39543 .18943 .39379 .18667 .39521 Metetra
.18667 .39521 .18943 .39379 .20264 .3905 .2 .39197 Metetra
.2 .39197 .20264 .3905 .21586 .38553 .21333 .38705 Metetra
.21333 .38705 .21586 .38553 .22907 .37883 .22667 .38041 Metetra
.22667 .38041 .22907 .37883 .24229 .37033 .24 .37198 Metetra
.379 .801 .61 r
.24 .37198 .24229 .37033 .25551 .35996 .25333 .3617 Metetra
.435 .82 .586 r
.25333 .3617 .25551 .35996 .26872 .34762 .26667 .34947 Metetra
.481 .831 .558 r
.26667 .34947 .26872 .34762 .28194 .33321 .28 .33519 Metetra
.52 .835 .527 r
.28 .33519 .28194 .33321 .29515 .31659 .29333 .31874 Metetra
.552 .833 .492 r
.29333 .31874 .29515 .31659 .30837 .29762 .30667 .29995 Metetra
.576 .826 .455 r
.30667 .29995 .30837 .29762 .32159 .2761 .32 .27867 Metetra
.594 .814 .417 r
.32 .27867 .32159 .2761 .3348 .25182 .33333 .25468 Metetra
.606 .799 .377 r
.33333 .25468 .3348 .25182 .34802 .22452 .34667 .22774 Metetra
.34667 .22774 .34802 .22452 .36123 .19388 .36 .19756 Metetra
.36 .19756 .36123 .19388 .37445 .15952 .37333 .16381 Metetra
.37333 .16381 .37445 .15952 .38767 .12097 .38667 .12606 Metetra
.38667 .12606 .38767 .12097 .40088 .07762 .4 .08382 Metetra
.4 .08382 .40088 .07762 .4141 .05507 .41333 .05333 Metetra
.88 .38731 .87665 .3861 .88987 .37992 .89333 .38106 Metetra
.86667 .39203 .86344 .39077 .87665 .3861 .88 .38731 Metetra
.031 0 0 r
.85333 .3952 .85022 .39389 .86344 .39077 .86667 .39203 Metetra
.069 0 0 r
.84 .39679 .837 .39545 .85022 .39389 .85333 .3952 Metetra
.111 0 0 r
.82667 .39681 .82379 .39543 .837 .39545 .84 .39679 Metetra
.155 0 0 r
.81333 .39521 .81057 .39379 .82379 .39543 .82667 .39681 Metetra
.2 0 0 r
.8 .39197 .79736 .3905 .81057 .39379 .81333 .39521 Metetra
.245 0 0 r
.78667 .38705 .78414 .38553 .79736 .3905 .8 .39197 Metetra
.29 0 0 r
.77333 .38041 .77093 .37883 .78414 .38553 .78667 .38705 Metetra
.334 0 0 r
.76 .37198 .75771 .37033 .77093 .37883 .77333 .38041 Metetra
.376 0 0 r
.74667 .3617 .74449 .35996 .75771 .37033 .76 .37198 Metetra
0 .126 .572 r
.73333 .34947 .73128 .34762 .74449 .35996 .74667 .3617 Metetra
0 .067 .543 r
.72 .33519 .71806 .33321 .73128 .34762 .73333 .34947 Metetra
0 .01 .509 r
.70667 .31874 .70485 .31659 .71806 .33321 .72 .33519 Metetra
0 0 .473 r
.69333 .29995 .69163 .29762 .70485 .31659 .70667 .31874 Metetra
.559 .1 0 r
.68 .27867 .67841 .2761 .69163 .29762 .69333 .29995 Metetra
.591 .153 0 r
.66667 .25468 .6652 .25182 .67841 .2761 .68 .27867 Metetra
.622 .204 0 r
.65333 .22774 .65198 .22452 .6652 .25182 .66667 .25468 Metetra
.653 .255 0 r
.64 .19756 .63877 .19388 .65198 .22452 .65333 .22774 Metetra
.685 .304 0 r
.62667 .16381 .62555 .15952 .63877 .19388 .64 .19756 Metetra
.718 .354 0 r
.61333 .12606 .61233 .12097 .62555 .15952 .62667 .16381 Metetra
.752 .404 0 r
.6 .08382 .59912 .07762 .61233 .12097 .61333 .12606 Metetra
0 0 .467 r
.58667 .05333 .5859 .05507 .59912 .07762 .6 .08382 Metetra
.441 0 0 r
.10314 .38222 .10667 .38106 .12 .38731 .11659 .38853 Metetra
.368 0 0 r
.11659 .38853 .12 .38731 .13333 .39203 .13004 .39331 Metetra
.288 0 0 r
.13004 .39331 .13333 .39203 .14667 .3952 .1435 .39652 Metetra
.201 0 0 r
.1435 .39652 .14667 .3952 .16 .39679 .15695 .39816 Metetra
.112 0 0 r
.15695 .39816 .16 .39679 .17333 .39681 .1704 .39822 Metetra
.021 0 0 r
.1704 .39822 .17333 .39681 .18667 .39521 .18386 .39667 Metetra
.18386 .39667 .18667 .39521 .2 .39197 .19731 .39349 Metetra
.19731 .39349 .2 .39197 .21333 .38705 .21076 .38864 Metetra
.21076 .38864 .21333 .38705 .22667 .38041 .22422 .38209 Metetra
.22422 .38209 .22667 .38041 .24 .37198 .23767 .37377 Metetra
.23767 .37377 .24 .37198 .25333 .3617 .25112 .36361 Metetra
.417 .81 .579 r
.25112 .36361 .25333 .3617 .26667 .34947 .26457 .35153 Metetra
.462 .82 .55 r
.26457 .35153 .26667 .34947 .28 .33519 .27803 .33744 Metetra
.499 .823 .517 r
.27803 .33744 .28 .33519 .29333 .31874 .29148 .32119 Metetra
.529 .82 .48 r
.29148 .32119 .29333 .31874 .30667 .29995 .30493 .30267 Metetra
.30493 .30267 .30667 .29995 .32 .27867 .31839 .2817 Metetra
.31839 .2817 .32 .27867 .33333 .25468 .33184 .25809 Metetra
.33184 .25809 .33333 .25468 .34667 .22774 .34529 .23163 Metetra
.34529 .23163 .34667 .22774 .36 .19756 .35874 .20205 Metetra
.35874 .20205 .36 .19756 .37333 .16381 .3722 .16906 Metetra
.3722 .16906 .37333 .16381 .38667 .12606 .38565 .1323 Metetra
.38565 .1323 .38667 .12606 .4 .08382 .3991 .09137 Metetra
.3991 .09137 .4 .08382 .41333 .05333 .41256 .05157 Metetra
.88341 .38853 .88 .38731 .89333 .38106 .89686 .38222 Metetra
.86996 .39331 .86667 .39203 .88 .38731 .88341 .38853 Metetra
.03 0 0 r
.8565 .39652 .85333 .3952 .86667 .39203 .86996 .39331 Metetra
.069 0 0 r
.84305 .39816 .84 .39679 .85333 .3952 .8565 .39652 Metetra
.11 0 0 r
.8296 .39822 .82667 .39681 .84 .39679 .84305 .39816 Metetra
.154 0 0 r
.81614 .39667 .81333 .39521 .82667 .39681 .8296 .39822 Metetra
.2 0 0 r
.80269 .39349 .8 .39197 .81333 .39521 .81614 .39667 Metetra
.246 0 0 r
.78924 .38864 .78667 .38705 .8 .39197 .80269 .39349 Metetra
.292 0 0 r
.77578 .38209 .77333 .38041 .78667 .38705 .78924 .38864 Metetra
.338 0 0 r
.76233 .37377 .76 .37198 .77333 .38041 .77578 .38209 Metetra
.382 0 0 r
.74888 .36361 .74667 .3617 .76 .37198 .76233 .37377 Metetra
.424 0 0 r
.73543 .35153 .73333 .34947 .74667 .3617 .74888 .36361 Metetra
.465 0 0 r
.72197 .33744 .72 .33519 .73333 .34947 .73543 .35153 Metetra
.504 0 0 r
.70852 .32119 .70667 .31874 .72 .33519 .72197 .33744 Metetra
.541 .054 0 r
.69507 .30267 .69333 .29995 .70667 .31874 .70852 .32119 Metetra
.577 .11 0 r
.68161 .2817 .68 .27867 .69333 .29995 .69507 .30267 Metetra
.612 .165 0 r
.66816 .25809 .66667 .25468 .68 .27867 .68161 .2817 Metetra
.646 .219 0 r
.65471 .23163 .65333 .22774 .66667 .25468 .66816 .25809 Metetra
.68 .271 0 r
.64126 .20205 .64 .19756 .65333 .22774 .65471 .23163 Metetra
.714 .323 0 r
.6278 .16906 .62667 .16381 .64 .19756 .64126 .20205 Metetra
.748 .374 0 r
.61435 .1323 .61333 .12606 .62667 .16381 .6278 .16906 Metetra
.784 .426 0 r
.6009 .09137 .6 .08382 .61333 .12606 .61435 .1323 Metetra
0 0 .396 r
.58744 .05157 .58667 .05333 .6 .08382 .6009 .09137 Metetra
.441 0 0 r
.09955 .3834 .10314 .38222 .11659 .38853 .11312 .38978 Metetra
.368 0 0 r
.11312 .38978 .11659 .38853 .13004 .39331 .1267 .3946 Metetra
.288 0 0 r
.1267 .3946 .13004 .39331 .1435 .39652 .14027 .39786 Metetra
.203 0 0 r
.14027 .39786 .1435 .39652 .15695 .39816 .15385 .39955 Metetra
.114 0 0 r
.15385 .39955 .15695 .39816 .1704 .39822 .16742 .39966 Metetra
.025 0 0 r
.16742 .39966 .1704 .39822 .18386 .39667 .181 .39816 Metetra
.181 .39816 .18386 .39667 .19731 .39349 .19457 .39506 Metetra
.19457 .39506 .19731 .39349 .21076 .38864 .20814 .3903 Metetra
.20814 .3903 .21076 .38864 .22422 .38209 .22172 .38386 Metetra
.22172 .38386 .22422 .38209 .23767 .37377 .23529 .37567 Metetra
.23529 .37567 .23767 .37377 .25112 .36361 .24887 .36568 Metetra
.24887 .36568 .25112 .36361 .26457 .35153 .26244 .35379 Metetra
.26244 .35379 .26457 .35153 .27803 .33744 .27602 .33993 Metetra
.27602 .33993 .27803 .33744 .29148 .32119 .28959 .32396 Metetra
.28959 .32396 .29148 .32119 .30493 .30267 .30317 .30576 Metetra
.30317 .30576 .30493 .30267 .31839 .2817 .31674 .28519 Metetra
.31674 .28519 .31839 .2817 .33184 .25809 .33032 .26205 Metetra
.33032 .26205 .33184 .25809 .34529 .23163 .34389 .23616 Metetra
.34389 .23616 .34529 .23163 .35874 .20205 .35747 .2073 Metetra
.35747 .2073 .35874 .20205 .3722 .16906 .37104 .1752 Metetra
.37104 .1752 .3722 .16906 .38565 .1323 .38462 .1396 Metetra
.38462 .1396 .38565 .1323 .3991 .09137 .39819 .10019 Metetra
.39819 .10019 .3991 .09137 .41256 .05157 .41176 .05666 Metetra
.069 0 0 r
.41176 .05666 .41256 .05157 .42601 .05157 .42534 .04977 Metetra
.88688 .38978 .88341 .38853 .89686 .38222 .90045 .3834 Metetra
.8733 .3946 .86996 .39331 .88341 .38853 .88688 .38978 Metetra
.03 0 0 r
.85973 .39786 .8565 .39652 .86996 .39331 .8733 .3946 Metetra
.068 0 0 r
.84615 .39955 .84305 .39816 .8565 .39652 .85973 .39786 Metetra
.109 0 0 r
.83258 .39966 .8296 .39822 .84305 .39816 .84615 .39955 Metetra
.153 0 0 r
.819 .39816 .81614 .39667 .8296 .39822 .83258 .39966 Metetra
.199 0 0 r
.80543 .39506 .80269 .39349 .81614 .39667 .819 .39816 Metetra
.246 0 0 r
.79186 .3903 .78924 .38864 .80269 .39349 .80543 .39506 Metetra
.294 0 0 r
.77828 .38386 .77578 .38209 .78924 .38864 .79186 .3903 Metetra
.34 0 0 r
.76471 .37567 .76233 .37377 .77578 .38209 .77828 .38386 Metetra
.386 0 0 r
.75113 .36568 .74888 .36361 .76233 .37377 .76471 .37567 Metetra
.431 0 0 r
.73756 .35379 .73543 .35153 .74888 .36361 .75113 .36568 Metetra
.474 0 0 r
.72398 .33993 .72197 .33744 .73543 .35153 .73756 .35379 Metetra
.515 .001 0 r
.71041 .32396 .70852 .32119 .72197 .33744 .72398 .33993 Metetra
.555 .06 0 r
.69683 .30576 .69507 .30267 .70852 .32119 .71041 .32396 Metetra
.594 .119 0 r
.68326 .28519 .68161 .2817 .69507 .30267 .69683 .30576 Metetra
.631 .175 0 r
.66968 .26205 .66816 .25809 .68161 .2817 .68326 .28519 Metetra
.668 .231 0 r
.65611 .23616 .65471 .23163 .66816 .25809 .66968 .26205 Metetra
.704 .285 0 r
.64253 .2073 .64126 .20205 .65471 .23163 .65611 .23616 Metetra
.739 .338 0 r
.62896 .1752 .6278 .16906 .64126 .20205 .64253 .2073 Metetra
.775 .39 0 r
.61538 .1396 .61435 .1323 .6278 .16906 .62896 .1752 Metetra
.812 .443 0 r
.60181 .10019 .6009 .09137 .61435 .1323 .61538 .1396 Metetra
.728 .386 0 r
.58824 .05666 .58744 .05157 .6009 .09137 .60181 .10019 Metetra
0 .435 .792 r
.57466 .04977 .57399 .05157 .58744 .05157 .58824 .05666 Metetra
.441 0 0 r
.09589 .38461 .09955 .3834 .11312 .38978 .10959 .39105 Metetra
.369 0 0 r
.10959 .39105 .11312 .38978 .1267 .3946 .12329 .39592 Metetra
.289 0 0 r
.12329 .39592 .1267 .3946 .14027 .39786 .13699 .39923 Metetra
.204 0 0 r
.13699 .39923 .14027 .39786 .15385 .39955 .15068 .40096 Metetra
.117 0 0 r
.15068 .40096 .15385 .39955 .16742 .39966 .16438 .40112 Metetra
.03 0 0 r
.16438 .40112 .16742 .39966 .181 .39816 .17808 .39969 Metetra
.17808 .39969 .181 .39816 .19457 .39506 .19178 .39667 Metetra
.19178 .39667 .19457 .39506 .20814 .3903 .20548 .39202 Metetra
.20548 .39202 .20814 .3903 .22172 .38386 .21918 .38571 Metetra
.21918 .38571 .22172 .38386 .23529 .37567 .23288 .37769 Metetra
.23288 .37769 .23529 .37567 .24887 .36568 .24658 .36789 Metetra
.24658 .36789 .24887 .36568 .26244 .35379 .26027 .35624 Metetra
.26027 .35624 .26244 .35379 .27602 .33993 .27397 .34266 Metetra
.27397 .34266 .27602 .33993 .28959 .32396 .28767 .32702 Metetra
.28767 .32702 .28959 .32396 .30317 .30576 .30137 .30922 Metetra
.30137 .30922 .30317 .30576 .31674 .28519 .31507 .28911 Metetra
.31507 .28911 .31674 .28519 .33032 .26205 .32877 .26653 Metetra
.32877 .26653 .33032 .26205 .34389 .23616 .34247 .24132 Metetra
.34247 .24132 .34389 .23616 .35747 .2073 .35616 .21328 Metetra
.35616 .21328 .35747 .2073 .37104 .1752 .36986 .18221 Metetra
.36986 .18221 .37104 .1752 .38462 .1396 .38356 .14789 Metetra
.38356 .14789 .38462 .1396 .39819 .10019 .39726 .11014 Metetra
.39726 .11014 .39819 .10019 .41176 .05666 .41096 .06878 Metetra
0 0 .069 r
.41096 .06878 .41176 .05666 .42534 .04977 .42466 .04795 Metetra
.89041 .39105 .88688 .38978 .90045 .3834 .90411 .38461 Metetra
.87671 .39592 .8733 .3946 .88688 .38978 .89041 .39105 Metetra
.029 0 0 r
.86301 .39923 .85973 .39786 .8733 .3946 .87671 .39592 Metetra
.067 0 0 r
.84932 .40096 .84615 .39955 .85973 .39786 .86301 .39923 Metetra
.108 0 0 r
.83562 .40112 .83258 .39966 .84615 .39955 .84932 .40096 Metetra
.152 0 0 r
.82192 .39969 .819 .39816 .83258 .39966 .83562 .40112 Metetra
.198 0 0 r
.80822 .39667 .80543 .39506 .819 .39816 .82192 .39969 Metetra
.245 0 0 r
.79452 .39202 .79186 .3903 .80543 .39506 .80822 .39667 Metetra
.293 0 0 r
.78082 .38571 .77828 .38386 .79186 .3903 .79452 .39202 Metetra
.341 0 0 r
.76712 .37769 .76471 .37567 .77828 .38386 .78082 .38571 Metetra
.389 0 0 r
.75342 .36789 .75113 .36568 .76471 .37567 .76712 .37769 Metetra
.436 0 0 r
.73973 .35624 .73756 .35379 .75113 .36568 .75342 .36789 Metetra
.481 0 0 r
.72603 .34266 .72398 .33993 .73756 .35379 .73973 .35624 Metetra
.525 .003 0 r
.71233 .32702 .71041 .32396 .72398 .33993 .72603 .34266 Metetra
.568 .065 0 r
.69863 .30922 .69683 .30576 .71041 .32396 .71233 .32702 Metetra
.609 .125 0 r
.68493 .28911 .68326 .28519 .69683 .30576 .69863 .30922 Metetra
.648 .183 0 r
.67123 .26653 .66968 .26205 .68326 .28519 .68493 .28911 Metetra
.687 .24 0 r
.65753 .24132 .65611 .23616 .66968 .26205 .67123 .26653 Metetra
.724 .296 0 r
.64384 .21328 .64253 .2073 .65611 .23616 .65753 .24132 Metetra
.761 .35 0 r
.63014 .18221 .62896 .1752 .64253 .2073 .64384 .21328 Metetra
.798 .403 0 r
.61644 .14789 .61538 .1396 .62896 .1752 .63014 .18221 Metetra
.835 .455 0 r
.60274 .11014 .60181 .10019 .61538 .1396 .61644 .14789 Metetra
.871 .507 .015 r
.58904 .06878 .58824 .05666 .60181 .10019 .60274 .11014 Metetra
0 .035 .578 r
.57534 .04795 .57466 .04977 .58824 .05666 .58904 .06878 Metetra
.442 0 0 r
.09217 .38584 .09589 .38461 .10959 .39105 .10599 .39234 Metetra
.368 0 0 r
.10599 .39234 .10959 .39105 .12329 .39592 .11982 .39726 Metetra
.289 0 0 r
.11982 .39726 .12329 .39592 .13699 .39923 .13364 .4006 Metetra
.205 0 0 r
.13364 .4006 .13699 .39923 .15068 .40096 .14747 .40238 Metetra
.119 0 0 r
.14747 .40238 .15068 .40096 .16438 .40112 .16129 .4026 Metetra
.034 0 0 r
.16129 .4026 .16438 .40112 .17808 .39969 .17512 .40125 Metetra
.17512 .40125 .17808 .39969 .19178 .39667 .18894 .39832 Metetra
.18894 .39832 .19178 .39667 .20548 .39202 .20276 .39379 Metetra
.20276 .39379 .20548 .39202 .21918 .38571 .21659 .38764 Metetra
.21659 .38764 .21918 .38571 .23288 .37769 .23041 .3798 Metetra
.23041 .3798 .23288 .37769 .24658 .36789 .24424 .37024 Metetra
.24424 .37024 .24658 .36789 .26027 .35624 .25806 .35887 Metetra
.25806 .35887 .26027 .35624 .27397 .34266 .27189 .34561 Metetra
.27189 .34561 .27397 .34266 .28767 .32702 .28571 .33036 Metetra
.28571 .33036 .28767 .32702 .30137 .30922 .29954 .31301 Metetra
.29954 .31301 .30137 .30922 .31507 .28911 .31336 .29344 Metetra
.31336 .29344 .31507 .28911 .32877 .26653 .32719 .2715 Metetra
.32719 .2715 .32877 .26653 .34247 .24132 .34101 .24705 Metetra
.34101 .24705 .34247 .24132 .35616 .21328 .35484 .21994 Metetra
.35484 .21994 .35616 .21328 .36986 .18221 .36866 .19 Metetra
.36866 .19 .36986 .18221 .38356 .14789 .38249 .15709 Metetra
.38249 .15709 .38356 .14789 .39726 .11014 .39631 .12111 Metetra
.39631 .12111 .39726 .11014 .41096 .06878 .41014 .08203 Metetra
0 0 .053 r
.41014 .08203 .41096 .06878 .42466 .04795 .42396 .04608 Metetra
.89401 .39234 .89041 .39105 .90411 .38461 .90783 .38584 Metetra
.88018 .39726 .87671 .39592 .89041 .39105 .89401 .39234 Metetra
.028 0 0 r
.86636 .4006 .86301 .39923 .87671 .39592 .88018 .39726 Metetra
.065 0 0 r
.85253 .40238 .84932 .40096 .86301 .39923 .86636 .4006 Metetra
.106 0 0 r
.83871 .4026 .83562 .40112 .84932 .40096 .85253 .40238 Metetra
.149 0 0 r
.82488 .40125 .82192 .39969 .83562 .40112 .83871 .4026 Metetra
.195 0 0 r
.81106 .39832 .80822 .39667 .82192 .39969 .82488 .40125 Metetra
.243 0 0 r
.79724 .39379 .79452 .39202 .80822 .39667 .81106 .39832 Metetra
.292 0 0 r
.78341 .38764 .78082 .38571 .79452 .39202 .79724 .39379 Metetra
.341 0 0 r
.76959 .3798 .76712 .37769 .78082 .38571 .78341 .38764 Metetra
.39 0 0 r
.75576 .37024 .75342 .36789 .76712 .37769 .76959 .3798 Metetra
.439 0 0 r
.74194 .35887 .73973 .35624 .75342 .36789 .75576 .37024 Metetra
.486 0 0 r
.72811 .34561 .72603 .34266 .73973 .35624 .74194 .35887 Metetra
.533 .004 0 r
.71429 .33036 .71233 .32702 .72603 .34266 .72811 .34561 Metetra
.578 .067 0 r
.70046 .31301 .69863 .30922 .71233 .32702 .71429 .33036 Metetra
.621 .128 0 r
.68664 .29344 .68493 .28911 .69863 .30922 .70046 .31301 Metetra
.663 .188 0 r
.67281 .2715 .67123 .26653 .68493 .28911 .68664 .29344 Metetra
.703 .247 0 r
.65899 .24705 .65753 .24132 .67123 .26653 .67281 .2715 Metetra
.742 .304 0 r
.64516 .21994 .64384 .21328 .65753 .24132 .65899 .24705 Metetra
.78 .359 0 r
.63134 .19 .63014 .18221 .64384 .21328 .64516 .21994 Metetra
.817 .412 0 r
.61751 .15709 .61644 .14789 .63014 .18221 .63134 .19 Metetra
.853 .464 0 r
.60369 .12111 .60274 .11014 .61644 .14789 .61751 .15709 Metetra
.887 .514 .045 r
.58986 .08203 .58904 .06878 .60274 .11014 .60369 .12111 Metetra
0 0 .421 r
.57604 .04608 .57534 .04795 .58904 .06878 .58986 .08203 Metetra
.441 0 0 r
.08837 .3871 .09217 .38584 .10599 .39234 .10233 .39365 Metetra
.368 0 0 r
.10233 .39365 .10599 .39234 .11982 .39726 .11628 .39861 Metetra
.289 0 0 r
.11628 .39861 .11982 .39726 .13364 .4006 .13023 .40199 Metetra
.205 0 0 r
.13023 .40199 .13364 .4006 .14747 .40238 .14419 .40381 Metetra
.121 0 0 r
.14419 .40381 .14747 .40238 .16129 .4026 .15814 .40408 Metetra
.038 0 0 r
.15814 .40408 .16129 .4026 .17512 .40125 .17209 .40281 Metetra
.17209 .40281 .17512 .40125 .18894 .39832 .18605 .39999 Metetra
.18605 .39999 .18894 .39832 .20276 .39379 .2 .39561 Metetra
.2 .39561 .20276 .39379 .21659 .38764 .21395 .38963 Metetra
.21395 .38963 .21659 .38764 .23041 .3798 .22791 .38201 Metetra
.22791 .38201 .23041 .3798 .24424 .37024 .24186 .37271 Metetra
.24186 .37271 .24424 .37024 .25806 .35887 .25581 .36166 Metetra
.25581 .36166 .25806 .35887 .27189 .34561 .26977 .34877 Metetra
.26977 .34877 .27189 .34561 .28571 .33036 .28372 .33396 Metetra
.28372 .33396 .28571 .33036 .29954 .31301 .29767 .31713 Metetra
.29767 .31713 .29954 .31301 .31336 .29344 .31163 .29816 Metetra
.31163 .29816 .31336 .29344 .32719 .2715 .32558 .27694 Metetra
.32558 .27694 .32719 .2715 .34101 .24705 .33953 .25334 Metetra
.33953 .25334 .34101 .24705 .35484 .21994 .35349 .22723 Metetra
.35349 .22723 .35484 .21994 .36866 .19 .36744 .19852 Metetra
.36744 .19852 .36866 .19 .38249 .15709 .3814 .16711 Metetra
.3814 .16711 .38249 .15709 .39631 .12111 .39535 .13299 Metetra
.39535 .13299 .39631 .12111 .41014 .08203 .4093 .09624 Metetra
0 0 .065 r
.4093 .09624 .41014 .08203 .42396 .04608 .42326 .05713 Metetra
.151 0 .041 r
.42326 .05713 .42396 .04608 .43779 .04608 .43721 .04419 Metetra
.89767 .39365 .89401 .39234 .90783 .38584 .91163 .3871 Metetra
.88372 .39861 .88018 .39726 .89401 .39234 .89767 .39365 Metetra
.027 0 0 r
.86977 .40199 .86636 .4006 .88018 .39726 .88372 .39861 Metetra
.063 0 0 r
.85581 .40381 .85253 .40238 .86636 .4006 .86977 .40199 Metetra
.103 0 0 r
.84186 .40408 .83871 .4026 .85253 .40238 .85581 .40381 Metetra
.146 0 0 r
.82791 .40281 .82488 .40125 .83871 .4026 .84186 .40408 Metetra
.192 0 0 r
.81395 .39999 .81106 .39832 .82488 .40125 .82791 .40281 Metetra
.24 0 0 r
.8 .39561 .79724 .39379 .81106 .39832 .81395 .39999 Metetra
.289 0 0 r
.78605 .38963 .78341 .38764 .79724 .39379 .8 .39561 Metetra
.339 0 0 r
.77209 .38201 .76959 .3798 .78341 .38764 .78605 .38963 Metetra
.39 0 0 r
.75814 .37271 .75576 .37024 .76959 .3798 .77209 .38201 Metetra
.44 0 0 r
.74419 .36166 .74194 .35887 .75576 .37024 .75814 .37271 Metetra
.49 0 0 r
.73023 .34877 .72811 .34561 .74194 .35887 .74419 .36166 Metetra
.538 .003 0 r
.71628 .33396 .71429 .33036 .72811 .34561 .73023 .34877 Metetra
.585 .067 0 r
.70233 .31713 .70046 .31301 .71429 .33036 .71628 .33396 Metetra
.631 .13 0 r
.68837 .29816 .68664 .29344 .70046 .31301 .70233 .31713 Metetra
.675 .191 0 r
.67442 .27694 .67281 .2715 .68664 .29344 .68837 .29816 Metetra
.716 .251 0 r
.66047 .25334 .65899 .24705 .67281 .2715 .67442 .27694 Metetra
.757 .309 0 r
.64651 .22723 .64516 .21994 .65899 .24705 .66047 .25334 Metetra
.795 .364 0 r
.63256 .19852 .63134 .19 .64516 .21994 .64651 .22723 Metetra
.832 .418 0 r
.6186 .16711 .61751 .15709 .63134 .19 .63256 .19852 Metetra
.867 .469 .001 r
.60465 .13299 .60369 .12111 .61751 .15709 .6186 .16711 Metetra
.899 .516 .071 r
.5907 .09624 .58986 .08203 .60369 .12111 .60465 .13299 Metetra
.858 .482 0 r
.57674 .05713 .57604 .04608 .58986 .08203 .5907 .09624 Metetra
0 .234 .699 r
.56279 .04419 .56221 .04608 .57604 .04608 .57674 .05713 Metetra
.441 0 0 r
.08451 .3884 .08837 .3871 .10233 .39365 .09859 .39498 Metetra
.367 0 0 r
.09859 .39498 .10233 .39365 .11628 .39861 .11268 .39997 Metetra
.288 0 0 r
.11268 .39997 .11628 .39861 .13023 .40199 .12676 .40338 Metetra
.205 0 0 r
.12676 .40338 .13023 .40199 .14419 .40381 .14085 .40524 Metetra
.122 0 0 r
.14085 .40524 .14419 .40381 .15814 .40408 .15493 .40557 Metetra
.041 0 0 r
.15493 .40557 .15814 .40408 .17209 .40281 .16901 .40438 Metetra
.16901 .40438 .17209 .40281 .18605 .39999 .1831 .40168 Metetra
.1831 .40168 .18605 .39999 .2 .39561 .19718 .39745 Metetra
.19718 .39745 .2 .39561 .21395 .38963 .21127 .39166 Metetra
.21127 .39166 .21395 .38963 .22791 .38201 .22535 .38429 Metetra
.22535 .38429 .22791 .38201 .24186 .37271 .23944 .37529 Metetra
.23944 .37529 .24186 .37271 .25581 .36166 .25352 .36459 Metetra
.25352 .36459 .25581 .36166 .26977 .34877 .26761 .35212 Metetra
.26761 .35212 .26977 .34877 .28372 .33396 .28169 .33781 Metetra
.28169 .33781 .28372 .33396 .29767 .31713 .29577 .32155 Metetra
.29577 .32155 .29767 .31713 .31163 .29816 .30986 .30325 Metetra
.30986 .30325 .31163 .29816 .32558 .27694 .32394 .28281 Metetra
.32394 .28281 .32558 .27694 .33953 .25334 .33803 .26013 Metetra
.33803 .26013 .33953 .25334 .35349 .22723 .35211 .23511 Metetra
.35211 .23511 .35349 .22723 .36744 .19852 .3662 .2077 Metetra
.3662 .2077 .36744 .19852 .3814 .16711 .38028 .17787 Metetra
.38028 .17787 .3814 .16711 .39535 .13299 .39437 .14566 Metetra
0 0 .018 r
.39437 .14566 .39535 .13299 .4093 .09624 .40845 .11127 Metetra
0 0 .088 r
.40845 .11127 .4093 .09624 .42326 .05713 .42254 .07508 Metetra
0 0 .179 r
.42254 .07508 .42326 .05713 .43721 .04419 .43662 .04225 Metetra
.90141 .39498 .89767 .39365 .91163 .3871 .91549 .3884 Metetra
.88732 .39997 .88372 .39861 .89767 .39365 .90141 .39498 Metetra
.025 0 0 r
.87324 .40338 .86977 .40199 .88372 .39861 .88732 .39997 Metetra
.061 0 0 r
.85915 .40524 .85581 .40381 .86977 .40199 .87324 .40338 Metetra
.1 0 0 r
.84507 .40557 .84186 .40408 .85581 .40381 .85915 .40524 Metetra
.142 0 0 r
.83099 .40438 .82791 .40281 .84186 .40408 .84507 .40557 Metetra
.187 0 0 r
.8169 .40168 .81395 .39999 .82791 .40281 .83099 .40438 Metetra
.235 0 0 r
.80282 .39745 .8 .39561 .81395 .39999 .8169 .40168 Metetra
.284 0 0 r
.78873 .39166 .78605 .38963 .8 .39561 .80282 .39745 Metetra
.335 0 0 r
.77465 .38429 .77209 .38201 .78605 .38963 .78873 .39166 Metetra
.387 0 0 r
.76056 .37529 .75814 .37271 .77209 .38201 .77465 .38429 Metetra
.439 0 0 r
.74648 .36459 .74419 .36166 .75814 .37271 .76056 .37529 Metetra
.491 0 0 r
.73239 .35212 .73023 .34877 .74419 .36166 .74648 .36459 Metetra
.542 0 0 r
.71831 .33781 .71628 .33396 .73023 .34877 .73239 .35212 Metetra
.591 .064 0 r
.70423 .32155 .70233 .31713 .71628 .33396 .71831 .33781 Metetra
.638 .129 0 r
.69014 .30325 .68837 .29816 .70233 .31713 .70423 .32155 Metetra
.684 .192 0 r
.67606 .28281 .67442 .27694 .68837 .29816 .69014 .30325 Metetra
.727 .252 0 r
.66197 .26013 .66047 .25334 .67442 .27694 .67606 .28281 Metetra
.768 .311 0 r
.64789 .23511 .64651 .22723 .66047 .25334 .66197 .26013 Metetra
.807 .367 0 r
.6338 .2077 .63256 .19852 .64651 .22723 .64789 .23511 Metetra
.843 .42 0 r
.61972 .17787 .6186 .16711 .63256 .19852 .6338 .2077 Metetra
.876 .469 .024 r
.60563 .14566 .60465 .13299 .6186 .16711 .61972 .17787 Metetra
.906 .515 .093 r
.59155 .11127 .5907 .09624 .60465 .13299 .60563 .14566 Metetra
.93 .555 .166 r
.57746 .07508 .57674 .05713 .5907 .09624 .59155 .11127 Metetra
0 0 .443 r
.56338 .04225 .56279 .04419 .57674 .05713 .57746 .07508 Metetra
.44 0 0 r
.08057 .38973 .08451 .3884 .09859 .39498 .09479 .39634 Metetra
.365 0 0 r
.09479 .39634 .09859 .39498 .11268 .39997 .109 .40133 Metetra
.286 0 0 r
.109 .40133 .11268 .39997 .12676 .40338 .12322 .40476 Metetra
.204 0 0 r
.12322 .40476 .12676 .40338 .14085 .40524 .13744 .40666 Metetra
.123 0 0 r
.13744 .40666 .14085 .40524 .15493 .40557 .15166 .40705 Metetra
.044 0 0 r
.15166 .40705 .15493 .40557 .16901 .40438 .16588 .40595 Metetra
.16588 .40595 .16901 .40438 .1831 .40168 .18009 .40337 Metetra
.18009 .40337 .1831 .40168 .19718 .39745 .19431 .3993 Metetra
.19431 .3993 .19718 .39745 .21127 .39166 .20853 .39373 Metetra
.20853 .39373 .21127 .39166 .22535 .38429 .22275 .38663 Metetra
.22275 .38663 .22535 .38429 .23944 .37529 .23697 .37796 Metetra
.23697 .37796 .23944 .37529 .25352 .36459 .25118 .36765 Metetra
.25118 .36765 .25352 .36459 .26761 .35212 .2654 .35565 Metetra
.2654 .35565 .26761 .35212 .28169 .33781 .27962 .34187 Metetra
.27962 .34187 .28169 .33781 .29577 .32155 .29384 .32624 Metetra
.29384 .32624 .29577 .32155 .30986 .30325 .30806 .30867 Metetra
.30806 .30867 .30986 .30325 .32394 .28281 .32227 .28908 Metetra
.32227 .28908 .32394 .28281 .33803 .26013 .33649 .26738 Metetra
.33649 .26738 .33803 .26013 .35211 .23511 .35071 .24352 Metetra
.35071 .24352 .35211 .23511 .3662 .2077 .36493 .21748 Metetra
.36493 .21748 .3662 .2077 .38028 .17787 .37915 .18927 Metetra
.37915 .18927 .38028 .17787 .39437 .14566 .39336 .15901 Metetra
0 0 .038 r
.39336 .15901 .39437 .14566 .40845 .11127 .40758 .12697 Metetra
0 0 .108 r
.40758 .12697 .40845 .11127 .42254 .07508 .4218 .09361 Metetra
0 0 .182 r
.4218 .09361 .42254 .07508 .43662 .04225 .43602 .05978 Metetra
.188 0 .218 r
.43602 .05978 .43662 .04225 .4507 .04225 .45024 .04028 Metetra
.90521 .39634 .90141 .39498 .91549 .3884 .91943 .38973 Metetra
.891 .40133 .88732 .39997 .90141 .39498 .90521 .39634 Metetra
.023 0 0 r
.87678 .40476 .87324 .40338 .88732 .39997 .891 .40133 Metetra
.058 0 0 r
.86256 .40666 .85915 .40524 .87324 .40338 .87678 .40476 Metetra
.096 0 0 r
.84834 .40705 .84507 .40557 .85915 .40524 .86256 .40666 Metetra
.137 0 0 r
.83412 .40595 .83099 .40438 .84507 .40557 .84834 .40705 Metetra
.182 0 0 r
.81991 .40337 .8169 .40168 .83099 .40438 .83412 .40595 Metetra
.229 0 0 r
.80569 .3993 .80282 .39745 .8169 .40168 .81991 .40337 Metetra
.279 0 0 r
.79147 .39373 .78873 .39166 .80282 .39745 .80569 .3993 Metetra
.33 0 0 r
.77725 .38663 .77465 .38429 .78873 .39166 .79147 .39373 Metetra
.383 0 0 r
.76303 .37796 .76056 .37529 .77465 .38429 .77725 .38663 Metetra
.437 0 0 r
.74882 .36765 .74648 .36459 .76056 .37529 .76303 .37796 Metetra
.49 0 0 r
.7346 .35565 .73239 .35212 .74648 .36459 .74882 .36765 Metetra
.543 0 0 r
.72038 .34187 .71831 .33781 .73239 .35212 .7346 .35565 Metetra
.594 .06 0 r
.70616 .32624 .70423 .32155 .71831 .33781 .72038 .34187 Metetra
.643 .125 0 r
.69194 .30867 .69014 .30325 .70423 .32155 .70616 .32624 Metetra
.69 .189 0 r
.67773 .28908 .67606 .28281 .69014 .30325 .69194 .30867 Metetra
.735 .251 0 r
.66351 .26738 .66197 .26013 .67606 .28281 .67773 .28908 Metetra
.776 .31 0 r
.64929 .24352 .64789 .23511 .66197 .26013 .66351 .26738 Metetra
.815 .366 0 r
.63507 .21748 .6338 .2077 .64789 .23511 .64929 .24352 Metetra
.85 .418 0 r
.62085 .18927 .61972 .17787 .6338 .2077 .63507 .21748 Metetra
.881 .466 .043 r
.60664 .15901 .60563 .14566 .61972 .17787 .62085 .18927 Metetra
.908 .51 .112 r
.59242 .12697 .59155 .11127 .60563 .14566 .60664 .15901 Metetra
.929 .547 .183 r
.5782 .09361 .57746 .07508 .59155 .11127 .59242 .12697 Metetra
.926 .543 .166 r
.56398 .05978 .56338 .04225 .57746 .07508 .5782 .09361 Metetra
0 .064 .593 r
.54976 .04028 .5493 .04225 .56338 .04225 .56398 .05978 Metetra
.438 0 0 r
.07656 .3911 .08057 .38973 .09479 .39634 .09091 .39771 Metetra
.362 0 0 r
.09091 .39771 .09479 .39634 .109 .40133 .10526 .40271 Metetra
.283 0 0 r
.10526 .40271 .109 .40133 .12322 .40476 .11962 .40614 Metetra
.202 0 0 r
.11962 .40614 .12322 .40476 .13744 .40666 .13397 .40806 Metetra
.122 0 0 r
.13397 .40806 .13744 .40666 .15166 .40705 .14833 .4085 Metetra
.046 0 0 r
.14833 .4085 .15166 .40705 .16588 .40595 .16268 .40749 Metetra
.16268 .40749 .16588 .40595 .18009 .40337 .17703 .40504 Metetra
.17703 .40504 .18009 .40337 .19431 .3993 .19139 .40116 Metetra
.19139 .40116 .19431 .3993 .20853 .39373 .20574 .39582 Metetra
.20574 .39582 .20853 .39373 .22275 .38663 .2201 .38902 Metetra
.2201 .38902 .22275 .38663 .23697 .37796 .23445 .3807 Metetra
.23445 .3807 .23697 .37796 .25118 .36765 .2488 .37082 Metetra
.2488 .37082 .25118 .36765 .2654 .35565 .26316 .35932 Metetra
.26316 .35932 .2654 .35565 .27962 .34187 .27751 .34613 Metetra
.27751 .34613 .27962 .34187 .29384 .32624 .29187 .33118 Metetra
.29187 .33118 .29384 .32624 .30806 .30867 .30622 .3144 Metetra
.30622 .3144 .30806 .30867 .32227 .28908 .32057 .29571 Metetra
.32057 .29571 .32227 .28908 .33649 .26738 .33493 .27506 Metetra
.33493 .27506 .33649 .26738 .35071 .24352 .34928 .25241 Metetra
.34928 .25241 .35071 .24352 .36493 .21748 .36364 .22778 Metetra
.36364 .22778 .36493 .21748 .37915 .18927 .37799 .20123 Metetra
.37799 .20123 .37915 .18927 .39336 .15901 .39234 .17293 Metetra
0 0 .055 r
.39234 .17293 .39336 .15901 .40758 .12697 .4067 .1432 Metetra
0 0 .125 r
.4067 .1432 .40758 .12697 .4218 .09361 .42105 .11258 Metetra
.006 0 .196 r
.42105 .11258 .4218 .09361 .43602 .05978 .43541 .08193 Metetra
.112 0 .27 r
.43541 .08193 .43602 .05978 .45024 .04028 .44976 .0526 Metetra
.155 0 .073 r
.44976 .0526 .45024 .04028 .46445 .04028 .46411 .03828 Metetra
.90909 .39771 .90521 .39634 .91943 .38973 .92344 .3911 Metetra
.89474 .40271 .891 .40133 .90521 .39634 .90909 .39771 Metetra
.022 0 0 r
.88038 .40614 .87678 .40476 .891 .40133 .89474 .40271 Metetra
.055 0 0 r
.86603 .40806 .86256 .40666 .87678 .40476 .88038 .40614 Metetra
.091 0 0 r
.85167 .4085 .84834 .40705 .86256 .40666 .86603 .40806 Metetra
.131 0 0 r
.83732 .40749 .83412 .40595 .84834 .40705 .85167 .4085 Metetra
.175 0 0 r
.82297 .40504 .81991 .40337 .83412 .40595 .83732 .40749 Metetra
.222 0 0 r
.80861 .40116 .80569 .3993 .81991 .40337 .82297 .40504 Metetra
.271 0 0 r
.79426 .39582 .79147 .39373 .80569 .3993 .80861 .40116 Metetra
.323 0 0 r
.7799 .38902 .77725 .38663 .79147 .39373 .79426 .39582 Metetra
.377 0 0 r
.76555 .3807 .76303 .37796 .77725 .38663 .7799 .38902 Metetra
.432 0 0 r
.7512 .37082 .74882 .36765 .76303 .37796 .76555 .3807 Metetra
.487 0 0 r
.73684 .35932 .7346 .35565 .74882 .36765 .7512 .37082 Metetra
.541 0 0 r
.72249 .34613 .72038 .34187 .7346 .35565 .73684 .35932 Metetra
.595 .052 0 r
.70813 .33118 .70616 .32624 .72038 .34187 .72249 .34613 Metetra
.646 .119 0 r
.69378 .3144 .69194 .30867 .70616 .32624 .70813 .33118 Metetra
.694 .184 0 r
.67943 .29571 .67773 .28908 .69194 .30867 .69378 .3144 Metetra
.739 .247 0 r
.66507 .27506 .66351 .26738 .67773 .28908 .67943 .29571 Metetra
.781 .306 0 r
.65072 .25241 .64929 .24352 .66351 .26738 .66507 .27506 Metetra
.82 .362 0 r
.63636 .22778 .63507 .21748 .64929 .24352 .65072 .25241 Metetra
.854 .414 0 r
.62201 .20123 .62085 .18927 .63507 .21748 .63636 .22778 Metetra
.883 .46 .06 r
.60766 .17293 .60664 .15901 .62085 .18927 .62201 .20123 Metetra
.907 .501 .128 r
.5933 .1432 .59242 .12697 .60664 .15901 .60766 .17293 Metetra
.925 .535 .197 r
.57895 .11258 .5782 .09361 .59242 .12697 .5933 .1432 Metetra
.933 .56 .265 r
.56459 .08193 .56398 .05978 .5782 .09361 .57895 .11258 Metetra
.879 .458 .041 r
.55024 .0526 .54976 .04028 .56398 .05978 .56459 .08193 Metetra
0 .193 .671 r
.53589 .03828 .53555 .04028 .54976 .04028 .55024 .0526 Metetra
.435 0 0 r
.07246 .3925 .07656 .3911 .09091 .39771 .08696 .3991 Metetra
.359 0 0 r
.08696 .3991 .09091 .39771 .10526 .40271 .10145 .40407 Metetra
.279 0 0 r
.10145 .40407 .10526 .40271 .11962 .40614 .11594 .4075 Metetra
.199 0 0 r
.11594 .4075 .11962 .40614 .13397 .40806 .13043 .40943 Metetra
.121 0 0 r
.13043 .40943 .13397 .40806 .14833 .4085 .14493 .40992 Metetra
.047 0 0 r
.14493 .40992 .14833 .4085 .16268 .40749 .15942 .409 Metetra
.15942 .409 .16268 .40749 .17703 .40504 .17391 .40668 Metetra
.17391 .40668 .17703 .40504 .19139 .40116 .18841 .40299 Metetra
.18841 .40299 .19139 .40116 .20574 .39582 .2029 .39791 Metetra
.2029 .39791 .20574 .39582 .2201 .38902 .21739 .39142 Metetra
.21739 .39142 .2201 .38902 .23445 .3807 .23188 .38349 Metetra
.23188 .38349 .23445 .3807 .2488 .37082 .24638 .37407 Metetra
.24638 .37407 .2488 .37082 .26316 .35932 .26087 .36312 Metetra
.26087 .36312 .26316 .35932 .27751 .34613 .27536 .35056 Metetra
.27536 .35056 .27751 .34613 .29187 .33118 .28986 .33634 Metetra
.28986 .33634 .29187 .33118 .30622 .3144 .30435 .3204 Metetra
.30435 .3204 .30622 .3144 .32057 .29571 .31884 .30266 Metetra
.31884 .30266 .32057 .29571 .33493 .27506 .33333 .28311 Metetra
.33333 .28311 .33493 .27506 .34928 .25241 .34783 .26173 Metetra
.34783 .26173 .34928 .25241 .36364 .22778 .36232 .23855 Metetra
.36232 .23855 .36364 .22778 .37799 .20123 .37681 .21368 Metetra
0 0 .003 r
.37681 .21368 .37799 .20123 .39234 .17293 .3913 .18733 Metetra
0 0 .07 r
.3913 .18733 .39234 .17293 .4067 .1432 .4058 .15986 Metetra
0 0 .138 r
.4058 .15986 .4067 .1432 .42105 .11258 .42029 .13183 Metetra
.059 0 .207 r
.42029 .13183 .42105 .11258 .43541 .08193 .43478 .10413 Metetra
.162 0 .277 r
.43478 .10413 .43541 .08193 .44976 .0526 .44928 .07803 Metetra
.283 .031 .345 r
.44928 .07803 .44976 .0526 .46411 .03828 .46377 .05531 Metetra
.225 0 .207 r
.46377 .05531 .46411 .03828 .47847 .03828 .47826 .03815 Metetra
.085 .643 .713 r
.47826 .03815 .47847 .03828 .49282 .03828 .49275 .03623 Metetra
.91304 .3991 .90909 .39771 .92344 .3911 .92754 .3925 Metetra
.89855 .40407 .89474 .40271 .90909 .39771 .91304 .3991 Metetra
.02 0 0 r
.88406 .4075 .88038 .40614 .89474 .40271 .89855 .40407 Metetra
.051 0 0 r
.86957 .40943 .86603 .40806 .88038 .40614 .88406 .4075 Metetra
.086 0 0 r
.85507 .40992 .85167 .4085 .86603 .40806 .86957 .40943 Metetra
.125 0 0 r
.84058 .409 .83732 .40749 .85167 .4085 .85507 .40992 Metetra
.167 0 0 r
.82609 .40668 .82297 .40504 .83732 .40749 .84058 .409 Metetra
.213 0 0 r
.81159 .40299 .80861 .40116 .82297 .40504 .82609 .40668 Metetra
.262 0 0 r
.7971 .39791 .79426 .39582 .80861 .40116 .81159 .40299 Metetra
.314 0 0 r
.78261 .39142 .7799 .38902 .79426 .39582 .7971 .39791 Metetra
.368 0 0 r
.76812 .38349 .76555 .3807 .7799 .38902 .78261 .39142 Metetra
.424 0 0 r
.75362 .37407 .7512 .37082 .76555 .3807 .76812 .38349 Metetra
.481 0 0 r
.73913 .36312 .73684 .35932 .7512 .37082 .75362 .37407 Metetra
.537 0 0 r
.72464 .35056 .72249 .34613 .73684 .35932 .73913 .36312 Metetra
.592 .043 0 r
.71014 .33634 .70813 .33118 .72249 .34613 .72464 .35056 Metetra
.645 .11 0 r
.69565 .3204 .69378 .3144 .70813 .33118 .71014 .33634 Metetra
.695 .176 0 r
.68116 .30266 .67943 .29571 .69378 .3144 .69565 .3204 Metetra
.741 .24 0 r
.66667 .28311 .66507 .27506 .67943 .29571 .68116 .30266 Metetra
.783 .3 0 r
.65217 .26173 .65072 .25241 .66507 .27506 .66667 .28311 Metetra
.821 .355 0 r
.63768 .23855 .63636 .22778 .65072 .25241 .65217 .26173 Metetra
.854 .406 .007 r
.62319 .21368 .62201 .20123 .63636 .22778 .63768 .23855 Metetra
.882 .451 .073 r
.6087 .18733 .60766 .17293 .62201 .20123 .62319 .21368 Metetra
.903 .49 .14 r
.5942 .15986 .5933 .1432 .60766 .17293 .6087 .18733 Metetra
.917 .521 .206 r
.57971 .13183 .57895 .11258 .5933 .1432 .5942 .15986 Metetra
.922 .543 .271 r
.56522 .10413 .56459 .08193 .57895 .11258 .57971 .13183 Metetra
.914 .552 .333 r
.55072 .07803 .55024 .0526 .56459 .08193 .56522 .10413 Metetra
.891 .474 .19 r
.53623 .05531 .53589 .03828 .55024 .0526 .55072 .07803 Metetra
0 .037 .532 r
.52174 .03815 .52153 .03828 .53589 .03828 .53623 .05531 Metetra
.065 .616 .828 r
.50725 .03623 .50718 .03828 .52153 .03828 .52174 .03815 Metetra
.431 0 0 r
.06829 .39394 .07246 .3925 .08696 .3991 .08293 .4005 Metetra
.354 0 0 r
.08293 .4005 .08696 .3991 .10145 .40407 .09756 .40543 Metetra
.274 0 0 r
.09756 .40543 .10145 .40407 .11594 .4075 .1122 .40883 Metetra
.195 0 0 r
.1122 .40883 .11594 .4075 .13043 .40943 .12683 .41077 Metetra
.118 0 0 r
.12683 .41077 .13043 .40943 .14493 .40992 .14146 .41129 Metetra
.047 0 0 r
.14146 .41129 .14493 .40992 .15942 .409 .1561 .41045 Metetra
.1561 .41045 .15942 .409 .17391 .40668 .17073 .40828 Metetra
.17073 .40828 .17391 .40668 .18841 .40299 .18537 .40478 Metetra
.18537 .40478 .18841 .40299 .2029 .39791 .2 .39997 Metetra
.2 .39997 .2029 .39791 .21739 .39142 .21463 .39382 Metetra
.21463 .39382 .21739 .39142 .23188 .38349 .22927 .3863 Metetra
.22927 .3863 .23188 .38349 .24638 .37407 .2439 .37738 Metetra
.2439 .37738 .24638 .37407 .26087 .36312 .25854 .36701 Metetra
.25854 .36701 .26087 .36312 .27536 .35056 .27317 .35513 Metetra
.27317 .35513 .27536 .35056 .28986 .33634 .2878 .34169 Metetra
.2878 .34169 .28986 .33634 .30435 .3204 .30244 .32663 Metetra
.30244 .32663 .30435 .3204 .31884 .30266 .31707 .30991 Metetra
.31707 .30991 .31884 .30266 .33333 .28311 .33171 .2915 Metetra
.33171 .2915 .33333 .28311 .34783 .26173 .34634 .27142 Metetra
.34634 .27142 .34783 .26173 .36232 .23855 .36098 .24973 Metetra
.36098 .24973 .36232 .23855 .37681 .21368 .37561 .22655 Metetra
0 0 .015 r
.37561 .22655 .37681 .21368 .3913 .18733 .39024 .20213 Metetra
0 0 .082 r
.39024 .20213 .3913 .18733 .4058 .15986 .40488 .17685 Metetra
.024 0 .148 r
.40488 .17685 .4058 .15986 .42029 .13183 .41951 .15129 Metetra
.109 0 .215 r
.41951 .15129 .42029 .13183 .43478 .10413 .43415 .1263 Metetra
.207 0 .281 r
.43415 .1263 .43478 .10413 .44928 .07803 .44878 .10308 Metetra
.319 .052 .342 r
.44878 .10308 .44928 .07803 .46377 .05531 .46341 .08316 Metetra
.44 .163 .394 r
.46341 .08316 .46377 .05531 .47826 .03815 .47805 .06835 Metetra
.562 .271 .432 r
.47805 .06835 .47826 .03815 .49275 .03623 .49268 .0604 Metetra
.649 .301 .369 r
.49268 .0604 .49275 .03623 .50725 .03623 .50732 .0604 Metetra
.91707 .4005 .91304 .3991 .92754 .3925 .93171 .39394 Metetra
.90244 .40543 .89855 .40407 .91304 .3991 .91707 .4005 Metetra
.017 0 0 r
.8878 .40883 .88406 .4075 .89855 .40407 .90244 .40543 Metetra
.047 0 0 r
.87317 .41077 .86957 .40943 .88406 .4075 .8878 .40883 Metetra
.08 0 0 r
.85854 .41129 .85507 .40992 .86957 .40943 .87317 .41077 Metetra
.117 0 0 r
.8439 .41045 .84058 .409 .85507 .40992 .85854 .41129 Metetra
.158 0 0 r
.82927 .40828 .82609 .40668 .84058 .409 .8439 .41045 Metetra
.203 0 0 r
.81463 .40478 .81159 .40299 .82609 .40668 .82927 .40828 Metetra
.251 0 0 r
.8 .39997 .7971 .39791 .81159 .40299 .81463 .40478 Metetra
.303 0 0 r
.78537 .39382 .78261 .39142 .7971 .39791 .8 .39997 Metetra
.358 0 0 r
.77073 .3863 .76812 .38349 .78261 .39142 .78537 .39382 Metetra
.415 0 0 r
.7561 .37738 .75362 .37407 .76812 .38349 .77073 .3863 Metetra
.473 0 0 r
.74146 .36701 .73913 .36312 .75362 .37407 .7561 .37738 Metetra
.531 0 0 r
.72683 .35513 .72464 .35056 .73913 .36312 .74146 .36701 Metetra
.587 .03 0 r
.7122 .34169 .71014 .33634 .72464 .35056 .72683 .35513 Metetra
.642 .099 0 r
.69756 .32663 .69565 .3204 .71014 .33634 .7122 .34169 Metetra
.693 .166 0 r
.68293 .30991 .68116 .30266 .69565 .3204 .69756 .32663 Metetra
.74 .23 0 r
.66829 .2915 .66667 .28311 .68116 .30266 .68293 .30991 Metetra
.782 .29 0 r
.65366 .27142 .65217 .26173 .66667 .28311 .66829 .2915 Metetra
.819 .345 0 r
.63902 .24973 .63768 .23855 .65217 .26173 .65366 .27142 Metetra
.851 .395 .019 r
.62439 .22655 .62319 .21368 .63768 .23855 .63902 .24973 Metetra
.877 .439 .085 r
.60976 .20213 .6087 .18733 .62319 .21368 .62439 .22655 Metetra
.896 .476 .149 r
.59512 .17685 .5942 .15986 .6087 .18733 .60976 .20213 Metetra
.907 .504 .213 r
.58049 .15129 .57971 .13183 .5942 .15986 .59512 .17685 Metetra
.908 .523 .274 r
.56585 .1263 .56522 .10413 .57971 .13183 .58049 .15129 Metetra
.898 .529 .331 r
.55122 .10308 .55072 .07803 .56522 .10413 .56585 .1263 Metetra
.872 .52 .381 r
.53659 .08316 .53623 .05531 .55072 .07803 .55122 .10308 Metetra
.827 .492 .421 r
.52195 .06835 .52174 .03815 .53623 .05531 .53659 .08316 Metetra
.76 .395 .363 r
.50732 .0604 .50725 .03623 .52174 .03815 .52195 .06835 Metetra
.426 0 0 r
.06404 .39543 .06829 .39394 .08293 .4005 .07882 .40191 Metetra
.347 0 0 r
.07882 .40191 .08293 .4005 .09756 .40543 .0936 .40678 Metetra
.267 0 0 r
.0936 .40678 .09756 .40543 .1122 .40883 .10837 .41013 Metetra
.189 0 0 r
.10837 .41013 .1122 .40883 .12683 .41077 .12315 .41204 Metetra
.114 0 0 r
.12315 .41204 .12683 .41077 .14146 .41129 .13793 .41259 Metetra
.045 0 0 r
.13793 .41259 .14146 .41129 .1561 .41045 .15271 .41183 Metetra
.15271 .41183 .1561 .41045 .17073 .40828 .16749 .4098 Metetra
.16749 .4098 .17073 .40828 .18537 .40478 .18227 .40651 Metetra
.18227 .40651 .18537 .40478 .2 .39997 .19704 .40198 Metetra
.19704 .40198 .2 .39997 .21463 .39382 .21182 .39619 Metetra
.21182 .39619 .21463 .39382 .22927 .3863 .2266 .38912 Metetra
.2266 .38912 .22927 .3863 .2439 .37738 .24138 .38073 Metetra
.24138 .38073 .2439 .37738 .25854 .36701 .25616 .37098 Metetra
.25616 .37098 .25854 .36701 .27317 .35513 .27094 .35982 Metetra
.27094 .35982 .27317 .35513 .2878 .34169 .28571 .3472 Metetra
.28571 .3472 .2878 .34169 .30244 .32663 .30049 .33307 Metetra
.30049 .33307 .30244 .32663 .31707 .30991 .31527 .3174 Metetra
.31527 .3174 .31707 .30991 .33171 .2915 .33005 .30018 Metetra
.33005 .30018 .33171 .2915 .34634 .27142 .34483 .28144 Metetra
.34483 .28144 .34634 .27142 .36098 .24973 .35961 .26125 Metetra
.35961 .26125 .36098 .24973 .37561 .22655 .37438 .23977 Metetra
0 0 .025 r
.37438 .23977 .37561 .22655 .39024 .20213 .38916 .21725 Metetra
.003 0 .091 r
.38916 .21725 .39024 .20213 .40488 .17685 .40394 .19408 Metetra
.073 0 .156 r
.40394 .19408 .40488 .17685 .41951 .15129 .41872 .17085 Metetra
.154 0 .22 r
.41872 .17085 .41951 .15129 .43415 .1263 .4335 .14837 Metetra
.247 0 .281 r
.4335 .14837 .43415 .1263 .44878 .10308 .44828 .12771 Metetra
.351 .068 .337 r
.44828 .12771 .44878 .10308 .46341 .08316 .46305 .11021 Metetra
.46 .169 .383 r
.46305 .11021 .46341 .08316 .47805 .06835 .47783 .09737 Metetra
.569 .267 .416 r
.47783 .09737 .47805 .06835 .49268 .0604 .49261 .09053 Metetra
.667 .352 .431 r
.49261 .09053 .49268 .0604 .50732 .0604 .50739 .09053 Metetra
.92118 .40191 .91707 .4005 .93171 .39394 .93596 .39543 Metetra
.9064 .40678 .90244 .40543 .91707 .4005 .92118 .40191 Metetra
.015 0 0 r
.89163 .41013 .8878 .40883 .90244 .40543 .9064 .40678 Metetra
.042 0 0 r
.87685 .41204 .87317 .41077 .8878 .40883 .89163 .41013 Metetra
.074 0 0 r
.86207 .41259 .85854 .41129 .87317 .41077 .87685 .41204 Metetra
.109 0 0 r
.84729 .41183 .8439 .41045 .85854 .41129 .86207 .41259 Metetra
.148 0 0 r
.83251 .4098 .82927 .40828 .8439 .41045 .84729 .41183 Metetra
.191 0 0 r
.81773 .40651 .81463 .40478 .82927 .40828 .83251 .4098 Metetra
.239 0 0 r
.80296 .40198 .8 .39997 .81463 .40478 .81773 .40651 Metetra
.29 0 0 r
.78818 .39619 .78537 .39382 .8 .39997 .80296 .40198 Metetra
.345 0 0 r
.7734 .38912 .77073 .3863 .78537 .39382 .78818 .39619 Metetra
.403 0 0 r
.75862 .38073 .7561 .37738 .77073 .3863 .7734 .38912 Metetra
.462 0 0 r
.74384 .37098 .74146 .36701 .7561 .37738 .75862 .38073 Metetra
.521 0 0 r
.72906 .35982 .72683 .35513 .74146 .36701 .74384 .37098 Metetra
.579 .015 0 r
.71429 .3472 .7122 .34169 .72683 .35513 .72906 .35982 Metetra
.635 .085 0 r
.69951 .33307 .69756 .32663 .7122 .34169 .71429 .3472 Metetra
.687 .152 0 r
.68473 .3174 .68293 .30991 .69756 .32663 .69951 .33307 Metetra
.735 .217 0 r
.66995 .30018 .66829 .2915 .68293 .30991 .68473 .3174 Metetra
.777 .277 0 r
.65517 .28144 .65366 .27142 .66829 .2915 .66995 .30018 Metetra
.814 .333 0 r
.64039 .26125 .63902 .24973 .65366 .27142 .65517 .28144 Metetra
.845 .382 .028 r
.62562 .23977 .62439 .22655 .63902 .24973 .64039 .26125 Metetra
.869 .424 .093 r
.61084 .21725 .60976 .20213 .62439 .22655 .62562 .23977 Metetra
.886 .459 .156 r
.59606 .19408 .59512 .17685 .60976 .20213 .61084 .21725 Metetra
.895 .485 .217 r
.58128 .17085 .58049 .15129 .59512 .17685 .59606 .19408 Metetra
.894 .502 .274 r
.5665 .14837 .56585 .1263 .58049 .15129 .58128 .17085 Metetra
.881 .506 .327 r
.55172 .12771 .55122 .10308 .56585 .1263 .5665 .14837 Metetra
.854 .495 .372 r
.53695 .11021 .53659 .08316 .55122 .10308 .55172 .12771 Metetra
.81 .467 .407 r
.52217 .09737 .52195 .06835 .53659 .08316 .53695 .11021 Metetra
.748 .42 .428 r
.50739 .09053 .50732 .0604 .52195 .06835 .52217 .09737 Metetra
.419 0 0 r
.0597 .39696 .06404 .39543 .07882 .40191 .07463 .40333 Metetra
.339 0 0 r
.07463 .40333 .07882 .40191 .0936 .40678 .08955 .4081 Metetra
.259 0 0 r
.08955 .4081 .0936 .40678 .10837 .41013 .10448 .41137 Metetra
.181 0 0 r
.10448 .41137 .10837 .41013 .12315 .41204 .1194 .41325 Metetra
.108 0 0 r
.1194 .41325 .12315 .41204 .13793 .41259 .13433 .41381 Metetra
.042 0 0 r
.13433 .41381 .13793 .41259 .15271 .41183 .14925 .41312 Metetra
.14925 .41312 .15271 .41183 .16749 .4098 .16418 .41123 Metetra
.16418 .41123 .16749 .4098 .18227 .40651 .1791 .40816 Metetra
.1791 .40816 .18227 .40651 .19704 .40198 .19403 .40392 Metetra
.19403 .40392 .19704 .40198 .21182 .39619 .20896 .39851 Metetra
.20896 .39851 .21182 .39619 .2266 .38912 .22388 .39191 Metetra
.22388 .39191 .2266 .38912 .24138 .38073 .23881 .38408 Metetra
.23881 .38408 .24138 .38073 .25616 .37098 .25373 .37499 Metetra
.25373 .37499 .25616 .37098 .27094 .35982 .26866 .36459 Metetra
.26866 .36459 .27094 .35982 .28571 .3472 .28358 .35283 Metetra
.28358 .35283 .28571 .3472 .30049 .33307 .29851 .33967 Metetra
.29851 .33967 .30049 .33307 .31527 .3174 .31343 .3251 Metetra
.31343 .3251 .31527 .3174 .33005 .30018 .32836 .30911 Metetra
.32836 .30911 .33005 .30018 .34483 .28144 .34328 .29173 Metetra
.34328 .29173 .34483 .28144 .35961 .26125 .35821 .27307 Metetra
.35821 .27307 .35961 .26125 .37438 .23977 .37313 .25327 Metetra
0 0 .033 r
.37313 .25327 .37438 .23977 .38916 .21725 .38806 .23262 Metetra
.051 0 .098 r
.38806 .23262 .38916 .21725 .40394 .19408 .40299 .21149 Metetra
.119 0 .161 r
.40299 .21149 .40394 .19408 .41872 .17085 .41791 .19046 Metetra
.196 0 .222 r
.41791 .19046 .41872 .17085 .4335 .14837 .43284 .17028 Metetra
.283 0 .279 r
.43284 .17028 .4335 .14837 .44828 .12771 .44776 .15192 Metetra
.378 .082 .33 r
.44776 .15192 .44828 .12771 .46305 .11021 .46269 .13654 Metetra
.477 .173 .371 r
.46269 .13654 .46305 .11021 .47783 .09737 .47761 .12535 Metetra
.574 .261 .4 r
.47761 .12535 .47783 .09737 .49261 .09053 .49254 .11943 Metetra
.662 .338 .414 r
.49254 .11943 .49261 .09053 .50739 .09053 .50746 .11943 Metetra
.92537 .40333 .92118 .40191 .93596 .39543 .9403 .39696 Metetra
.91045 .4081 .9064 .40678 .92118 .40191 .92537 .40333 Metetra
.012 0 0 r
.89552 .41137 .89163 .41013 .9064 .40678 .91045 .4081 Metetra
.038 0 0 r
.8806 .41325 .87685 .41204 .89163 .41013 .89552 .41137 Metetra
.066 0 0 r
.86567 .41381 .86207 .41259 .87685 .41204 .8806 .41325 Metetra
.099 0 0 r
.85075 .41312 .84729 .41183 .86207 .41259 .86567 .41381 Metetra
.136 0 0 r
.83582 .41123 .83251 .4098 .84729 .41183 .85075 .41312 Metetra
.178 0 0 r
.8209 .40816 .81773 .40651 .83251 .4098 .83582 .41123 Metetra
.225 0 0 r
.80597 .40392 .80296 .40198 .81773 .40651 .8209 .40816 Metetra
.275 0 0 r
.79104 .39851 .78818 .39619 .80296 .40198 .80597 .40392 Metetra
.33 0 0 r
.77612 .39191 .7734 .38912 .78818 .39619 .79104 .39851 Metetra
.388 0 0 r
.76119 .38408 .75862 .38073 .7734 .38912 .77612 .39191 Metetra
.448 0 0 r
.74627 .37499 .74384 .37098 .75862 .38073 .76119 .38408 Metetra
.509 0 0 r
.73134 .36459 .72906 .35982 .74384 .37098 .74627 .37499 Metetra
.569 0 0 r
.71642 .35283 .71429 .3472 .72906 .35982 .73134 .36459 Metetra
.626 .068 0 r
.70149 .33967 .69951 .33307 .71429 .3472 .71642 .35283 Metetra
.679 .136 0 r
.68657 .3251 .68473 .3174 .69951 .33307 .70149 .33967 Metetra
.727 .201 0 r
.67164 .30911 .66995 .30018 .68473 .3174 .68657 .3251 Metetra
.77 .262 0 r
.65672 .29173 .65517 .28144 .66995 .30018 .67164 .30911 Metetra
.806 .317 0 r
.64179 .27307 .64039 .26125 .65517 .28144 .65672 .29173 Metetra
.836 .365 .036 r
.62687 .25327 .62562 .23977 .64039 .26125 .64179 .27307 Metetra
.858 .407 .1 r
.61194 .23262 .61084 .21725 .62562 .23977 .62687 .25327 Metetra
.873 .44 .161 r
.59701 .21149 .59606 .19408 .61084 .21725 .61194 .23262 Metetra
.88 .465 .219 r
.58209 .19046 .58128 .17085 .59606 .19408 .59701 .21149 Metetra
.877 .479 .273 r
.56716 .17028 .5665 .14837 .58128 .17085 .58209 .19046 Metetra
.863 .482 .321 r
.55224 .15192 .55172 .12771 .5665 .14837 .56716 .17028 Metetra
.836 .47 .362 r
.53731 .13654 .53695 .11021 .55172 .12771 .55224 .15192 Metetra
.794 .444 .393 r
.52239 .12535 .52217 .09737 .53695 .11021 .53731 .13654 Metetra
.736 .399 .411 r
.50746 .11943 .50739 .09053 .52217 .09737 .52239 .12535 Metetra
.411 0 0 r
.05528 .39852 .0597 .39696 .07463 .40333 .07035 .40475 Metetra
.329 0 0 r
.07035 .40475 .07463 .40333 .08955 .4081 .08543 .40938 Metetra
.248 0 0 r
.08543 .40938 .08955 .4081 .10448 .41137 .1005 .41255 Metetra
.171 0 0 r
.1005 .41255 .10448 .41137 .1194 .41325 .11558 .41436 Metetra
.101 0 0 r
.11558 .41436 .1194 .41325 .13433 .41381 .13065 .41492 Metetra
.038 0 0 r
.13065 .41492 .13433 .41381 .14925 .41312 .14573 .4143 Metetra
.14573 .4143 .14925 .41312 .16418 .41123 .1608 .41254 Metetra
.1608 .41254 .16418 .41123 .1791 .40816 .17588 .40969 Metetra
.17588 .40969 .1791 .40816 .19403 .40392 .19095 .40576 Metetra
.19095 .40576 .19403 .40392 .20896 .39851 .20603 .40075 Metetra
.20603 .40075 .20896 .39851 .22388 .39191 .22111 .39464 Metetra
.22111 .39464 .22388 .39191 .23881 .38408 .23618 .38741 Metetra
.23618 .38741 .23881 .38408 .25373 .37499 .25126 .37901 Metetra
.25126 .37901 .25373 .37499 .26866 .36459 .26633 .3694 Metetra
.26633 .3694 .26866 .36459 .28358 .35283 .28141 .35855 Metetra
.28141 .35855 .28358 .35283 .29851 .33967 .29648 .34641 Metetra
.29648 .34641 .29851 .33967 .31343 .3251 .31156 .33297 Metetra
.31156 .33297 .31343 .3251 .32836 .30911 .32663 .31824 Metetra
.32663 .31824 .32836 .30911 .34328 .29173 .34171 .30226 Metetra
.34171 .30226 .34328 .29173 .35821 .27307 .35678 .28512 Metetra
.35678 .28512 .35821 .27307 .37313 .25327 .37186 .26701 Metetra
.039 0 .039 r
.37186 .26701 .37313 .25327 .38806 .23262 .38693 .24818 Metetra
.096 0 .103 r
.38693 .24818 .38806 .23262 .40299 .21149 .40201 .22903 Metetra
.162 0 .164 r
.40201 .22903 .40299 .21149 .41791 .19046 .41709 .21007 Metetra
.235 0 .222 r
.41709 .21007 .41791 .19046 .43284 .17028 .43216 .19202 Metetra
.316 .009 .275 r
.43216 .19202 .43284 .17028 .44776 .15192 .44724 .17574 Metetra
.403 .093 .321 r
.44724 .17574 .44776 .15192 .46269 .13654 .46231 .1622 Metetra
.492 .176 .359 r
.46231 .1622 .46269 .13654 .47761 .12535 .47739 .15244 Metetra
.578 .255 .384 r
.47739 .15244 .47761 .12535 .49254 .11943 .49246 .14731 Metetra
.657 .324 .396 r
.49246 .14731 .49254 .11943 .50746 .11943 .50754 .14731 Metetra
.92965 .40475 .92537 .40333 .9403 .39696 .94472 .39852 Metetra
.91457 .40938 .91045 .4081 .92537 .40333 .92965 .40475 Metetra
.009 0 0 r
.8995 .41255 .89552 .41137 .91045 .4081 .91457 .40938 Metetra
.032 0 0 r
.88442 .41436 .8806 .41325 .89552 .41137 .8995 .41255 Metetra
.058 0 0 r
.86935 .41492 .86567 .41381 .8806 .41325 .88442 .41436 Metetra
.089 0 0 r
.85427 .4143 .85075 .41312 .86567 .41381 .86935 .41492 Metetra
.124 0 0 r
.8392 .41254 .83582 .41123 .85075 .41312 .85427 .4143 Metetra
.164 0 0 r
.82412 .40969 .8209 .40816 .83582 .41123 .8392 .41254 Metetra
.209 0 0 r
.80905 .40576 .80597 .40392 .8209 .40816 .82412 .40969 Metetra
.258 0 0 r
.79397 .40075 .79104 .39851 .80597 .40392 .80905 .40576 Metetra
.313 0 0 r
.77889 .39464 .77612 .39191 .79104 .39851 .79397 .40075 Metetra
.371 0 0 r
.76382 .38741 .76119 .38408 .77612 .39191 .77889 .39464 Metetra
.432 0 0 r
.74874 .37901 .74627 .37499 .76119 .38408 .76382 .38741 Metetra
.494 0 0 r
.73367 .3694 .73134 .36459 .74627 .37499 .74874 .37901 Metetra
.554 0 0 r
.71859 .35855 .71642 .35283 .73134 .36459 .73367 .3694 Metetra
.613 .048 0 r
.70352 .34641 .70149 .33967 .71642 .35283 .71859 .35855 Metetra
.667 .117 0 r
.68844 .33297 .68657 .3251 .70149 .33967 .70352 .34641 Metetra
.716 .183 0 r
.67337 .31824 .67164 .30911 .68657 .3251 .68844 .33297 Metetra
.759 .244 0 r
.65829 .30226 .65672 .29173 .67164 .30911 .67337 .31824 Metetra
.795 .299 0 r
.64322 .28512 .64179 .27307 .65672 .29173 .65829 .30226 Metetra
.824 .347 .041 r
.62814 .26701 .62687 .25327 .64179 .27307 .64322 .28512 Metetra
.845 .387 .104 r
.61307 .24818 .61194 .23262 .62687 .25327 .62814 .26701 Metetra
.859 .419 .163 r
.59799 .22903 .59701 .21149 .61194 .23262 .61307 .24818 Metetra
.864 .443 .218 r
.58291 .21007 .58209 .19046 .59701 .21149 .59799 .22903 Metetra
.86 .456 .269 r
.56784 .19202 .56716 .17028 .58209 .19046 .58291 .21007 Metetra
.845 .457 .314 r
.55276 .17574 .55224 .15192 .56716 .17028 .56784 .19202 Metetra
.818 .446 .351 r
.53769 .1622 .53731 .13654 .55224 .15192 .55276 .17574 Metetra
.778 .42 .378 r
.52261 .15244 .52239 .12535 .53731 .13654 .53769 .1622 Metetra
.725 .38 .394 r
.50754 .14731 .50746 .11943 .52239 .12535 .52261 .15244 Metetra
.4 0 0 r
.05076 .40013 .05528 .39852 .07035 .40475 .06599 .40616 Metetra
.317 0 0 r
.06599 .40616 .07035 .40475 .08543 .40938 .08122 .41061 Metetra
.235 0 0 r
.08122 .41061 .08543 .40938 .1005 .41255 .09645 .41364 Metetra
.16 0 0 r
.09645 .41364 .1005 .41255 .11558 .41436 .11168 .41537 Metetra
.091 0 0 r
.11168 .41537 .11558 .41436 .13065 .41492 .1269 .41591 Metetra
.031 0 0 r
.1269 .41591 .13065 .41492 .14573 .4143 .14213 .41533 Metetra
.14213 .41533 .14573 .4143 .1608 .41254 .15736 .41371 Metetra
.15736 .41371 .1608 .41254 .17588 .40969 .17259 .41109 Metetra
.17259 .41109 .17588 .40969 .19095 .40576 .18782 .40747 Metetra
.18782 .40747 .19095 .40576 .20603 .40075 .20305 .40288 Metetra
.20305 .40288 .20603 .40075 .22111 .39464 .21827 .39729 Metetra
.21827 .39729 .22111 .39464 .23618 .38741 .2335 .39068 Metetra
.2335 .39068 .23618 .38741 .25126 .37901 .24873 .38301 Metetra
.24873 .38301 .25126 .37901 .26633 .3694 .26396 .37424 Metetra
.26396 .37424 .26633 .3694 .28141 .35855 .27919 .36432 Metetra
.27919 .36432 .28141 .35855 .29648 .34641 .29442 .35324 Metetra
.29442 .35324 .29648 .34641 .31156 .33297 .30964 .34098 Metetra
.30964 .34098 .31156 .33297 .32663 .31824 .32487 .32754 Metetra
.32487 .32754 .32663 .31824 .34171 .30226 .3401 .31297 Metetra
.3401 .31297 .34171 .30226 .35678 .28512 .35533 .29738 Metetra
.036 0 0 r
.35533 .29738 .35678 .28512 .37186 .26701 .37056 .28093 Metetra
.085 0 .043 r
.37056 .28093 .37186 .26701 .38693 .24818 .38579 .2639 Metetra
.141 0 .105 r
.38579 .2639 .38693 .24818 .40201 .22903 .40102 .24664 Metetra
.203 0 .165 r
.40102 .24664 .40201 .22903 .41709 .21007 .41624 .22965 Metetra
.272 0 .22 r
.41624 .22965 .41709 .21007 .43216 .19202 .43147 .21357 Metetra
.346 .024 .269 r
.43147 .21357 .43216 .19202 .44724 .17574 .4467 .19916 Metetra
.425 .102 .312 r
.4467 .19916 .44724 .17574 .46231 .1622 .46193 .18728 Metetra
.504 .177 .346 r
.46193 .18728 .46231 .1622 .47739 .15244 .47716 .17876 Metetra
.582 .248 .369 r
.47716 .17876 .47739 .15244 .49246 .14731 .49239 .1743 Metetra
.652 .31 .38 r
.49239 .1743 .49246 .14731 .50754 .14731 .50761 .1743 Metetra
.93401 .40616 .92965 .40475 .94472 .39852 .94924 .40013 Metetra
.91878 .41061 .91457 .40938 .92965 .40475 .93401 .40616 Metetra
.006 0 0 r
.90355 .41364 .8995 .41255 .91457 .40938 .91878 .41061 Metetra
.026 0 0 r
.88832 .41537 .88442 .41436 .8995 .41255 .90355 .41364 Metetra
.05 0 0 r
.8731 .41591 .86935 .41492 .88442 .41436 .88832 .41537 Metetra
.077 0 0 r
.85787 .41533 .85427 .4143 .86935 .41492 .8731 .41591 Metetra
.11 0 0 r
.84264 .41371 .8392 .41254 .85427 .4143 .85787 .41533 Metetra
.148 0 0 r
.82741 .41109 .82412 .40969 .8392 .41254 .84264 .41371 Metetra
.191 0 0 r
.81218 .40747 .80905 .40576 .82412 .40969 .82741 .41109 Metetra
.239 0 0 r
.79695 .40288 .79397 .40075 .80905 .40576 .81218 .40747 Metetra
.293 0 0 r
.78173 .39729 .77889 .39464 .79397 .40075 .79695 .40288 Metetra
.351 0 0 r
.7665 .39068 .76382 .38741 .77889 .39464 .78173 .39729 Metetra
.412 0 0 r
.75127 .38301 .74874 .37901 .76382 .38741 .7665 .39068 Metetra
.475 0 0 r
.73604 .37424 .73367 .3694 .74874 .37901 .75127 .38301 Metetra
.537 0 0 r
.72081 .36432 .71859 .35855 .73367 .3694 .73604 .37424 Metetra
.597 .025 0 r
.70558 .35324 .70352 .34641 .71859 .35855 .72081 .36432 Metetra
.652 .095 0 r
.69036 .34098 .68844 .33297 .70352 .34641 .70558 .35324 Metetra
.701 .161 0 r
.67513 .32754 .67337 .31824 .68844 .33297 .69036 .34098 Metetra
.745 .223 0 r
.6599 .31297 .65829 .30226 .67337 .31824 .67513 .32754 Metetra
.78 .278 0 r
.64467 .29738 .64322 .28512 .65829 .30226 .6599 .31297 Metetra
.809 .326 .045 r
.62944 .28093 .62814 .26701 .64322 .28512 .64467 .29738 Metetra
.829 .365 .106 r
.61421 .2639 .61307 .24818 .62814 .26701 .62944 .28093 Metetra
.842 .397 .164 r
.59898 .24664 .59799 .22903 .61307 .24818 .61421 .2639 Metetra
.846 .419 .216 r
.58376 .22965 .58291 .21007 .59799 .22903 .59898 .24664 Metetra
.841 .431 .264 r
.56853 .21357 .56784 .19202 .58291 .21007 .58376 .22965 Metetra
.826 .432 .305 r
.5533 .19916 .55276 .17574 .56784 .19202 .56853 .21357 Metetra
.8 .422 .339 r
.53807 .18728 .53769 .1622 .55276 .17574 .5533 .19916 Metetra
.763 .398 .364 r
.52284 .17876 .52261 .15244 .53769 .1622 .53807 .18728 Metetra
.713 .36 .378 r
.50761 .1743 .50754 .14731 .52261 .15244 .52284 .17876 Metetra
.387 0 0 r
.04615 .40177 .05076 .40013 .06599 .40616 .06154 .40755 Metetra
.302 0 0 r
.06154 .40755 .06599 .40616 .08122 .41061 .07692 .41179 Metetra
.22 0 0 r
.07692 .41179 .08122 .41061 .09645 .41364 .09231 .41464 Metetra
.145 0 0 r
.09231 .41464 .09645 .41364 .11168 .41537 .10769 .41625 Metetra
.079 0 0 r
.10769 .41625 .11168 .41537 .1269 .41591 .12308 .41674 Metetra
.023 0 0 r
.12308 .41674 .1269 .41591 .14213 .41533 .13846 .4162 Metetra
.13846 .4162 .14213 .41533 .15736 .41371 .15385 .41471 Metetra
.15385 .41471 .15736 .41371 .17259 .41109 .16923 .41231 Metetra
.16923 .41231 .17259 .41109 .18782 .40747 .18462 .40903 Metetra
.18462 .40903 .18782 .40747 .20305 .40288 .2 .40487 Metetra
.2 .40487 .20305 .40288 .21827 .39729 .21538 .39982 Metetra
.21538 .39982 .21827 .39729 .2335 .39068 .23077 .39386 Metetra
.23077 .39386 .2335 .39068 .24873 .38301 .24615 .38695 Metetra
.24615 .38695 .24873 .38301 .26396 .37424 .26154 .37905 Metetra
.26154 .37905 .26396 .37424 .27919 .36432 .27692 .37012 Metetra
.27692 .37012 .27919 .36432 .29442 .35324 .29231 .36014 Metetra
.29231 .36014 .29442 .35324 .30964 .34098 .30769 .34908 Metetra
.30769 .34908 .30964 .34098 .32487 .32754 .32308 .33696 Metetra
.001 0 0 r
.32308 .33696 .32487 .32754 .3401 .31297 .33846 .32383 Metetra
.039 0 0 r
.33846 .32383 .3401 .31297 .35533 .29738 .35385 .30978 Metetra
.082 0 0 r
.35385 .30978 .35533 .29738 .37056 .28093 .36923 .295 Metetra
.13 0 .045 r
.36923 .295 .37056 .28093 .38579 .2639 .38462 .27971 Metetra
.184 0 .106 r
.38462 .27971 .38579 .2639 .40102 .24664 .4 .26428 Metetra
.242 0 .164 r
.4 .26428 .40102 .24664 .41624 .22965 .41538 .24916 Metetra
.306 0 .216 r
.41538 .24916 .41624 .22965 .43147 .21357 .43077 .23492 Metetra
.374 .038 .262 r
.43077 .23492 .43147 .21357 .4467 .19916 .44615 .22224 Metetra
.444 .109 .302 r
.44615 .22224 .4467 .19916 .46193 .18728 .46154 .21183 Metetra
.516 .177 .332 r
.46154 .21183 .46193 .18728 .47716 .17876 .47692 .2044 Metetra
.584 .241 .353 r
.47692 .2044 .47716 .17876 .49239 .1743 .49231 .20053 Metetra
.647 .297 .363 r
.49231 .20053 .49239 .1743 .50761 .1743 .50769 .20053 Metetra
.93846 .40755 .93401 .40616 .94924 .40013 .95385 .40177 Metetra
.92308 .41179 .91878 .41061 .93401 .40616 .93846 .40755 Metetra
.003 0 0 r
.90769 .41464 .90355 .41364 .91878 .41061 .92308 .41179 Metetra
.02 0 0 r
.89231 .41625 .88832 .41537 .90355 .41364 .90769 .41464 Metetra
.04 0 0 r
.87692 .41674 .8731 .41591 .88832 .41537 .89231 .41625 Metetra
.065 0 0 r
.86154 .4162 .85787 .41533 .8731 .41591 .87692 .41674 Metetra
.095 0 0 r
.84615 .41471 .84264 .41371 .85787 .41533 .86154 .4162 Metetra
.13 0 0 r
.83077 .41231 .82741 .41109 .84264 .41371 .84615 .41471 Metetra
.171 0 0 r
.81538 .40903 .81218 .40747 .82741 .41109 .83077 .41231 Metetra
.218 0 0 r
.8 .40487 .79695 .40288 .81218 .40747 .81538 .40903 Metetra
.271 0 0 r
.78462 .39982 .78173 .39729 .79695 .40288 .8 .40487 Metetra
.329 0 0 r
.76923 .39386 .7665 .39068 .78173 .39729 .78462 .39982 Metetra
.39 0 0 r
.75385 .38695 .75127 .38301 .7665 .39068 .76923 .39386 Metetra
.453 0 0 r
.73846 .37905 .73604 .37424 .75127 .38301 .75385 .38695 Metetra
.516 0 0 r
.72308 .37012 .72081 .36432 .73604 .37424 .73846 .37905 Metetra
.577 0 0 r
.70769 .36014 .70558 .35324 .72081 .36432 .72308 .37012 Metetra
.633 .07 0 r
.69231 .34908 .69036 .34098 .70558 .35324 .70769 .36014 Metetra
.683 .137 0 r
.67692 .33696 .67513 .32754 .69036 .34098 .69231 .34908 Metetra
.727 .199 0 r
.66154 .32383 .6599 .31297 .67513 .32754 .67692 .33696 Metetra
.763 .254 0 r
.64615 .30978 .64467 .29738 .6599 .31297 .66154 .32383 Metetra
.791 .302 .046 r
.63077 .295 .62944 .28093 .64467 .29738 .64615 .30978 Metetra
.811 .342 .107 r
.61538 .27971 .61421 .2639 .62944 .28093 .63077 .295 Metetra
.823 .373 .162 r
.6 .26428 .59898 .24664 .61421 .2639 .61538 .27971 Metetra
.826 .394 .213 r
.58462 .24916 .58376 .22965 .59898 .24664 .6 .26428 Metetra
.821 .406 .258 r
.56923 .23492 .56853 .21357 .58376 .22965 .58462 .24916 Metetra
.806 .407 .296 r
.55385 .22224 .5533 .19916 .56853 .21357 .56923 .23492 Metetra
.782 .398 .327 r
.53846 .21183 .53807 .18728 .5533 .19916 .55385 .22224 Metetra
.747 .376 .349 r
.52308 .2044 .52284 .17876 .53807 .18728 .53846 .21183 Metetra
.702 .342 .362 r
.50769 .20053 .50761 .1743 .52284 .17876 .52308 .2044 Metetra
.371 0 0 r
.04145 .40345 .04615 .40177 .06154 .40755 .05699 .40892 Metetra
.284 0 0 r
.05699 .40892 .06154 .40755 .07692 .41179 .07254 .41288 Metetra
.202 0 0 r
.07254 .41288 .07692 .41179 .09231 .41464 .08808 .41551 Metetra
.128 0 0 r
.08808 .41551 .09231 .41464 .10769 .41625 .10363 .41697 Metetra
.065 0 0 r
.10363 .41697 .10769 .41625 .12308 .41674 .11917 .41739 Metetra
.012 0 0 r
.11917 .41739 .12308 .41674 .13846 .4162 .13472 .41687 Metetra
.13472 .41687 .13846 .4162 .15385 .41471 .15026 .4155 Metetra
.15026 .4155 .15385 .41471 .16923 .41231 .1658 .41333 Metetra
.1658 .41333 .16923 .41231 .18462 .40903 .18135 .41038 Metetra
.18135 .41038 .18462 .40903 .2 .40487 .19689 .40667 Metetra
.19689 .40667 .2 .40487 .21538 .39982 .21244 .40219 Metetra
.21244 .40219 .21538 .39982 .23077 .39386 .22798 .39691 Metetra
.22798 .39691 .23077 .39386 .24615 .38695 .24352 .3908 Metetra
.24352 .3908 .24615 .38695 .26154 .37905 .25907 .38381 Metetra
.25907 .38381 .26154 .37905 .27692 .37012 .27461 .37591 Metetra
.27461 .37591 .27692 .37012 .29231 .36014 .29016 .36705 Metetra
.29016 .36705 .29231 .36014 .30769 .34908 .3057 .35724 Metetra
.012 0 0 r
.3057 .35724 .30769 .34908 .32308 .33696 .32124 .34647 Metetra
.047 0 0 r
.32124 .34647 .32308 .33696 .33846 .32383 .33679 .33479 Metetra
.086 0 0 r
.33679 .33479 .33846 .32383 .35385 .30978 .35233 .32231 Metetra
.128 0 0 r
.35233 .32231 .35385 .30978 .36923 .295 .36788 .30916 Metetra
.175 0 .045 r
.36788 .30916 .36923 .295 .38462 .27971 .38342 .2956 Metetra
.225 0 .105 r
.38342 .2956 .38462 .27971 .4 .26428 .39896 .28194 Metetra
.279 0 .161 r
.39896 .28194 .4 .26428 .41538 .24916 .41451 .2686 Metetra
.337 0 .211 r
.41451 .2686 .41538 .24916 .43077 .23492 .43005 .25608 Metetra
.399 .051 .255 r
.43005 .25608 .43077 .23492 .44615 .22224 .4456 .24498 Metetra
.462 .115 .291 r
.4456 .24498 .44615 .22224 .46154 .21183 .46114 .23591 Metetra
.526 .177 .319 r
.46114 .23591 .46154 .21183 .47692 .2044 .47668 .22947 Metetra
.586 .234 .338 r
.47668 .22947 .47692 .2044 .49231 .20053 .49223 .22611 Metetra
.643 .284 .347 r
.49223 .22611 .49231 .20053 .50769 .20053 .50777 .22611 Metetra
.94301 .40892 .93846 .40755 .95385 .40177 .95855 .40345 Metetra
.92746 .41288 .92308 .41179 .93846 .40755 .94301 .40892 Metetra
.91192 .41551 .90769 .41464 .92308 .41179 .92746 .41288 Metetra
.013 0 0 r
.89637 .41697 .89231 .41625 .90769 .41464 .91192 .41551 Metetra
.03 0 0 r
.88083 .41739 .87692 .41674 .89231 .41625 .89637 .41697 Metetra
.051 0 0 r
.86528 .41687 .86154 .4162 .87692 .41674 .88083 .41739 Metetra
.078 0 0 r
.84974 .4155 .84615 .41471 .86154 .4162 .86528 .41687 Metetra
.111 0 0 r
.8342 .41333 .83077 .41231 .84615 .41471 .84974 .4155 Metetra
.149 0 0 r
.81865 .41038 .81538 .40903 .83077 .41231 .8342 .41333 Metetra
.195 0 0 r
.80311 .40667 .8 .40487 .81538 .40903 .81865 .41038 Metetra
.246 0 0 r
.78756 .40219 .78462 .39982 .8 .40487 .80311 .40667 Metetra
.303 0 0 r
.77202 .39691 .76923 .39386 .78462 .39982 .78756 .40219 Metetra
.364 0 0 r
.75648 .3908 .75385 .38695 .76923 .39386 .77202 .39691 Metetra
.428 0 0 r
.74093 .38381 .73846 .37905 .75385 .38695 .75648 .3908 Metetra
.492 0 0 r
.72539 .37591 .72308 .37012 .73846 .37905 .74093 .38381 Metetra
.553 0 0 r
.70984 .36705 .70769 .36014 .72308 .37012 .72539 .37591 Metetra
.611 .042 0 r
.6943 .35724 .69231 .34908 .70769 .36014 .70984 .36705 Metetra
.662 .11 0 r
.67876 .34647 .67692 .33696 .69231 .34908 .6943 .35724 Metetra
.706 .172 0 r
.66321 .33479 .66154 .32383 .67692 .33696 .67876 .34647 Metetra
.742 .228 0 r
.64767 .32231 .64615 .30978 .66154 .32383 .66321 .33479 Metetra
.77 .276 .046 r
.63212 .30916 .63077 .295 .64615 .30978 .64767 .32231 Metetra
.79 .316 .106 r
.61658 .2956 .61538 .27971 .63077 .295 .63212 .30916 Metetra
.801 .347 .16 r
.60104 .28194 .6 .26428 .61538 .27971 .61658 .2956 Metetra
.805 .368 .208 r
.58549 .2686 .58462 .24916 .6 .26428 .60104 .28194 Metetra
.8 .38 .251 r
.56995 .25608 .56923 .23492 .58462 .24916 .58549 .2686 Metetra
.787 .382 .286 r
.5544 .24498 .55385 .22224 .56923 .23492 .56995 .25608 Metetra
.764 .374 .315 r
.53886 .23591 .53846 .21183 .55385 .22224 .5544 .24498 Metetra
.732 .354 .335 r
.52332 .22947 .52308 .2044 .53846 .21183 .53886 .23591 Metetra
.692 .324 .346 r
.50777 .22611 .50769 .20053 .52308 .2044 .52332 .22947 Metetra
.352 0 0 r
.03665 .40514 .04145 .40345 .05699 .40892 .05236 .41025 Metetra
.263 0 0 r
.05236 .41025 .05699 .40892 .07254 .41288 .06806 .41388 Metetra
.18 0 0 r
.06806 .41388 .07254 .41288 .08808 .41551 .08377 .41624 Metetra
.108 0 0 r
.08377 .41624 .08808 .41551 .10363 .41697 .09948 .41751 Metetra
.048 0 0 r
.09948 .41751 .10363 .41697 .11917 .41739 .11518 .41782 Metetra
.11518 .41782 .11917 .41739 .13472 .41687 .13089 .41731 Metetra
.13089 .41731 .13472 .41687 .15026 .4155 .1466 .41605 Metetra
.1466 .41605 .15026 .4155 .1658 .41333 .1623 .4141 Metetra
.1623 .4141 .1658 .41333 .18135 .41038 .17801 .41151 Metetra
.17801 .41151 .18135 .41038 .19689 .40667 .19372 .40827 Metetra
.19372 .40827 .19689 .40667 .21244 .40219 .20942 .40438 Metetra
.20942 .40438 .21244 .40219 .22798 .39691 .22513 .39981 Metetra
.22513 .39981 .22798 .39691 .24352 .3908 .24084 .39452 Metetra
.24084 .39452 .24352 .3908 .25907 .38381 .25654 .38848 Metetra
.25654 .38848 .25907 .38381 .27461 .37591 .27225 .38164 Metetra
.27225 .38164 .27461 .37591 .29016 .36705 .28796 .37396 Metetra
.024 0 0 r
.28796 .37396 .29016 .36705 .3057 .35724 .30366 .36542 Metetra
.058 0 0 r
.30366 .36542 .3057 .35724 .32124 .34647 .31937 .35603 Metetra
.094 0 0 r
.31937 .35603 .32124 .34647 .33679 .33479 .33508 .34583 Metetra
.133 0 0 r
.33508 .34583 .33679 .33479 .35233 .32231 .35079 .33491 Metetra
.174 0 0 r
.35079 .33491 .35233 .32231 .36788 .30916 .36649 .3234 Metetra
.218 0 .044 r
.36649 .3234 .36788 .30916 .38342 .2956 .3822 .31153 Metetra
.265 0 .103 r
.3822 .31153 .38342 .2956 .39896 .28194 .39791 .29959 Metetra
.315 0 .157 r
.39791 .29959 .39896 .28194 .41451 .2686 .41361 .28794 Metetra
.367 .002 .205 r
.41361 .28794 .41451 .2686 .43005 .25608 .42932 .27705 Metetra
.422 .062 .246 r
.42932 .27705 .43005 .25608 .4456 .24498 .44503 .26742 Metetra
.479 .121 .28 r
.44503 .26742 .4456 .24498 .46114 .23591 .46073 .25958 Metetra
.535 .176 .306 r
.46073 .25958 .46114 .23591 .47668 .22947 .47644 .25402 Metetra
.588 .227 .323 r
.47644 .25402 .47668 .22947 .49223 .22611 .49215 .25114 Metetra
.638 .271 .332 r
.49215 .25114 .49223 .22611 .50777 .22611 .50785 .25114 Metetra
.94764 .41025 .94301 .40892 .95855 .40345 .96335 .40514 Metetra
.93194 .41388 .92746 .41288 .94301 .40892 .94764 .41025 Metetra
.91623 .41624 .91192 .41551 .92746 .41288 .93194 .41388 Metetra
.006 0 0 r
.90052 .41751 .89637 .41697 .91192 .41551 .91623 .41624 Metetra
.019 0 0 r
.88482 .41782 .88083 .41739 .89637 .41697 .90052 .41751 Metetra
.037 0 0 r
.86911 .41731 .86528 .41687 .88083 .41739 .88482 .41782 Metetra
.06 0 0 r
.8534 .41605 .84974 .4155 .86528 .41687 .86911 .41731 Metetra
.09 0 0 r
.8377 .4141 .8342 .41333 .84974 .4155 .8534 .41605 Metetra
.126 0 0 r
.82199 .41151 .81865 .41038 .8342 .41333 .8377 .4141 Metetra
.169 0 0 r
.80628 .40827 .80311 .40667 .81865 .41038 .82199 .41151 Metetra
.219 0 0 r
.79058 .40438 .78756 .40219 .80311 .40667 .80628 .40827 Metetra
.275 0 0 r
.77487 .39981 .77202 .39691 .78756 .40219 .79058 .40438 Metetra
.336 0 0 r
.75916 .39452 .75648 .3908 .77202 .39691 .77487 .39981 Metetra
.399 0 0 r
.74346 .38848 .74093 .38381 .75648 .3908 .75916 .39452 Metetra
.464 0 0 r
.72775 .38164 .72539 .37591 .74093 .38381 .74346 .38848 Metetra
.526 0 0 r
.71204 .37396 .70984 .36705 .72539 .37591 .72775 .38164 Metetra
.584 .011 0 r
.69634 .36542 .6943 .35724 .70984 .36705 .71204 .37396 Metetra
.636 .08 0 r
.68063 .35603 .67876 .34647 .6943 .35724 .69634 .36542 Metetra
.681 .143 0 r
.66492 .34583 .66321 .33479 .67876 .34647 .68063 .35603 Metetra
.718 .2 0 r
.64921 .33491 .64767 .32231 .66321 .33479 .66492 .34583 Metetra
.746 .248 .045 r
.63351 .3234 .63212 .30916 .64767 .32231 .64921 .33491 Metetra
.766 .288 .103 r
.6178 .31153 .61658 .2956 .63212 .30916 .63351 .3234 Metetra
.778 .32 .156 r
.60209 .29959 .60104 .28194 .61658 .2956 .6178 .31153 Metetra
.782 .342 .203 r
.58639 .28794 .58549 .2686 .60104 .28194 .60209 .29959 Metetra
.778 .354 .243 r
.57068 .27705 .56995 .25608 .58549 .2686 .58639 .28794 Metetra
.766 .357 .276 r
.55497 .26742 .5544 .24498 .56995 .25608 .57068 .27705 Metetra
.746 .35 .303 r
.53927 .25958 .53886 .23591 .5544 .24498 .55497 .26742 Metetra
.717 .333 .321 r
.52356 .25402 .52332 .22947 .53886 .23591 .53927 .25958 Metetra
.681 .307 .331 r
.50785 .25114 .50777 .22611 .52332 .22947 .52356 .25402 Metetra
.329 0 0 r
.03175 .40686 .03665 .40514 .05236 .41025 .04762 .41152 Metetra
.237 0 0 r
.04762 .41152 .05236 .41025 .06806 .41388 .06349 .41476 Metetra
.155 0 0 r
.06349 .41476 .06806 .41388 .08377 .41624 .07937 .4168 Metetra
.085 0 0 r
.07937 .4168 .08377 .41624 .09948 .41751 .09524 .41783 Metetra
.028 0 0 r
.09524 .41783 .09948 .41751 .11518 .41782 .11111 .41802 Metetra
.11111 .41802 .11518 .41782 .13089 .41731 .12698 .41748 Metetra
.048 .615 .712 r
.12698 .41748 .13089 .41731 .1466 .41605 .14286 .41632 Metetra
.069 .631 .712 r
.14286 .41632 .1466 .41605 .1623 .4141 .15873 .4146 Metetra
.08 .639 .703 r
.15873 .4146 .1623 .4141 .17801 .41151 .1746 .41236 Metetra
.1746 .41236 .17801 .41151 .19372 .40827 .19048 .40961 Metetra
.19048 .40961 .19372 .40827 .20942 .40438 .20635 .40633 Metetra
.20635 .40633 .20942 .40438 .22513 .39981 .22222 .4025 Metetra
.22222 .4025 .22513 .39981 .24084 .39452 .2381 .39808 Metetra
.2381 .39808 .24084 .39452 .25654 .38848 .25397 .39302 Metetra
.003 0 0 r
.25397 .39302 .25654 .38848 .27225 .38164 .26984 .38728 Metetra
.034 0 0 r
.26984 .38728 .27225 .38164 .28796 .37396 .28571 .38081 Metetra
.068 0 0 r
.28571 .38081 .28796 .37396 .30366 .36542 .30159 .37359 Metetra
.103 0 0 r
.30159 .37359 .30366 .36542 .31937 .35603 .31746 .36561 Metetra
.14 0 0 r
.31746 .36561 .31937 .35603 .33508 .34583 .33333 .35691 Metetra
.179 0 0 r
.33333 .35691 .33508 .34583 .35079 .33491 .34921 .34755 Metetra
.219 0 0 r
.34921 .34755 .35079 .33491 .36649 .3234 .36508 .33768 Metetra
.26 0 .041 r
.36508 .33768 .36649 .3234 .3822 .31153 .38095 .32748 Metetra
.304 0 .099 r
.38095 .32748 .3822 .31153 .39791 .29959 .39683 .31721 Metetra
.349 0 .152 r
.39683 .31721 .39791 .29959 .41361 .28794 .4127 .3072 Metetra
.396 .017 .198 r
.4127 .3072 .41361 .28794 .42932 .27705 .42857 .29785 Metetra
.445 .072 .237 r
.42857 .29785 .42932 .27705 .44503 .26742 .44444 .2896 Metetra
.494 .125 .269 r
.44444 .2896 .44503 .26742 .46073 .25958 .46032 .28289 Metetra
.543 .175 .293 r
.46032 .28289 .46073 .25958 .47644 .25402 .47619 .27815 Metetra
.59 .22 .309 r
.47619 .27815 .47644 .25402 .49215 .25114 .49206 .27569 Metetra
.633 .259 .317 r
.49206 .27569 .49215 .25114 .50785 .25114 .50794 .27569 Metetra
.95238 .41152 .94764 .41025 .96335 .40514 .96825 .40686 Metetra
.93651 .41476 .93194 .41388 .94764 .41025 .95238 .41152 Metetra
.92063 .4168 .91623 .41624 .93194 .41388 .93651 .41476 Metetra
.90476 .41783 .90052 .41751 .91623 .41624 .92063 .4168 Metetra
.007 0 0 r
.88889 .41802 .88482 .41782 .90052 .41751 .90476 .41783 Metetra
.021 0 0 r
.87302 .41748 .86911 .41731 .88482 .41782 .88889 .41802 Metetra
0 .543 .706 r
.85714 .41632 .8534 .41605 .86911 .41731 .87302 .41748 Metetra
.067 0 0 r
.84127 .4146 .8377 .4141 .8534 .41605 .85714 .41632 Metetra
.101 0 0 r
.8254 .41236 .82199 .41151 .8377 .4141 .84127 .4146 Metetra
.141 0 0 r
.80952 .40961 .80628 .40827 .82199 .41151 .8254 .41236 Metetra
.189 0 0 r
.79365 .40633 .79058 .40438 .80628 .40827 .80952 .40961 Metetra
.244 0 0 r
.77778 .4025 .77487 .39981 .79058 .40438 .79365 .40633 Metetra
.304 0 0 r
.7619 .39808 .75916 .39452 .77487 .39981 .77778 .4025 Metetra
.367 0 0 r
.74603 .39302 .74346 .38848 .75916 .39452 .7619 .39808 Metetra
.432 0 0 r
.73016 .38728 .72775 .38164 .74346 .38848 .74603 .39302 Metetra
.495 0 0 r
.71429 .38081 .71204 .37396 .72775 .38164 .73016 .38728 Metetra
.554 0 0 r
.69841 .37359 .69634 .36542 .71204 .37396 .71429 .38081 Metetra
.607 .047 0 r
.68254 .36561 .68063 .35603 .69634 .36542 .69841 .37359 Metetra
.653 .111 0 r
.66667 .35691 .66492 .34583 .68063 .35603 .68254 .36561 Metetra
.691 .169 0 r
.65079 .34755 .64921 .33491 .66492 .34583 .66667 .35691 Metetra
.72 .218 .042 r
.63492 .33768 .63351 .3234 .64921 .33491 .65079 .34755 Metetra
.741 .259 .1 r
.61905 .32748 .6178 .31153 .63351 .3234 .63492 .33768 Metetra
.753 .291 .151 r
.60317 .31721 .60209 .29959 .6178 .31153 .61905 .32748 Metetra
.758 .314 .196 r
.5873 .3072 .58639 .28794 .60209 .29959 .60317 .31721 Metetra
.756 .328 .234 r
.57143 .29785 .57068 .27705 .58639 .28794 .5873 .3072 Metetra
.745 .332 .266 r
.55556 .2896 .55497 .26742 .57068 .27705 .57143 .29785 Metetra
.728 .327 .29 r
.53968 .28289 .53927 .25958 .55497 .26742 .55556 .2896 Metetra
.703 .313 .307 r
.52381 .27815 .52356 .25402 .53927 .25958 .53968 .28289 Metetra
.671 .29 .316 r
.50794 .27569 .50785 .25114 .52356 .25402 .52381 .27815 Metetra
.301 0 0 r
.02674 .40858 .03175 .40686 .04762 .41152 .04278 .41272 Metetra
.208 0 0 r
.04278 .41272 .04762 .41152 .06349 .41476 .05882 .41549 Metetra
.126 0 0 r
.05882 .41549 .06349 .41476 .07937 .4168 .07487 .41715 Metetra
.059 0 0 r
.07487 .41715 .07937 .4168 .09524 .41783 .09091 .41791 Metetra
.005 0 0 r
.09091 .41791 .09524 .41783 .11111 .41802 .10695 .41793 Metetra
.034 .605 .72 r
.10695 .41793 .11111 .41802 .12698 .41748 .12299 .41735 Metetra
.06 .625 .728 r
.12299 .41735 .12698 .41748 .14286 .41632 .13904 .41628 Metetra
.075 .637 .727 r
.13904 .41628 .14286 .41632 .15873 .4146 .15508 .41478 Metetra
.08 .64 .718 r
.15508 .41478 .15873 .4146 .1746 .41236 .17112 .4129 Metetra
.17112 .4129 .1746 .41236 .19048 .40961 .18717 .41065 Metetra
.18717 .41065 .19048 .40961 .20635 .40633 .20321 .40801 Metetra
.20321 .40801 .20635 .40633 .22222 .4025 .21925 .40495 Metetra
.21925 .40495 .22222 .4025 .2381 .39808 .23529 .40143 Metetra
.007 0 0 r
.23529 .40143 .2381 .39808 .25397 .39302 .25134 .3974 Metetra
.04 0 0 r
.25134 .3974 .25397 .39302 .26984 .38728 .26738 .3928 Metetra
.075 0 0 r
.26738 .3928 .26984 .38728 .28571 .38081 .28342 .38758 Metetra
.112 0 0 r
.28342 .38758 .28571 .38081 .30159 .37359 .29947 .38171 Metetra
.149 0 0 r
.29947 .38171 .30159 .37359 .31746 .36561 .31551 .37517 Metetra
.187 0 0 r
.31551 .37517 .31746 .36561 .33333 .35691 .33155 .36799 Metetra
.225 0 0 r
.33155 .36799 .33333 .35691 .34921 .34755 .34759 .36022 Metetra
.263 0 0 r
.34759 .36022 .34921 .34755 .36508 .33768 .36364 .35198 Metetra
.302 0 .037 r
.36364 .35198 .36508 .33768 .38095 .32748 .37968 .34342 Metetra
.341 0 .095 r
.37968 .34342 .38095 .32748 .39683 .31721 .39572 .33479 Metetra
.382 0 .146 r
.39572 .33479 .39683 .31721 .4127 .3072 .41176 .32636 Metetra
.423 .032 .19 r
.41176 .32636 .4127 .3072 .42857 .29785 .42781 .31849 Metetra
.466 .082 .227 r
.42781 .31849 .42857 .29785 .44444 .2896 .44385 .31154 Metetra
.508 .13 .257 r
.44385 .31154 .44444 .2896 .46032 .28289 .45989 .30589 Metetra
.55 .174 .28 r
.45989 .30589 .46032 .28289 .47619 .27815 .47594 .30191 Metetra
.591 .213 .295 r
.47594 .30191 .47619 .27815 .49206 .27569 .49198 .29984 Metetra
.628 .247 .302 r
.49198 .29984 .49206 .27569 .50794 .27569 .50802 .29984 Metetra
.95722 .41272 .95238 .41152 .96825 .40686 .97326 .40858 Metetra
.94118 .41549 .93651 .41476 .95238 .41152 .95722 .41272 Metetra
.92513 .41715 .92063 .4168 .93651 .41476 .94118 .41549 Metetra
.90909 .41791 .90476 .41783 .92063 .4168 .92513 .41715 Metetra
.005 .582 .712 r
.89305 .41793 .88889 .41802 .90476 .41783 .90909 .41791 Metetra
0 .573 .722 r
.87701 .41735 .87302 .41748 .88889 .41802 .89305 .41793 Metetra
0 .559 .723 r
.86096 .41628 .85714 .41632 .87302 .41748 .87701 .41735 Metetra
0 .54 .714 r
.84492 .41478 .84127 .4146 .85714 .41632 .86096 .41628 Metetra
.073 0 0 r
.82888 .4129 .8254 .41236 .84127 .4146 .84492 .41478 Metetra
.111 0 0 r
.81283 .41065 .80952 .40961 .8254 .41236 .82888 .4129 Metetra
.157 0 0 r
.79679 .40801 .79365 .40633 .80952 .40961 .81283 .41065 Metetra
.209 0 0 r
.78075 .40495 .77778 .4025 .79365 .40633 .79679 .40801 Metetra
.268 0 0 r
.76471 .40143 .7619 .39808 .77778 .4025 .78075 .40495 Metetra
.331 0 0 r
.74866 .3974 .74603 .39302 .7619 .39808 .76471 .40143 Metetra
.396 0 0 r
.73262 .3928 .73016 .38728 .74603 .39302 .74866 .3974 Metetra
.46 0 0 r
.71658 .38758 .71429 .38081 .73016 .38728 .73262 .3928 Metetra
.52 0 0 r
.70053 .38171 .69841 .37359 .71429 .38081 .71658 .38758 Metetra
.574 .012 0 r
.68449 .37517 .68254 .36561 .69841 .37359 .70053 .38171 Metetra
.621 .077 0 r
.66845 .36799 .66667 .35691 .68254 .36561 .68449 .37517 Metetra
.66 .136 0 r
.65241 .36022 .65079 .34755 .66667 .35691 .66845 .36799 Metetra
.69 .186 .038 r
.63636 .35198 .63492 .33768 .65079 .34755 .65241 .36022 Metetra
.712 .228 .095 r
.62032 .34342 .61905 .32748 .63492 .33768 .63636 .35198 Metetra
.727 .261 .145 r
.60428 .33479 .60317 .31721 .61905 .32748 .62032 .34342 Metetra
.733 .285 .188 r
.58824 .32636 .5873 .3072 .60317 .31721 .60428 .33479 Metetra
.732 .301 .225 r
.57219 .31849 .57143 .29785 .5873 .3072 .58824 .32636 Metetra
.724 .307 .255 r
.55615 .31154 .55556 .2896 .57143 .29785 .57219 .31849 Metetra
.709 .304 .278 r
.54011 .30589 .53968 .28289 .55556 .2896 .55615 .31154 Metetra
.688 .293 .294 r
.52406 .30191 .52381 .27815 .53968 .28289 .54011 .30589 Metetra
.66 .274 .302 r
.50802 .29984 .50794 .27569 .52381 .27815 .52406 .30191 Metetra
.269 0 0 r
.02162 .41029 .02674 .40858 .04278 .41272 .03784 .41382 Metetra
.174 0 0 r
.03784 .41382 .04278 .41272 .05882 .41549 .05405 .41606 Metetra
.093 0 0 r
.05405 .41606 .05882 .41549 .07487 .41715 .07027 .41728 Metetra
.028 0 0 r
.07027 .41728 .07487 .41715 .09091 .41791 .08649 .4177 Metetra
.021 .594 .721 r
.08649 .4177 .09091 .41791 .10695 .41793 .1027 .41751 Metetra
.055 .621 .738 r
.1027 .41751 .10695 .41793 .12299 .41735 .11892 .41687 Metetra
.075 .637 .745 r
.11892 .41687 .12299 .41735 .13904 .41628 .13514 .41587 Metetra
.084 .644 .744 r
.13514 .41587 .13904 .41628 .15508 .41478 .15135 .41459 Metetra
.082 .642 .734 r
.15135 .41459 .15508 .41478 .17112 .4129 .16757 .41308 Metetra
.071 .633 .715 r
.16757 .41308 .17112 .4129 .18717 .41065 .18378 .41135 Metetra
.18378 .41135 .18717 .41065 .20321 .40801 .2 .40937 Metetra
.2 .40937 .20321 .40801 .21925 .40495 .21622 .40712 Metetra
.003 0 0 r
.21622 .40712 .21925 .40495 .23529 .40143 .23243 .40454 Metetra
.038 0 0 r
.23243 .40454 .23529 .40143 .25134 .3974 .24865 .40157 Metetra
.076 0 0 r
.24865 .40157 .25134 .3974 .26738 .3928 .26486 .39815 Metetra
.116 0 0 r
.26486 .39815 .26738 .3928 .28342 .38758 .28108 .39422 Metetra
.156 0 0 r
.28108 .39422 .28342 .38758 .29947 .38171 .2973 .38974 Metetra
.195 0 0 r
.2973 .38974 .29947 .38171 .31551 .37517 .31351 .38468 Metetra
.233 0 0 r
.31351 .38468 .31551 .37517 .33155 .36799 .32973 .37905 Metetra
.271 0 0 r
.32973 .37905 .33155 .36799 .34759 .36022 .34595 .37288 Metetra
.307 0 0 r
.34595 .37288 .34759 .36022 .36364 .35198 .36216 .36627 Metetra
.342 0 .032 r
.36216 .36627 .36364 .35198 .37968 .34342 .37838 .35935 Metetra
.377 0 .089 r
.37838 .35935 .37968 .34342 .39572 .33479 .39459 .35233 Metetra
.413 0 .139 r
.39459 .35233 .39572 .33479 .41176 .32636 .41081 .34544 Metetra
.449 .046 .181 r
.41081 .34544 .41176 .32636 .42781 .31849 .42703 .33898 Metetra
.486 .091 .217 r
.42703 .33898 .42781 .31849 .44385 .31154 .44324 .33327 Metetra
.522 .134 .246 r
.44324 .33327 .44385 .31154 .45989 .30589 .45946 .32863 Metetra
.558 .172 .267 r
.45946 .32863 .45989 .30589 .47594 .30191 .47568 .32536 Metetra
.592 .207 .281 r
.47568 .32536 .47594 .30191 .49198 .29984 .49189 .32366 Metetra
.623 .235 .288 r
.49189 .32366 .49198 .29984 .50802 .29984 .50811 .32366 Metetra
.96216 .41382 .95722 .41272 .97326 .40858 .97838 .41029 Metetra
.94595 .41606 .94118 .41549 .95722 .41272 .96216 .41382 Metetra
.92973 .41728 .92513 .41715 .94118 .41549 .94595 .41606 Metetra
.02 .593 .712 r
.91351 .4177 .90909 .41791 .92513 .41715 .92973 .41728 Metetra
.019 .592 .732 r
.8973 .41751 .89305 .41793 .90909 .41791 .91351 .4177 Metetra
.013 .587 .741 r
.88108 .41687 .87701 .41735 .89305 .41793 .8973 .41751 Metetra
.001 .577 .741 r
.86486 .41587 .86096 .41628 .87701 .41735 .88108 .41687 Metetra
0 .561 .732 r
.84865 .41459 .84492 .41478 .86096 .41628 .86486 .41587 Metetra
0 .54 .713 r
.83243 .41308 .82888 .4129 .84492 .41478 .84865 .41459 Metetra
.079 0 0 r
.81622 .41135 .81283 .41065 .82888 .4129 .83243 .41308 Metetra
.122 0 0 r
.8 .40937 .79679 .40801 .81283 .41065 .81622 .41135 Metetra
.172 0 0 r
.78378 .40712 .78075 .40495 .79679 .40801 .8 .40937 Metetra
.23 0 0 r
.76757 .40454 .76471 .40143 .78075 .40495 .78378 .40712 Metetra
.292 0 0 r
.75135 .40157 .74866 .3974 .76471 .40143 .76757 .40454 Metetra
.357 0 0 r
.73514 .39815 .73262 .3928 .74866 .3974 .75135 .40157 Metetra
.421 0 0 r
.71892 .39422 .71658 .38758 .73262 .3928 .73514 .39815 Metetra
.482 0 0 r
.7027 .38974 .70053 .38171 .71658 .38758 .71892 .39422 Metetra
.537 0 0 r
.68649 .38468 .68449 .37517 .70053 .38171 .7027 .38974 Metetra
.586 .041 0 r
.67027 .37905 .66845 .36799 .68449 .37517 .68649 .38468 Metetra
.626 .101 0 r
.65405 .37288 .65241 .36022 .66845 .36799 .67027 .37905 Metetra
.658 .153 .033 r
.63784 .36627 .63636 .35198 .65241 .36022 .65405 .37288 Metetra
.682 .196 .089 r
.62162 .35935 .62032 .34342 .63636 .35198 .63784 .36627 Metetra
.698 .231 .138 r
.60541 .35233 .60428 .33479 .62032 .34342 .62162 .35935 Metetra
.706 .256 .18 r
.58919 .34544 .58824 .32636 .60428 .33479 .60541 .35233 Metetra
.708 .273 .216 r
.57297 .33898 .57219 .31849 .58824 .32636 .58919 .34544 Metetra
.702 .282 .244 r
.55676 .33327 .55615 .31154 .57219 .31849 .57297 .33898 Metetra
.691 .282 .266 r
.54054 .32863 .54011 .30589 .55615 .31154 .55676 .33327 Metetra
.673 .274 .28 r
.52432 .32536 .52406 .30191 .54011 .30589 .54054 .32863 Metetra
.65 .258 .288 r
.50811 .32366 .50802 .29984 .52406 .30191 .52432 .32536 Metetra
.231 0 0 r
.01639 .41198 .02162 .41029 .03784 .41382 .03279 .4148 Metetra
.135 0 0 r
.03279 .4148 .03784 .41382 .05405 .41606 .04918 .41643 Metetra
.055 0 0 r
.04918 .41643 .05405 .41606 .07027 .41728 .06557 .41713 Metetra
.006 .582 .714 r
.06557 .41713 .07027 .41728 .08649 .4177 .08197 .41717 Metetra
.05 .617 .741 r
.08197 .41717 .08649 .4177 .1027 .41751 .09836 .41674 Metetra
.078 .639 .757 r
.09836 .41674 .1027 .41751 .11892 .41687 .11475 .41599 Metetra
.092 .65 .764 r
.11475 .41599 .11892 .41687 .13514 .41587 .13115 .41505 Metetra
.094 .652 .762 r
.13115 .41505 .13514 .41587 .15135 .41459 .14754 .41399 Metetra
.086 .645 .751 r
.14754 .41399 .15135 .41459 .16757 .41308 .16393 .41286 Metetra
.068 .631 .732 r
.16393 .41286 .16757 .41308 .18378 .41135 .18033 .41165 Metetra
.18033 .41165 .18378 .41135 .2 .40937 .19672 .41037 Metetra
.19672 .41037 .2 .40937 .21622 .40712 .21311 .40895 Metetra
.027 0 0 r
.21311 .40895 .21622 .40712 .23243 .40454 .22951 .40735 Metetra
.068 0 0 r
.22951 .40735 .23243 .40454 .24865 .40157 .2459 .40549 Metetra
.112 0 0 r
.2459 .40549 .24865 .40157 .26486 .39815 .2623 .4033 Metetra
.156 0 0 r
.2623 .4033 .26486 .39815 .28108 .39422 .27869 .40071 Metetra
.199 0 0 r
.27869 .40071 .28108 .39422 .2973 .38974 .29508 .39766 Metetra
.241 0 0 r
.29508 .39766 .2973 .38974 .31351 .38468 .31148 .39411 Metetra
.279 0 0 r
.31148 .39411 .31351 .38468 .32973 .37905 .32787 .39006 Metetra
.316 0 0 r
.32787 .39006 .32973 .37905 .34595 .37288 .34426 .38551 Metetra
.349 0 0 r
.34426 .38551 .34595 .37288 .36216 .36627 .36066 .38054 Metetra
.382 0 .026 r
.36066 .38054 .36216 .36627 .37838 .35935 .37705 .37525 Metetra
.413 0 .082 r
.37705 .37525 .37838 .35935 .39459 .35233 .39344 .36982 Metetra
.444 .016 .131 r
.39344 .36982 .39459 .35233 .41081 .34544 .40984 .36444 Metetra
.474 .06 .173 r
.40984 .36444 .41081 .34544 .42703 .33898 .42623 .35935 Metetra
.505 .1 .207 r
.42623 .35935 .42703 .33898 .44324 .33327 .44262 .35484 Metetra
.535 .138 .234 r
.44262 .35484 .44324 .33327 .45946 .32863 .45902 .35116 Metetra
.565 .171 .255 r
.45902 .35116 .45946 .32863 .47568 .32536 .47541 .34855 Metetra
.593 .2 .268 r
.47541 .34855 .47568 .32536 .49189 .32366 .4918 .34719 Metetra
.618 .224 .275 r
.4918 .34719 .49189 .32366 .50811 .32366 .5082 .34719 Metetra
.003 0 0 r
.96721 .4148 .96216 .41382 .97838 .41029 .98361 .41198 Metetra
.95082 .41643 .94595 .41606 .96216 .41382 .96721 .4148 Metetra
.93443 .41713 .92973 .41728 .94595 .41606 .95082 .41643 Metetra
.029 .601 .735 r
.91803 .41717 .91351 .4177 .92973 .41728 .93443 .41713 Metetra
.033 .603 .753 r
.90164 .41674 .8973 .41751 .91351 .4177 .91803 .41717 Metetra
.032 .601 .762 r
.88525 .41599 .88108 .41687 .8973 .41751 .90164 .41674 Metetra
.024 .595 .761 r
.86885 .41505 .86486 .41587 .88108 .41687 .88525 .41599 Metetra
.009 .583 .75 r
.85246 .41399 .84865 .41459 .86486 .41587 .86885 .41505 Metetra
0 .565 .731 r
.83607 .41286 .83243 .41308 .84865 .41459 .85246 .41399 Metetra
.044 0 0 r
.81967 .41165 .81622 .41135 .83243 .41308 .83607 .41286 Metetra
.084 0 0 r
.80328 .41037 .8 .40937 .81622 .41135 .81967 .41165 Metetra
.132 0 0 r
.78689 .40895 .78378 .40712 .8 .40937 .80328 .41037 Metetra
.188 0 0 r
.77049 .40735 .76757 .40454 .78378 .40712 .78689 .40895 Metetra
.249 0 0 r
.7541 .40549 .75135 .40157 .76757 .40454 .77049 .40735 Metetra
.313 0 0 r
.7377 .4033 .73514 .39815 .75135 .40157 .7541 .40549 Metetra
.378 0 0 r
.72131 .40071 .71892 .39422 .73514 .39815 .7377 .4033 Metetra
.44 0 0 r
.70492 .39766 .7027 .38974 .71892 .39422 .72131 .40071 Metetra
.497 0 0 r
.68852 .39411 .68649 .38468 .7027 .38974 .70492 .39766 Metetra
.547 .002 0 r
.67213 .39006 .67027 .37905 .68649 .38468 .68852 .39411 Metetra
.589 .064 0 r
.65574 .38551 .65405 .37288 .67027 .37905 .67213 .39006 Metetra
.623 .117 .027 r
.63934 .38054 .63784 .36627 .65405 .37288 .65574 .38551 Metetra
.649 .162 .083 r
.62295 .37525 .62162 .35935 .63784 .36627 .63934 .38054 Metetra
.667 .199 .131 r
.60656 .36982 .60541 .35233 .62162 .35935 .62295 .37525 Metetra
.678 .226 .172 r
.59016 .36444 .58919 .34544 .60541 .35233 .60656 .36982 Metetra
.682 .246 .206 r
.57377 .35935 .57297 .33898 .58919 .34544 .59016 .36444 Metetra
.68 .256 .233 r
.55738 .35484 .55676 .33327 .57297 .33898 .57377 .35935 Metetra
.672 .259 .254 r
.54098 .35116 .54054 .32863 .55676 .33327 .55738 .35484 Metetra
.659 .255 .268 r
.52459 .34855 .52432 .32536 .54054 .32863 .54098 .35116 Metetra
.64 .243 .275 r
.5082 .34719 .50811 .32366 .52432 .32536 .52459 .34855 Metetra
.187 0 0 r
.01105 .41362 .01639 .41198 .03279 .4148 .02762 .41564 Metetra
.09 0 0 r
.02762 .41564 .03279 .4148 .04918 .41643 .0442 .41655 Metetra
.013 0 0 r
.0442 .41655 .04918 .41643 .06557 .41713 .06077 .41668 Metetra
.044 .613 .737 r
.06077 .41668 .06557 .41713 .08197 .41717 .07735 .41627 Metetra
.083 .643 .762 r
.07735 .41627 .08197 .41717 .09836 .41674 .09392 .41554 Metetra
.105 .659 .777 r
.09392 .41554 .09836 .41674 .11475 .41599 .1105 .41467 Metetra
.112 .664 .783 r
.1105 .41467 .11475 .41599 .13115 .41505 .12707 .41377 Metetra
.107 .661 .78 r
.12707 .41377 .13115 .41505 .14754 .41399 .14365 .41292 Metetra
.091 .649 .769 r
.14365 .41292 .14754 .41399 .16393 .41286 .16022 .41217 Metetra
.066 .63 .749 r
.16022 .41217 .16393 .41286 .18033 .41165 .1768 .41152 Metetra
.033 .604 .72 r
.1768 .41152 .18033 .41165 .19672 .41037 .19337 .41095 Metetra
.006 0 0 r
.19337 .41095 .19672 .41037 .21311 .40895 .20994 .41041 Metetra
.051 0 0 r
.20994 .41041 .21311 .40895 .22951 .40735 .22652 .40982 Metetra
.099 0 0 r
.22652 .40982 .22951 .40735 .2459 .40549 .24309 .40911 Metetra
.148 0 0 r
.24309 .40911 .2459 .40549 .2623 .4033 .25967 .4082 Metetra
.196 0 0 r
.25967 .4082 .2623 .4033 .27869 .40071 .27624 .407 Metetra
.243 0 0 r
.27624 .407 .27869 .40071 .29508 .39766 .29282 .40543 Metetra
.286 0 0 r
.29282 .40543 .29508 .39766 .31148 .39411 .30939 .40344 Metetra
.325 0 0 r
.30939 .40344 .31148 .39411 .32787 .39006 .32597 .40099 Metetra
.36 0 0 r
.32597 .40099 .32787 .39006 .34426 .38551 .34254 .39809 Metetra
.391 0 0 r
.34254 .39809 .34426 .38551 .36066 .38054 .35912 .39477 Metetra
.42 0 .019 r
.35912 .39477 .36066 .38054 .37705 .37525 .37569 .39112 Metetra
.447 0 .075 r
.37569 .39112 .37705 .37525 .39344 .36982 .39227 .38726 Metetra
.473 .034 .123 r
.39227 .38726 .39344 .36982 .40984 .36444 .40884 .38336 Metetra
.498 .073 .164 r
.40884 .38336 .40984 .36444 .42623 .35935 .42541 .37962 Metetra
.523 .109 .197 r
.42541 .37962 .42623 .35935 .44262 .35484 .44199 .37626 Metetra
.548 .142 .223 r
.44199 .37626 .44262 .35484 .45902 .35116 .45856 .3735 Metetra
.571 .17 .243 r
.45856 .3735 .45902 .35116 .47541 .34855 .47514 .37154 Metetra
.594 .194 .256 r
.47514 .37154 .47541 .34855 .4918 .34719 .49171 .37051 Metetra
.614 .214 .262 r
.49171 .37051 .4918 .34719 .5082 .34719 .50829 .37051 Metetra
.009 0 0 r
.97238 .41564 .96721 .4148 .98361 .41198 .98895 .41362 Metetra
.9558 .41655 .95082 .41643 .96721 .4148 .97238 .41564 Metetra
.026 .599 .729 r
.93923 .41668 .93443 .41713 .95082 .41643 .9558 .41655 Metetra
.04 .608 .758 r
.92265 .41627 .91803 .41717 .93443 .41713 .93923 .41668 Metetra
.048 .613 .776 r
.90608 .41554 .90164 .41674 .91803 .41717 .92265 .41627 Metetra
.052 .615 .783 r
.8895 .41467 .88525 .41599 .90164 .41674 .90608 .41554 Metetra
.048 .613 .781 r
.87293 .41377 .86885 .41505 .88525 .41599 .8895 .41467 Metetra
.038 .605 .77 r
.85635 .41292 .85246 .41399 .86885 .41505 .87293 .41377 Metetra
.019 .592 .75 r
.83978 .41217 .83607 .41286 .85246 .41399 .85635 .41292 Metetra
0 .571 .721 r
.8232 .41152 .81967 .41165 .83607 .41286 .83978 .41217 Metetra
.044 0 0 r
.80663 .41095 .80328 .41037 .81967 .41165 .8232 .41152 Metetra
.09 0 0 r
.79006 .41041 .78689 .40895 .80328 .41037 .80663 .41095 Metetra
.143 0 0 r
.77348 .40982 .77049 .40735 .78689 .40895 .79006 .41041 Metetra
.203 0 0 r
.75691 .40911 .7541 .40549 .77049 .40735 .77348 .40982 Metetra
.266 0 0 r
.74033 .4082 .7377 .4033 .7541 .40549 .75691 .40911 Metetra
.331 0 0 r
.72376 .407 .72131 .40071 .7377 .4033 .74033 .4082 Metetra
.394 0 0 r
.70718 .40543 .70492 .39766 .72131 .40071 .72376 .407 Metetra
.452 0 0 r
.69061 .40344 .68852 .39411 .70492 .39766 .70718 .40543 Metetra
.504 0 0 r
.67403 .40099 .67213 .39006 .68852 .39411 .69061 .40344 Metetra
.548 .025 0 r
.65746 .39809 .65574 .38551 .67213 .39006 .67403 .40099 Metetra
.585 .08 .021 r
.64088 .39477 .63934 .38054 .65574 .38551 .65746 .39809 Metetra
.614 .128 .076 r
.62431 .39112 .62295 .37525 .63934 .38054 .64088 .39477 Metetra
.635 .166 .123 r
.60773 .38726 .60656 .36982 .62295 .37525 .62431 .39112 Metetra
.649 .196 .163 r
.59116 .38336 .59016 .36444 .60656 .36982 .60773 .38726 Metetra
.656 .218 .196 r
.57459 .37962 .57377 .35935 .59016 .36444 .59116 .38336 Metetra
.658 .231 .222 r
.55801 .37626 .55738 .35484 .57377 .35935 .57459 .37962 Metetra
.653 .237 .242 r
.54144 .3735 .54098 .35116 .55738 .35484 .55801 .37626 Metetra
.644 .236 .255 r
.52486 .37154 .52459 .34855 .54098 .35116 .54144 .3735 Metetra
.631 .228 .262 r
.50829 .37051 .5082 .34719 .52459 .34855 .52486 .37154 Metetra
.136 0 0 r
.00559 .41519 .01105 .41362 .02762 .41564 .02235 .41629 Metetra
.04 0 0 r
.02235 .41629 .02762 .41564 .0442 .41655 .03911 .41641 Metetra
.034 .605 .723 r
.03911 .41641 .0442 .41655 .06077 .41668 .05587 .41587 Metetra
.086 .646 .76 r
.05587 .41587 .06077 .41668 .07735 .41627 .07263 .41495 Metetra
.119 .67 .784 r
.07263 .41495 .07735 .41627 .09392 .41554 .08939 .41389 Metetra
.134 .68 .799 r
.08939 .41389 .09392 .41554 .1105 .41467 .10615 .41285 Metetra
.134 .68 .803 r
.10615 .41285 .1105 .41467 .12707 .41377 .12291 .41197 Metetra
.122 .67 .8 r
.12291 .41197 .12707 .41377 .14365 .41292 .13966 .41133 Metetra
.098 .653 .788 r
.13966 .41133 .14365 .41292 .16022 .41217 .15642 .41098 Metetra
.065 .628 .767 r
.15642 .41098 .16022 .41217 .1768 .41152 .17318 .4109 Metetra
.025 .597 .737 r
.17318 .4109 .1768 .41152 .19337 .41095 .18994 .41107 Metetra
.022 0 0 r
.18994 .41107 .19337 .41095 .20994 .41041 .2067 .41143 Metetra
.074 0 0 r
.2067 .41143 .20994 .41041 .22652 .40982 .22346 .41191 Metetra
.128 0 0 r
.22346 .41191 .22652 .40982 .24309 .40911 .24022 .41241 Metetra
.183 0 0 r
.24022 .41241 .24309 .40911 .25967 .4082 .25698 .41282 Metetra
.236 0 0 r
.25698 .41282 .25967 .4082 .27624 .407 .27374 .41305 Metetra
.285 0 0 r
.27374 .41305 .27624 .407 .29282 .40543 .2905 .41301 Metetra
.33 0 0 r
.2905 .41301 .29282 .40543 .30939 .40344 .30726 .41262 Metetra
.369 0 0 r
.30726 .41262 .30939 .40344 .32597 .40099 .32402 .41182 Metetra
.403 0 0 r
.32402 .41182 .32597 .40099 .34254 .39809 .34078 .4106 Metetra
.432 0 0 r
.34078 .4106 .34254 .39809 .35912 .39477 .35754 .40896 Metetra
.458 0 .012 r
.35754 .40896 .35912 .39477 .37569 .39112 .3743 .40695 Metetra
.481 .014 .067 r
.3743 .40695 .37569 .39112 .39227 .38726 .39106 .40467 Metetra
.502 .052 .115 r
.39106 .40467 .39227 .38726 .40884 .38336 .40782 .40224 Metetra
.522 .087 .154 r
.40782 .40224 .40884 .38336 .42541 .37962 .42458 .39982 Metetra
.541 .118 .187 r
.42458 .39982 .42541 .37962 .44199 .37626 .44134 .39759 Metetra
.56 .146 .212 r
.44134 .39759 .44199 .37626 .45856 .3735 .4581 .39572 Metetra
.578 .169 .231 r
.4581 .39572 .45856 .3735 .47514 .37154 .47486 .39438 Metetra
.594 .189 .244 r
.47486 .39438 .47514 .37154 .49171 .37051 .49162 .39367 Metetra
.609 .204 .25 r
.49162 .39367 .49171 .37051 .50829 .37051 .50838 .39367 Metetra
.015 0 0 r
.97765 .41629 .97238 .41564 .98895 .41362 .99441 .41519 Metetra
.01 .585 .713 r
.96089 .41641 .9558 .41655 .97238 .41564 .97765 .41629 Metetra
.032 .602 .755 r
.94413 .41587 .93923 .41668 .9558 .41655 .96089 .41641 Metetra
.05 .614 .783 r
.92737 .41495 .92265 .41627 .93923 .41668 .94413 .41587 Metetra
.064 .623 .799 r
.91061 .41389 .90608 .41554 .92265 .41627 .92737 .41495 Metetra
.072 .629 .805 r
.89385 .41285 .8895 .41467 .90608 .41554 .91061 .41389 Metetra
.074 .631 .802 r
.87709 .41197 .87293 .41377 .8895 .41467 .89385 .41285 Metetra
.068 .628 .791 r
.86034 .41133 .85635 .41292 .87293 .41377 .87709 .41197 Metetra
.054 .619 .77 r
.84358 .41098 .83978 .41217 .85635 .41292 .86034 .41133 Metetra
.031 .602 .74 r
.82682 .4109 .8232 .41152 .83978 .41217 .84358 .41098 Metetra
.002 0 0 r
.81006 .41107 .80663 .41095 .8232 .41152 .82682 .4109 Metetra
.044 0 0 r
.7933 .41143 .79006 .41041 .80663 .41095 .81006 .41107 Metetra
.095 0 0 r
.77654 .41191 .77348 .40982 .79006 .41041 .7933 .41143 Metetra
.153 0 0 r
.75978 .41241 .75691 .40911 .77348 .40982 .77654 .41191 Metetra
.216 0 0 r
.74302 .41282 .74033 .4082 .75691 .40911 .75978 .41241 Metetra
.281 0 0 r
.72626 .41305 .72376 .407 .74033 .4082 .74302 .41282 Metetra
.344 0 0 r
.7095 .41301 .70718 .40543 .72376 .407 .72626 .41305 Metetra
.404 0 0 r
.69274 .41262 .69061 .40344 .70718 .40543 .7095 .41301 Metetra
.458 0 0 r
.67598 .41182 .67403 .40099 .69061 .40344 .69274 .41262 Metetra
.505 0 0 r
.65922 .4106 .65746 .39809 .67403 .40099 .67598 .41182 Metetra
.545 .042 .013 r
.64246 .40896 .64088 .39477 .65746 .39809 .65922 .4106 Metetra
.576 .092 .068 r
.6257 .40695 .62431 .39112 .64088 .39477 .64246 .40896 Metetra
.601 .133 .115 r
.60894 .40467 .60773 .38726 .62431 .39112 .6257 .40695 Metetra
.618 .165 .154 r
.59218 .40224 .59116 .38336 .60773 .38726 .60894 .40467 Metetra
.629 .19 .186 r
.57542 .39982 .57459 .37962 .59116 .38336 .59218 .40224 Metetra
.634 .206 .212 r
.55866 .39759 .55801 .37626 .57459 .37962 .57542 .39982 Metetra
.634 .215 .231 r
.5419 .39572 .54144 .3735 .55801 .37626 .55866 .39759 Metetra
.63 .218 .243 r
.52514 .39438 .52486 .37154 .54144 .3735 .5419 .39572 Metetra
.621 .214 .25 r
.50838 .39367 .50829 .37051 .52486 .37154 .52514 .39438 Metetra
.078 0 0 r
0 .41667 .00559 .41519 .02235 .41629 .01695 .41673 Metetra
.01695 .41673 .02235 .41629 .03911 .41641 .0339 .41594 Metetra
.086 .646 .748 r
.0339 .41594 .03911 .41641 .05587 .41587 .05085 .41465 Metetra
.132 .68 .784 r
.05085 .41465 .05587 .41587 .07263 .41495 .0678 .41316 Metetra
.158 .698 .807 r
.0678 .41316 .07263 .41495 .08939 .41389 .08475 .4117 Metetra
.166 .703 .82 r
.08475 .4117 .08939 .41389 .10615 .41285 .10169 .41047 Metetra
.158 .696 .824 r
.10169 .41047 .10615 .41285 .12291 .41197 .11864 .4096 Metetra
.138 .681 .82 r
.11864 .4096 .12291 .41197 .13966 .41133 .13559 .40916 Metetra
.107 .658 .807 r
.13559 .40916 .13966 .41133 .15642 .41098 .15254 .4092 Metetra
.066 .627 .785 r
.15254 .4092 .15642 .41098 .17318 .4109 .16949 .40972 Metetra
.017 .59 .754 r
.16949 .40972 .17318 .4109 .18994 .41107 .18644 .41067 Metetra
0 .546 .712 r
.18644 .41067 .18994 .41107 .2067 .41143 .20339 .41198 Metetra
.096 0 0 r
.20339 .41198 .2067 .41143 .22346 .41191 .22034 .41357 Metetra
.157 0 0 r
.22034 .41357 .22346 .41191 .24022 .41241 .23729 .41532 Metetra
.217 0 0 r
.23729 .41532 .24022 .41241 .25698 .41282 .25424 .41711 Metetra
.274 0 0 r
.25424 .41711 .25698 .41282 .27374 .41305 .27119 .41884 Metetra
.326 0 0 r
.27119 .41884 .27374 .41305 .2905 .41301 .28814 .42038 Metetra
.372 0 0 r
.28814 .42038 .2905 .41301 .30726 .41262 .30508 .42164 Metetra
.412 0 0 r
.30508 .42164 .30726 .41262 .32402 .41182 .32203 .42253 Metetra
.445 0 0 r
.32203 .42253 .32402 .41182 .34078 .4106 .33898 .42302 Metetra
.472 0 0 r
.33898 .42302 .34078 .4106 .35754 .40896 .35593 .42308 Metetra
.494 0 .005 r
.35593 .42308 .35754 .40896 .3743 .40695 .37288 .42273 Metetra
.513 .036 .059 r
.37288 .42273 .3743 .40695 .39106 .40467 .38983 .42203 Metetra
.53 .07 .106 r
.38983 .42203 .39106 .40467 .40782 .40224 .40678 .42107 Metetra
.545 .1 .145 r
.40678 .42107 .40782 .40224 .42458 .39982 .42373 .41996 Metetra
.559 .127 .177 r
.42373 .41996 .42458 .39982 .44134 .39759 .44068 .41884 Metetra
.572 .15 .202 r
.44068 .41884 .44134 .39759 .4581 .39572 .45763 .41785 Metetra
.585 .169 .22 r
.45763 .41785 .4581 .39572 .47486 .39438 .47458 .41711 Metetra
.596 .184 .232 r
.47458 .41711 .47486 .39438 .49162 .39367 .49153 .41672 Metetra
.605 .195 .238 r
.49153 .41672 .49162 .39367 .50838 .39367 .50847 .41672 Metetra
.021 0 0 r
.98305 .41673 .97765 .41629 .99441 .41519 1 .41667 Metetra
.009 .584 .741 r
.9661 .41594 .96089 .41641 .97765 .41629 .98305 .41673 Metetra
.037 .603 .781 r
.94915 .41465 .94413 .41587 .96089 .41641 .9661 .41594 Metetra
.061 .619 .807 r
.9322 .41316 .92737 .41495 .94413 .41587 .94915 .41465 Metetra
.081 .632 .822 r
.91525 .4117 .91061 .41389 .92737 .41495 .9322 .41316 Metetra
.094 .643 .827 r
.89831 .41047 .89385 .41285 .91061 .41389 .91525 .4117 Metetra
.1 .649 .824 r
.88136 .4096 .87709 .41197 .89385 .41285 .89831 .41047 Metetra
.099 .651 .811 r
.86441 .40916 .86034 .41133 .87709 .41197 .88136 .4096 Metetra
.09 .646 .79 r
.84746 .4092 .84358 .41098 .86034 .41133 .86441 .40916 Metetra
.071 .633 .759 r
.83051 .40972 .82682 .4109 .84358 .41098 .84746 .4092 Metetra
.042 .611 .717 r
.81356 .41067 .81006 .41107 .82682 .4109 .83051 .40972 Metetra
.79661 .41198 .7933 .41143 .81006 .41107 .81356 .41067 Metetra
.045 0 0 r
.77966 .41357 .77654 .41191 .7933 .41143 .79661 .41198 Metetra
.101 0 0 r
.76271 .41532 .75978 .41241 .77654 .41191 .77966 .41357 Metetra
.163 0 0 r
.74576 .41711 .74302 .41282 .75978 .41241 .76271 .41532 Metetra
.227 0 0 r
.72881 .41884 .72626 .41305 .74302 .41282 .74576 .41711 Metetra
.292 0 0 r
.71186 .42038 .7095 .41301 .72626 .41305 .72881 .41884 Metetra
.353 0 0 r
.69492 .42164 .69274 .41262 .7095 .41301 .71186 .42038 Metetra
.409 0 0 r
.67797 .42253 .67598 .41182 .69274 .41262 .69492 .42164 Metetra
.459 0 0 r
.66102 .42302 .65922 .4106 .67598 .41182 .67797 .42253 Metetra
.502 .004 .006 r
.64407 .42308 .64246 .40896 .65922 .4106 .66102 .42302 Metetra
.537 .055 .06 r
.62712 .42273 .6257 .40695 .64246 .40896 .64407 .42308 Metetra
.565 .099 .106 r
.61017 .42203 .60894 .40467 .6257 .40695 .62712 .42273 Metetra
.586 .134 .145 r
.59322 .42107 .59218 .40224 .60894 .40467 .61017 .42203 Metetra
.601 .162 .177 r
.57627 .41996 .57542 .39982 .59218 .40224 .59322 .42107 Metetra
.611 .181 .202 r
.55932 .41884 .55866 .39759 .57542 .39982 .57627 .41996 Metetra
.615 .194 .22 r
.54237 .41785 .5419 .39572 .55866 .39759 .55932 .41884 Metetra
.615 .2 .232 r
.52542 .41711 .52514 .39438 .5419 .39572 .54237 .41785 Metetra
.612 .2 .238 r
.50847 .41672 .50838 .39367 .52514 .39438 .52542 .41711 Metetra
0 g
.25 Mabswid
0 0 m
0 .5 L
s
0 .5 m
1 .5 L
s
1 .5 m
1 0 L
s
1 0 m
0 0 L
s
0 0 m
1 0 L
s
0 0 m
.0058 .0029 L
s
[(-2)] -0.01161 -0.0058 1 .4 Mshowa
.25 0 m
.25488 .00488 L
s
[(-1)] .24024 -0.00976 1 .8 Mshowa
.5 0 m
.5 .00781 L
s
[(0)] .5 -0.01562 0 1 Mshowa
.75 0 m
.74512 .00488 L
s
[(1)] .75976 -0.00976 -1 .8 Mshowa
1 0 m
.9942 .0029 L
s
[(2)] 1.01161 -0.0058 -1 .4 Mshowa
.125 Mabswid
.05 0 m
.05343 .0019 L
s
.1 0 m
.10335 .0021 L
s
.15 0 m
.15326 .00233 L
s
.2 0 m
.20312 .0026 L
s
.3 0 m
.30265 .00331 L
s
.35 0 m
.35225 .00375 L
s
.4 0 m
.40168 .00419 L
s
.45 0 m
.45091 .00455 L
s
.55 0 m
.54909 .00455 L
s
.6 0 m
.59832 .00419 L
s
.65 0 m
.64775 .00375 L
s
.7 0 m
.69735 .00331 L
s
.8 0 m
.79688 .0026 L
s
.85 0 m
.84674 .00233 L
s
.9 0 m
.89665 .0021 L
s
.95 0 m
.94657 .0019 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML009OG0P27e`00U]L0103Ge`26e`00D]L4043G00@0emL0@=L404;G001De`030=OG03oG00@0emL0
@]L00`3Ge`11e`00E=L00`3Ge`0oe`040=OG04;G00<0emL0@ML001?G100ee`@01=L00`3Ge`0oe`04
0=OG04;G00<0emL0>mL400;G000Ce`030=OG03kG00<0emL0@=L204?G00<0emL0>mL00`3Ge`03e`00
5=L00`3Ge`0ke`<0QML303kG00<0emL00]L000gG1004e`030=OG03cG00<0emL0QML00`3Ge`0me`03
0=OG007G000De`<01=L00`3Ge`3oe`400ML1e`004mL0103Ge`04e`030=OG0?cG00@0emL00]L001?G
1004eo`01=L200?G000Ce`040=OG00CG0`000mL0e`0ie`802mL00`3Ge`09e`030=OG00WG00<0emL0
2]L00`3Ge`09e`030=OG00WG00<0emL02]L00`3Ge`09e`030=OG00[G00<0emL02ML00`3Ge`0je`80
00?G0=L02=L001?G00@0emL01=L00`3Ge`0200;G00<0emL0LmL00`3Ge`1fe`800mL00`3Ge`07e`00
4mL0103Ge`04e`030=OG00;G0`3/e`801ML00`3Ge`07e`005=L200GG00<0emL01=L200;G00<0emL0
i=L200OG00<0emL01mL001_G0P07e`<0i=L200WG00<0emL01mL001_G00<0emL02=L20003e`3G0=kG
0P0;e`030=OG00OG000Ke`D02=L200?G00<0emL0emL200gG00<0emL01mL001_G00@0emL02mL20003
e`3G0=KG0P0?e`030=OG00OG000Ke`040=OG00gG0P02e`030=OG05cG4`1Qe`804ML00`3Ge`07e`00
5]L40005e`00e`003mL30003e`3G05CG20029@8000Y@M01jLgX0WWVN0P000`80000605SG0P0Ce`03
0=OG00OG000Ke`040=OG017G0`1Be`@00RD3000=BP0U07@0Ng@0M9id0003WP8000D30<L02P020003
0`000080DmL201GG00<0emL01mL001_G100Ce`8000?G0=L0C]L400039@0U0080018U02D0BP1@M01j
LgX0WWVN0:@20003W<40008000D30009001Ae`805mL00`3Ge`07e`006mL0103Ge`0Ee`800]L00`3G
0017e`L000HU00409TX2000:D7@0Ng@0M9id00>N00T0WP00aig70<H0201<e`806ML00`3Ge`07e`00
6mL00`3Ge`0He`<000?G0=L0A]L8000M0@009RD0BU1:051d07YcNP2NNIh0Y9h0W<6L09`00P001/L0
000304[G0P0Ke`030=OG00OG000Ke`806mL30003e`3G04?G1P0010400BH200099P00M51d07]d00D0
0ih00`2Nb0020007WLL009`0a`020004aP0004OG0P0Me`030=OG00OG000Ke`030=OG00_G0P04e`03
0=OG00;G0`03e`<000?G0=L0@ML8000:9@009@0U04Y@BP@000>NM9h00`0029h0Y9h0WP2L0P001<00
ai`604CG0P0Oe`030=OG00OG000Ke`030=OG00[G00@0emL02mL00`3Ge`02e`<0@ML9000B0@00BP1@
07A@M01jM01jWgX00Yh20008W/P0b0370<P30004a`00W0@0@ML2027G00<0emL01mL001_G00<0emL0
2]L0103Ge`0;e`030=OG00CG0P000mL0e`0le`P000@100010P001DXU04Y@008000Y@M02NM9h0WWZN
0P0019h0W/P20006W@0009c71P0oe`808mL00`3Ge`07e`006mL00`3Ge`04e`@00]L0103Ge`08e`<0
2ML20003e`0003[G1@0010400042000A9P1@9U00M01d07Yd07ZONP000ih2000<b038W/P0b<L0a`37
0P000lH0000203cG0P0Ue`030=OG00OG000Ke`030=OG00[G00@0emL02=L00`3Ge`0;e`<000?G0=L0
=]L8008100L09@409DXU008000m@BP1@M02NM9h0WWZN09h00P002Yk8WP2Mb0370<L20003W0000080
>]L202OG00<0emL01mL001_G0P0;e`040=OG00SG00<0emL03ML30003e`3G03CG2000104002D2000?
D2I@07A@M01jM01jWgX000>N00L0W/P0b9k8008000C70<O8200he`80:ML00`3Ge`07e`006mL00`3G
e`0;e`802ML40003e`0000_G0`000mL0e`0be`L00P4200059@009DX00P001TY@BP1@M0D000BNNYh0
0Yh20005b9h00<P00P000id0000603KG0P0[e`030=OG00OG000Ke`030=OG01[G00@0emL03=L40003
e`3G02oG10001P4000400@8000TV0500D01dD7@010000gZNNP03000:WP2Nb0380<P0b0<000G8a`00
a`0503?G0P0]e`030=OG00OG0002e`801=L00`3Ge`02e`@00]L300GG00<0emL06]L0103Ge`0>e`80
00?G0=L0;]L800030@01008000XU02D09@1:D4X00W@01`1jM7X0WWX00P02WP0609d0WP2M0P001LL0
a`3700H0<ML202oG00<0emL01mL00005e`3Ge`002=L00`3Ge`06e`030=OG00;G00<0emL06]L0103G
e`0@ecX000DU0@0U9P020005BU00M5000P001gYd07ZNNP000ih20004b038WP8000K8X`370<Li037G
00<0emL01mL00005e`3Ge`002ML00`3Ge`05e`030=OG00;G0P0Ke`040=OG017G00<0emL0;ML90081
00L09BD09DXU00<000i907Ad07YdNP2NNYh0WP8000VMY9d0WLP0aid02@0_e`030=OG033G00<0emL0
1mL00005e`3Ge`002]L0103GemL300GG00<0emL06]L0103Ge`0Ae`030=OG02cG1P001@40004U0080
018U001@BU00M51d07Yd07ZNNP03WP0709jT0<RNb0020004X`00b0<000?70000100^e`030=OG033G
00<0emL01mL00005e`3Ge`002mL0103Ge`07e`030=OG01_G0P02e`801=L00`3Ge`02e`<00]L00`3G
e`0/e`L000@100410P001BD002E:008000=9M0000g@02@1jM7X0WWZN0002WP8000BTW@2M0`0019g7
0<L702kG00<0emL0<=L00`3Ge`07e`0000GG0=OG0008e`040=OG00;G00<0emL01ML00`3Ge`0Ne`04
0=OG00_G00<0e`00;]L900030@010080015:0500D01dD01dNW@0NYij0003WP0;09jT0<P0b0380<P0
0P000lL0a`020003a`000080;]L00`3Ge`0`e`030=OG00OG0002e`802]L200?G1004e`030=OG01kG
00@0emL02mL00`3G000]e`X000<102D00P002BD09@0U04Ud0002M0L000=jWP000Yh01`2M09d0WLP0
0`000lL0000802gG00<0emL0<=L00`3Ge`07e`006mL201oG00@0emL02=L300;G00<0emL0:mL70009
0@0002D102E:008000E9D01dD0030007M01dWW@0WP030005WZ@0b9h00P001LRMb03800<000?70000
1@0]e`030=OG033G00<0emL01mL001_G00<0emL07]L0103Ge`08e`030=OG00@0;=L800040@000@80
0RD01P0UBRD0B@800g@0201jM7X0WWBN0P002ih0WIjM09g8W@2M008000C7002L1@0]e`030=OG033G
00<0emL01mL001_G00<0emL07]L0103Ge`08e`030=OG00;G00<0emL0:]L;00050BD002D00P000e19
D002000:D01dNW@0M9id00>N00L0WP00b9k8008000NMb000`@31008000?70000100/e`030=OG033G
00<0emL01mL001_G00<0emL07mL200WG10000mL0e`0[e`/000hU000U02D09DXU04Ud00=d01<0NWAj
09idWP2NW@2MWYd0W@2M008000C7002M0P000lL0`00302cG00<0emL0<=L00`3Ge`07e`006mL00`3G
e`0_e`030=OG02[G1P000`400@0200090@00BP1:0519008000]dD01dNW@0M9id0003WP0309jN0080
00RNb0380<P0b0<000C700301@0/e`030=OG033G00<0emL01mL001_G0P0`e`030=OG02[G2@001040
0042008U00P09@1904Ud00=d0180NWAj09idWP2NW@2M09d0WLP20006W@00a`370P000i`0W00202cG
00<0emL0<=L00`3Ge`07e`006mL00`3Ge`0]e`<0:mL:00080@009@1:9DX20008BE00M500M7X700:N
00H0WYh0b9h2000:b9g80<RM0<40`@8000?700000`0[e`030=OG033G00<0emL01mL001_G00<0emL0
;mL00`3Ge`0Ye`X000<102D00P039@0704U:B@19M0030007M01jLgX0WP03000:WYfN09jM09g8W@80
00C70<NM1P000l00000[e`030=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0Ye`D000D10000
0@0200059@00BRD00P000e19D004000;M7Yd07BNM01jWWX00`0019h0W/P20005WLP009d00P000lL0
000802[G00<0emL0<=L00`3Ge`07e`006mL00`3Ge`0_e`030=OG02SG2@000`400002000K9@0U02D0
BDY904Ud07AcM01jLgX0WW>N09jM008000RNW@2M09d0W@<000BMa`371`0Ze`030=OG033G00<0emL0
1mL001_G00<0emL0;mL00`3Ge`0Xe`T000<100400P0022D002E:05190P003gA@07AjM01dWW@0NYij
0003WP8000C80<RM0P000lRM00020003`@2L008000?600000P0Ze`030=OG033G00<0emL01mL001_G
0P0`e`030=OG02SG2`007`409BD09DTU04T0B@19M01dLg@0NW=j09icWP2NWIh00P0029d0WIjM09g7
0P001Id0002L00L0:ML00`3Ge`0`e`030=OG00OG000Ke`030=OG02oG00<0emL09mL700080@0002D1
02D20003BRE:008000U9D01dD01dNW@01@0017ZNNP03WP0709h00<RMb0020004WLP0a`<000C7002L
100Ye`030=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0We`X000D100009@02000<9DTU04U@
B@19M01d0`000gYcNP03000<WP2NWIh0WYd0WIjM0P001lNM00370<40200Ye`030=OG033G00<0emL0
1mL001_G00<0emL0;mL00`3Ge`0Ve`/000<100400P0012D0BRD20006D4U@07A@0P002GYd07BNM01j
WP0200>N00<0WYh00P001Yg80<P0b08000>M00002@0Xe`030=OG033G00<0emL01mL001_G00<0emL0
;mL00`3Ge`0Ve`/000<102D00P002BD09@0U04U@B@04000;M7=d07YcNP2NLih00`002ih0WYd0W@2M
09g1008000NM0000W02L00<000>L0000:=L00`3Ge`0`e`030=OG00OG000Ke`80<=L00`3Ge`0Ue`d0
00<U0@000RD2000FBDX0D4U@07A?07AjM01dWW@0NYij00:N0P02WP030<RM008000G8W@00a`020004
W@00a`L09mL00`3Ge`0`e`030=OG00OG000Ke`030=OG02oG00<0emL09ML<00049@0U008U00L09DTU
04U@00800199M01dLg@0NW=j09icWP2NLih2000?W@2MWYd0WL6M09g10<6L008000?00000100We`03
0=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0Ue`T000D100019@0200069@00BTU:0`004G@0
M4l0M7Yd07BNM01jWWX000>N00L0W@00b9g8008000FMb000W@020004a`00W0H09mL00`3Ge`0`e`03
0=OG00OG0008e`801=L00`3Ge`02e`<01ML00`3Ge`0_e`030=OG02CG3@0052D002D09@0UBBD0BE00
M4Ud07Ac1`004G>N09icWP2NW@2MWYd0W@2M008000G1002L`@020003W00000@09]L00`3Ge`0`e`03
0=OG00OG0007e`040=OG00_G00<0emL00]L00`3Ge`0_e`030=OG02CG3@002@40000UB@1:B@020006
M4T0CgA?0`001g@0M9id07@00`03WP0309fN008000FMb038W@020008a`00W@2M09`702KG00<0emL0
<=L00`3Ge`07e`001mL0103Ge`0;e`030=OG00;G0P0`e`030=OG02?G30000`40000200<U0`001RD0
BE00M0<000]dLg@0M7=d09icWP030006WP2NW@2M0`03W@0609d00<6L2`0Ue`030=OG033G00<0emL0
1mL000OG00@0emL02=L300GG00<0emL0;mL00`3Ge`0Se`/000@U000U0P002TTUB@1:BDX0M4T20003
M7<000=d00T0M9id07BNM0000Yh2000:WIjM09fN0<RMb08000BM09g70`000lL0000502GG00<0emL0
<=L00`3Ge`07e`001mL0103Ge`08e`030=OG00GG00<0emL0;mL00`3Ge`0Se`X000D100009@02008U
0P000bE99@04000CM4Ud07AcM01dLg@0WW>N09icWP030004WP2NW@800Yd00`2M00020004W<40`0T0
9=L00`3Ge`0`e`030=OG00OG0007e`040=OG00SG00<0emL01ML00`3Ge`0_e`030=OG02;G40004BD0
B@1904Y9BP1dB@1cM7<000=d00T0M9id07BNM0000ih00`2MWP020008WIh0`P380<420003W@2M00/0
9=L00`3Ge`0`e`030=OG00OG0008e`802ML400CG00<0emL0;mL00`3Ge`0Re`/000<102D00P0022@0
04TU02E90P002DU@07A9M01dL`07000:Lih0WW>N09jGWP8000BM09fM0P02W@<000K1002L09`602CG
00<0emL0<=L00`3Ge`07e`006mL2033G00<0emL08ML=00039@00008U00l0BBE904X0D01dB@1cM7<0
0`001g<0Liic07<00`03WP0409fNW@8000^N0<:M`P31WL40`@020004W000`08000>L00000P0Se`03
0=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0Qe``000DU00009@0200039DTU008000M90519
D01d00<000]dLg@0M7=d09icWP030007WP2NUih0WP0200>M0P02W@8000C10<6L0P000i`0000402?G
00<0emL0<=L00`3Ge`07e`006mL00`3Ge`0_e`030=OG023G4P0034T0BBE9051904UdB@80015dL`1c
M7<0Liic07>NL`2GWP02000>WIjM09fN0<:M`P310<420004W@00`@D000?000000P0Re`030=OG033G
00<0emL01mL001_G00<0emL0;mL00`3Ge`0Pe`d000TU000T02@09DT00P02B@030500008001=dBG@0
M7=d07AcM02NLih0WW>N00<000BN09jM0P02W@0609d0W@2L0P000id0`@020003W00000@08]L00`3G
e`0`e`030=OG00OG000Ke`030=OG02oG00<0emL07mL?00059@009DT00`0014T0D4T2000IM4T0LgAc
07=dL`1cWW<0Liic09NNU`2MWP020004WIh0WP<000G1W@00`@020003W02L00X08ML00`3Ge`0`e`03
0=OG00OG000Ke`80<=L00`3Ge`0Oe`h000`U000T9B@09DTU04T2000KLdUc07A9M01dLg@0M7=d09ic
WP2NLih0WW>N008000JMWP2MU`03W@0609bM09fL0`000i`00005027G00<0emL0<=L00`3Ge`07e`00
6mL00`3Ge`0_e`030=OG01kG4P0014TU0003B@8000U904UdB@1cM7<03@002INNU`2MWYd0W@030006
WIh009g10P001id00<6L09`02@0Pe`030=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0Nea80
00PT02@09DTU009900H0LdUc07@3000;M7=d07AcM02NLih00`004Yh0WW>N09fGW@2MU`2G09d0UP80
00>M09d02`0Pe`030=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0Mea0000LT9@009DT00099
0P001U1904UdB@80015dL`1cM7<0Liic07>NL`1cWP020007WIjM09fNW@020004WYd0W@8000?1W@00
0P000i`0W0020003`00000D07mL00`3Ge`0`e`030=OG00OG000Ke`030=OG02oG00<0emL07ML@0006
9@0092DT0`001RD0BDT0L`<001=dBG@0M7=d07AcM02NLih0WW>N00<000NN09fGW@2M00<000RMU`2F
WIH0UP8000FL0000W00601oG00<0emL0<=L00`3Ge`07e`006mL00`3Ge`0_e`030=OG01cG400022DT
00199DT00TT01019D4T2000IM4T0LgAc07=dL`1cWW<0Liic07>NL`2GWP020008WIjM09fNW@02W@80
00RM`@00W02L`0D000>L00000P0Ne`030=OG033G00<0emL01mL001_G0P0`e`030=OG01cG4P0012@0
92D200049DT0B@<001]cBG<0M4Ud07AcM01dLg@0WW>N09icWP2NLih00`001Id0WINM008000NG09H0
UP2F00<000FFW000UP0701gG00<0emL0<=L00`3Ge`07e`006mL00`3Ge`0_e`030=OG01_G3`001B@0
02@U00<000A904U90P003G=904UdB@1cM7<0Lg@01`003Iic07>NL`2GWYL0Uih00P001IfNW@2M0080
0Yd20003`I`0008000>L0000200Me`030=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0Je`l0
00`T000T9B@094T0BBD200=900L0LdUc07A900@000Md07AcM01d00@000YcWP2NLih0WG>M0P003iNM
09fG09JMUP2FWIH0UP030003UP0000H07=L00`3Ge`0`e`030=OG00OG000Ke`030=OG02oG00<0emL0
6]LB00069B@004TU0`0024T0BG=904Ud10003g<0LgAc07>NL`1cWW<0L`040008WYL0UijG09L300:M
0P02W@8000NL`@00UP2F00T07=L00`3Ge`0`e`030=OG00OG000Ke`030=OG02oG00<0emL06MLC0007
900T02A90003B@0404U9B@<001Mc07=9L`1dLg@0M7=d07AcM02NLih0W@03000BWG>M09ecW@2MU`2F
09H0UP2F0P000i`000020003UP0000D06mL00`3Ge`0`e`030=OG00OG000Ke`80<=L00`3Ge`0Ie`d0
00<T00000R@20004900UB@800dT00`190002000KBGA907=dL`1cM7<0Liic07>NL`1cWW<0Liic00<0
00FG09NMU`0200:M00H0U`00WIH20004W000UP8000BL002F1@0Je`030=OG033G00<0emL01mL001_G
00<0emL0;mL00`3Ge`0Hea4000DT000T9@030003B@1900990P02B@0O07=9L`1cBG<0M7=d07AcM01d
Lg@0WW>N09ecW@2ML`020005WG>M09d00`002ifF09JMUP2FW02F00<000>F00001@0Je`030=OG033G
00<0emL01mL001_G00<0emL0;mL00`3Ge`0Gea400R@20003BB@000=900<0BDT00P002TUcB@19M4T0
Lg@?000:WW<0Liic09NNU`8000VMU`2GWIL0Uid00P001IJM002F008000FL0000W00701WG00<0emL0
<=L00`3Ge`07e`000]L200CG00<0emL00mL00`3Ge`02e`<01ML00`3Ge`0_e`030=OG01OG4`000b@0
90020003BBA900<000=904T00TT0101cBG<30003L`1c009c00X0M7=d07AcM02G0`002IecW@2MLid0
W@030003WG>M008000>F09H00`000iH000020003UP2F00T06=L00`3Ge`0`e`030=OG00OG00001ML0
emL000WG00<0emL01ML00`3Ge`02e`030=OG02oG00<0emL05]L>0004900T00<T0P000b@0B@02B@0:
04U9B@19LdT0B@<001=cM7<0LgAc07>HL`1cWW<0Liic00<000mc09NNU`2GWIL0UifG09L00`0029JM
09bFW02L0`0019`009H601OG00<0emL0<=L00`3Ge`07e`0000GG0=OG000:e`030=OG00CG00<0emL0
0]L2033G00<0emL05ML@0003900000<T00D094T0B@030004BDQ900=90P001dUc07=9L`000g<03`1d
Lg@0M7=d09McU`2GL`020007WG>M09ecW@030008W@2MLYd0WIH200:F0P000iH0UP0:01OG00<0emL0
<=L00`3Ge`07e`0000GG0=OG000:e`040=OGe`<01ML00`3Ge`0_e`030=OG01GG3@001R@0900T008T
0P0014TT0002B@0604U9B@190`006dUdB@1cM7<0LgAc07>HL`1cWW<0Liic07>NL`030008U`2GWIL0
Uid20003UifG008000NM09`0W02F00<000>F00000P000g80000301KG00<0emL0<=L00`3Ge`07e`00
00GG0=OG000;e`040=OG00OG00<0emL0;mL00`3Ge`0Dea4000<T00000`002dTT0019B4T0BDQ90080
00]9K@1cBG<0LdUc0003L`0C07AcM01dLg@0Ug>G09McU`2GL`020007WG>M09MbU`020004LYd0U`<0
00FF001bUP030003UP2F00P05ML00`3Ge`0`e`030=OG00OG00001ML0emL000SG00@0emL00]L00`3G
e`05e`030=OG02oG00<0emL04mL?0003900T008T00<0B2@00`000dP0B@02B@0304T0008000Y9LdT0
BGA907=d3`002Yic07>NL`1cWW<30007U`2GWIL0U`030007UYfF09JL0003UP0309H0008000>F0000
1@0Ee`030=OG033G00<0emL01mL000;G0P09e`@00]L400CG00<0emL0;mL00`3Ge`0Bea<000<T0000
0R@0201894P0BDQ90P002DQ906e9K@1cB@040003L`1c009c00D0Lg=c0003L`0307<000<000UcU`2G
LiL0Ug<00P002iMbU`2GLYL0Ug:G008000Eb002FLP020003UP2F00T05=L00`3Ge`0`e`030=OG00OG
000Ke`80<=L00`3Ge`0Aea4000<T00000P002B@00018BDP0B@030007BFe904UcB@03000GK@1cM7<0
LgAc07=dL`1cWW<0Liic07<00`001g>NL`1cWG<00`001IL0UifG00<000>F09H01P001iH0002F09H0
1`0Ce`030=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0@ea4000<T00000R@2000694P0B2A8
0P0024Q904U8B@1]0`0027=9L`1cBG<00g<01@1cLg<000=c00P0Lg=c09McU`<000RG09McU`2GLP80
00JGLYL0UW82000:UW:F09Ib06bFK0@000>F00000P000f`0000Be`030=OG033G00<0emL01mL001_G
00<0emL0;mL00`3Ge`0?ea4000DT00009002000594PT04P00`001TQ9B019K@<0025cB@1]Lfd0LgAc
07=dL`1cM7<0Liic07>NL`1cWW<0Lid00`001Yec07>ML`<000FG07:GLP0200:F0P001IH007:F0080
00A/002F1`0Ae`030=OG033G00<0emL01mL001_G00<0emL0;mL00`3Ge`0>eaL000DT04PTB0020006
94P0BDQ90`003TT0LdUc07=9L`1cBG<00g<01@1cLg<000=c00h0Lg=c09McU`2GLiL0U`@000EbU`2G
LP020005UW:F09H00`0019H006`30003K00000X04=L00`3Ge`0`e`030=OG00OG000Ke`030=OG02oG
00@0emOG6`0012@09002900602A8900T0`001DQ9B01800<000i9LdT0BG=906ecK@1cM0l0012NL`1c
WW>N09ec07>ML`1c0P0019d0Ug83000ALP1bUW80LYH0UW:F09I/06`00P000g80000A00?G00<0emL0
<=L00`3Ge`07e`006mL00`3Ge`0]eb@000@T00000b@2000694P0B2A80P003DQ904U8B@1cBG<0LdT0
10000g<0L`02L`0507=cL`000g<00`1c0004000=Ug<0LiMc07>G09MbU`020005LYL0UW800P000iI/
UP060003K00000<00V`00`1/000G033G00<0emL01mL001_G0P0Zeb<000<T00000`02900302@00080
0dP00`180002000:B6d0LdUcB@19L`@001Q]07=dL`1cM7<0LgAc07>HL`1cV7<0LiP4000:Lid0WG>M
09McU`<000BG09Mb0`001780K9H20005K000UV`08P0/e`030=OG00OG000Ke`030=OG02KG9`0012@0
0003908000HTB01894P2009800H0BDP0B4T5000:L`1cBG<0LdUc00=c00D0Lg=c0003L`0507=cL`00
17<00`1c00030009Ug<0LYMb07:G008000EbUP1bK0020003LVab00H000I/001/06`O02WG00<0emL0
1mL001_G00<0emL08mL[008T00<090000P001BA8901800<000I8B@1]B6d3000YLdT0BG=906ecK@1c
M7<0LgAc07=dL`1cV7<0LiQcV02HLiP0Ug>G09L00`001iMcU`2GLYL00`0019L0UW830004K01/UP80
00A/001/0`02K2009]L00`3Ge`07e`006mL00`3Ge`0Pe`/000=800006`001b@0000T02@00P0012@0
94P40003B018009800<0B0000P004DQ]B6d0LdUc07=9L`1cBG<000=c00D0Lg=c0003L`0307=c009c
00D0Lg=c0003L`0407=cL`<000Qb07:GLP1/LP<000AbK01/0P03K0D00V`V02?G00<0emL01mL001_G
00<0emL07ML]008T00<090000P000bA80002009800H0B4P0BDP3000>B6d0LdUc07=9LdT0KG<H000=
LiP0Ug>G09McU`2GL`030008LYL0Ug:G09H30003UV`0008000A/06a/20000dP0000R023G00<0emL0
1mL001_G0P0Le`/000<T000080000b@090020003900T00<000@TB2@00TP4000<B018BDP0B6e804Uc
1@002W<0Lfec07=]L`03L`0507=cL`0017<00`1c0003009c00X0Lg=c079cLP1/10001W9/06abK0<0
00=/06`00P03K0D000=/00000P000dP0000Q01kG00<0emL01mL001_G00<0emL05mL<0003B0000200
00@T000T0P0290<000<TB0000TP4000<B01]B6d0KDQ]07=910000g=]0003L`0K07=cL`1cM7<0LgAc
07>HL`1cV7>H09McU`2G00@000acU`2GLiL0Ug:G07<40005K9H0LV`00`0026`0001/04Q/2@000f`0
000S01[G00<0emL01mL001_G00<0emL05ML`00039000008000TT0000900TB2@00`000dP0B002B007
04Q8B018B@04000CB018LdQc07=9L`1cKG<0Lfec0003L`0507=cL`0017<01@1cLg<000=c00<0K000
0`0037=b06acK01/LV`0K0<00f`00`1800020006B00004Q/<@0Ge`030=OG00OG000Ke`030=OG01;G
<0000b@000030009900004PTB01800<00dP01`18B4P0KDP010002W<0LdUc07=]L`04L`0S07=cL`1c
M7<0LgAc07>HL`1cV7>H09McU`2GLiL0Ug>G07<010002W:G07=/L`1bK7830003LP1/009/10000dP0
00020003K00002h05ML00`3Ge`07e`006mL00`3Ge`0?e``000=800000`000dP0000Q00049000008T
00<092@00`000dPT0003B00304Q800@001]804Q]B018KDP0B7=804UcBG<0Lfec07=]L`000g<01@1c
Lg<000Ac00D0Lg=c0003L`0:06acK01/Lf`0K0@000=bK0000f`00`18K0030005K4P0B6`00`000f`0
B00d01;G00<0emL01mL001_G0P0=e``000=800000`000dP0000O0003900000<000@T04PT1@04B003
04Q800@0011/06e8K@1cB7<0LdUc07=]8@001g>G09McU`000g<01P1cK7<0L`D000=bK0000V`00`1/
00040003K01/00@000A804Q8<`0>e`030=OG00OG000Ke`030=OG00WG30000dP000040003900002`0
00=8900020000dP0B002B00;04Q/B018KDP0B6d010003dP0KG=]L`1cKG<0Lfec0003L`0507=cL`00
17<01P1cLg<0K@@000]cK01/Lf`0K7=/0003K00304Q/00P000A804Q8@00<e`030=OG00OG000Ke`03
0=OG00KG1P000dP000030003B00000@000<T00009@0012@094P80003B01800=800/0K4P0B6a8K01]
B0080006L`1cKG<017<01@1cLg<000=c00D0Lg=c0003L`0307=c009c00D0Lg=c0003L`0307<000P0
00McK01/Lf`000=/00H0B6a804P8009800<09000>P09e`030=OG00OG000Ce`@01=L00`3Ge`03e``0
00=8000010000b@0000/000:901894P0B2A800=800<0B4P02@006dP0B6e804QcB018LdP0KG=]06ec
KG<0Lfec0003L`0507=cL`0017<04`1cLg<0KG=]06acK01/Lf`0B7<020001dQ/06a8K0000dP01P18
B4P0B4801]L00`3Ge`07e`005ML00`3Ge`03e`040=OGe`<000=80000CP005dP0B6a8K01]B6d0Lfac
07=]L`1cKG<000=c00<0Lg<00W<01@1cLg<000=c00D0Lg=c0004L`0507=cL`000g<04`1cLg<0Lfec
07=/Lf`0K7=/04P0E004e`030=OG00OG000Ee`030=OG00?G;009e`d00R@02P0TB2@094PTB003B005
04Q8B0000dP0701/B6`0K4Q/06e8KDP0B7=804QcB01]Lfd0KG<A009c01h0Lg=c06ecK@1/Lfac07=/
L`1cB7<0K4Q/06a8K003B00>04Q8B01894PT02A8900390`02]L/00WG000Ee`030=OG00?G00<0emL0
4=L<00WG0P0He`P00TP06018B4P0K4Q/B018K4P0B6a804Q]B01/La401]L01@22YX8000KG4@0057=]
06acK01/Lf`0B6a8K01/B6`00dP00`18B00901SG0P08e``04mL00`3Ge`07e`005ML00`3Ge`03e`03
0=OG02?G0P0ReaX05mL01@2VPJH001OG6P0Se`809ML00`3Ge`07e`004mL300GG00<0emL08ML205GG
00D0PZJ2001Fe`808mL00`3Ge`07e`005ML00`3Ge`03e`030=OG01oG0P1Ge`050:J1YP00F=L2027G
00<0emL01mL001_G00<0emL07ML205WG00D0PZJ2001Je`807mL00`3Ge`07e`006mL201cG0P1Ke`D0
G=L201gG00<0emL01mL001_G00<0emL06ML20<3G0P0Ke`030=OG00OG000Ke`030=OG01OG0P34e`80
6ML00`3Ge`07e`006mL00`3Ge`0Ee`80b=L201OG00<0emL01mL001_G00<0emL04mL20<cG0P0Ee`03
0=OG00OG000Ke`804]L20=3G0P0Ce`030=OG00OG000Ke`030=OG00oG0P3De`804ML00`3Ge`07e`00
6mL00`3Ge`0=e`80f=L200oG00<0emL01mL001_G00<0emL02mL20=cG0P0=e`030=OG00OG000Ke`03
0=OG00WG0P3Pe`802mL00`3Ge`07e`006mL200SG0P3Te`802ML00`3Ge`07e`006mL00`3Ge`05e`80
j=L200OG00<0emL01mL001_G00<0emL00mL20>cG0P05e`030=OG00OG000Ke`040=OGe`80l=L200?G
00<0emL01mL001_G00@0e`00m=L20003e`3G00SG000Keo`02ML00?oG8ML00?oG8ML00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.108143, 0.25147, 0.0039849, \
0.00318792}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{810, 763},
WindowMargins->{{67, Automatic}, {Automatic, 105}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 1178, 19, 446, "Input"],

Cell[CellGroupData[{
Cell[2908, 73, 193, 6, 72, "Input"],
Cell[3104, 81, 10365, 438, 152, 4064, 356, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[13484, 522, 309, 9, 132, "Input"],
Cell[13796, 533, 82, 5, 52, "Input"],

Cell[CellGroupData[{
Cell[13903, 542, 39, 1, 32, "Input"],
Cell[13945, 545, 54, 1, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14036, 551, 247, 9, 132, "Input"],
Cell[14286, 562, 345, 6, 41, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14668, 573, 430, 14, 232, "Input"],
Cell[15101, 589, 218, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15356, 597, 61, 2, 32, "Input"],
Cell[15420, 601, 59, 1, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15516, 607, 328, 7, 101, "Input"],
Cell[15847, 616, 11459, 479, 152, 4781, 392, "GraphicsData", "PostScript", \
"Graphics"],
Cell[27309, 1097, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27483, 1105, 81, 2, 32, "Input"],
Cell[27567, 1109, 11007, 469, 152, 4463, 384, "GraphicsData", "PostScript", \
"Graphics"],
Cell[38577, 1580, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38744, 1588, 223, 7, 92, "Input"],
Cell[38970, 1597, 285160, 7140, 152, 258950, 6812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[324133, 8739, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[324307, 8747, 92, 2, 32, "Input"],
Cell[324402, 8751, 281514, 7069, 152, 259076, 6787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[605919, 15822, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[606093, 15830, 92, 2, 32, "Input"],
Cell[606188, 15834, 262992, 6608, 152, 243974, 6369, "GraphicsData", \
"PostScript", "Graphics"],
Cell[869183, 22444, 137, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

