(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    375909,      10316]*)
(*NotebookOutlinePosition[    376539,      10338]*)
(*  CellTagsIndexPosition[    376495,      10334]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \( (*\ c48 : \ 
        Corner\ in\ a\ boundary\ curve\ of\ a\ membrane\ *) \)], "Input"],

Cell[CellGroupData[{

Cell["\<\
(*Program Corner: Calculation  of a square mem-
brane, with  a smaller square cut out.
Inhomogeneous boundary condition, const = 1 on y=1
for x from 1 to -1 and sin(Pi*y/2) for x=1, -1<y<1.
Symmetric solution around diagonal.
Choice of collocation points, setup of
matrix m :*)
Clear[n,b,dx,dy,x,y,plot1,T,G]
n=9;b=2.; dx=2*b/(n-1);
dy=b/(n-1);
Table[{x[i]=b/2.,y[i]=(i-1)*dy},{i,1,n-4}];
Table[{x[i]=b/2.-(i-5)*dx,y[i]=b/2.},{i,n-3,n}];
T=Table[{x[i],y[i]},{i,1,n}]
L=Table[{{b/2.,0},{b/2.,b/2.},{-b/2.,b/2.},{-b/2.,-b/2.},
{0.,-b/2.},{0.,0.},{b/2.,0.}}];
G=Graphics[Line[L], AspectRatio->1]
plot1=ListPlot[Table[{x[i],y[i]},{i,1,n}],
PlotStyle->PointSize[1/40],AspectRatio->1.,
DisplayFunction->Identity]
SG=Show[G,plot1,DisplayFunction->$DisplayFunction]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \({{1.`, 0}, {1.`, 0.25`}, {1.`, 0.5`}, {1.`, 0.75`}, {1.`, 1.`}, {0.5`, 
        1.`}, {0.`, 1.`}, {\(-0.5`\), 1.`}, {\(-1.`\), 1.`}}\)], "Output"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .5 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.97619 .5 L
s
.025 w
.97619 .5 Mdot
.97619 .61905 Mdot
.97619 .7381 Mdot
.97619 .85714 Mdot
.97619 .97619 Mdot
.7381 .97619 Mdot
.5 .97619 Mdot
.2619 .97619 Mdot
.02381 .97619 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016PP10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG6mL00?oG6mL00?oG6mL00?oG6mL00?oG
6mL00?oG6mL00?oG6mL000KGQ`2=e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
RmL000KG00<0emL0PmL00`3Ge`2;e`001]L00`3Ge`23e`030=OG08_G0006e`030=OG08?G00<0emL0
P]L400GG0006e`030=OG08?G00<0emL0PML600CG0006e`030=OG08?G00<0emL0PML600CG0006e`03
0=OG08?GRP04e`001]L00`3Ge`3oe`SG1P04e`001]L00`3Ge`3oe`WG1005e`001]L00`3Ge`3oe`[G
00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3G
e`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`00
1]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3G
e`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG
2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`03
0=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG
0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`03
0=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0
omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG
00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`WG1005e`00
1]L00`3Ge`3oe`SG1P04e`001]L00`3Ge`3oe`SG1P04e`001]L00`3Ge`3oe`SG1P04e`001]L00`3G
e`3oe`SG1P04e`001]L00`3Ge`3oe`WG1005e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0
omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG
00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL0
1ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G
00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3G
e`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`00
1]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3G
e`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG
2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`03
0=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG
0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL9e`@0
1ML000KG00<0emL0omL8e`H01=L000KG00<0emL0omL8e`H01=L000KG00<0emL0omL8e`H01=L000KG
00<0emL0omL8e`H01=L000KG00<0emL0omL9e`@01ML000KG00<0emL0omL:e`030=OG00GG0006e`03
0=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG
0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`03
0=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0
omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG
00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL0
1ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G
00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3G
e`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`00
1]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3G
e`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL9e`@01ML000KG00<0emL0omL8e`H0
1=L000KG00<0emL0omL8e`H01=L000KG00<0emL0omL8e`H01=L000KG00<0emL0omL8e`H01=L000KG
00<0emL0omL9e`@01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`00
1]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3G
e`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG
2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0006e`03
0=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`030=OG00GG
0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0omL:e`03
0=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG00<0emL0
omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL01ML000KG
00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G00<0emL0
1ML000KG00<0emL0omL:e`030=OG00GG0006e`030=OG0?oG2]L00`3Ge`05e`001]L00`3Ge`3oe`[G
00<0emL01ML000KG00<0emL0omL:e`030=OG00GG0005e`@0?mL403oG100oe`@0?mL400GG0004e`H0
?ML603gG1P0me`H0?ML600CG0004e`H0?ML603gG1P0me`H0?ML600CG0004eol04`04e`001=L603gG
1P0me`H0?ML603gG1P04e`001ML403oG100oe`@0?mL403oG1005e`00omLKe`00omLKe`00omLKe`00
omLKe`00\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-1.05001, -1.05001, 0.00747339, \
0.00747339}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
(* Transformation from Cartesian to polar
coordinates for use in Bessel functions,
Setup of the matrix m *)
Clear[f,r];m=Table[m[[k,l]]=k*l,{k,1,n},{l,1,n}];

Table[f[l]=ArcTan[x[l],y[l]],{l,1,n}];
Table[r[l]=Sqrt[x[l]^2+y[l]^2],{l,1,n}];
m=Table[m[[k,l]]=BesselJ[2*(2*k-1)/3,r[l]]*
Sin[2*(2*k-1)*f[l]/3],{l,1,n},{k,1,n}];
Det[m];\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell["MatrixForm[m];", "Input",
  FontSize->18],

Cell[CellGroupData[{

Cell["\<\
(* Definition of the two inhomogeneous
boundary conditions  and solution of the 
linear equations for the partial amplitudes A *)
Clear[b,kolist,A];

b={N[Sin[Pi*y[1]/2.]],N[Sin[Pi*y[2]/2.]],
N[Sin[Pi*y[3]/2.]],N[Sin[Pi*y[4]/2.]],N[Sin[Pi*y[5]/2]],1,1,1,1}
LinearSolve[m,b];
kolist=%;
Table[A[k]=kolist[[k]],{k,1,9}]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->18],

Cell[BoxData[
    \({0.`, 0.3826834323650898`, 0.7071067811865475`, 0.9238795325112867`, 
      1.`, 1, 1, 1, 1}\)], "Output"],

Cell[BoxData[
    \({1.988154025368144`, 2.0227233042951887`, 5.005849935017153`, 
      30.474335358742334`, 
      601.0246903943033`, \(-831.5977140682664`\), \(-52615.266530012246`\), 
      480920.6441357887`, 0.`}\)], "Output"]
}, Open  ]],

Cell["\<\
r[x_,y_]:=N[Sqrt[x^2+y^2]]
f[x_,y_]:=N[ArcTan[x,y]] /;y>=0 ; 
f[x_,y_]:=2*Pi+N[ArcTan[x,y]] /; y<0
fxy[x_,y_]:=Sum[A[k]*BesselJ[2*(2*k-1)/3,r[x,y]]*
Sin[2*(2*k-1)*f[x,y]/3],{k,1,8}]\
\>", "Input",
  FontSize->18],

Cell[BoxData[
    \(TraditionalForm\`fxy(x_, 
        y_) := \[Sum]\+\(k = 1\)\%8\( A(
            k)\)\ \(\(J\_\(2\/3\ \((2\ k - 1)\)\)\)(r(x, y))\)\ \(sin(
            2\/3\ \((2\ k - 1)\)\ \(f(x, y)\))\)\)], "Input",
  FontSize->18],

Cell[CellGroupData[{

Cell["Table[fxy[x[i],y[i]],{i,1,n}]", "Input",
  FontSize->18],

Cell[BoxData[
    \({0.`, 0.38268343236508984`, 0.7071067811865475`, 0.9238795325112868`, 
      0.9999999999999999`, 0.9999999999999999`, 1.`, 0.9999999999999999`, 
      1.`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["fxy[x[9],y[9]]", "Input",
  FontSize->18],

Cell[BoxData[
    \(1.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(* Definition of r(x,y,) and f=phi(x,y) for the
plot in cartesian coordinates *)Clear[r,f,plot2]
r[x_,y_]:=N[Sqrt[x^2+y^2]]
f[x_,y_]:=N[ArcTan[x,y]] /;y>=0 ; 
f[x_,y_]:=2*Pi+N[ArcTan[x,y]] /; y<0
GG[x_,y_]:=Sum[A[k]*BesselJ[2*(2*k-1)/3,r[x,y]]*
Sin[2*(2*k-1)*f[x,y]/3],{k,1,8}]
plot2=Plot3D[{GG[x,y],Hue[0.4*GG[x,y]]},
{x,-1.1,1.1},{y,-1.1,1.1}, PlotRange->{0.,1.05},
PlotPoints->15,Mesh->False,ClipFill->None] \
\>", "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.054 .23578 -12 -8.77849 ]
[.054 .23578 0 .22151 ]
[.19044 .18208 -23.484 -9 ]
[.19044 .18208 .51596 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.48682 .06553 -15.9072 -9 ]
[.48682 .06553 2.09282 0 ]
[.64814 .00214 -5.01809 -9 ]
[.64814 .00214 .98191 0 ]
[.71662 .0192 0 -6.23824 ]
[.71662 .0192 12 2.76176 ]
[.79014 .13178 0 -6.12821 ]
[.79014 .13178 24 2.87179 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.91668 .32556 0 -5.94523 ]
[.91668 .32556 18 3.05477 ]
[.97152 .40955 0 -5.86834 ]
[.97152 .40955 6 3.13166 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01654 .31258 -24 -2.78245 ]
[.01654 .31258 0 6.21755 ]
[.00784 .36708 -18 -2.82867 ]
[.00784 .36708 0 6.17133 ]
[-0.00116 .42352 -24 -2.8767 ]
[-0.00116 .42352 0 6.1233 ]
[-0.01049 .48199 -6 -2.92665 ]
[-0.01049 .48199 0 6.07335 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.06351 .24482 m
.06826 .24934 L
s
[(-1)] .054 .23578 1 .95078 Mshowa
.19951 .19156 m
.20405 .1963 L
s
[(-0.5)] .19044 .18208 .957 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.49481 .07594 m
.4988 .08114 L
s
[(0.5)] .48682 .06553 .76746 1 Mshowa
.65547 .01303 m
.65913 .01847 L
s
[(1)] .64814 .00214 .6727 1 Mshowa
.125 Mabswid
.09013 .23439 m
.09296 .23713 L
s
.11704 .22386 m
.11985 .22662 L
s
.14424 .21321 m
.14702 .216 L
s
.17173 .20244 m
.17448 .20526 L
s
.2276 .18057 m
.23029 .18344 L
s
.25599 .16945 m
.25866 .17235 L
s
.2847 .15821 m
.28733 .16113 L
s
.31372 .14684 m
.31632 .1498 L
s
.37274 .12374 m
.37527 .12675 L
s
.40274 .11199 m
.40524 .11502 L
s
.43308 .10011 m
.43555 .10317 L
s
.46377 .08809 m
.4662 .09118 L
s
.5262 .06364 m
.52856 .0668 L
s
.55796 .05121 m
.56028 .05439 L
s
.59008 .03863 m
.59236 .04184 L
s
.62258 .0259 m
.62482 .02914 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.70438 .02393 m
.69826 .0263 L
s
[(-1)] .71662 .0192 -1 .38628 Mshowa
.7778 .13624 m
.77163 .13848 L
s
[(-0.5)] .79014 .13178 -1 .36182 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.90419 .32957 m
.89794 .33158 L
s
[(0.5)] .91668 .32556 -1 .32116 Mshowa
.95897 .41336 m
.95269 .41527 L
s
[(1)] .97152 .40955 -1 .30408 Mshowa
.125 Mabswid
.71969 .04735 m
.71602 .04876 L
s
.73468 .07028 m
.731 .07167 L
s
.74936 .09273 m
.74567 .0941 L
s
.76373 .11471 m
.76003 .11606 L
s
.7916 .15734 m
.78789 .15866 L
s
.80511 .17801 m
.8014 .17932 L
s
.81836 .19827 m
.81464 .19957 L
s
.83134 .21814 m
.82762 .21942 L
s
.85656 .25671 m
.85283 .25797 L
s
.86881 .27545 m
.86507 .27669 L
s
.88083 .29383 m
.87709 .29506 L
s
.89262 .31187 m
.88887 .31308 L
s
.91555 .34695 m
.9118 .34814 L
s
.9267 .364 m
.92295 .36518 L
s
.93765 .38075 m
.93389 .38192 L
s
.94841 .39721 m
.94464 .39836 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.0288 .30791 m
.03493 .30557 L
s
[(0.25)] .01654 .31258 1 -0.38168 Mshowa
.02014 .36251 m
.02629 .36023 L
s
[(0.5)] .00784 .36708 1 -0.37141 Mshowa
.01118 .41906 m
.01735 .41684 L
s
[(0.75)] -0.00116 .42352 1 -0.36073 Mshowa
.0019 .47766 m
.00809 .47549 L
s
[(1)] -0.01049 .48199 1 -0.34963 Mshowa
.125 Mabswid
.03551 .26555 m
.03918 .26412 L
s
.03385 .27603 m
.03752 .27461 L
s
.03218 .28658 m
.03585 .28517 L
s
.03049 .29721 m
.03417 .2958 L
s
.02709 .31868 m
.03077 .31728 L
s
.02537 .32952 m
.02906 .32813 L
s
.02364 .34044 m
.02733 .33906 L
s
.0219 .35144 m
.02559 .35006 L
s
.01838 .37367 m
.02207 .3723 L
s
.0166 .3849 m
.02029 .38354 L
s
.01481 .3962 m
.0185 .39485 L
s
.013 .40759 m
.0167 .40625 L
s
.00935 .43061 m
.01306 .42929 L
s
.00751 .44225 m
.01122 .44093 L
s
.00565 .45397 m
.00936 .45265 L
s
.00378 .46577 m
.00749 .46446 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
0 1 .363 r
.39288 .79262 .39839 .79628 .40752 .79468 .40203 .79107 Mtetra
0 1 .371 r
.40203 .79107 .40752 .79468 .41669 .79292 .41121 .78936 Mtetra
0 1 .378 r
.41121 .78936 .41669 .79292 .4259 .79101 .42044 .7875 Mtetra
0 1 .384 r
.42044 .7875 .4259 .79101 .43514 .78896 .42971 .7855 Mtetra
0 1 .388 r
.42971 .7855 .43514 .78896 .44443 .78678 .43901 .78336 Mtetra
0 1 .391 r
.43901 .78336 .44443 .78678 .45374 .78448 .44835 .78109 Mtetra
0 1 .392 r
.44835 .78109 .45374 .78448 .4631 .78207 .45773 .77872 Mtetra
0 1 .393 r
.45773 .77872 .4631 .78207 .47248 .77957 .46714 .77625 Mtetra
0 1 .392 r
.46714 .77625 .47248 .77957 .4819 .77701 .47658 .7737 Mtetra
0 1 .391 r
.47658 .7737 .4819 .77701 .49135 .77439 .48605 .77108 Mtetra
0 1 .39 r
.48605 .77108 .49135 .77439 .50084 .77174 .49556 .76842 Mtetra
0 1 .388 r
.49556 .76842 .50084 .77174 .51035 .76908 .5051 .76573 Mtetra
0 1 .387 r
.5051 .76573 .51035 .76908 .5199 .76642 .51468 .76302 Mtetra
0 1 .385 r
.51468 .76302 .5199 .76642 .52948 .76377 .52429 .76032 Mtetra
0 1 .384 r
.52429 .76032 .52948 .76377 .5391 .76117 .53392 .75763 Mtetra
0 1 .383 r
.53392 .75763 .5391 .76117 .54874 .7586 .5436 .75497 Mtetra
0 1 .382 r
.5436 .75497 .54874 .7586 .55843 .7561 .5533 .75235 Mtetra
0 1 .383 r
.5533 .75235 .55843 .7561 .56814 .75367 .56305 .74977 Mtetra
0 1 .384 r
.56305 .74977 .56814 .75367 .5779 .7513 .57282 .74725 Mtetra
0 1 .386 r
.57282 .74725 .5779 .7513 .58769 .74902 .58263 .74479 Mtetra
0 1 .389 r
.58263 .74479 .58769 .74902 .59752 .74682 .59248 .74239 Mtetra
0 1 .393 r
.59248 .74239 .59752 .74682 .60738 .74469 .60237 .74005 Mtetra
0 1 .397 r
.60237 .74005 .60738 .74469 .61729 .74264 .6123 .73777 Mtetra
0 1 .403 r
.6123 .73777 .61729 .74264 .62724 .74066 .62226 .73554 Mtetra
0 1 .409 r
.62226 .73554 .62724 .74066 .63723 .73875 .63227 .73337 Mtetra
0 1 .415 r
.63227 .73337 .63723 .73875 .64726 .73688 .64231 .73124 Mtetra
0 1 .423 r
.64231 .73124 .64726 .73688 .65733 .73505 .65239 .72915 Mtetra
0 1 .43 r
.65239 .72915 .65733 .73505 .66745 .73325 .66252 .72707 Mtetra
0 1 .438 r
.66252 .72707 .66745 .73325 .6776 .73146 .67269 .725 Mtetra
0 1 .447 r
.67269 .725 .6776 .73146 .6878 .72965 .68289 .72293 Mtetra
0 1 .455 r
.68289 .72293 .6878 .72965 .69804 .72783 .69314 .72084 Mtetra
0 1 .462 r
.69314 .72084 .69804 .72783 .70832 .72596 .70342 .71871 Mtetra
0 1 .47 r
.70342 .71871 .70832 .72596 .71864 .72402 .71375 .71653 Mtetra
0 1 .476 r
.71375 .71653 .71864 .72402 .72899 .722 .72411 .71429 Mtetra
0 1 .482 r
.72411 .71429 .72899 .722 .73938 .71988 .73451 .71196 Mtetra
0 1 .487 r
.73451 .71196 .73938 .71988 .74981 .71765 .74494 .70954 Mtetra
0 1 .491 r
.74494 .70954 .74981 .71765 .76027 .71528 .7554 .70702 Mtetra
0 1 .493 r
.7554 .70702 .76027 .71528 .77076 .71277 .7659 .70438 Mtetra
0 1 .495 r
.7659 .70438 .77076 .71277 .78127 .71009 .77643 .70161 Mtetra
0 1 .494 r
.77643 .70161 .78127 .71009 .79182 .70725 .78699 .69871 Mtetra
0 1 .493 r
.78699 .69871 .79182 .70725 .80239 .70424 .79758 .69568 Mtetra
0 1 .489 r
.79758 .69568 .80239 .70424 .81298 .70106 .8082 .69252 Mtetra
0 1 .484 r
.8082 .69252 .81298 .70106 .8236 .6977 .81884 .68922 Mtetra
0 1 .478 r
.81884 .68922 .8236 .6977 .83424 .69418 .82951 .6858 Mtetra
0 1 .471 r
.82951 .6858 .83424 .69418 .84491 .6905 .84021 .68227 Mtetra
0 1 .462 r
.84021 .68227 .84491 .6905 .85559 .68669 .85093 .67865 Mtetra
0 1 .452 r
.85093 .67865 .85559 .68669 .8663 .68276 .86168 .67495 Mtetra
0 1 .441 r
.86168 .67495 .8663 .68276 .87703 .67875 .87247 .67121 Mtetra
0 1 .43 r
.87247 .67121 .87703 .67875 .88779 .67467 .88329 .66745 Mtetra
0 1 .419 r
.88329 .66745 .88779 .67467 .89859 .67057 .89415 .66371 Mtetra
0 1 .409 r
.89415 .66371 .89859 .67057 .90942 .6665 .90505 .66003 Mtetra
0 1 .399 r
.90505 .66003 .90942 .6665 .92029 .6625 .916 .65646 Mtetra
0 1 .39 r
.916 .65646 .92029 .6625 .93121 .65862 .92701 .65304 Mtetra
0 1 .384 r
.92701 .65304 .93121 .65862 .94219 .65492 .93808 .64984 Mtetra
0 1 .379 r
.93808 .64984 .94219 .65492 .95324 .65146 .94922 .6469 Mtetra
.94922 .6469 .95324 .65146 .96437 .64833 .96046 .64431 Mtetra
0 1 .382 r
.96046 .64431 .96437 .64833 .97559 .64557 .97179 .64211 Mtetra
0 1 .389 r
.97179 .64211 .97559 .64557 .98692 .64329 .98323 .6404 Mtetra
0 1 .403 r
.98323 .6404 .98692 .64329 .99837 .64155 .9948 .63924 Mtetra
0 1 .371 r
.38734 .78879 .39288 .79262 .40203 .79107 .3965 .78728 Mtetra
0 1 .381 r
.3965 .78728 .40203 .79107 .41121 .78936 .40571 .78562 Mtetra
0 1 .389 r
.40571 .78562 .41121 .78936 .42044 .7875 .41495 .78381 Mtetra
0 1 .395 r
.41495 .78381 .42044 .7875 .42971 .7855 .42424 .78184 Mtetra
0 1 .399 r
.42424 .78184 .42971 .7855 .43901 .78336 .43356 .77973 Mtetra
0 1 .403 r
.43356 .77973 .43901 .78336 .44835 .78109 .44293 .77749 Mtetra
0 1 .405 r
.44293 .77749 .44835 .78109 .45773 .77872 .45232 .77514 Mtetra
.45232 .77514 .45773 .77872 .46714 .77625 .46175 .77267 Mtetra
.46175 .77267 .46714 .77625 .47658 .7737 .47122 .77012 Mtetra
.47122 .77012 .47658 .7737 .48605 .77108 .48072 .76749 Mtetra
0 1 .403 r
.48072 .76749 .48605 .77108 .49556 .76842 .49026 .7648 Mtetra
0 1 .401 r
.49026 .7648 .49556 .76842 .5051 .76573 .49982 .76206 Mtetra
0 1 .399 r
.49982 .76206 .5051 .76573 .51468 .76302 .50942 .7593 Mtetra
0 1 .397 r
.50942 .7593 .51468 .76302 .52429 .76032 .51905 .75652 Mtetra
0 1 .395 r
.51905 .75652 .52429 .76032 .53392 .75763 .52872 .75373 Mtetra
0 1 .393 r
.52872 .75373 .53392 .75763 .5436 .75497 .53841 .75096 Mtetra
0 1 .392 r
.53841 .75096 .5436 .75497 .5533 .75235 .54814 .74821 Mtetra
0 1 .391 r
.54814 .74821 .5533 .75235 .56305 .74977 .55791 .74548 Mtetra
.55791 .74548 .56305 .74977 .57282 .74725 .56771 .7428 Mtetra
.56771 .7428 .57282 .74725 .58263 .74479 .57754 .74015 Mtetra
0 1 .392 r
.57754 .74015 .58263 .74479 .59248 .74239 .58741 .73755 Mtetra
0 1 .394 r
.58741 .73755 .59248 .74239 .60237 .74005 .59732 .735 Mtetra
0 1 .396 r
.59732 .735 .60237 .74005 .6123 .73777 .60726 .73249 Mtetra
0 1 .399 r
.60726 .73249 .6123 .73777 .62226 .73554 .61724 .73003 Mtetra
0 1 .403 r
.61724 .73003 .62226 .73554 .63227 .73337 .62726 .72761 Mtetra
0 1 .407 r
.62726 .72761 .63227 .73337 .64231 .73124 .63732 .72522 Mtetra
0 1 .411 r
.63732 .72522 .64231 .73124 .65239 .72915 .64742 .72286 Mtetra
0 1 .416 r
.64742 .72286 .65239 .72915 .66252 .72707 .65755 .72052 Mtetra
0 1 .422 r
.65755 .72052 .66252 .72707 .67269 .725 .66773 .71819 Mtetra
0 1 .427 r
.66773 .71819 .67269 .725 .68289 .72293 .67794 .71586 Mtetra
0 1 .432 r
.67794 .71586 .68289 .72293 .69314 .72084 .6882 .71352 Mtetra
0 1 .438 r
.6882 .71352 .69314 .72084 .70342 .71871 .69849 .71115 Mtetra
0 1 .442 r
.69849 .71115 .70342 .71871 .71375 .71653 .70882 .70874 Mtetra
0 1 .447 r
.70882 .70874 .71375 .71653 .72411 .71429 .71919 .70629 Mtetra
0 1 .451 r
.71919 .70629 .72411 .71429 .73451 .71196 .72959 .70377 Mtetra
0 1 .454 r
.72959 .70377 .73451 .71196 .74494 .70954 .74003 .70118 Mtetra
0 1 .456 r
.74003 .70118 .74494 .70954 .7554 .70702 .75051 .69851 Mtetra
0 1 .457 r
.75051 .69851 .7554 .70702 .7659 .70438 .76101 .69575 Mtetra
0 1 .458 r
.76101 .69575 .7659 .70438 .77643 .70161 .77155 .69289 Mtetra
0 1 .457 r
.77155 .69289 .77643 .70161 .78699 .69871 .78213 .68994 Mtetra
0 1 .455 r
.78213 .68994 .78699 .69871 .79758 .69568 .79273 .68688 Mtetra
0 1 .452 r
.79273 .68688 .79758 .69568 .8082 .69252 .80337 .68373 Mtetra
0 1 .448 r
.80337 .68373 .8082 .69252 .81884 .68922 .81403 .68049 Mtetra
0 1 .442 r
.81403 .68049 .81884 .68922 .82951 .6858 .82473 .67716 Mtetra
0 1 .436 r
.82473 .67716 .82951 .6858 .84021 .68227 .83546 .67376 Mtetra
0 1 .429 r
.83546 .67376 .84021 .68227 .85093 .67865 .84622 .6703 Mtetra
0 1 .422 r
.84622 .6703 .85093 .67865 .86168 .67495 .85702 .66681 Mtetra
0 1 .414 r
.85702 .66681 .86168 .67495 .87247 .67121 .86785 .66331 Mtetra
0 1 .406 r
.86785 .66331 .87247 .67121 .88329 .66745 .87872 .65984 Mtetra
0 1 .399 r
.87872 .65984 .88329 .66745 .89415 .66371 .88964 .65641 Mtetra
0 1 .392 r
.88964 .65641 .89415 .66371 .90505 .66003 .90061 .65309 Mtetra
0 1 .387 r
.90061 .65309 .90505 .66003 .916 .65646 .91163 .6499 Mtetra
0 1 .383 r
.91163 .6499 .916 .65646 .92701 .65304 .92271 .64689 Mtetra
0 1 .381 r
.92271 .64689 .92701 .65304 .93808 .64984 .93387 .64412 Mtetra
0 1 .383 r
.93387 .64412 .93808 .64984 .94922 .6469 .9451 .64165 Mtetra
0 1 .387 r
.9451 .64165 .94922 .6469 .96046 .64431 .95643 .63953 Mtetra
0 1 .396 r
.95643 .63953 .96046 .64431 .97179 .64211 .96786 .63782 Mtetra
0 1 .41 r
.96786 .63782 .97179 .64211 .98323 .6404 .9794 .6366 Mtetra
0 1 .429 r
.9794 .6366 .98323 .6404 .9948 .63924 .99108 .63594 Mtetra
0 1 .378 r
.38176 .78479 .38734 .78879 .3965 .78728 .39094 .78333 Mtetra
0 1 .389 r
.39094 .78333 .3965 .78728 .40571 .78562 .40017 .78171 Mtetra
0 1 .397 r
.40017 .78171 .40571 .78562 .41495 .78381 .40943 .77993 Mtetra
0 1 .404 r
.40943 .77993 .41495 .78381 .42424 .78184 .41874 .77799 Mtetra
0 1 .409 r
.41874 .77799 .42424 .78184 .43356 .77973 .42808 .7759 Mtetra
0 1 .412 r
.42808 .7759 .43356 .77973 .44293 .77749 .43747 .77368 Mtetra
0 1 .415 r
.43747 .77368 .44293 .77749 .45232 .77514 .44689 .77132 Mtetra
0 1 .416 r
.44689 .77132 .45232 .77514 .46175 .77267 .45634 .76885 Mtetra
.45634 .76885 .46175 .77267 .47122 .77012 .46583 .76628 Mtetra
0 1 .415 r
.46583 .76628 .47122 .77012 .48072 .76749 .47536 .76361 Mtetra
0 1 .413 r
.47536 .76361 .48072 .76749 .49026 .7648 .48491 .76088 Mtetra
0 1 .411 r
.48491 .76088 .49026 .7648 .49982 .76206 .4945 .75809 Mtetra
0 1 .409 r
.4945 .75809 .49982 .76206 .50942 .7593 .50413 .75525 Mtetra
0 1 .406 r
.50413 .75525 .50942 .7593 .51905 .75652 .51378 .75238 Mtetra
0 1 .403 r
.51378 .75238 .51905 .75652 .52872 .75373 .52347 .74949 Mtetra
0 1 .4 r
.52347 .74949 .52872 .75373 .53841 .75096 .53319 .74659 Mtetra
0 1 .398 r
.53319 .74659 .53841 .75096 .54814 .74821 .54295 .7437 Mtetra
0 1 .395 r
.54295 .7437 .54814 .74821 .55791 .74548 .55273 .74082 Mtetra
0 1 .394 r
.55273 .74082 .55791 .74548 .56771 .7428 .56255 .73796 Mtetra
0 1 .392 r
.56255 .73796 .56771 .7428 .57754 .74015 .57241 .73513 Mtetra
0 1 .391 r
.57241 .73513 .57754 .74015 .58741 .73755 .5823 .73232 Mtetra
.5823 .73232 .58741 .73755 .59732 .735 .59222 .72956 Mtetra
.59222 .72956 .59732 .735 .60726 .73249 .60218 .72682 Mtetra
.60218 .72682 .60726 .73249 .61724 .73003 .61218 .72412 Mtetra
0 1 .393 r
.61218 .72412 .61724 .73003 .62726 .72761 .62221 .72146 Mtetra
0 1 .394 r
.62221 .72146 .62726 .72761 .63732 .72522 .63229 .71882 Mtetra
0 1 .396 r
.63229 .71882 .63732 .72522 .64742 .72286 .6424 .71621 Mtetra
0 1 .399 r
.6424 .71621 .64742 .72286 .65755 .72052 .65254 .71362 Mtetra
0 1 .401 r
.65254 .71362 .65755 .72052 .66773 .71819 .66273 .71103 Mtetra
0 1 .404 r
.66273 .71103 .66773 .71819 .67794 .71586 .67295 .70845 Mtetra
0 1 .407 r
.67295 .70845 .67794 .71586 .6882 .71352 .68321 .70587 Mtetra
0 1 .41 r
.68321 .70587 .6882 .71352 .69849 .71115 .69351 .70327 Mtetra
0 1 .412 r
.69351 .70327 .69849 .71115 .70882 .70874 .70385 .70064 Mtetra
0 1 .415 r
.70385 .70064 .70882 .70874 .71919 .70629 .71422 .69798 Mtetra
0 1 .417 r
.71422 .69798 .71919 .70629 .72959 .70377 .72464 .69528 Mtetra
0 1 .418 r
.72464 .69528 .72959 .70377 .74003 .70118 .73508 .69253 Mtetra
0 1 .419 r
.73508 .69253 .74003 .70118 .75051 .69851 .74557 .68972 Mtetra
.74557 .68972 .75051 .69851 .76101 .69575 .75609 .68684 Mtetra
.75609 .68684 .76101 .69575 .77155 .69289 .76664 .6839 Mtetra
0 1 .417 r
.76664 .6839 .77155 .69289 .78213 .68994 .77722 .68089 Mtetra
0 1 .415 r
.77722 .68089 .78213 .68994 .79273 .68688 .78785 .67782 Mtetra
0 1 .412 r
.78785 .67782 .79273 .68688 .80337 .68373 .7985 .67467 Mtetra
0 1 .409 r
.7985 .67467 .80337 .68373 .81403 .68049 .80919 .67147 Mtetra
0 1 .404 r
.80919 .67147 .81403 .68049 .82473 .67716 .81991 .66822 Mtetra
0 1 .4 r
.81991 .66822 .82473 .67716 .83546 .67376 .83067 .66493 Mtetra
0 1 .394 r
.83067 .66493 .83546 .67376 .84622 .6703 .84146 .66162 Mtetra
0 1 .389 r
.84146 .66162 .84622 .6703 .85702 .66681 .8523 .65831 Mtetra
0 1 .384 r
.8523 .65831 .85702 .66681 .86785 .66331 .86317 .65503 Mtetra
0 1 .379 r
.86317 .65503 .86785 .66331 .87872 .65984 .87409 .6518 Mtetra
0 1 .375 r
.87409 .6518 .87872 .65984 .88964 .65641 .88506 .64866 Mtetra
0 1 .372 r
.88506 .64866 .88964 .65641 .90061 .65309 .89609 .64564 Mtetra
0 1 .37 r
.89609 .64564 .90061 .65309 .91163 .6499 .90717 .64279 Mtetra
.90717 .64279 .91163 .6499 .92271 .64689 .91832 .64014 Mtetra
0 1 .373 r
.91832 .64014 .92271 .64689 .93387 .64412 .92955 .63775 Mtetra
0 1 .379 r
.92955 .63775 .93387 .64412 .9451 .64165 .94086 .63568 Mtetra
0 1 .389 r
.94086 .63568 .9451 .64165 .95643 .63953 .95227 .63397 Mtetra
0 1 .402 r
.95227 .63397 .95643 .63953 .96786 .63782 .96379 .63269 Mtetra
0 1 .421 r
.96379 .63269 .96786 .63782 .9794 .6366 .97543 .63189 Mtetra
0 1 .445 r
.97543 .63189 .9794 .6366 .99108 .63594 .9872 .63166 Mtetra
0 1 .384 r
.37615 .78062 .38176 .78479 .39094 .78333 .38535 .77922 Mtetra
0 1 .395 r
.38535 .77922 .39094 .78333 .40017 .78171 .39459 .77763 Mtetra
0 1 .404 r
.39459 .77763 .40017 .78171 .40943 .77993 .40388 .77588 Mtetra
0 1 .411 r
.40388 .77588 .40943 .77993 .41874 .77799 .4132 .77396 Mtetra
0 1 .416 r
.4132 .77396 .41874 .77799 .42808 .7759 .42257 .77188 Mtetra
0 1 .42 r
.42257 .77188 .42808 .7759 .43747 .77368 .43197 .76965 Mtetra
0 1 .423 r
.43197 .76965 .43747 .77368 .44689 .77132 .44142 .76728 Mtetra
0 1 .424 r
.44142 .76728 .44689 .77132 .45634 .76885 .45089 .76479 Mtetra
.45089 .76479 .45634 .76885 .46583 .76628 .46041 .76218 Mtetra
0 1 .423 r
.46041 .76218 .46583 .76628 .47536 .76361 .46996 .75947 Mtetra
0 1 .421 r
.46996 .75947 .47536 .76361 .48491 .76088 .47954 .75668 Mtetra
0 1 .418 r
.47954 .75668 .48491 .76088 .4945 .75809 .48915 .75381 Mtetra
0 1 .415 r
.48915 .75381 .4945 .75809 .50413 .75525 .4988 .75088 Mtetra
0 1 .412 r
.4988 .75088 .50413 .75525 .51378 .75238 .50848 .74791 Mtetra
0 1 .408 r
.50848 .74791 .51378 .75238 .52347 .74949 .51819 .7449 Mtetra
0 1 .404 r
.51819 .7449 .52347 .74949 .53319 .74659 .52794 .74187 Mtetra
0 1 .4 r
.52794 .74187 .53319 .74659 .54295 .7437 .53771 .73883 Mtetra
0 1 .396 r
.53771 .73883 .54295 .7437 .55273 .74082 .54752 .73579 Mtetra
0 1 .393 r
.54752 .73579 .55273 .74082 .56255 .73796 .55736 .73275 Mtetra
0 1 .389 r
.55736 .73275 .56255 .73796 .57241 .73513 .56724 .72972 Mtetra
0 1 .386 r
.56724 .72972 .57241 .73513 .5823 .73232 .57715 .72672 Mtetra
0 1 .384 r
.57715 .72672 .5823 .73232 .59222 .72956 .58709 .72373 Mtetra
0 1 .382 r
.58709 .72373 .59222 .72956 .60218 .72682 .59707 .72077 Mtetra
0 1 .38 r
.59707 .72077 .60218 .72682 .61218 .72412 .60708 .71784 Mtetra
0 1 .379 r
.60708 .71784 .61218 .72412 .62221 .72146 .61713 .71493 Mtetra
0 1 .378 r
.61713 .71493 .62221 .72146 .63229 .71882 .62721 .71205 Mtetra
0 1 .377 r
.62721 .71205 .63229 .71882 .6424 .71621 .63734 .70918 Mtetra
.63734 .70918 .6424 .71621 .65254 .71362 .64749 .70634 Mtetra
.64749 .70634 .65254 .71362 .66273 .71103 .65769 .70351 Mtetra
0 1 .378 r
.65769 .70351 .66273 .71103 .67295 .70845 .66792 .70069 Mtetra
.66792 .70069 .67295 .70845 .68321 .70587 .67819 .69787 Mtetra
0 1 .379 r
.67819 .69787 .68321 .70587 .69351 .70327 .6885 .69505 Mtetra
.6885 .69505 .69351 .70327 .70385 .70064 .69884 .69222 Mtetra
0 1 .38 r
.69884 .69222 .70385 .70064 .71422 .69798 .70922 .68936 Mtetra
.70922 .68936 .71422 .69798 .72464 .69528 .71964 .68648 Mtetra
.71964 .68648 .72464 .69528 .73508 .69253 .7301 .68357 Mtetra
0 1 .379 r
.7301 .68357 .73508 .69253 .74557 .68972 .74059 .68063 Mtetra
0 1 .378 r
.74059 .68063 .74557 .68972 .75609 .68684 .75112 .67765 Mtetra
0 1 .377 r
.75112 .67765 .75609 .68684 .76664 .6839 .76168 .67462 Mtetra
0 1 .375 r
.76168 .67462 .76664 .6839 .77722 .68089 .77228 .67156 Mtetra
0 1 .373 r
.77228 .67156 .77722 .68089 .78785 .67782 .78292 .66845 Mtetra
0 1 .37 r
.78292 .66845 .78785 .67782 .7985 .67467 .79359 .66531 Mtetra
0 1 .367 r
.79359 .66531 .7985 .67467 .80919 .67147 .8043 .66214 Mtetra
0 1 .363 r
.8043 .66214 .80919 .67147 .81991 .66822 .81504 .65895 Mtetra
0 1 .36 r
.81504 .65895 .81991 .66822 .83067 .66493 .82583 .65576 Mtetra
0 1 .356 r
.82583 .65576 .83067 .66493 .84146 .66162 .83665 .65258 Mtetra
0 1 .353 r
.83665 .65258 .84146 .66162 .8523 .65831 .84752 .64943 Mtetra
0 1 .35 r
.84752 .64943 .8523 .65831 .86317 .65503 .85843 .64633 Mtetra
0 1 .347 r
.85843 .64633 .86317 .65503 .87409 .6518 .8694 .64332 Mtetra
0 1 .346 r
.8694 .64332 .87409 .6518 .88506 .64866 .88041 .64042 Mtetra
.88041 .64042 .88506 .64866 .89609 .64564 .89149 .63767 Mtetra
0 1 .348 r
.89149 .63767 .89609 .64564 .90717 .64279 .90263 .63511 Mtetra
0 1 .352 r
.90263 .63511 .90717 .64279 .91832 .64014 .91384 .63277 Mtetra
0 1 .359 r
.91384 .63277 .91832 .64014 .92955 .63775 .92514 .63071 Mtetra
0 1 .369 r
.92514 .63071 .92955 .63775 .94086 .63568 .93652 .62898 Mtetra
0 1 .382 r
.93652 .62898 .94086 .63568 .95227 .63397 .948 .62762 Mtetra
0 1 .4 r
.948 .62762 .95227 .63397 .96379 .63269 .95959 .6267 Mtetra
0 1 .423 r
.95959 .6267 .96379 .63269 .97543 .63189 .97131 .62627 Mtetra
0 1 .452 r
.97131 .62627 .97543 .63189 .9872 .63166 .98316 .62639 Mtetra
0 1 .388 r
.37051 .77631 .37615 .78062 .38535 .77922 .37973 .77494 Mtetra
0 1 .399 r
.37973 .77494 .38535 .77922 .39459 .77763 .38899 .77339 Mtetra
0 1 .409 r
.38899 .77339 .39459 .77763 .40388 .77588 .39829 .77166 Mtetra
0 1 .416 r
.39829 .77166 .40388 .77588 .4132 .77396 .40764 .76975 Mtetra
0 1 .422 r
.40764 .76975 .4132 .77396 .42257 .77188 .41702 .76767 Mtetra
0 1 .426 r
.41702 .76767 .42257 .77188 .43197 .76965 .42645 .76542 Mtetra
0 1 .429 r
.42645 .76542 .43197 .76965 .44142 .76728 .43591 .76303 Mtetra
0 1 .43 r
.43591 .76303 .44142 .76728 .45089 .76479 .44541 .7605 Mtetra
0 1 .429 r
.44541 .7605 .45089 .76479 .46041 .76218 .45495 .75785 Mtetra
0 1 .428 r
.45495 .75785 .46041 .76218 .46996 .75947 .46452 .75508 Mtetra
0 1 .426 r
.46452 .75508 .46996 .75947 .47954 .75668 .47413 .75221 Mtetra
0 1 .422 r
.47413 .75221 .47954 .75668 .48915 .75381 .48377 .74925 Mtetra
0 1 .418 r
.48377 .74925 .48915 .75381 .4988 .75088 .49344 .74622 Mtetra
0 1 .414 r
.49344 .74622 .4988 .75088 .50848 .74791 .50314 .74314 Mtetra
0 1 .409 r
.50314 .74314 .50848 .74791 .51819 .7449 .51288 .74 Mtetra
0 1 .404 r
.51288 .74 .51819 .7449 .52794 .74187 .52264 .73682 Mtetra
0 1 .399 r
.52264 .73682 .52794 .74187 .53771 .73883 .53244 .73362 Mtetra
0 1 .393 r
.53244 .73362 .53771 .73883 .54752 .73579 .54227 .7304 Mtetra
0 1 .388 r
.54227 .7304 .54752 .73579 .55736 .73275 .55214 .72718 Mtetra
0 1 .383 r
.55214 .72718 .55736 .73275 .56724 .72972 .56203 .72395 Mtetra
0 1 .378 r
.56203 .72395 .56724 .72972 .57715 .72672 .57196 .72074 Mtetra
0 1 .373 r
.57196 .72074 .57715 .72672 .58709 .72373 .58192 .71753 Mtetra
0 1 .369 r
.58192 .71753 .58709 .72373 .59707 .72077 .59192 .71434 Mtetra
0 1 .365 r
.59192 .71434 .59707 .72077 .60708 .71784 .60195 .71117 Mtetra
0 1 .361 r
.60195 .71117 .60708 .71784 .61713 .71493 .61201 .70802 Mtetra
0 1 .358 r
.61201 .70802 .61713 .71493 .62721 .71205 .62211 .70489 Mtetra
0 1 .355 r
.62211 .70489 .62721 .71205 .63734 .70918 .63224 .70179 Mtetra
0 1 .352 r
.63224 .70179 .63734 .70918 .64749 .70634 .64241 .6987 Mtetra
0 1 .35 r
.64241 .6987 .64749 .70634 .65769 .70351 .65261 .69563 Mtetra
0 1 .348 r
.65261 .69563 .65769 .70351 .66792 .70069 .66285 .69258 Mtetra
0 1 .346 r
.66285 .69258 .66792 .70069 .67819 .69787 .67313 .68953 Mtetra
0 1 .345 r
.67313 .68953 .67819 .69787 .6885 .69505 .68345 .68649 Mtetra
0 1 .343 r
.68345 .68649 .6885 .69505 .69884 .69222 .6938 .68345 Mtetra
0 1 .341 r
.6938 .68345 .69884 .69222 .70922 .68936 .70419 .68041 Mtetra
0 1 .34 r
.70419 .68041 .70922 .68936 .71964 .68648 .71461 .67736 Mtetra
0 1 .338 r
.71461 .67736 .71964 .68648 .7301 .68357 .72507 .6743 Mtetra
0 1 .336 r
.72507 .6743 .7301 .68357 .74059 .68063 .73557 .67123 Mtetra
0 1 .334 r
.73557 .67123 .74059 .68063 .75112 .67765 .74611 .66813 Mtetra
0 1 .332 r
.74611 .66813 .75112 .67765 .76168 .67462 .75668 .66502 Mtetra
0 1 .33 r
.75668 .66502 .76168 .67462 .77228 .67156 .76729 .6619 Mtetra
0 1 .327 r
.76729 .6619 .77228 .67156 .78292 .66845 .77794 .65876 Mtetra
0 1 .325 r
.77794 .65876 .78292 .66845 .79359 .66531 .78863 .65562 Mtetra
0 1 .322 r
.78863 .65562 .79359 .66531 .8043 .66214 .79936 .65247 Mtetra
0 1 .319 r
.79936 .65247 .8043 .66214 .81504 .65895 .81012 .64933 Mtetra
0 1 .317 r
.81012 .64933 .81504 .65895 .82583 .65576 .82093 .64622 Mtetra
0 1 .314 r
.82093 .64622 .82583 .65576 .83665 .65258 .83179 .64315 Mtetra
0 1 .313 r
.83179 .64315 .83665 .65258 .84752 .64943 .84268 .64013 Mtetra
0 1 .312 r
.84268 .64013 .84752 .64943 .85843 .64633 .85363 .6372 Mtetra
.85363 .6372 .85843 .64633 .8694 .64332 .86463 .63437 Mtetra
0 1 .313 r
.86463 .63437 .8694 .64332 .88041 .64042 .87569 .63168 Mtetra
0 1 .316 r
.87569 .63168 .88041 .64042 .89149 .63767 .88681 .62915 Mtetra
0 1 .32 r
.88681 .62915 .89149 .63767 .90263 .63511 .898 .62684 Mtetra
0 1 .328 r
.898 .62684 .90263 .63511 .91384 .63277 .90927 .62477 Mtetra
0 1 .338 r
.90927 .62477 .91384 .63277 .92514 .63071 .92062 .62299 Mtetra
0 1 .351 r
.92062 .62299 .92514 .63071 .93652 .62898 .93206 .62154 Mtetra
0 1 .368 r
.93206 .62154 .93652 .62898 .948 .62762 .9436 .62048 Mtetra
0 1 .39 r
.9436 .62048 .948 .62762 .95959 .6267 .95526 .61985 Mtetra
0 1 .417 r
.95526 .61985 .95959 .6267 .97131 .62627 .96704 .61972 Mtetra
0 1 .449 r
.96704 .61972 .97131 .62627 .98316 .62639 .97896 .62013 Mtetra
0 1 .391 r
.36484 .77185 .37051 .77631 .37973 .77494 .37408 .77053 Mtetra
0 1 .403 r
.37408 .77053 .37973 .77494 .38899 .77339 .38335 .769 Mtetra
0 1 .412 r
.38335 .769 .38899 .77339 .39829 .77166 .39267 .76728 Mtetra
0 1 .42 r
.39267 .76728 .39829 .77166 .40764 .76975 .40204 .76536 Mtetra
0 1 .426 r
.40204 .76536 .40764 .76975 .41702 .76767 .41145 .76327 Mtetra
0 1 .43 r
.41145 .76327 .41702 .76767 .42645 .76542 .42089 .761 Mtetra
0 1 .433 r
.42089 .761 .42645 .76542 .43591 .76303 .43038 .75857 Mtetra
.43038 .75857 .43591 .76303 .44541 .7605 .4399 .75599 Mtetra
.4399 .75599 .44541 .7605 .45495 .75785 .44946 .75328 Mtetra
0 1 .431 r
.44946 .75328 .45495 .75785 .46452 .75508 .45906 .75043 Mtetra
0 1 .428 r
.45906 .75043 .46452 .75508 .47413 .75221 .46869 .74748 Mtetra
0 1 .424 r
.46869 .74748 .47413 .75221 .48377 .74925 .47835 .74442 Mtetra
0 1 .419 r
.47835 .74442 .48377 .74925 .49344 .74622 .48804 .74128 Mtetra
0 1 .414 r
.48804 .74128 .49344 .74622 .50314 .74314 .49777 .73806 Mtetra
0 1 .407 r
.49777 .73806 .50314 .74314 .51288 .74 .50753 .73478 Mtetra
0 1 .401 r
.50753 .73478 .51288 .74 .52264 .73682 .51732 .73145 Mtetra
0 1 .394 r
.51732 .73145 .52264 .73682 .53244 .73362 .52714 .72808 Mtetra
0 1 .387 r
.52714 .72808 .53244 .73362 .54227 .7304 .53699 .72468 Mtetra
0 1 .38 r
.53699 .72468 .54227 .7304 .55214 .72718 .54688 .72126 Mtetra
0 1 .373 r
.54688 .72126 .55214 .72718 .56203 .72395 .55679 .71783 Mtetra
0 1 .366 r
.55679 .71783 .56203 .72395 .57196 .72074 .56674 .7144 Mtetra
0 1 .359 r
.56674 .7144 .57196 .72074 .58192 .71753 .57672 .71097 Mtetra
0 1 .352 r
.57672 .71097 .58192 .71753 .59192 .71434 .58673 .70754 Mtetra
0 1 .346 r
.58673 .70754 .59192 .71434 .60195 .71117 .59677 .70414 Mtetra
0 1 .34 r
.59677 .70414 .60195 .71117 .61201 .70802 .60685 .70074 Mtetra
0 1 .334 r
.60685 .70074 .61201 .70802 .62211 .70489 .61696 .69737 Mtetra
0 1 .329 r
.61696 .69737 .62211 .70489 .63224 .70179 .6271 .69402 Mtetra
0 1 .324 r
.6271 .69402 .63224 .70179 .64241 .6987 .63728 .69069 Mtetra
0 1 .319 r
.63728 .69069 .64241 .6987 .65261 .69563 .6475 .68739 Mtetra
0 1 .315 r
.6475 .68739 .65261 .69563 .66285 .69258 .65775 .6841 Mtetra
0 1 .311 r
.65775 .6841 .66285 .69258 .67313 .68953 .66803 .68083 Mtetra
0 1 .307 r
.66803 .68083 .67313 .68953 .68345 .68649 .67836 .67758 Mtetra
0 1 .303 r
.67836 .67758 .68345 .68649 .6938 .68345 .68871 .67434 Mtetra
0 1 .3 r
.68871 .67434 .6938 .68345 .70419 .68041 .69911 .67112 Mtetra
0 1 .297 r
.69911 .67112 .70419 .68041 .71461 .67736 .70954 .6679 Mtetra
0 1 .294 r
.70954 .6679 .71461 .67736 .72507 .6743 .72001 .66469 Mtetra
0 1 .291 r
.72001 .66469 .72507 .6743 .73557 .67123 .73052 .66149 Mtetra
0 1 .288 r
.73052 .66149 .73557 .67123 .74611 .66813 .74106 .65829 Mtetra
0 1 .285 r
.74106 .65829 .74611 .66813 .75668 .66502 .75164 .65509 Mtetra
0 1 .282 r
.75164 .65509 .75668 .66502 .76729 .6619 .76227 .65191 Mtetra
0 1 .279 r
.76227 .65191 .76729 .6619 .77794 .65876 .77293 .64873 Mtetra
0 1 .276 r
.77293 .64873 .77794 .65876 .78863 .65562 .78363 .64557 Mtetra
0 1 .274 r
.78363 .64557 .78863 .65562 .79936 .65247 .79437 .64244 Mtetra
0 1 .272 r
.79437 .64244 .79936 .65247 .81012 .64933 .80516 .63934 Mtetra
0 1 .27 r
.80516 .63934 .81012 .64933 .82093 .64622 .81599 .63629 Mtetra
0 1 .269 r
.81599 .63629 .82093 .64622 .83179 .64315 .82687 .6333 Mtetra
.82687 .6333 .83179 .64315 .84268 .64013 .83779 .6304 Mtetra
.83779 .6304 .84268 .64013 .85363 .6372 .84877 .6276 Mtetra
0 1 .271 r
.84877 .6276 .85363 .6372 .86463 .63437 .8598 .62492 Mtetra
0 1 .275 r
.8598 .62492 .86463 .63437 .87569 .63168 .8709 .62241 Mtetra
0 1 .28 r
.8709 .62241 .87569 .63168 .88681 .62915 .88206 .62008 Mtetra
0 1 .287 r
.88206 .62008 .88681 .62915 .898 .62684 .89329 .61797 Mtetra
0 1 .297 r
.89329 .61797 .898 .62684 .90927 .62477 .90461 .61612 Mtetra
0 1 .31 r
.90461 .61612 .90927 .62477 .92062 .62299 .916 .61456 Mtetra
0 1 .327 r
.916 .61456 .92062 .62299 .93206 .62154 .9275 .61335 Mtetra
0 1 .347 r
.9275 .61335 .93206 .62154 .9436 .62048 .93909 .61253 Mtetra
0 1 .372 r
.93909 .61253 .9436 .62048 .95526 .61985 .9508 .61215 Mtetra
0 1 .401 r
.9508 .61215 .95526 .61985 .96704 .61972 .96264 .61225 Mtetra
0 1 .436 r
.96264 .61225 .96704 .61972 .97896 .62013 .97462 .6129 Mtetra
0 1 .392 r
.35914 .76727 .36484 .77185 .37408 .77053 .36839 .76598 Mtetra
0 1 .405 r
.36839 .76598 .37408 .77053 .38335 .769 .37768 .76447 Mtetra
0 1 .415 r
.37768 .76447 .38335 .769 .39267 .76728 .38702 .76275 Mtetra
0 1 .423 r
.38702 .76275 .39267 .76728 .40204 .76536 .39641 .76082 Mtetra
0 1 .429 r
.39641 .76082 .40204 .76536 .41145 .76327 .40584 .7587 Mtetra
0 1 .433 r
.40584 .7587 .41145 .76327 .42089 .761 .4153 .7564 Mtetra
0 1 .435 r
.4153 .7564 .42089 .761 .43038 .75857 .42481 .75392 Mtetra
.42481 .75392 .43038 .75857 .4399 .75599 .43436 .75128 Mtetra
0 1 .434 r
.43436 .75128 .4399 .75599 .44946 .75328 .44394 .74849 Mtetra
0 1 .432 r
.44394 .74849 .44946 .75328 .45906 .75043 .45356 .74555 Mtetra
0 1 .428 r
.45356 .74555 .45906 .75043 .46869 .74748 .46321 .7425 Mtetra
0 1 .423 r
.46321 .7425 .46869 .74748 .47835 .74442 .4729 .73933 Mtetra
0 1 .417 r
.4729 .73933 .47835 .74442 .48804 .74128 .48262 .73606 Mtetra
0 1 .41 r
.48262 .73606 .48804 .74128 .49777 .73806 .49237 .7327 Mtetra
0 1 .403 r
.49237 .7327 .49777 .73806 .50753 .73478 .50215 .72926 Mtetra
0 1 .395 r
.50215 .72926 .50753 .73478 .51732 .73145 .51196 .72577 Mtetra
0 1 .386 r
.51196 .72577 .51732 .73145 .52714 .72808 .5218 .72222 Mtetra
0 1 .377 r
.5218 .72222 .52714 .72808 .53699 .72468 .53168 .71862 Mtetra
0 1 .368 r
.53168 .71862 .53699 .72468 .54688 .72126 .54158 .715 Mtetra
0 1 .359 r
.54158 .715 .54688 .72126 .55679 .71783 .55152 .71136 Mtetra
0 1 .35 r
.55152 .71136 .55679 .71783 .56674 .7144 .56148 .7077 Mtetra
0 1 .341 r
.56148 .7077 .56674 .7144 .57672 .71097 .57148 .70404 Mtetra
0 1 .332 r
.57148 .70404 .57672 .71097 .58673 .70754 .58151 .70038 Mtetra
0 1 .324 r
.58151 .70038 .58673 .70754 .59677 .70414 .59156 .69673 Mtetra
0 1 .315 r
.59156 .69673 .59677 .70414 .60685 .70074 .60166 .6931 Mtetra
0 1 .307 r
.60166 .6931 .60685 .70074 .61696 .69737 .61178 .68948 Mtetra
0 1 .299 r
.61178 .68948 .61696 .69737 .6271 .69402 .62193 .68589 Mtetra
0 1 .292 r
.62193 .68589 .6271 .69402 .63728 .69069 .63212 .68232 Mtetra
0 1 .285 r
.63212 .68232 .63728 .69069 .6475 .68739 .64235 .67877 Mtetra
0 1 .278 r
.64235 .67877 .6475 .68739 .65775 .6841 .65261 .67526 Mtetra
0 1 .272 r
.65261 .67526 .65775 .6841 .66803 .68083 .6629 .67177 Mtetra
0 1 .266 r
.6629 .67177 .66803 .68083 .67836 .67758 .67323 .66831 Mtetra
0 1 .261 r
.67323 .66831 .67836 .67758 .68871 .67434 .68359 .66488 Mtetra
0 1 .255 r
.68359 .66488 .68871 .67434 .69911 .67112 .69399 .66147 Mtetra
0 1 .25 r
.69399 .66147 .69911 .67112 .70954 .6679 .70443 .65809 Mtetra
0 1 .246 r
.70443 .65809 .70954 .6679 .72001 .66469 .71491 .65473 Mtetra
0 1 .242 r
.71491 .65473 .72001 .66469 .73052 .66149 .72542 .6514 Mtetra
0 1 .238 r
.72542 .6514 .73052 .66149 .74106 .65829 .73597 .64809 Mtetra
0 1 .234 r
.73597 .64809 .74106 .65829 .75164 .65509 .74657 .64481 Mtetra
0 1 .23 r
.74657 .64481 .75164 .65509 .76227 .65191 .7572 .64156 Mtetra
0 1 .227 r
.7572 .64156 .76227 .65191 .77293 .64873 .76787 .63834 Mtetra
0 1 .225 r
.76787 .63834 .77293 .64873 .78363 .64557 .77858 .63516 Mtetra
0 1 .222 r
.77858 .63516 .78363 .64557 .79437 .64244 .78934 .63203 Mtetra
0 1 .221 r
.78934 .63203 .79437 .64244 .80516 .63934 .80014 .62895 Mtetra
0 1 .22 r
.80014 .62895 .80516 .63934 .81599 .63629 .81099 .62595 Mtetra
.81099 .62595 .81599 .63629 .82687 .6333 .82189 .62303 Mtetra
0 1 .221 r
.82189 .62303 .82687 .6333 .83779 .6304 .83284 .62021 Mtetra
0 1 .223 r
.83284 .62021 .83779 .6304 .84877 .6276 .84385 .61752 Mtetra
0 1 .226 r
.84385 .61752 .84877 .6276 .8598 .62492 .85491 .61497 Mtetra
0 1 .231 r
.85491 .61497 .8598 .62492 .8709 .62241 .86604 .6126 Mtetra
0 1 .239 r
.86604 .6126 .8709 .62241 .88206 .62008 .87723 .61043 Mtetra
0 1 .248 r
.87723 .61043 .88206 .62008 .89329 .61797 .8885 .60849 Mtetra
0 1 .261 r
.8885 .60849 .89329 .61797 .90461 .61612 .89985 .60681 Mtetra
0 1 .276 r
.89985 .60681 .90461 .61612 .916 .61456 .91129 .60545 Mtetra
0 1 .295 r
.91129 .60545 .916 .61456 .9275 .61335 .92282 .60443 Mtetra
0 1 .318 r
.92282 .60443 .9275 .61335 .93909 .61253 .93446 .60379 Mtetra
0 1 .345 r
.93446 .60379 .93909 .61253 .9508 .61215 .94622 .6036 Mtetra
0 1 .377 r
.94622 .6036 .9508 .61215 .96264 .61225 .9581 .60388 Mtetra
0 1 .414 r
.9581 .60388 .96264 .61225 .97462 .6129 .97012 .6047 Mtetra
0 1 .393 r
.35341 .76257 .35914 .76727 .36839 .76598 .36267 .76131 Mtetra
0 1 .405 r
.36267 .76131 .36839 .76598 .37768 .76447 .37198 .75981 Mtetra
0 1 .416 r
.37198 .75981 .37768 .76447 .38702 .76275 .38134 .75808 Mtetra
0 1 .424 r
.38134 .75808 .38702 .76275 .39641 .76082 .39075 .75613 Mtetra
0 1 .43 r
.39075 .75613 .39641 .76082 .40584 .7587 .40019 .75398 Mtetra
0 1 .433 r
.40019 .75398 .40584 .7587 .4153 .7564 .40968 .75162 Mtetra
0 1 .435 r
.40968 .75162 .4153 .7564 .42481 .75392 .41921 .74908 Mtetra
.41921 .74908 .42481 .75392 .43436 .75128 .42878 .74636 Mtetra
0 1 .433 r
.42878 .74636 .43436 .75128 .44394 .74849 .43839 .74348 Mtetra
0 1 .43 r
.43839 .74348 .44394 .74849 .45356 .74555 .44803 .74045 Mtetra
0 1 .425 r
.44803 .74045 .45356 .74555 .46321 .7425 .45771 .73728 Mtetra
0 1 .419 r
.45771 .73728 .46321 .7425 .4729 .73933 .46742 .73398 Mtetra
0 1 .412 r
.46742 .73398 .4729 .73933 .48262 .73606 .47716 .73057 Mtetra
0 1 .404 r
.47716 .73057 .48262 .73606 .49237 .7327 .48693 .72706 Mtetra
0 1 .395 r
.48693 .72706 .49237 .7327 .50215 .72926 .49674 .72346 Mtetra
0 1 .386 r
.49674 .72346 .50215 .72926 .51196 .72577 .50657 .71978 Mtetra
0 1 .376 r
.50657 .71978 .51196 .72577 .5218 .72222 .51644 .71604 Mtetra
0 1 .365 r
.51644 .71604 .5218 .72222 .53168 .71862 .52633 .71225 Mtetra
0 1 .354 r
.52633 .71225 .53168 .71862 .54158 .715 .53626 .70842 Mtetra
0 1 .343 r
.53626 .70842 .54158 .715 .55152 .71136 .54621 .70455 Mtetra
0 1 .331 r
.54621 .70455 .55152 .71136 .56148 .7077 .55619 .70067 Mtetra
0 1 .32 r
.55619 .70067 .56148 .7077 .57148 .70404 .56621 .69677 Mtetra
0 1 .309 r
.56621 .69677 .57148 .70404 .58151 .70038 .57625 .69287 Mtetra
0 1 .298 r
.57625 .69287 .58151 .70038 .59156 .69673 .58632 .68897 Mtetra
0 1 .287 r
.58632 .68897 .59156 .69673 .60166 .6931 .59643 .68509 Mtetra
0 1 .276 r
.59643 .68509 .60166 .6931 .61178 .68948 .60656 .68123 Mtetra
0 1 .266 r
.60656 .68123 .61178 .68948 .62193 .68589 .61673 .67738 Mtetra
0 1 .256 r
.61673 .67738 .62193 .68589 .63212 .68232 .62693 .67357 Mtetra
0 1 .247 r
.62693 .67357 .63212 .68232 .64235 .67877 .63716 .66979 Mtetra
0 1 .238 r
.63716 .66979 .64235 .67877 .65261 .67526 .64743 .66605 Mtetra
0 1 .23 r
.64743 .66605 .65261 .67526 .6629 .67177 .65773 .66234 Mtetra
0 1 .222 r
.65773 .66234 .6629 .67177 .67323 .66831 .66806 .65867 Mtetra
0 1 .214 r
.66806 .65867 .67323 .66831 .68359 .66488 .67843 .65504 Mtetra
0 1 .207 r
.67843 .65504 .68359 .66488 .69399 .66147 .68884 .65145 Mtetra
0 1 .201 r
.68884 .65145 .69399 .66147 .70443 .65809 .69928 .64791 Mtetra
0 1 .195 r
.69928 .64791 .70443 .65809 .71491 .65473 .70977 .64441 Mtetra
0 1 .189 r
.70977 .64441 .71491 .65473 .72542 .6514 .72029 .64094 Mtetra
0 1 .184 r
.72029 .64094 .72542 .6514 .73597 .64809 .73085 .63753 Mtetra
0 1 .18 r
.73085 .63753 .73597 .64809 .74657 .64481 .74144 .63416 Mtetra
0 1 .176 r
.74144 .63416 .74657 .64481 .7572 .64156 .75208 .63084 Mtetra
0 1 .172 r
.75208 .63084 .7572 .64156 .76787 .63834 .76277 .62757 Mtetra
0 1 .169 r
.76277 .62757 .76787 .63834 .77858 .63516 .77349 .62436 Mtetra
0 1 .167 r
.77349 .62436 .77858 .63516 .78934 .63203 .78426 .62122 Mtetra
0 1 .166 r
.78426 .62122 .78934 .63203 .80014 .62895 .79508 .61816 Mtetra
.79508 .61816 .80014 .62895 .81099 .62595 .80594 .61519 Mtetra
.80594 .61519 .81099 .62595 .82189 .62303 .81686 .61232 Mtetra
0 1 .168 r
.81686 .61232 .82189 .62303 .83284 .62021 .82783 .60957 Mtetra
0 1 .171 r
.82783 .60957 .83284 .62021 .84385 .61752 .83886 .60696 Mtetra
0 1 .176 r
.83886 .60696 .84385 .61752 .85491 .61497 .84995 .60451 Mtetra
0 1 .183 r
.84995 .60451 .85491 .61497 .86604 .6126 .8611 .60225 Mtetra
0 1 .192 r
.8611 .60225 .86604 .6126 .87723 .61043 .87232 .6002 Mtetra
0 1 .204 r
.87232 .6002 .87723 .61043 .8885 .60849 .88362 .59839 Mtetra
0 1 .218 r
.88362 .59839 .8885 .60849 .89985 .60681 .89501 .59686 Mtetra
0 1 .235 r
.89501 .59686 .89985 .60681 .91129 .60545 .90648 .59563 Mtetra
0 1 .256 r
.90648 .59563 .91129 .60545 .92282 .60443 .91805 .59476 Mtetra
0 1 .281 r
.91805 .59476 .92282 .60443 .93446 .60379 .92972 .59427 Mtetra
0 1 .31 r
.92972 .59427 .93446 .60379 .94622 .6036 .94151 .59421 Mtetra
0 1 .344 r
.94151 .59421 .94622 .6036 .9581 .60388 .95343 .59462 Mtetra
0 1 .383 r
.95343 .59462 .9581 .60388 .97012 .6047 .96549 .59555 Mtetra
0 1 .392 r
.34764 .75779 .35341 .76257 .36267 .76131 .35691 .75654 Mtetra
0 1 .405 r
.35691 .75654 .36267 .76131 .37198 .75981 .36624 .75503 Mtetra
0 1 .416 r
.36624 .75503 .37198 .75981 .38134 .75808 .37562 .75329 Mtetra
0 1 .424 r
.37562 .75329 .38134 .75808 .39075 .75613 .38505 .75131 Mtetra
0 1 .429 r
.38505 .75131 .39075 .75613 .40019 .75398 .39452 .7491 Mtetra
0 1 .433 r
.39452 .7491 .40019 .75398 .40968 .75162 .40403 .74669 Mtetra
0 1 .434 r
.40403 .74669 .40968 .75162 .41921 .74908 .41358 .74407 Mtetra
0 1 .433 r
.41358 .74407 .41921 .74908 .42878 .74636 .42317 .74126 Mtetra
0 1 .431 r
.42317 .74126 .42878 .74636 .43839 .74348 .4328 .73828 Mtetra
0 1 .427 r
.4328 .73828 .43839 .74348 .44803 .74045 .44247 .73514 Mtetra
0 1 .421 r
.44247 .73514 .44803 .74045 .45771 .73728 .45217 .73184 Mtetra
0 1 .414 r
.45217 .73184 .45771 .73728 .46742 .73398 .4619 .7284 Mtetra
0 1 .405 r
.4619 .7284 .46742 .73398 .47716 .73057 .47167 .72483 Mtetra
0 1 .396 r
.47167 .72483 .47716 .73057 .48693 .72706 .48147 .72116 Mtetra
0 1 .385 r
.48147 .72116 .48693 .72706 .49674 .72346 .49129 .71738 Mtetra
0 1 .374 r
.49129 .71738 .49674 .72346 .50657 .71978 .50115 .71351 Mtetra
0 1 .362 r
.50115 .71351 .50657 .71978 .51644 .71604 .51104 .70957 Mtetra
0 1 .349 r
.51104 .70957 .51644 .71604 .52633 .71225 .52095 .70557 Mtetra
0 1 .336 r
.52095 .70557 .52633 .71225 .53626 .70842 .5309 .70151 Mtetra
0 1 .323 r
.5309 .70151 .53626 .70842 .54621 .70455 .54087 .69742 Mtetra
0 1 .309 r
.54087 .69742 .54621 .70455 .55619 .70067 .55087 .6933 Mtetra
0 1 .296 r
.55087 .6933 .55619 .70067 .56621 .69677 .5609 .68915 Mtetra
0 1 .282 r
.5609 .68915 .56621 .69677 .57625 .69287 .57096 .685 Mtetra
0 1 .268 r
.57096 .685 .57625 .69287 .58632 .68897 .58105 .68086 Mtetra
0 1 .255 r
.58105 .68086 .58632 .68897 .59643 .68509 .59117 .67672 Mtetra
0 1 .242 r
.59117 .67672 .59643 .68509 .60656 .68123 .60131 .6726 Mtetra
0 1 .229 r
.60131 .6726 .60656 .68123 .61673 .67738 .61149 .66851 Mtetra
0 1 .217 r
.61149 .66851 .61673 .67738 .62693 .67357 .6217 .66445 Mtetra
0 1 .205 r
.6217 .66445 .62693 .67357 .63716 .66979 .63194 .66043 Mtetra
0 1 .194 r
.63194 .66043 .63716 .66979 .64743 .66605 .64221 .65646 Mtetra
0 1 .184 r
.64221 .65646 .64743 .66605 .65773 .66234 .65252 .65253 Mtetra
0 1 .174 r
.65252 .65253 .65773 .66234 .66806 .65867 .66286 .64866 Mtetra
0 1 .164 r
.66286 .64866 .66806 .65867 .67843 .65504 .67324 .64483 Mtetra
0 1 .155 r
.67324 .64483 .67843 .65504 .68884 .65145 .68365 .64107 Mtetra
0 1 .147 r
.68365 .64107 .68884 .65145 .69928 .64791 .6941 .63736 Mtetra
0 1 .14 r
.6941 .63736 .69928 .64791 .70977 .64441 .70459 .63371 Mtetra
0 1 .133 r
.70459 .63371 .70977 .64441 .72029 .64094 .71511 .63012 Mtetra
0 1 .127 r
.71511 .63012 .72029 .64094 .73085 .63753 .72568 .62659 Mtetra
0 1 .122 r
.72568 .62659 .73085 .63753 .74144 .63416 .73628 .62313 Mtetra
0 1 .117 r
.73628 .62313 .74144 .63416 .75208 .63084 .74693 .61973 Mtetra
0 1 .113 r
.74693 .61973 .75208 .63084 .76277 .62757 .75762 .61641 Mtetra
0 1 .11 r
.75762 .61641 .76277 .62757 .77349 .62436 .76836 .61317 Mtetra
0 1 .108 r
.76836 .61317 .77349 .62436 .78426 .62122 .77914 .61001 Mtetra
0 1 .107 r
.77914 .61001 .78426 .62122 .79508 .61816 .78997 .60695 Mtetra
.78997 .60695 .79508 .61816 .80594 .61519 .80085 .60399 Mtetra
0 1 .109 r
.80085 .60399 .80594 .61519 .81686 .61232 .81178 .60116 Mtetra
0 1 .111 r
.81178 .60116 .81686 .61232 .82783 .60957 .82276 .59846 Mtetra
0 1 .116 r
.82276 .59846 .82783 .60957 .83886 .60696 .83381 .59591 Mtetra
0 1 .122 r
.83381 .59591 .83886 .60696 .84995 .60451 .84492 .59353 Mtetra
0 1 .13 r
.84492 .59353 .84995 .60451 .8611 .60225 .85609 .59135 Mtetra
0 1 .14 r
.85609 .59135 .8611 .60225 .87232 .6002 .86734 .58939 Mtetra
0 1 .153 r
.86734 .58939 .87232 .6002 .88362 .59839 .87867 .58768 Mtetra
0 1 .169 r
.87867 .58768 .88362 .59839 .89501 .59686 .89007 .58625 Mtetra
0 1 .188 r
.89007 .58625 .89501 .59686 .90648 .59563 .90157 .58513 Mtetra
0 1 .21 r
.90157 .58513 .90648 .59563 .91805 .59476 .91317 .58435 Mtetra
0 1 .237 r
.91317 .58435 .91805 .59476 .92972 .59427 .92487 .58396 Mtetra
0 1 .267 r
.92487 .58396 .92972 .59427 .94151 .59421 .93669 .58399 Mtetra
0 1 .303 r
.93669 .58399 .94151 .59421 .95343 .59462 .94864 .58448 Mtetra
0 1 .343 r
.94864 .58448 .95343 .59462 .96549 .59555 .96072 .58548 Mtetra
0 1 .391 r
.34183 .75293 .34764 .75779 .35691 .75654 .35113 .75168 Mtetra
0 1 .405 r
.35113 .75168 .35691 .75654 .36624 .75503 .36047 .75016 Mtetra
0 1 .415 r
.36047 .75016 .36624 .75503 .37562 .75329 .36987 .74838 Mtetra
0 1 .423 r
.36987 .74838 .37562 .75329 .38505 .75131 .37932 .74636 Mtetra
0 1 .428 r
.37932 .74636 .38505 .75131 .39452 .7491 .38881 .74409 Mtetra
0 1 .431 r
.38881 .74409 .39452 .7491 .40403 .74669 .39834 .7416 Mtetra
0 1 .432 r
.39834 .7416 .40403 .74669 .41358 .74407 .40792 .7389 Mtetra
0 1 .43 r
.40792 .7389 .41358 .74407 .42317 .74126 .41753 .73599 Mtetra
0 1 .427 r
.41753 .73599 .42317 .74126 .4328 .73828 .42719 .73289 Mtetra
0 1 .421 r
.42719 .73289 .4328 .73828 .44247 .73514 .43688 .72962 Mtetra
0 1 .415 r
.43688 .72962 .44247 .73514 .45217 .73184 .4466 .72618 Mtetra
0 1 .406 r
.4466 .72618 .45217 .73184 .4619 .7284 .45636 .72259 Mtetra
0 1 .396 r
.45636 .72259 .4619 .7284 .47167 .72483 .46615 .71886 Mtetra
0 1 .385 r
.46615 .71886 .47167 .72483 .48147 .72116 .47597 .71501 Mtetra
0 1 .373 r
.47597 .71501 .48147 .72116 .49129 .71738 .48582 .71104 Mtetra
0 1 .36 r
.48582 .71104 .49129 .71738 .50115 .71351 .4957 .70697 Mtetra
0 1 .346 r
.4957 .70697 .50115 .71351 .51104 .70957 .50561 .70282 Mtetra
0 1 .331 r
.50561 .70282 .51104 .70957 .52095 .70557 .51555 .69859 Mtetra
0 1 .316 r
.51555 .69859 .52095 .70557 .5309 .70151 .52551 .6943 Mtetra
0 1 .3 r
.52551 .6943 .5309 .70151 .54087 .69742 .5355 .68997 Mtetra
0 1 .284 r
.5355 .68997 .54087 .69742 .55087 .6933 .54552 .6856 Mtetra
0 1 .268 r
.54552 .6856 .55087 .6933 .5609 .68915 .55557 .6812 Mtetra
0 1 .252 r
.55557 .6812 .5609 .68915 .57096 .685 .56564 .6768 Mtetra
0 1 .236 r
.56564 .6768 .57096 .685 .58105 .68086 .57574 .67239 Mtetra
0 1 .22 r
.57574 .67239 .58105 .68086 .59117 .67672 .58587 .66799 Mtetra
0 1 .204 r
.58587 .66799 .59117 .67672 .60131 .6726 .59603 .66362 Mtetra
0 1 .189 r
.59603 .66362 .60131 .6726 .61149 .66851 .60622 .65927 Mtetra
0 1 .174 r
.60622 .65927 .61149 .66851 .6217 .66445 .61644 .65496 Mtetra
0 1 .16 r
.61644 .65496 .6217 .66445 .63194 .66043 .62669 .6507 Mtetra
0 1 .147 r
.62669 .6507 .63194 .66043 .64221 .65646 .63697 .64649 Mtetra
0 1 .134 r
.63697 .64649 .64221 .65646 .65252 .65253 .64728 .64235 Mtetra
0 1 .122 r
.64728 .64235 .65252 .65253 .66286 .64866 .65763 .63826 Mtetra
0 1 .11 r
.65763 .63826 .66286 .64866 .67324 .64483 .66801 .63424 Mtetra
0 1 .1 r
.66801 .63424 .67324 .64483 .68365 .64107 .67843 .6303 Mtetra
0 1 .09 r
.67843 .6303 .68365 .64107 .6941 .63736 .68888 .62642 Mtetra
0 1 .081 r
.68888 .62642 .6941 .63736 .70459 .63371 .69937 .62263 Mtetra
0 1 .073 r
.69937 .62263 .70459 .63371 .71511 .63012 .7099 .61891 Mtetra
0 1 .066 r
.7099 .61891 .71511 .63012 .72568 .62659 .72047 .61527 Mtetra
0 1 .06 r
.72047 .61527 .72568 .62659 .73628 .62313 .73108 .61171 Mtetra
0 1 .055 r
.73108 .61171 .73628 .62313 .74693 .61973 .74174 .60824 Mtetra
0 1 .051 r
.74174 .60824 .74693 .61973 .75762 .61641 .75243 .60486 Mtetra
0 1 .047 r
.75243 .60486 .75762 .61641 .76836 .61317 .76318 .60157 Mtetra
0 1 .045 r
.76318 .60157 .76836 .61317 .77914 .61001 .77397 .59839 Mtetra
0 1 .044 r
.77397 .59839 .77914 .61001 .78997 .60695 .78481 .59531 Mtetra
0 1 .045 r
.78481 .59531 .78997 .60695 .80085 .60399 .7957 .59236 Mtetra
0 1 .047 r
.7957 .59236 .80085 .60399 .81178 .60116 .80664 .58954 Mtetra
0 1 .05 r
.80664 .58954 .81178 .60116 .82276 .59846 .81764 .58687 Mtetra
0 1 .055 r
.81764 .58687 .82276 .59846 .83381 .59591 .8287 .58436 Mtetra
0 1 .062 r
.8287 .58436 .83381 .59591 .84492 .59353 .83983 .58203 Mtetra
0 1 .071 r
.83983 .58203 .84492 .59353 .85609 .59135 .85102 .57991 Mtetra
0 1 .083 r
.85102 .57991 .85609 .59135 .86734 .58939 .86229 .57801 Mtetra
0 1 .097 r
.86229 .57801 .86734 .58939 .87867 .58768 .87363 .57637 Mtetra
0 1 .114 r
.87363 .57637 .87867 .58768 .89007 .58625 .88506 .575 Mtetra
0 1 .134 r
.88506 .575 .89007 .58625 .90157 .58513 .89658 .57395 Mtetra
0 1 .157 r
.89658 .57395 .90157 .58513 .91317 .58435 .90819 .57323 Mtetra
0 1 .185 r
.90819 .57323 .91317 .58435 .92487 .58396 .91992 .5729 Mtetra
0 1 .217 r
.91992 .5729 .92487 .58396 .93669 .58399 .93175 .57297 Mtetra
0 1 .253 r
.93175 .57297 .93669 .58399 .94864 .58448 .94372 .5735 Mtetra
0 1 .295 r
.94372 .5735 .94864 .58448 .96072 .58548 .95581 .57451 Mtetra
0 1 .39 r
.33599 .74801 .34183 .75293 .35113 .75168 .3453 .74675 Mtetra
0 1 .403 r
.3453 .74675 .35113 .75168 .36047 .75016 .35467 .74521 Mtetra
0 1 .413 r
.35467 .74521 .36047 .75016 .36987 .74838 .36409 .74338 Mtetra
0 1 .421 r
.36409 .74338 .36987 .74838 .37932 .74636 .37355 .7413 Mtetra
0 1 .426 r
.37355 .7413 .37932 .74636 .38881 .74409 .38307 .73896 Mtetra
0 1 .428 r
.38307 .73896 .38881 .74409 .39834 .7416 .39262 .73638 Mtetra
.39262 .73638 .39834 .7416 .40792 .7389 .40222 .73357 Mtetra
0 1 .425 r
.40222 .73357 .40792 .7389 .41753 .73599 .41186 .73055 Mtetra
0 1 .421 r
.41186 .73055 .41753 .73599 .42719 .73289 .42154 .72733 Mtetra
0 1 .415 r
.42154 .72733 .42719 .73289 .43688 .72962 .43125 .72391 Mtetra
0 1 .406 r
.43125 .72391 .43688 .72962 .4466 .72618 .441 .72032 Mtetra
0 1 .396 r
.441 .72032 .4466 .72618 .45636 .72259 .45078 .71657 Mtetra
0 1 .385 r
.45078 .71657 .45636 .72259 .46615 .71886 .4606 .71266 Mtetra
0 1 .372 r
.4606 .71266 .46615 .71886 .47597 .71501 .47044 .70861 Mtetra
0 1 .358 r
.47044 .70861 .47597 .71501 .48582 .71104 .48032 .70444 Mtetra
0 1 .343 r
.48032 .70444 .48582 .71104 .4957 .70697 .49022 .70017 Mtetra
0 1 .327 r
.49022 .70017 .4957 .70697 .50561 .70282 .50015 .69579 Mtetra
0 1 .31 r
.50015 .69579 .50561 .70282 .51555 .69859 .51011 .69133 Mtetra
0 1 .292 r
.51011 .69133 .51555 .69859 .52551 .6943 .52009 .6868 Mtetra
0 1 .274 r
.52009 .6868 .52551 .6943 .5355 .68997 .5301 .68221 Mtetra
0 1 .256 r
.5301 .68221 .5355 .68997 .54552 .6856 .54014 .67758 Mtetra
0 1 .237 r
.54014 .67758 .54552 .6856 .55557 .6812 .5502 .67292 Mtetra
0 1 .218 r
.5502 .67292 .55557 .6812 .56564 .6768 .56029 .66825 Mtetra
0 1 .2 r
.56029 .66825 .56564 .6768 .57574 .67239 .57041 .66357 Mtetra
0 1 .181 r
.57041 .66357 .57574 .67239 .58587 .66799 .58055 .65891 Mtetra
0 1 .163 r
.58055 .65891 .58587 .66799 .59603 .66362 .59072 .65427 Mtetra
0 1 .145 r
.59072 .65427 .59603 .66362 .60622 .65927 .60092 .64966 Mtetra
0 1 .128 r
.60092 .64966 .60622 .65927 .61644 .65496 .61115 .6451 Mtetra
0 1 .111 r
.61115 .6451 .61644 .65496 .62669 .6507 .6214 .64059 Mtetra
0 1 .096 r
.6214 .64059 .62669 .6507 .63697 .64649 .63169 .63615 Mtetra
0 1 .081 r
.63169 .63615 .63697 .64649 .64728 .64235 .64201 .63177 Mtetra
0 1 .066 r
.64201 .63177 .64728 .64235 .65763 .63826 .65236 .62748 Mtetra
0 1 .053 r
.65236 .62748 .65763 .63826 .66801 .63424 .66275 .62326 Mtetra
0 1 .041 r
.66275 .62326 .66801 .63424 .67843 .6303 .67317 .61914 Mtetra
0 1 .029 r
.67317 .61914 .67843 .6303 .68888 .62642 .68362 .6151 Mtetra
0 1 .019 r
.68362 .6151 .68888 .62642 .69937 .62263 .69412 .61115 Mtetra
0 1 .01 r
.69412 .61115 .69937 .62263 .7099 .61891 .70465 .6073 Mtetra
0 1 .002 r
.70465 .6073 .7099 .61891 .72047 .61527 .71523 .60355 Mtetra
.005 1 0 r
.71523 .60355 .72047 .61527 .73108 .61171 .72584 .5999 Mtetra
.011 1 0 r
.72584 .5999 .73108 .61171 .74174 .60824 .7365 .59634 Mtetra
.016 1 0 r
.7365 .59634 .74174 .60824 .75243 .60486 .7472 .5929 Mtetra
.019 1 0 r
.7472 .5929 .75243 .60486 .76318 .60157 .75795 .58956 Mtetra
.022 1 0 r
.75795 .58956 .76318 .60157 .77397 .59839 .76875 .58634 Mtetra
.76875 .58634 .77397 .59839 .78481 .59531 .7796 .58324 Mtetra
.7796 .58324 .78481 .59531 .7957 .59236 .7905 .58028 Mtetra
.02 1 0 r
.7905 .58028 .7957 .59236 .80664 .58954 .80145 .57746 Mtetra
.016 1 0 r
.80145 .57746 .80664 .58954 .81764 .58687 .81246 .5748 Mtetra
.01 1 0 r
.81246 .5748 .81764 .58687 .8287 .58436 .82354 .57231 Mtetra
.003 1 0 r
.82354 .57231 .8287 .58436 .83983 .58203 .83467 .57001 Mtetra
0 1 .007 r
.83467 .57001 .83983 .58203 .85102 .57991 .84588 .56792 Mtetra
0 1 .019 r
.84588 .56792 .85102 .57991 .86229 .57801 .85716 .56606 Mtetra
0 1 .034 r
.85716 .56606 .86229 .57801 .87363 .57637 .86852 .56445 Mtetra
0 1 .052 r
.86852 .56445 .87363 .57637 .88506 .575 .87996 .56312 Mtetra
0 1 .073 r
.87996 .56312 .88506 .575 .89658 .57395 .89149 .56209 Mtetra
0 1 .098 r
.89149 .56209 .89658 .57395 .90819 .57323 .90312 .56141 Mtetra
0 1 .126 r
.90312 .56141 .90819 .57323 .91992 .5729 .91486 .56109 Mtetra
0 1 .159 r
.91486 .56109 .91992 .5729 .93175 .57297 .92671 .56116 Mtetra
0 1 .196 r
.92671 .56116 .93175 .57297 .94372 .5735 .93868 .56168 Mtetra
0 1 .237 r
.93868 .56168 .94372 .5735 .95581 .57451 .95079 .56266 Mtetra
0 1 .388 r
.33011 .74306 .33599 .74801 .3453 .74675 .33944 .74177 Mtetra
0 1 .401 r
.33944 .74177 .3453 .74675 .35467 .74521 .34883 .74018 Mtetra
0 1 .411 r
.34883 .74018 .35467 .74521 .36409 .74338 .35827 .7383 Mtetra
0 1 .418 r
.35827 .7383 .36409 .74338 .37355 .7413 .36776 .73614 Mtetra
0 1 .422 r
.36776 .73614 .37355 .7413 .38307 .73896 .37729 .73371 Mtetra
0 1 .424 r
.37729 .73371 .38307 .73896 .39262 .73638 .38687 .73103 Mtetra
0 1 .423 r
.38687 .73103 .39262 .73638 .40222 .73357 .39649 .72811 Mtetra
0 1 .419 r
.39649 .72811 .40222 .73357 .41186 .73055 .40616 .72496 Mtetra
0 1 .414 r
.40616 .72496 .41186 .73055 .42154 .72733 .41586 .7216 Mtetra
0 1 .406 r
.41586 .7216 .42154 .72733 .43125 .72391 .4256 .71803 Mtetra
0 1 .396 r
.4256 .71803 .43125 .72391 .441 .72032 .43537 .71427 Mtetra
0 1 .385 r
.43537 .71427 .441 .72032 .45078 .71657 .44518 .71034 Mtetra
0 1 .372 r
.44518 .71034 .45078 .71657 .4606 .71266 .45502 .70624 Mtetra
0 1 .357 r
.45502 .70624 .4606 .71266 .47044 .70861 .46489 .702 Mtetra
0 1 .341 r
.46489 .702 .47044 .70861 .48032 .70444 .47478 .69761 Mtetra
0 1 .324 r
.47478 .69761 .48032 .70444 .49022 .70017 .48471 .69311 Mtetra
0 1 .305 r
.48471 .69311 .49022 .70017 .50015 .69579 .49466 .68849 Mtetra
0 1 .286 r
.49466 .68849 .50015 .69579 .51011 .69133 .50464 .68379 Mtetra
0 1 .266 r
.50464 .68379 .51011 .69133 .52009 .6868 .51465 .679 Mtetra
0 1 .246 r
.51465 .679 .52009 .6868 .5301 .68221 .52468 .67415 Mtetra
0 1 .225 r
.52468 .67415 .5301 .68221 .54014 .67758 .53473 .66926 Mtetra
0 1 .203 r
.53473 .66926 .54014 .67758 .5502 .67292 .54481 .66432 Mtetra
0 1 .182 r
.54481 .66432 .5502 .67292 .56029 .66825 .55492 .65937 Mtetra
0 1 .161 r
.55492 .65937 .56029 .66825 .57041 .66357 .56505 .65442 Mtetra
0 1 .139 r
.56505 .65442 .57041 .66357 .58055 .65891 .5752 .64948 Mtetra
0 1 .118 r
.5752 .64948 .58055 .65891 .59072 .65427 .58538 .64456 Mtetra
0 1 .098 r
.58538 .64456 .59072 .65427 .60092 .64966 .59559 .63968 Mtetra
0 1 .078 r
.59559 .63968 .60092 .64966 .61115 .6451 .60582 .63486 Mtetra
0 1 .059 r
.60582 .63486 .61115 .6451 .6214 .64059 .61609 .6301 Mtetra
0 1 .041 r
.61609 .6301 .6214 .64059 .63169 .63615 .62638 .62541 Mtetra
0 1 .023 r
.62638 .62541 .63169 .63615 .64201 .63177 .63671 .62081 Mtetra
0 1 .007 r
.63671 .62081 .64201 .63177 .65236 .62748 .64706 .6163 Mtetra
.008 1 0 r
.64706 .6163 .65236 .62748 .66275 .62326 .65745 .61189 Mtetra
.022 1 0 r
.65745 .61189 .66275 .62326 .67317 .61914 .66787 .60758 Mtetra
.035 1 0 r
.66787 .60758 .67317 .61914 .68362 .6151 .67833 .60338 Mtetra
.047 1 0 r
.67833 .60338 .68362 .6151 .69412 .61115 .68883 .59928 Mtetra
.057 1 0 r
.68883 .59928 .69412 .61115 .70465 .6073 .69937 .5953 Mtetra
.066 1 0 r
.69937 .5953 .70465 .6073 .71523 .60355 .70995 .59143 Mtetra
.074 1 0 r
.70995 .59143 .71523 .60355 .72584 .5999 .72057 .58768 Mtetra
.081 1 0 r
.72057 .58768 .72584 .5999 .7365 .59634 .73123 .58404 Mtetra
.086 1 0 r
.73123 .58404 .7365 .59634 .7472 .5929 .74193 .58052 Mtetra
.09 1 0 r
.74193 .58052 .7472 .5929 .75795 .58956 .75269 .57713 Mtetra
.093 1 0 r
.75269 .57713 .75795 .58956 .76875 .58634 .76349 .57387 Mtetra
.76349 .57387 .76875 .58634 .7796 .58324 .77434 .57074 Mtetra
.77434 .57074 .7796 .58324 .7905 .58028 .78525 .56776 Mtetra
.091 1 0 r
.78525 .56776 .7905 .58028 .80145 .57746 .79621 .56493 Mtetra
.086 1 0 r
.79621 .56493 .80145 .57746 .81246 .5748 .80723 .56226 Mtetra
.08 1 0 r
.80723 .56226 .81246 .5748 .82354 .57231 .81831 .55977 Mtetra
.072 1 0 r
.81831 .55977 .82354 .57231 .83467 .57001 .82946 .55748 Mtetra
.062 1 0 r
.82946 .55748 .83467 .57001 .84588 .56792 .84068 .5554 Mtetra
.049 1 0 r
.84068 .5554 .84588 .56792 .85716 .56606 .85197 .55354 Mtetra
.034 1 0 r
.85197 .55354 .85716 .56606 .86852 .56445 .86333 .55194 Mtetra
.015 1 0 r
.86333 .55194 .86852 .56445 .87996 .56312 .87479 .55062 Mtetra
0 1 .006 r
.87479 .55062 .87996 .56312 .89149 .56209 .88633 .54959 Mtetra
0 1 .031 r
.88633 .54959 .89149 .56209 .90312 .56141 .89797 .5489 Mtetra
0 1 .06 r
.89797 .5489 .90312 .56141 .91486 .56109 .90971 .54856 Mtetra
0 1 .093 r
.90971 .54856 .91486 .56109 .92671 .56116 .92156 .5486 Mtetra
0 1 .13 r
.92156 .5486 .92671 .56116 .93868 .56168 .93354 .54906 Mtetra
0 1 .172 r
.93354 .54906 .93868 .56168 .95079 .56266 .94564 .54998 Mtetra
0 1 .387 r
.32419 .73809 .33011 .74306 .33944 .74177 .33354 .73676 Mtetra
0 1 .399 r
.33354 .73676 .33944 .74177 .34883 .74018 .34295 .73511 Mtetra
0 1 .409 r
.34295 .73511 .34883 .74018 .35827 .7383 .35241 .73315 Mtetra
0 1 .415 r
.35241 .73315 .35827 .7383 .36776 .73614 .36192 .7309 Mtetra
0 1 .418 r
.36192 .7309 .36776 .73614 .37729 .73371 .37148 .72837 Mtetra
0 1 .419 r
.37148 .72837 .37729 .73371 .38687 .73103 .38109 .72558 Mtetra
0 1 .417 r
.38109 .72558 .38687 .73103 .39649 .72811 .39073 .72253 Mtetra
0 1 .412 r
.39073 .72253 .39649 .72811 .40616 .72496 .40042 .71924 Mtetra
0 1 .405 r
.40042 .71924 .40616 .72496 .41586 .7216 .41015 .71572 Mtetra
0 1 .396 r
.41015 .71572 .41586 .7216 .4256 .71803 .41991 .71198 Mtetra
0 1 .385 r
.41991 .71198 .4256 .71803 .43537 .71427 .42971 .70805 Mtetra
0 1 .372 r
.42971 .70805 .43537 .71427 .44518 .71034 .43954 .70392 Mtetra
0 1 .357 r
.43954 .70392 .44518 .71034 .45502 .70624 .44941 .69963 Mtetra
0 1 .34 r
.44941 .69963 .45502 .70624 .46489 .702 .4593 .69516 Mtetra
0 1 .322 r
.4593 .69516 .46489 .702 .47478 .69761 .46922 .69055 Mtetra
0 1 .303 r
.46922 .69055 .47478 .69761 .48471 .69311 .47917 .68581 Mtetra
0 1 .282 r
.47917 .68581 .48471 .69311 .49466 .68849 .48915 .68095 Mtetra
0 1 .26 r
.48915 .68095 .49466 .68849 .50464 .68379 .49915 .67599 Mtetra
0 1 .238 r
.49915 .67599 .50464 .68379 .51465 .679 .50917 .67093 Mtetra
0 1 .214 r
.50917 .67093 .51465 .679 .52468 .67415 .51922 .66581 Mtetra
0 1 .191 r
.51922 .66581 .52468 .67415 .53473 .66926 .5293 .66063 Mtetra
0 1 .167 r
.5293 .66063 .53473 .66926 .54481 .66432 .53939 .65541 Mtetra
0 1 .142 r
.53939 .65541 .54481 .66432 .55492 .65937 .54951 .65017 Mtetra
0 1 .118 r
.54951 .65017 .55492 .65937 .56505 .65442 .55966 .64492 Mtetra
0 1 .094 r
.55966 .64492 .56505 .65442 .5752 .64948 .56982 .63969 Mtetra
0 1 .07 r
.56982 .63969 .5752 .64948 .58538 .64456 .58001 .63449 Mtetra
0 1 .047 r
.58001 .63449 .58538 .64456 .59559 .63968 .59023 .62933 Mtetra
0 1 .025 r
.59023 .62933 .59559 .63968 .60582 .63486 .60047 .62424 Mtetra
0 1 .003 r
.60047 .62424 .60582 .63486 .61609 .6301 .61074 .61922 Mtetra
.018 1 0 r
.61074 .61922 .61609 .6301 .62638 .62541 .62104 .61428 Mtetra
.038 1 0 r
.62104 .61428 .62638 .62541 .63671 .62081 .63137 .60945 Mtetra
.056 1 0 r
.63137 .60945 .63671 .62081 .64706 .6163 .64173 .60472 Mtetra
.073 1 0 r
.64173 .60472 .64706 .6163 .65745 .61189 .65212 .60011 Mtetra
.089 1 0 r
.65212 .60011 .65745 .61189 .66787 .60758 .66255 .59562 Mtetra
.104 1 0 r
.66255 .59562 .66787 .60758 .67833 .60338 .67301 .59125 Mtetra
.117 1 0 r
.67301 .59125 .67833 .60338 .68883 .59928 .68351 .587 Mtetra
.129 1 0 r
.68351 .587 .68883 .59928 .69937 .5953 .69405 .58289 Mtetra
.139 1 0 r
.69405 .58289 .69937 .5953 .70995 .59143 .70463 .57891 Mtetra
.148 1 0 r
.70463 .57891 .70995 .59143 .72057 .58768 .71525 .57505 Mtetra
.155 1 0 r
.71525 .57505 .72057 .58768 .73123 .58404 .72592 .57133 Mtetra
.161 1 0 r
.72592 .57133 .73123 .58404 .74193 .58052 .73663 .56774 Mtetra
.165 1 0 r
.73663 .56774 .74193 .58052 .75269 .57713 .74738 .56429 Mtetra
.168 1 0 r
.74738 .56429 .75269 .57713 .76349 .57387 .75819 .56097 Mtetra
.169 1 0 r
.75819 .56097 .76349 .57387 .77434 .57074 .76905 .55781 Mtetra
.168 1 0 r
.76905 .55781 .77434 .57074 .78525 .56776 .77996 .55479 Mtetra
.166 1 0 r
.77996 .55479 .78525 .56776 .79621 .56493 .79092 .55194 Mtetra
.162 1 0 r
.79092 .55194 .79621 .56493 .80723 .56226 .80195 .54925 Mtetra
.155 1 0 r
.80195 .54925 .80723 .56226 .81831 .55977 .81304 .54675 Mtetra
.147 1 0 r
.81304 .54675 .81831 .55977 .82946 .55748 .82419 .54444 Mtetra
.136 1 0 r
.82419 .54444 .82946 .55748 .84068 .5554 .83541 .54235 Mtetra
.123 1 0 r
.83541 .54235 .84068 .5554 .85197 .55354 .84671 .54048 Mtetra
.107 1 0 r
.84671 .54048 .85197 .55354 .86333 .55194 .85808 .53886 Mtetra
.089 1 0 r
.85808 .53886 .86333 .55194 .87479 .55062 .86954 .53752 Mtetra
.067 1 0 r
.86954 .53752 .87479 .55062 .88633 .54959 .88108 .53646 Mtetra
.042 1 0 r
.88108 .53646 .88633 .54959 .89797 .5489 .89272 .53572 Mtetra
.013 1 0 r
.89272 .53572 .89797 .5489 .90971 .54856 .90447 .53533 Mtetra
0 1 .02 r
.90447 .53533 .90971 .54856 .92156 .5486 .91632 .53531 Mtetra
0 1 .057 r
.91632 .53531 .92156 .5486 .93354 .54906 .92829 .53568 Mtetra
0 1 .098 r
.92829 .53568 .93354 .54906 .94564 .54998 .94039 .53649 Mtetra
0 1 .385 r
.31824 .73311 .32419 .73809 .33354 .73676 .32761 .73172 Mtetra
0 1 .397 r
.32761 .73172 .33354 .73676 .34295 .73511 .33704 .72999 Mtetra
0 1 .406 r
.33704 .72999 .34295 .73511 .35241 .73315 .34652 .72794 Mtetra
0 1 .412 r
.34652 .72794 .35241 .73315 .36192 .7309 .35605 .72559 Mtetra
0 1 .414 r
.35605 .72559 .36192 .7309 .37148 .72837 .36564 .72294 Mtetra
.36564 .72294 .37148 .72837 .38109 .72558 .37527 .72002 Mtetra
0 1 .41 r
.37527 .72002 .38109 .72558 .39073 .72253 .38494 .71683 Mtetra
0 1 .404 r
.38494 .71683 .39073 .72253 .40042 .71924 .39465 .71338 Mtetra
0 1 .396 r
.39465 .71338 .40042 .71924 .41015 .71572 .40441 .7097 Mtetra
0 1 .385 r
.40441 .7097 .41015 .71572 .41991 .71198 .4142 .70579 Mtetra
0 1 .372 r
.4142 .70579 .41991 .71198 .42971 .70805 .42402 .70166 Mtetra
0 1 .357 r
.42402 .70166 .42971 .70805 .43954 .70392 .43388 .69733 Mtetra
0 1 .34 r
.43388 .69733 .43954 .70392 .44941 .69963 .44377 .69282 Mtetra
0 1 .321 r
.44377 .69282 .44941 .69963 .4593 .69516 .45369 .68813 Mtetra
0 1 .301 r
.45369 .68813 .4593 .69516 .46922 .69055 .46363 .68328 Mtetra
0 1 .279 r
.46363 .68328 .46922 .69055 .47917 .68581 .47361 .67829 Mtetra
0 1 .256 r
.47361 .67829 .47917 .68581 .48915 .68095 .48361 .67317 Mtetra
0 1 .232 r
.48361 .67317 .48915 .68095 .49915 .67599 .49363 .66793 Mtetra
0 1 .207 r
.49363 .66793 .49915 .67599 .50917 .67093 .50367 .6626 Mtetra
0 1 .181 r
.50367 .6626 .50917 .67093 .51922 .66581 .51374 .65719 Mtetra
0 1 .154 r
.51374 .65719 .51922 .66581 .5293 .66063 .52383 .65171 Mtetra
0 1 .127 r
.52383 .65171 .5293 .66063 .53939 .65541 .53395 .64619 Mtetra
0 1 .1 r
.53395 .64619 .53939 .65541 .54951 .65017 .54408 .64065 Mtetra
0 1 .073 r
.54408 .64065 .54951 .65017 .55966 .64492 .55424 .6351 Mtetra
0 1 .046 r
.55424 .6351 .55966 .64492 .56982 .63969 .56442 .62956 Mtetra
0 1 .019 r
.56442 .62956 .56982 .63969 .58001 .63449 .57462 .62406 Mtetra
.007 1 0 r
.57462 .62406 .58001 .63449 .59023 .62933 .58485 .61861 Mtetra
.033 1 0 r
.58485 .61861 .59023 .62933 .60047 .62424 .5951 .61324 Mtetra
.057 1 0 r
.5951 .61324 .60047 .62424 .61074 .61922 .60537 .60795 Mtetra
.08 1 0 r
.60537 .60795 .61074 .61922 .62104 .61428 .61567 .60276 Mtetra
.102 1 0 r
.61567 .60276 .62104 .61428 .63137 .60945 .62601 .59768 Mtetra
.123 1 0 r
.62601 .59768 .63137 .60945 .64173 .60472 .63637 .59273 Mtetra
.142 1 0 r
.63637 .59273 .64173 .60472 .65212 .60011 .64676 .58792 Mtetra
.16 1 0 r
.64676 .58792 .65212 .60011 .66255 .59562 .65719 .58324 Mtetra
.176 1 0 r
.65719 .58324 .66255 .59562 .67301 .59125 .66766 .57871 Mtetra
.191 1 0 r
.66766 .57871 .67301 .59125 .68351 .587 .67816 .57431 Mtetra
.204 1 0 r
.67816 .57431 .68351 .587 .69405 .58289 .6887 .57007 Mtetra
.215 1 0 r
.6887 .57007 .69405 .58289 .70463 .57891 .69928 .56597 Mtetra
.225 1 0 r
.69928 .56597 .70463 .57891 .71525 .57505 .7099 .56202 Mtetra
.233 1 0 r
.7099 .56202 .71525 .57505 .72592 .57133 .72057 .55821 Mtetra
.239 1 0 r
.72057 .55821 .72592 .57133 .73663 .56774 .73128 .55454 Mtetra
.244 1 0 r
.73128 .55454 .73663 .56774 .74738 .56429 .74204 .55103 Mtetra
.247 1 0 r
.74204 .55103 .74738 .56429 .75819 .56097 .75285 .54766 Mtetra
.248 1 0 r
.75285 .54766 .75819 .56097 .76905 .55781 .76371 .54445 Mtetra
.76371 .54445 .76905 .55781 .77996 .55479 .77462 .54139 Mtetra
.245 1 0 r
.77462 .54139 .77996 .55479 .79092 .55194 .78559 .5385 Mtetra
.241 1 0 r
.78559 .5385 .79092 .55194 .80195 .54925 .79662 .53578 Mtetra
.235 1 0 r
.79662 .53578 .80195 .54925 .81304 .54675 .80771 .53325 Mtetra
.226 1 0 r
.80771 .53325 .81304 .54675 .82419 .54444 .81886 .53091 Mtetra
.216 1 0 r
.81886 .53091 .82419 .54444 .83541 .54235 .83009 .52879 Mtetra
.202 1 0 r
.83009 .52879 .83541 .54235 .84671 .54048 .84138 .52689 Mtetra
.186 1 0 r
.84138 .52689 .84671 .54048 .85808 .53886 .85276 .52523 Mtetra
.168 1 0 r
.85276 .52523 .85808 .53886 .86954 .53752 .86422 .52384 Mtetra
.146 1 0 r
.86422 .52384 .86954 .53752 .88108 .53646 .87576 .52272 Mtetra
.121 1 0 r
.87576 .52272 .88108 .53646 .89272 .53572 .8874 .52192 Mtetra
.092 1 0 r
.8874 .52192 .89272 .53572 .90447 .53533 .89914 .52144 Mtetra
.06 1 0 r
.89914 .52144 .90447 .53533 .91632 .53531 .91098 .52131 Mtetra
.024 1 0 r
.91098 .52131 .91632 .53531 .92829 .53568 .92294 .52157 Mtetra
0 1 .017 r
.92294 .52157 .92829 .53568 .94039 .53649 .93502 .52223 Mtetra
0 1 .384 r
.31224 .72814 .31824 .73311 .32761 .73172 .32163 .72667 Mtetra
0 1 .395 r
.32163 .72667 .32761 .73172 .33704 .72999 .33108 .72485 Mtetra
0 1 .403 r
.33108 .72485 .33704 .72999 .34652 .72794 .34059 .72269 Mtetra
0 1 .408 r
.34059 .72269 .34652 .72794 .35605 .72559 .35015 .72022 Mtetra
0 1 .409 r
.35015 .72022 .35605 .72559 .36564 .72294 .35976 .71744 Mtetra
0 1 .407 r
.35976 .71744 .36564 .72294 .37527 .72002 .36941 .71437 Mtetra
0 1 .403 r
.36941 .71437 .37527 .72002 .38494 .71683 .37911 .71103 Mtetra
0 1 .395 r
.37911 .71103 .38494 .71683 .39465 .71338 .38885 .70742 Mtetra
0 1 .385 r
.38885 .70742 .39465 .71338 .40441 .7097 .39863 .70355 Mtetra
0 1 .373 r
.39863 .70355 .40441 .7097 .4142 .70579 .40845 .69945 Mtetra
0 1 .358 r
.40845 .69945 .4142 .70579 .42402 .70166 .4183 .69512 Mtetra
0 1 .341 r
.4183 .69512 .42402 .70166 .43388 .69733 .42819 .69058 Mtetra
0 1 .322 r
.42819 .69058 .43388 .69733 .44377 .69282 .4381 .68584 Mtetra
0 1 .301 r
.4381 .68584 .44377 .69282 .45369 .68813 .44805 .68091 Mtetra
0 1 .278 r
.44805 .68091 .45369 .68813 .46363 .68328 .45802 .67581 Mtetra
0 1 .254 r
.45802 .67581 .46363 .68328 .47361 .67829 .46801 .67056 Mtetra
0 1 .228 r
.46801 .67056 .47361 .67829 .48361 .67317 .47804 .66516 Mtetra
0 1 .201 r
.47804 .66516 .48361 .67317 .49363 .66793 .48808 .65964 Mtetra
0 1 .173 r
.48808 .65964 .49363 .66793 .50367 .6626 .49815 .65401 Mtetra
0 1 .144 r
.49815 .65401 .50367 .6626 .51374 .65719 .50824 .6483 Mtetra
0 1 .115 r
.50824 .6483 .51374 .65719 .52383 .65171 .51835 .64251 Mtetra
0 1 .085 r
.51835 .64251 .52383 .65171 .53395 .64619 .52848 .63668 Mtetra
0 1 .054 r
.52848 .63668 .53395 .64619 .54408 .64065 .53863 .63081 Mtetra
0 1 .024 r
.53863 .63081 .54408 .64065 .55424 .6351 .5488 .62494 Mtetra
.006 1 0 r
.5488 .62494 .55424 .6351 .56442 .62956 .55899 .61909 Mtetra
.036 1 0 r
.55899 .61909 .56442 .62956 .57462 .62406 .5692 .61328 Mtetra
.065 1 0 r
.5692 .61328 .57462 .62406 .58485 .61861 .57943 .60752 Mtetra
.093 1 0 r
.57943 .60752 .58485 .61861 .5951 .61324 .58969 .60185 Mtetra
.121 1 0 r
.58969 .60185 .5951 .61324 .60537 .60795 .59997 .59628 Mtetra
.147 1 0 r
.59997 .59628 .60537 .60795 .61567 .60276 .61028 .59083 Mtetra
.171 1 0 r
.61028 .59083 .61567 .60276 .62601 .59768 .62062 .58551 Mtetra
.194 1 0 r
.62062 .58551 .62601 .59768 .63637 .59273 .63098 .58033 Mtetra
.216 1 0 r
.63098 .58033 .63637 .59273 .64676 .58792 .64138 .57531 Mtetra
.235 1 0 r
.64138 .57531 .64676 .58792 .65719 .58324 .65181 .57045 Mtetra
.253 1 0 r
.65181 .57045 .65719 .58324 .66766 .57871 .66227 .56575 Mtetra
.269 1 0 r
.66227 .56575 .66766 .57871 .67816 .57431 .67277 .56121 Mtetra
.283 1 0 r
.67277 .56121 .67816 .57431 .6887 .57007 .68331 .55683 Mtetra
.296 1 0 r
.68331 .55683 .6887 .57007 .69928 .56597 .69389 .55262 Mtetra
.306 1 0 r
.69389 .55262 .69928 .56597 .7099 .56202 .70452 .54857 Mtetra
.315 1 0 r
.70452 .54857 .7099 .56202 .72057 .55821 .71518 .54467 Mtetra
.322 1 0 r
.71518 .54467 .72057 .55821 .73128 .55454 .72589 .54093 Mtetra
.327 1 0 r
.72589 .54093 .73128 .55454 .74204 .55103 .73665 .53735 Mtetra
.331 1 0 r
.73665 .53735 .74204 .55103 .75285 .54766 .74746 .53393 Mtetra
.332 1 0 r
.74746 .53393 .75285 .54766 .76371 .54445 .75832 .53066 Mtetra
.75832 .53066 .76371 .54445 .77462 .54139 .76924 .52756 Mtetra
.33 1 0 r
.76924 .52756 .77462 .54139 .78559 .5385 .78021 .52463 Mtetra
.325 1 0 r
.78021 .52463 .78559 .5385 .79662 .53578 .79124 .52187 Mtetra
.319 1 0 r
.79124 .52187 .79662 .53578 .80771 .53325 .80233 .51929 Mtetra
.311 1 0 r
.80233 .51929 .80771 .53325 .81886 .53091 .81349 .51691 Mtetra
.3 1 0 r
.81349 .51691 .81886 .53091 .83009 .52879 .82471 .51474 Mtetra
.287 1 0 r
.82471 .51474 .83009 .52879 .84138 .52689 .836 .51278 Mtetra
.271 1 0 r
.836 .51278 .84138 .52689 .85276 .52523 .84738 .51106 Mtetra
.252 1 0 r
.84738 .51106 .85276 .52523 .86422 .52384 .85883 .5096 Mtetra
.231 1 0 r
.85883 .5096 .86422 .52384 .87576 .52272 .87037 .50841 Mtetra
.206 1 0 r
.87037 .50841 .87576 .52272 .8874 .52192 .882 .5075 Mtetra
.178 1 0 r
.882 .5075 .8874 .52192 .89914 .52144 .89373 .50691 Mtetra
.147 1 0 r
.89373 .50691 .89914 .52144 .91098 .52131 .90556 .50666 Mtetra
.111 1 0 r
.90556 .50666 .91098 .52131 .92294 .52157 .9175 .50676 Mtetra
.072 1 0 r
.9175 .50676 .92294 .52157 .93502 .52223 .92957 .50725 Mtetra
0 1 .383 r
.3062 .7232 .31224 .72814 .32163 .72667 .31561 .72163 Mtetra
0 1 .393 r
.31561 .72163 .32163 .72667 .33108 .72485 .32509 .71969 Mtetra
0 1 .4 r
.32509 .71969 .33108 .72485 .34059 .72269 .33462 .71741 Mtetra
0 1 .404 r
.33462 .71741 .34059 .72269 .35015 .72022 .3442 .71481 Mtetra
.3442 .71481 .35015 .72022 .35976 .71744 .35384 .71188 Mtetra
0 1 .401 r
.35384 .71188 .35976 .71744 .36941 .71437 .36352 .70865 Mtetra
0 1 .395 r
.36352 .70865 .36941 .71437 .37911 .71103 .37325 .70514 Mtetra
0 1 .386 r
.37325 .70514 .37911 .71103 .38885 .70742 .38302 .70135 Mtetra
0 1 .374 r
.38302 .70135 .38885 .70742 .39863 .70355 .39283 .69729 Mtetra
0 1 .36 r
.39283 .69729 .39863 .70355 .40845 .69945 .40267 .69299 Mtetra
0 1 .343 r
.40267 .69299 .40845 .69945 .4183 .69512 .41255 .68844 Mtetra
0 1 .324 r
.41255 .68844 .4183 .69512 .42819 .69058 .42246 .68367 Mtetra
0 1 .303 r
.42246 .68367 .42819 .69058 .4381 .68584 .4324 .67869 Mtetra
0 1 .279 r
.4324 .67869 .4381 .68584 .44805 .68091 .44237 .67352 Mtetra
0 1 .254 r
.44237 .67352 .44805 .68091 .45802 .67581 .45237 .66816 Mtetra
0 1 .227 r
.45237 .66816 .45802 .67581 .46801 .67056 .46239 .66263 Mtetra
0 1 .199 r
.46239 .66263 .46801 .67056 .47804 .66516 .47244 .65694 Mtetra
0 1 .169 r
.47244 .65694 .47804 .66516 .48808 .65964 .48251 .65113 Mtetra
0 1 .138 r
.48251 .65113 .48808 .65964 .49815 .65401 .4926 .64519 Mtetra
0 1 .106 r
.4926 .64519 .49815 .65401 .50824 .6483 .50271 .63916 Mtetra
0 1 .073 r
.50271 .63916 .50824 .6483 .51835 .64251 .51284 .63304 Mtetra
0 1 .04 r
.51284 .63304 .51835 .64251 .52848 .63668 .52298 .62688 Mtetra
0 1 .006 r
.52298 .62688 .52848 .63668 .53863 .63081 .53315 .62068 Mtetra
.028 1 0 r
.53315 .62068 .53863 .63081 .5488 .62494 .54333 .61447 Mtetra
.061 1 0 r
.54333 .61447 .5488 .62494 .55899 .61909 .55353 .60828 Mtetra
.094 1 0 r
.55353 .60828 .55899 .61909 .5692 .61328 .56376 .60213 Mtetra
.127 1 0 r
.56376 .60213 .5692 .61328 .57943 .60752 .574 .59606 Mtetra
.158 1 0 r
.574 .59606 .57943 .60752 .58969 .60185 .58426 .59008 Mtetra
.188 1 0 r
.58426 .59008 .58969 .60185 .59997 .59628 .59455 .58421 Mtetra
.217 1 0 r
.59455 .58421 .59997 .59628 .61028 .59083 .60486 .57848 Mtetra
.244 1 0 r
.60486 .57848 .61028 .59083 .62062 .58551 .6152 .57291 Mtetra
.27 1 0 r
.6152 .57291 .62062 .58551 .63098 .58033 .62556 .5675 Mtetra
.293 1 0 r
.62556 .5675 .63098 .58033 .64138 .57531 .63596 .56227 Mtetra
.315 1 0 r
.63596 .56227 .64138 .57531 .65181 .57045 .64639 .55723 Mtetra
.334 1 0 r
.64639 .55723 .65181 .57045 .66227 .56575 .65686 .55236 Mtetra
.352 1 0 r
.65686 .55236 .66227 .56575 .67277 .56121 .66736 .54768 Mtetra
.367 1 0 r
.66736 .54768 .67277 .56121 .68331 .55683 .6779 .54318 Mtetra
.38 1 0 r
.6779 .54318 .68331 .55683 .69389 .55262 .68848 .53886 Mtetra
.392 1 0 r
.68848 .53886 .69389 .55262 .70452 .54857 .6991 .53471 Mtetra
.401 1 0 r
.6991 .53471 .70452 .54857 .71518 .54467 .70976 .53073 Mtetra
.409 1 0 r
.70976 .53073 .71518 .54467 .72589 .54093 .72048 .52692 Mtetra
.414 1 0 r
.72048 .52692 .72589 .54093 .73665 .53735 .73124 .52327 Mtetra
.418 1 0 r
.73124 .52327 .73665 .53735 .74746 .53393 .74205 .51979 Mtetra
.42 1 0 r
.74205 .51979 .74746 .53393 .75832 .53066 .75291 .51647 Mtetra
.75291 .51647 .75832 .53066 .76924 .52756 .76382 .51331 Mtetra
.418 1 0 r
.76382 .51331 .76924 .52756 .78021 .52463 .77479 .51033 Mtetra
.414 1 0 r
.77479 .51033 .78021 .52463 .79124 .52187 .78582 .50752 Mtetra
.408 1 0 r
.78582 .50752 .79124 .52187 .80233 .51929 .79691 .50489 Mtetra
.399 1 0 r
.79691 .50489 .80233 .51929 .81349 .51691 .80806 .50245 Mtetra
.389 1 0 r
.80806 .50245 .81349 .51691 .82471 .51474 .81928 .50021 Mtetra
.376 1 0 r
.81928 .50021 .82471 .51474 .836 .51278 .83057 .49819 Mtetra
.361 1 0 r
.83057 .49819 .836 .51278 .84738 .51106 .84194 .49639 Mtetra
.342 1 0 r
.84194 .49639 .84738 .51106 .85883 .5096 .85338 .49483 Mtetra
.321 1 0 r
.85338 .49483 .85883 .5096 .87037 .50841 .86491 .49354 Mtetra
.298 1 0 r
.86491 .49354 .87037 .50841 .882 .5075 .87653 .49251 Mtetra
.27 1 0 r
.87653 .49251 .882 .5075 .89373 .50691 .88825 .49179 Mtetra
.24 1 0 r
.88825 .49179 .89373 .50691 .90556 .50666 .90006 .49138 Mtetra
.205 1 0 r
.90006 .49138 .90556 .50666 .9175 .50676 .91198 .4913 Mtetra
.167 1 0 r
.91198 .4913 .9175 .50676 .92957 .50725 .92402 .49159 Mtetra
0 1 .382 r
.30011 .7183 .3062 .7232 .31561 .72163 .30955 .7166 Mtetra
0 1 .392 r
.30955 .7166 .31561 .72163 .32509 .71969 .31905 .71453 Mtetra
0 1 .398 r
.31905 .71453 .32509 .71969 .33462 .71741 .32861 .71211 Mtetra
0 1 .4 r
.32861 .71211 .33462 .71741 .3442 .71481 .33822 .70935 Mtetra
0 1 .399 r
.33822 .70935 .3442 .71481 .35384 .71188 .34789 .70627 Mtetra
0 1 .394 r
.34789 .70627 .35384 .71188 .36352 .70865 .3576 .70287 Mtetra
0 1 .386 r
.3576 .70287 .36352 .70865 .37325 .70514 .36735 .69917 Mtetra
0 1 .376 r
.36735 .69917 .37325 .70514 .38302 .70135 .37715 .69519 Mtetra
0 1 .362 r
.37715 .69519 .38302 .70135 .39283 .69729 .38699 .69093 Mtetra
0 1 .346 r
.38699 .69093 .39283 .69729 .40267 .69299 .39686 .68641 Mtetra
0 1 .327 r
.39686 .68641 .40267 .69299 .41255 .68844 .40677 .68164 Mtetra
0 1 .305 r
.40677 .68164 .41255 .68844 .42246 .68367 .41671 .67663 Mtetra
0 1 .282 r
.41671 .67663 .42246 .68367 .4324 .67869 .42668 .6714 Mtetra
0 1 .256 r
.42668 .6714 .4324 .67869 .44237 .67352 .43668 .66596 Mtetra
0 1 .228 r
.43668 .66596 .44237 .67352 .45237 .66816 .4467 .66033 Mtetra
0 1 .199 r
.4467 .66033 .45237 .66816 .46239 .66263 .45675 .65451 Mtetra
0 1 .167 r
.45675 .65451 .46239 .66263 .47244 .65694 .46682 .64853 Mtetra
0 1 .135 r
.46682 .64853 .47244 .65694 .48251 .65113 .47691 .6424 Mtetra
0 1 .101 r
.47691 .6424 .48251 .65113 .4926 .64519 .48702 .63614 Mtetra
0 1 .065 r
.48702 .63614 .4926 .64519 .50271 .63916 .49715 .62977 Mtetra
0 1 .029 r
.49715 .62977 .50271 .63916 .51284 .63304 .5073 .62332 Mtetra
.008 1 0 r
.5073 .62332 .51284 .63304 .52298 .62688 .51746 .6168 Mtetra
.045 1 0 r
.51746 .6168 .52298 .62688 .53315 .62068 .52765 .61024 Mtetra
.082 1 0 r
.52765 .61024 .53315 .62068 .54333 .61447 .53784 .60368 Mtetra
.119 1 0 r
.53784 .60368 .54333 .61447 .55353 .60828 .54806 .59713 Mtetra
.156 1 0 r
.54806 .59713 .55353 .60828 .56376 .60213 .55829 .59064 Mtetra
.192 1 0 r
.55829 .59064 .56376 .60213 .574 .59606 .56854 .58422 Mtetra
.226 1 0 r
.56854 .58422 .574 .59606 .58426 .59008 .57881 .57791 Mtetra
.26 1 0 r
.57881 .57791 .58426 .59008 .59455 .58421 .5891 .57173 Mtetra
.292 1 0 r
.5891 .57173 .59455 .58421 .60486 .57848 .59942 .56572 Mtetra
.321 1 0 r
.59942 .56572 .60486 .57848 .6152 .57291 .60976 .55988 Mtetra
.349 1 0 r
.60976 .55988 .6152 .57291 .62556 .5675 .62012 .55424 Mtetra
.375 1 0 r
.62012 .55424 .62556 .5675 .63596 .56227 .63052 .5488 Mtetra
.398 1 0 r
.63052 .5488 .63596 .56227 .64639 .55723 .64095 .54357 Mtetra
.42 1 0 r
.64095 .54357 .64639 .55723 .65686 .55236 .65141 .53854 Mtetra
.438 1 0 r
.65141 .53854 .65686 .55236 .66736 .54768 .66191 .53372 Mtetra
.455 1 0 r
.66191 .53372 .66736 .54768 .6779 .54318 .67245 .5291 Mtetra
.469 1 0 r
.67245 .5291 .6779 .54318 .68848 .53886 .68303 .52468 Mtetra
.482 1 0 r
.68303 .52468 .68848 .53886 .6991 .53471 .69365 .52044 Mtetra
.492 1 0 r
.69365 .52044 .6991 .53471 .70976 .53073 .70432 .51638 Mtetra
.5 1 0 r
.70432 .51638 .70976 .53073 .72048 .52692 .71503 .5125 Mtetra
.506 1 0 r
.71503 .5125 .72048 .52692 .73124 .52327 .72578 .50879 Mtetra
.51 1 0 r
.72578 .50879 .73124 .52327 .74205 .51979 .73659 .50525 Mtetra
.512 1 0 r
.73659 .50525 .74205 .51979 .75291 .51647 .74745 .50187 Mtetra
.74745 .50187 .75291 .51647 .76382 .51331 .75836 .49866 Mtetra
.51 1 0 r
.75836 .49866 .76382 .51331 .77479 .51033 .76933 .49562 Mtetra
.507 1 0 r
.76933 .49562 .77479 .51033 .78582 .50752 .78035 .49275 Mtetra
.501 1 0 r
.78035 .49275 .78582 .50752 .79691 .50489 .79144 .49005 Mtetra
.493 1 0 r
.79144 .49005 .79691 .50489 .80806 .50245 .80259 .48755 Mtetra
.483 1 0 r
.80259 .48755 .80806 .50245 .81928 .50021 .8138 .48523 Mtetra
.47 1 0 r
.8138 .48523 .81928 .50021 .83057 .49819 .82509 .48312 Mtetra
.455 1 0 r
.82509 .48312 .83057 .49819 .84194 .49639 .83644 .48123 Mtetra
.438 1 0 r
.83644 .48123 .84194 .49639 .85338 .49483 .84788 .47956 Mtetra
.417 1 0 r
.84788 .47956 .85338 .49483 .86491 .49354 .8594 .47814 Mtetra
.394 1 0 r
.8594 .47814 .86491 .49354 .87653 .49251 .871 .47698 Mtetra
.368 1 0 r
.871 .47698 .87653 .49251 .88825 .49179 .8827 .4761 Mtetra
.339 1 0 r
.8827 .4761 .88825 .49179 .90006 .49138 .89449 .47551 Mtetra
.306 1 0 r
.89449 .47551 .90006 .49138 .91198 .4913 .90638 .47523 Mtetra
.27 1 0 r
.90638 .47523 .91198 .4913 .92402 .49159 .91839 .47529 Mtetra
0 1 .383 r
.29398 .71343 .30011 .7183 .30955 .7166 .30345 .7116 Mtetra
0 1 .391 r
.30345 .7116 .30955 .7166 .31905 .71453 .31298 .70938 Mtetra
0 1 .395 r
.31298 .70938 .31905 .71453 .32861 .71211 .32256 .7068 Mtetra
0 1 .396 r
.32256 .7068 .32861 .71211 .33822 .70935 .3322 .70387 Mtetra
0 1 .393 r
.3322 .70387 .33822 .70935 .34789 .70627 .3419 .70061 Mtetra
0 1 .387 r
.3419 .70061 .34789 .70627 .3576 .70287 .35164 .69703 Mtetra
0 1 .377 r
.35164 .69703 .3576 .70287 .36735 .69917 .36142 .69314 Mtetra
0 1 .365 r
.36142 .69314 .36735 .69917 .37715 .69519 .37125 .68895 Mtetra
0 1 .349 r
.37125 .68895 .37715 .69519 .38699 .69093 .38111 .68448 Mtetra
0 1 .331 r
.38111 .68448 .38699 .69093 .39686 .68641 .39102 .67973 Mtetra
0 1 .31 r
.39102 .67973 .39686 .68641 .40677 .68164 .40095 .67472 Mtetra
0 1 .286 r
.40095 .67472 .40677 .68164 .41671 .67663 .41092 .66947 Mtetra
0 1 .26 r
.41092 .66947 .41671 .67663 .42668 .6714 .42092 .66398 Mtetra
0 1 .232 r
.42092 .66398 .42668 .6714 .43668 .66596 .43095 .65827 Mtetra
0 1 .201 r
.43095 .65827 .43668 .66596 .4467 .66033 .441 .65235 Mtetra
0 1 .169 r
.441 .65235 .4467 .66033 .45675 .65451 .45107 .64623 Mtetra
0 1 .135 r
.45107 .64623 .45675 .65451 .46682 .64853 .46117 .63994 Mtetra
0 1 .099 r
.46117 .63994 .46682 .64853 .47691 .6424 .47129 .63348 Mtetra
0 1 .061 r
.47129 .63348 .47691 .6424 .48702 .63614 .48142 .62689 Mtetra
0 1 .023 r
.48142 .62689 .48702 .63614 .49715 .62977 .49157 .62017 Mtetra
.017 1 0 r
.49157 .62017 .49715 .62977 .5073 .62332 .50174 .61335 Mtetra
.057 1 0 r
.50174 .61335 .5073 .62332 .51746 .6168 .51192 .60646 Mtetra
.098 1 0 r
.51192 .60646 .51746 .6168 .52765 .61024 .52212 .59953 Mtetra
.139 1 0 r
.52212 .59953 .52765 .61024 .53784 .60368 .53233 .59258 Mtetra
.18 1 0 r
.53233 .59258 .53784 .60368 .54806 .59713 .54256 .58565 Mtetra
.221 1 0 r
.54256 .58565 .54806 .59713 .55829 .59064 .5528 .57878 Mtetra
.26 1 0 r
.5528 .57878 .55829 .59064 .56854 .58422 .56306 .572 Mtetra
.299 1 0 r
.56306 .572 .56854 .58422 .57881 .57791 .57334 .56534 Mtetra
.335 1 0 r
.57334 .56534 .57881 .57791 .5891 .57173 .58363 .55884 Mtetra
.37 1 0 r
.58363 .55884 .5891 .57173 .59942 .56572 .59395 .55252 Mtetra
.403 1 0 r
.59395 .55252 .59942 .56572 .60976 .55988 .60429 .54641 Mtetra
.433 1 0 r
.60429 .54641 .60976 .55988 .62012 .55424 .61466 .54053 Mtetra
.461 1 0 r
.61466 .54053 .62012 .55424 .63052 .5488 .62505 .53488 Mtetra
.487 1 0 r
.62505 .53488 .63052 .5488 .64095 .54357 .63548 .52947 Mtetra
.509 1 0 r
.63548 .52947 .64095 .54357 .65141 .53854 .64594 .52429 Mtetra
.53 1 0 r
.64594 .52429 .65141 .53854 .66191 .53372 .65644 .51933 Mtetra
.547 1 0 r
.65644 .51933 .66191 .53372 .67245 .5291 .66698 .5146 Mtetra
.563 1 0 r
.66698 .5146 .67245 .5291 .68303 .52468 .67755 .51008 Mtetra
.576 1 0 r
.67755 .51008 .68303 .52468 .69365 .52044 .68817 .50576 Mtetra
.586 1 0 r
.68817 .50576 .69365 .52044 .70432 .51638 .69884 .50163 Mtetra
.595 1 0 r
.69884 .50163 .70432 .51638 .71503 .5125 .70954 .49769 Mtetra
.601 1 0 r
.70954 .49769 .71503 .5125 .72578 .50879 .7203 .49392 Mtetra
.606 1 0 r
.7203 .49392 .72578 .50879 .73659 .50525 .73111 .49032 Mtetra
.608 1 0 r
.73111 .49032 .73659 .50525 .74745 .50187 .74196 .48688 Mtetra
.609 1 0 r
.74196 .48688 .74745 .50187 .75836 .49866 .75287 .48362 Mtetra
.607 1 0 r
.75287 .48362 .75836 .49866 .76933 .49562 .76383 .48051 Mtetra
.604 1 0 r
.76383 .48051 .76933 .49562 .78035 .49275 .77485 .47758 Mtetra
.598 1 0 r
.77485 .47758 .78035 .49275 .79144 .49005 .78593 .47482 Mtetra
.59 1 0 r
.78593 .47482 .79144 .49005 .80259 .48755 .79707 .47223 Mtetra
.581 1 0 r
.79707 .47223 .80259 .48755 .8138 .48523 .80828 .46983 Mtetra
.569 1 0 r
.80828 .46983 .8138 .48523 .82509 .48312 .81956 .46762 Mtetra
.554 1 0 r
.81956 .46762 .82509 .48312 .83644 .48123 .8309 .46562 Mtetra
.538 1 0 r
.8309 .46562 .83644 .48123 .84788 .47956 .84232 .46383 Mtetra
.518 1 0 r
.84232 .46383 .84788 .47956 .8594 .47814 .85382 .46226 Mtetra
.496 1 0 r
.85382 .46226 .8594 .47814 .871 .47698 .86541 .46094 Mtetra
.472 1 0 r
.86541 .46094 .871 .47698 .8827 .4761 .87708 .45988 Mtetra
.444 1 0 r
.87708 .45988 .8827 .4761 .89449 .47551 .88885 .45909 Mtetra
.412 1 0 r
.88885 .45909 .89449 .47551 .90638 .47523 .90072 .45859 Mtetra
.378 1 0 r
.90072 .45859 .90638 .47523 .91839 .47529 .91269 .4584 Mtetra
0 1 .384 r
.2878 .70862 .29398 .71343 .30345 .7116 .2973 .70662 Mtetra
0 1 .391 r
.2973 .70662 .30345 .7116 .31298 .70938 .30685 .70424 Mtetra
0 1 .394 r
.30685 .70424 .31298 .70938 .32256 .7068 .31647 .70148 Mtetra
0 1 .393 r
.31647 .70148 .32256 .7068 .3322 .70387 .32614 .69837 Mtetra
0 1 .388 r
.32614 .69837 .3322 .70387 .3419 .70061 .33587 .69492 Mtetra
0 1 .38 r
.33587 .69492 .3419 .70061 .35164 .69703 .34564 .69114 Mtetra
0 1 .368 r
.34564 .69114 .35164 .69703 .36142 .69314 .35545 .68704 Mtetra
0 1 .354 r
.35545 .68704 .36142 .69314 .37125 .68895 .36531 .68264 Mtetra
0 1 .336 r
.36531 .68264 .37125 .68895 .38111 .68448 .37521 .67794 Mtetra
0 1 .316 r
.37521 .67794 .38111 .68448 .39102 .67973 .38514 .67296 Mtetra
0 1 .292 r
.38514 .67296 .39102 .67973 .40095 .67472 .39511 .66771 Mtetra
0 1 .266 r
.39511 .66771 .40095 .67472 .41092 .66947 .40511 .6622 Mtetra
0 1 .238 r
.40511 .6622 .41092 .66947 .42092 .66398 .41514 .65644 Mtetra
0 1 .207 r
.41514 .65644 .42092 .66398 .43095 .65827 .42519 .65045 Mtetra
0 1 .173 r
.42519 .65045 .43095 .65827 .441 .65235 .43527 .64423 Mtetra
0 1 .138 r
.43527 .64423 .441 .65235 .45107 .64623 .44537 .6378 Mtetra
0 1 .101 r
.44537 .6378 .45107 .64623 .46117 .63994 .4555 .63119 Mtetra
0 1 .061 r
.4555 .63119 .46117 .63994 .47129 .63348 .46564 .62439 Mtetra
0 1 .02 r
.46564 .62439 .47129 .63348 .48142 .62689 .4758 .61744 Mtetra
.022 1 0 r
.4758 .61744 .48142 .62689 .49157 .62017 .48597 .61035 Mtetra
.065 1 0 r
.48597 .61035 .49157 .62017 .50174 .61335 .49616 .60316 Mtetra
.109 1 0 r
.49616 .60316 .50174 .61335 .51192 .60646 .50636 .59587 Mtetra
.154 1 0 r
.50636 .59587 .51192 .60646 .52212 .59953 .51658 .58854 Mtetra
.199 1 0 r
.51658 .58854 .52212 .59953 .53233 .59258 .52681 .58118 Mtetra
.244 1 0 r
.52681 .58118 .53233 .59258 .54256 .58565 .53704 .57384 Mtetra
.289 1 0 r
.53704 .57384 .54256 .58565 .5528 .57878 .5473 .56657 Mtetra
.333 1 0 r
.5473 .56657 .5528 .57878 .56306 .572 .55756 .55939 Mtetra
.375 1 0 r
.55756 .55939 .56306 .572 .57334 .56534 .56784 .55236 Mtetra
.415 1 0 r
.56784 .55236 .57334 .56534 .58363 .55884 .57814 .54551 Mtetra
.453 1 0 r
.57814 .54551 .58363 .55884 .59395 .55252 .58846 .53887 Mtetra
.489 1 0 r
.58846 .53887 .59395 .55252 .60429 .54641 .5988 .53248 Mtetra
.522 1 0 r
.5988 .53248 .60429 .54641 .61466 .54053 .60917 .52635 Mtetra
.552 1 0 r
.60917 .52635 .61466 .54053 .62505 .53488 .61956 .52049 Mtetra
.58 1 0 r
.61956 .52049 .62505 .53488 .63548 .52947 .62999 .5149 Mtetra
.604 1 0 r
.62999 .5149 .63548 .52947 .64594 .52429 .64045 .50958 Mtetra
.625 1 0 r
.64045 .50958 .64594 .52429 .65644 .51933 .65094 .50451 Mtetra
.644 1 0 r
.65094 .50451 .65644 .51933 .66698 .5146 .66148 .49968 Mtetra
.66 1 0 r
.66148 .49968 .66698 .5146 .67755 .51008 .67205 .49508 Mtetra
.674 1 0 r
.67205 .49508 .67755 .51008 .68817 .50576 .68267 .49069 Mtetra
.685 1 0 r
.68267 .49069 .68817 .50576 .69884 .50163 .69333 .4865 Mtetra
.694 1 0 r
.69333 .4865 .69884 .50163 .70954 .49769 .70403 .48249 Mtetra
.701 1 0 r
.70403 .48249 .70954 .49769 .7203 .49392 .71479 .47867 Mtetra
.705 1 0 r
.71479 .47867 .7203 .49392 .73111 .49032 .72559 .47502 Mtetra
.708 1 0 r
.72559 .47502 .73111 .49032 .74196 .48688 .73644 .47153 Mtetra
.709 1 0 r
.73644 .47153 .74196 .48688 .75287 .48362 .74734 .4682 Mtetra
.708 1 0 r
.74734 .4682 .75287 .48362 .76383 .48051 .7583 .46504 Mtetra
.704 1 0 r
.7583 .46504 .76383 .48051 .77485 .47758 .76932 .46203 Mtetra
.699 1 0 r
.76932 .46203 .77485 .47758 .78593 .47482 .78039 .45919 Mtetra
.692 1 0 r
.78039 .45919 .78593 .47482 .79707 .47223 .79152 .45652 Mtetra
.683 1 0 r
.79152 .45652 .79707 .47223 .80828 .46983 .80272 .45402 Mtetra
.672 1 0 r
.80272 .45402 .80828 .46983 .81956 .46762 .81398 .45171 Mtetra
.658 1 0 r
.81398 .45171 .81956 .46762 .8309 .46562 .82531 .44958 Mtetra
.642 1 0 r
.82531 .44958 .8309 .46562 .84232 .46383 .83672 .44765 Mtetra
.624 1 0 r
.83672 .44765 .84232 .46383 .85382 .46226 .8482 .44593 Mtetra
.603 1 0 r
.8482 .44593 .85382 .46226 .86541 .46094 .85977 .44444 Mtetra
.58 1 0 r
.85977 .44444 .86541 .46094 .87708 .45988 .87141 .44318 Mtetra
.554 1 0 r
.87141 .44318 .87708 .45988 .88885 .45909 .88315 .44217 Mtetra
.525 1 0 r
.88315 .44217 .88885 .45909 .90072 .45859 .89498 .44142 Mtetra
.492 1 0 r
.89498 .44142 .90072 .45859 .91269 .4584 .90692 .44096 Mtetra
0 1 .386 r
.28157 .70387 .2878 .70862 .2973 .70662 .2911 .70169 Mtetra
0 1 .391 r
.2911 .70169 .2973 .70662 .30685 .70424 .30069 .69911 Mtetra
0 1 .392 r
.30069 .69911 .30685 .70424 .31647 .70148 .31034 .69617 Mtetra
0 1 .389 r
.31034 .69617 .31647 .70148 .32614 .69837 .32004 .69286 Mtetra
0 1 .383 r
.32004 .69286 .32614 .69837 .33587 .69492 .3298 .68921 Mtetra
0 1 .373 r
.3298 .68921 .33587 .69492 .34564 .69114 .3396 .68522 Mtetra
0 1 .359 r
.3396 .68522 .34564 .69114 .35545 .68704 .34945 .6809 Mtetra
0 1 .343 r
.34945 .6809 .35545 .68704 .36531 .68264 .35934 .67627 Mtetra
0 1 .323 r
.35934 .67627 .36531 .68264 .37521 .67794 .36927 .67134 Mtetra
0 1 .3 r
.36927 .67134 .37521 .67794 .38514 .67296 .37923 .66612 Mtetra
0 1 .274 r
.37923 .66612 .38514 .67296 .39511 .66771 .38923 .66061 Mtetra
0 1 .246 r
.38923 .66061 .39511 .66771 .40511 .6622 .39926 .65484 Mtetra
0 1 .214 r
.39926 .65484 .40511 .6622 .41514 .65644 .40932 .6488 Mtetra
0 1 .181 r
.40932 .6488 .41514 .65644 .42519 .65045 .41941 .64251 Mtetra
0 1 .144 r
.41941 .64251 .42519 .65045 .43527 .64423 .42952 .63599 Mtetra
0 1 .106 r
.42952 .63599 .43527 .64423 .44537 .6378 .43965 .62924 Mtetra
0 1 .065 r
.43965 .62924 .44537 .6378 .4555 .63119 .4498 .62229 Mtetra
0 1 .023 r
.4498 .62229 .4555 .63119 .46564 .62439 .45997 .61515 Mtetra
.022 1 0 r
.45997 .61515 .46564 .62439 .4758 .61744 .47015 .60783 Mtetra
.068 1 0 r
.47015 .60783 .4758 .61744 .48597 .61035 .48035 .60035 Mtetra
.115 1 0 r
.48035 .60035 .48597 .61035 .49616 .60316 .49056 .59275 Mtetra
.163 1 0 r
.49056 .59275 .49616 .60316 .50636 .59587 .50078 .58506 Mtetra
.213 1 0 r
.50078 .58506 .50636 .59587 .51658 .58854 .51102 .57729 Mtetra
.262 1 0 r
.51102 .57729 .51658 .58854 .52681 .58118 .52126 .5695 Mtetra
.312 1 0 r
.52126 .5695 .52681 .58118 .53704 .57384 .53151 .56172 Mtetra
.361 1 0 r
.53151 .56172 .53704 .57384 .5473 .56657 .54177 .554 Mtetra
.408 1 0 r
.54177 .554 .5473 .56657 .55756 .55939 .55204 .54639 Mtetra
.455 1 0 r
.55204 .54639 .55756 .55939 .56784 .55236 .56233 .53895 Mtetra
.499 1 0 r
.56233 .53895 .56784 .55236 .57814 .54551 .57263 .53173 Mtetra
.541 1 0 r
.57263 .53173 .57814 .54551 .58846 .53887 .58295 .52476 Mtetra
.58 1 0 r
.58295 .52476 .58846 .53887 .5988 .53248 .59329 .51807 Mtetra
.616 1 0 r
.59329 .51807 .5988 .53248 .60917 .52635 .60366 .51169 Mtetra
.648 1 0 r
.60366 .51169 .60917 .52635 .61956 .52049 .61405 .50563 Mtetra
.677 1 0 r
.61405 .50563 .61956 .52049 .62999 .5149 .62447 .49987 Mtetra
.703 1 0 r
.62447 .49987 .62999 .5149 .64045 .50958 .63493 .49442 Mtetra
.726 1 0 r
.63493 .49442 .64045 .50958 .65094 .50451 .64542 .48924 Mtetra
.745 1 0 r
.64542 .48924 .65094 .50451 .66148 .49968 .65595 .48433 Mtetra
.762 1 0 r
.65595 .48433 .66148 .49968 .67205 .49508 .66653 .47966 Mtetra
.776 1 0 r
.66653 .47966 .67205 .49508 .68267 .49069 .67714 .47522 Mtetra
.788 1 0 r
.67714 .47522 .68267 .49069 .69333 .4865 .6878 .47098 Mtetra
.797 1 0 r
.6878 .47098 .69333 .4865 .70403 .48249 .6985 .46693 Mtetra
.804 1 0 r
.6985 .46693 .70403 .48249 .71479 .47867 .70925 .46306 Mtetra
.809 1 0 r
.70925 .46306 .71479 .47867 .72559 .47502 .72004 .45936 Mtetra
.812 1 0 r
.72004 .45936 .72559 .47502 .73644 .47153 .73089 .45582 Mtetra
.813 1 0 r
.73089 .45582 .73644 .47153 .74734 .4682 .74179 .45244 Mtetra
.812 1 0 r
.74179 .45244 .74734 .4682 .7583 .46504 .75274 .44921 Mtetra
.809 1 0 r
.75274 .44921 .7583 .46504 .76932 .46203 .76375 .44614 Mtetra
.804 1 0 r
.76375 .44614 .76932 .46203 .78039 .45919 .77481 .44322 Mtetra
.798 1 0 r
.77481 .44322 .78039 .45919 .79152 .45652 .78593 .44045 Mtetra
.789 1 0 r
.78593 .44045 .79152 .45652 .80272 .45402 .79712 .43785 Mtetra
.779 1 0 r
.79712 .43785 .80272 .45402 .81398 .45171 .80837 .43541 Mtetra
.766 1 0 r
.80837 .43541 .81398 .45171 .82531 .44958 .81969 .43315 Mtetra
.751 1 0 r
.81969 .43315 .82531 .44958 .83672 .44765 .83107 .43107 Mtetra
.735 1 0 r
.83107 .43107 .83672 .44765 .8482 .44593 .84253 .42918 Mtetra
.715 1 0 r
.84253 .42918 .8482 .44593 .85977 .44444 .85407 .4275 Mtetra
.693 1 0 r
.85407 .4275 .85977 .44444 .87141 .44318 .86569 .42603 Mtetra
.669 1 0 r
.86569 .42603 .87141 .44318 .88315 .44217 .8774 .42478 Mtetra
.642 1 0 r
.8774 .42478 .88315 .44217 .89498 .44142 .8892 .42378 Mtetra
.612 1 0 r
.8892 .42378 .89498 .44142 .90692 .44096 .90109 .42303 Mtetra
0 1 .389 r
.27529 .69917 .28157 .70387 .2911 .70169 .28486 .69679 Mtetra
0 1 .392 r
.28486 .69679 .2911 .70169 .30069 .69911 .29448 .69401 Mtetra
0 1 .391 r
.29448 .69401 .30069 .69911 .31034 .69617 .30416 .69086 Mtetra
0 1 .386 r
.30416 .69086 .31034 .69617 .32004 .69286 .3139 .68734 Mtetra
0 1 .378 r
.3139 .68734 .32004 .69286 .3298 .68921 .32369 .68347 Mtetra
0 1 .366 r
.32369 .68347 .3298 .68921 .3396 .68522 .33352 .67926 Mtetra
0 1 .35 r
.33352 .67926 .3396 .68522 .34945 .6809 .3434 .67472 Mtetra
0 1 .331 r
.3434 .67472 .34945 .6809 .35934 .67627 .35333 .66986 Mtetra
0 1 .309 r
.35333 .66986 .35934 .67627 .36927 .67134 .36329 .66468 Mtetra
0 1 .284 r
.36329 .66468 .36927 .67134 .37923 .66612 .37329 .65921 Mtetra
0 1 .256 r
.37329 .65921 .37923 .66612 .38923 .66061 .38332 .65344 Mtetra
0 1 .225 r
.38332 .65344 .38923 .66061 .39926 .65484 .39338 .64739 Mtetra
0 1 .191 r
.39338 .64739 .39926 .65484 .40932 .6488 .40348 .64107 Mtetra
0 1 .154 r
.40348 .64107 .40932 .6488 .41941 .64251 .41359 .63448 Mtetra
0 1 .115 r
.41359 .63448 .41941 .64251 .42952 .63599 .42373 .62765 Mtetra
0 1 .073 r
.42373 .62765 .42952 .63599 .43965 .62924 .43389 .62058 Mtetra
0 1 .029 r
.43389 .62058 .43965 .62924 .4498 .62229 .44407 .61328 Mtetra
.017 1 0 r
.44407 .61328 .4498 .62229 .45997 .61515 .45427 .60577 Mtetra
.065 1 0 r
.45427 .60577 .45997 .61515 .47015 .60783 .46448 .59807 Mtetra
.115 1 0 r
.46448 .59807 .47015 .60783 .48035 .60035 .4747 .59019 Mtetra
.167 1 0 r
.4747 .59019 .48035 .60035 .49056 .59275 .48494 .58217 Mtetra
.219 1 0 r
.48494 .58217 .49056 .59275 .50078 .58506 .49518 .57403 Mtetra
.273 1 0 r
.49518 .57403 .50078 .58506 .51102 .57729 .50543 .56581 Mtetra
.327 1 0 r
.50543 .56581 .51102 .57729 .52126 .5695 .51569 .55754 Mtetra
.382 1 0 r
.51569 .55754 .52126 .5695 .53151 .56172 .52596 .54928 Mtetra
.435 1 0 r
.52596 .54928 .53151 .56172 .54177 .554 .53623 .54108 Mtetra
.488 1 0 r
.53623 .54108 .54177 .554 .55204 .54639 .54651 .533 Mtetra
.539 1 0 r
.54651 .533 .55204 .54639 .56233 .53895 .5568 .52511 Mtetra
.588 1 0 r
.5568 .52511 .56233 .53895 .57263 .53173 .5671 .51747 Mtetra
.634 1 0 r
.5671 .51747 .57263 .53173 .58295 .52476 .57742 .51014 Mtetra
.676 1 0 r
.57742 .51014 .58295 .52476 .59329 .51807 .58776 .50314 Mtetra
.715 1 0 r
.58776 .50314 .59329 .51807 .60366 .51169 .59813 .49651 Mtetra
.75 1 0 r
.59813 .49651 .60366 .51169 .61405 .50563 .60851 .49025 Mtetra
.78 1 0 r
.60851 .49025 .61405 .50563 .62447 .49987 .61893 .48435 Mtetra
.808 1 0 r
.61893 .48435 .62447 .49987 .63493 .49442 .62939 .47878 Mtetra
.831 1 0 r
.62939 .47878 .63493 .49442 .64542 .48924 .63988 .47353 Mtetra
.851 1 0 r
.63988 .47353 .64542 .48924 .65595 .48433 .65041 .46856 Mtetra
.868 1 0 r
.65041 .46856 .65595 .48433 .66653 .47966 .66098 .46385 Mtetra
.883 1 0 r
.66098 .46385 .66653 .47966 .67714 .47522 .67159 .45937 Mtetra
.894 1 0 r
.67159 .45937 .67714 .47522 .6878 .47098 .68224 .4551 Mtetra
.904 1 0 r
.68224 .4551 .6878 .47098 .6985 .46693 .69294 .45102 Mtetra
.911 1 0 r
.69294 .45102 .6985 .46693 .70925 .46306 .70368 .44711 Mtetra
.916 1 0 r
.70368 .44711 .70925 .46306 .72004 .45936 .71447 .44337 Mtetra
.919 1 0 r
.71447 .44337 .72004 .45936 .73089 .45582 .72532 .43979 Mtetra
.92 1 0 r
.72532 .43979 .73089 .45582 .74179 .45244 .73621 .43635 Mtetra
.73621 .43635 .74179 .45244 .75274 .44921 .74715 .43306 Mtetra
.917 1 0 r
.74715 .43306 .75274 .44921 .76375 .44614 .75815 .42991 Mtetra
.913 1 0 r
.75815 .42991 .76375 .44614 .77481 .44322 .7692 .42691 Mtetra
.907 1 0 r
.7692 .42691 .77481 .44322 .78593 .44045 .78032 .42405 Mtetra
.899 1 0 r
.78032 .42405 .78593 .44045 .79712 .43785 .79149 .42133 Mtetra
.89 1 0 r
.79149 .42133 .79712 .43785 .80837 .43541 .80272 .41877 Mtetra
.878 1 0 r
.80272 .41877 .80837 .43541 .81969 .43315 .81402 .41636 Mtetra
.865 1 0 r
.81402 .41636 .81969 .43315 .83107 .43107 .82539 .41412 Mtetra
.849 1 0 r
.82539 .41412 .83107 .43107 .84253 .42918 .83683 .41206 Mtetra
.831 1 0 r
.83683 .41206 .84253 .42918 .85407 .4275 .84834 .41017 Mtetra
.811 1 0 r
.84834 .41017 .85407 .4275 .86569 .42603 .85993 .40848 Mtetra
.789 1 0 r
.85993 .40848 .86569 .42603 .8774 .42478 .8716 .40699 Mtetra
.764 1 0 r
.8716 .40699 .8774 .42478 .8892 .42378 .88336 .40571 Mtetra
.736 1 0 r
.88336 .40571 .8892 .42378 .90109 .42303 .8952 .40465 Mtetra
0 1 .393 r
.26897 .69453 .27529 .69917 .28486 .69679 .27856 .69192 Mtetra
0 1 .394 r
.27856 .69192 .28486 .69679 .29448 .69401 .28822 .68893 Mtetra
0 1 .391 r
.28822 .68893 .29448 .69401 .30416 .69086 .29794 .68556 Mtetra
0 1 .384 r
.29794 .68556 .30416 .69086 .3139 .68734 .30771 .68182 Mtetra
0 1 .373 r
.30771 .68182 .3139 .68734 .32369 .68347 .31754 .67772 Mtetra
0 1 .359 r
.31754 .67772 .32369 .68347 .33352 .67926 .32741 .67328 Mtetra
0 1 .341 r
.32741 .67328 .33352 .67926 .3434 .67472 .33732 .66851 Mtetra
0 1 .32 r
.33732 .66851 .3434 .67472 .35333 .66986 .34728 .6634 Mtetra
0 1 .296 r
.34728 .6634 .35333 .66986 .36329 .66468 .35728 .65798 Mtetra
0 1 .268 r
.35728 .65798 .36329 .66468 .37329 .65921 .36731 .65225 Mtetra
0 1 .237 r
.36731 .65225 .37329 .65921 .38332 .65344 .37738 .64621 Mtetra
0 1 .203 r
.37738 .64621 .38332 .65344 .39338 .64739 .38747 .63988 Mtetra
0 1 .167 r
.38747 .63988 .39338 .64739 .40348 .64107 .3976 .63327 Mtetra
0 1 .127 r
.3976 .63327 .40348 .64107 .41359 .63448 .40775 .62638 Mtetra
0 1 .085 r
.40775 .62638 .41359 .63448 .42373 .62765 .41792 .61923 Mtetra
0 1 .04 r
.41792 .61923 .42373 .62765 .43389 .62058 .42811 .61182 Mtetra
.008 1 0 r
.42811 .61182 .43389 .62058 .44407 .61328 .43832 .60417 Mtetra
.057 1 0 r
.43832 .60417 .44407 .61328 .45427 .60577 .44855 .59628 Mtetra
.109 1 0 r
.44855 .59628 .45427 .60577 .46448 .59807 .45879 .58819 Mtetra
.163 1 0 r
.45879 .58819 .46448 .59807 .4747 .59019 .46904 .5799 Mtetra
.219 1 0 r
.46904 .5799 .4747 .59019 .48494 .58217 .4793 .57143 Mtetra
.277 1 0 r
.4793 .57143 .48494 .58217 .49518 .57403 .48956 .56282 Mtetra
.335 1 0 r
.48956 .56282 .49518 .57403 .50543 .56581 .49983 .55411 Mtetra
.395 1 0 r
.49983 .55411 .50543 .56581 .51569 .55754 .51011 .54533 Mtetra
.454 1 0 r
.51011 .54533 .51569 .55754 .52596 .54928 .52039 .53654 Mtetra
.514 1 0 r
.52039 .53654 .52596 .54928 .53623 .54108 .53067 .5278 Mtetra
.572 1 0 r
.53067 .5278 .53623 .54108 .54651 .533 .54096 .5192 Mtetra
.628 1 0 r
.54096 .5192 .54651 .533 .5568 .52511 .55126 .51081 Mtetra
.682 1 0 r
.55126 .51081 .5568 .52511 .5671 .51747 .56156 .50271 Mtetra
.732 1 0 r
.56156 .50271 .5671 .51747 .57742 .51014 .57188 .49498 Mtetra
.778 1 0 r
.57188 .49498 .57742 .51014 .58776 .50314 .58222 .48766 Mtetra
.819 1 0 r
.58222 .48766 .58776 .50314 .59813 .49651 .59258 .48078 Mtetra
.857 1 0 r
.59258 .48078 .59813 .49651 .60851 .49025 .60296 .47434 Mtetra
.889 1 0 r
.60296 .47434 .60851 .49025 .61893 .48435 .61338 .46831 Mtetra
.917 1 0 r
.61338 .46831 .61893 .48435 .62939 .47878 .62383 .46267 Mtetra
.941 1 0 r
.62383 .46267 .62939 .47878 .63988 .47353 .63431 .45737 Mtetra
.962 1 0 r
.63431 .45737 .63988 .47353 .65041 .46856 .64484 .45237 Mtetra
.979 1 0 r
.64484 .45237 .65041 .46856 .66098 .46385 .6554 .44764 Mtetra
.993 1 0 r
.6554 .44764 .66098 .46385 .67159 .45937 .66601 .44314 Mtetra
1 .995 0 r
.66601 .44314 .67159 .45937 .68224 .4551 .67666 .43886 Mtetra
1 .986 0 r
.67666 .43886 .68224 .4551 .69294 .45102 .68736 .43477 Mtetra
1 .979 0 r
.68736 .43477 .69294 .45102 .70368 .44711 .6981 .43084 Mtetra
1 .974 0 r
.6981 .43084 .70368 .44711 .71447 .44337 .70888 .42707 Mtetra
1 .97 0 r
.70888 .42707 .71447 .44337 .72532 .43979 .71972 .42345 Mtetra
1 .969 0 r
.71972 .42345 .72532 .43979 .73621 .43635 .7306 .41996 Mtetra
.7306 .41996 .73621 .43635 .74715 .43306 .74154 .41661 Mtetra
1 .971 0 r
.74154 .41661 .74715 .43306 .75815 .42991 .75253 .41339 Mtetra
1 .975 0 r
.75253 .41339 .75815 .42991 .7692 .42691 .76357 .4103 Mtetra
1 .98 0 r
.76357 .4103 .7692 .42691 .78032 .42405 .77467 .40734 Mtetra
1 .987 0 r
.77467 .40734 .78032 .42405 .79149 .42133 .78583 .40451 Mtetra
1 .996 0 r
.78583 .40451 .79149 .42133 .80272 .41877 .79705 .40181 Mtetra
.993 1 0 r
.79705 .40181 .80272 .41877 .81402 .41636 .80833 .39926 Mtetra
.981 1 0 r
.80833 .39926 .81402 .41636 .82539 .41412 .81967 .39685 Mtetra
.967 1 0 r
.81967 .39685 .82539 .41412 .83683 .41206 .83109 .39459 Mtetra
.951 1 0 r
.83109 .39459 .83683 .41206 .84834 .41017 .84257 .39249 Mtetra
.933 1 0 r
.84257 .39249 .84834 .41017 .85993 .40848 .85413 .39057 Mtetra
.912 1 0 r
.85413 .39057 .85993 .40848 .8716 .40699 .86576 .38881 Mtetra
.89 1 0 r
.86576 .38881 .8716 .40699 .88336 .40571 .87748 .38725 Mtetra
.865 1 0 r
.87748 .38725 .88336 .40571 .8952 .40465 .88928 .38588 Mtetra
0 1 .397 r
.26259 .68994 .26897 .69453 .27856 .69192 .27222 .6871 Mtetra
0 1 .396 r
.27222 .6871 .27856 .69192 .28822 .68893 .28192 .68387 Mtetra
0 1 .391 r
.28192 .68387 .28822 .68893 .29794 .68556 .29168 .68026 Mtetra
0 1 .382 r
.29168 .68026 .29794 .68556 .30771 .68182 .30148 .67629 Mtetra
0 1 .369 r
.30148 .67629 .30771 .68182 .31754 .67772 .31134 .67196 Mtetra
0 1 .352 r
.31134 .67196 .31754 .67772 .32741 .67328 .32125 .66729 Mtetra
0 1 .332 r
.32125 .66729 .32741 .67328 .33732 .66851 .3312 .66227 Mtetra
0 1 .309 r
.3312 .66227 .33732 .66851 .34728 .6634 .3412 .65692 Mtetra
0 1 .282 r
.3412 .65692 .34728 .6634 .35728 .65798 .35123 .65124 Mtetra
0 1 .252 r
.35123 .65124 .35728 .65798 .36731 .65225 .3613 .64524 Mtetra
0 1 .218 r
.3613 .64524 .36731 .65225 .37738 .64621 .3714 .63894 Mtetra
0 1 .182 r
.3714 .63894 .37738 .64621 .38747 .63988 .38153 .63233 Mtetra
0 1 .142 r
.38153 .63233 .38747 .63988 .3976 .63327 .39169 .62542 Mtetra
0 1 .1 r
.39169 .62542 .3976 .63327 .40775 .62638 .40187 .61822 Mtetra
0 1 .054 r
.40187 .61822 .40775 .62638 .41792 .61923 .41208 .61075 Mtetra
0 1 .006 r
.41208 .61075 .41792 .61923 .42811 .61182 .4223 .603 Mtetra
.045 1 0 r
.4223 .603 .42811 .61182 .43832 .60417 .43254 .59498 Mtetra
.098 1 0 r
.43254 .59498 .43832 .60417 .44855 .59628 .4428 .58672 Mtetra
.154 1 0 r
.4428 .58672 .44855 .59628 .45879 .58819 .45307 .57822 Mtetra
.213 1 0 r
.45307 .57822 .45879 .58819 .46904 .5799 .46335 .5695 Mtetra
.273 1 0 r
.46335 .5695 .46904 .5799 .4793 .57143 .47363 .56057 Mtetra
.335 1 0 r
.47363 .56057 .4793 .57143 .48956 .56282 .48392 .55147 Mtetra
.399 1 0 r
.48392 .55147 .48956 .56282 .49983 .55411 .49421 .54223 Mtetra
.464 1 0 r
.49421 .54223 .49983 .55411 .51011 .54533 .50451 .5329 Mtetra
.529 1 0 r
.50451 .5329 .51011 .54533 .52039 .53654 .51481 .52352 Mtetra
.595 1 0 r
.51481 .52352 .52039 .53654 .53067 .5278 .5251 .51419 Mtetra
.659 1 0 r
.5251 .51419 .53067 .5278 .54096 .5192 .5354 .50498 Mtetra
.721 1 0 r
.5354 .50498 .54096 .5192 .55126 .51081 .5457 .49601 Mtetra
.781 1 0 r
.5457 .49601 .55126 .51081 .56156 .50271 .55601 .4874 Mtetra
.836 1 0 r
.55601 .4874 .56156 .50271 .57188 .49498 .56632 .47923 Mtetra
.886 1 0 r
.56632 .47923 .57188 .49498 .58222 .48766 .57666 .47157 Mtetra
.93 1 0 r
.57666 .47157 .58222 .48766 .59258 .48078 .58701 .46445 Mtetra
.97 1 0 r
.58701 .46445 .59258 .48078 .60296 .47434 .59739 .45785 Mtetra
1 .997 0 r
.59739 .45785 .60296 .47434 .61338 .46831 .6078 .45174 Mtetra
1 .968 0 r
.6078 .45174 .61338 .46831 .62383 .46267 .61825 .44606 Mtetra
1 .943 0 r
.61825 .44606 .62383 .46267 .63431 .45737 .62873 .44075 Mtetra
1 .923 0 r
.62873 .44075 .63431 .45737 .64484 .45237 .63925 .43576 Mtetra
1 .906 0 r
.63925 .43576 .64484 .45237 .6554 .44764 .64981 .43105 Mtetra
1 .892 0 r
.64981 .43105 .6554 .44764 .66601 .44314 .66042 .42657 Mtetra
1 .881 0 r
.66042 .42657 .66601 .44314 .67666 .43886 .67106 .4223 Mtetra
1 .872 0 r
.67106 .4223 .67666 .43886 .68736 .43477 .68175 .41821 Mtetra
1 .865 0 r
.68175 .41821 .68736 .43477 .6981 .43084 .69249 .41427 Mtetra
1 .86 0 r
.69249 .41427 .6981 .43084 .70888 .42707 .70327 .41049 Mtetra
1 .857 0 r
.70327 .41049 .70888 .42707 .71972 .42345 .7141 .40683 Mtetra
1 .855 0 r
.7141 .40683 .71972 .42345 .7306 .41996 .72498 .4033 Mtetra
.72498 .4033 .7306 .41996 .74154 .41661 .7359 .3999 Mtetra
1 .857 0 r
.7359 .3999 .74154 .41661 .75253 .41339 .74688 .3966 Mtetra
1 .86 0 r
.74688 .3966 .75253 .41339 .76357 .4103 .75792 .39342 Mtetra
1 .865 0 r
.75792 .39342 .76357 .4103 .77467 .40734 .769 .39036 Mtetra
1 .871 0 r
.769 .39036 .77467 .40734 .78583 .40451 .78014 .38741 Mtetra
1 .879 0 r
.78014 .38741 .78583 .40451 .79705 .40181 .79134 .38457 Mtetra
1 .888 0 r
.79134 .38457 .79705 .40181 .80833 .39926 .8026 .38186 Mtetra
1 .899 0 r
.8026 .38186 .80833 .39926 .81967 .39685 .81393 .37928 Mtetra
1 .911 0 r
.81393 .37928 .81967 .39685 .83109 .39459 .82531 .37683 Mtetra
1 .926 0 r
.82531 .37683 .83109 .39459 .84257 .39249 .83677 .37451 Mtetra
1 .942 0 r
.83677 .37451 .84257 .39249 .85413 .39057 .84829 .37234 Mtetra
1 .96 0 r
.84829 .37234 .85413 .39057 .86576 .38881 .85989 .37032 Mtetra
1 .98 0 r
.85989 .37032 .86576 .38881 .87748 .38725 .87156 .36846 Mtetra
.998 1 0 r
.87156 .36846 .87748 .38725 .88928 .38588 .88331 .36677 Mtetra
0 1 .403 r
.25616 .6854 .26259 .68994 .27222 .6871 .26583 .68231 Mtetra
0 1 .399 r
.26583 .68231 .27222 .6871 .28192 .68387 .27557 .67883 Mtetra
0 1 .391 r
.27557 .67883 .28192 .68387 .29168 .68026 .28536 .67498 Mtetra
0 1 .38 r
.28536 .67498 .29168 .68026 .30148 .67629 .29521 .67077 Mtetra
0 1 .365 r
.29521 .67077 .30148 .67629 .31134 .67196 .30511 .6662 Mtetra
0 1 .346 r
.30511 .6662 .31134 .67196 .32125 .66729 .31505 .66127 Mtetra
0 1 .324 r
.31505 .66127 .32125 .66729 .3312 .66227 .32504 .65601 Mtetra
0 1 .298 r
.32504 .65601 .3312 .66227 .3412 .65692 .33507 .65041 Mtetra
0 1 .268 r
.33507 .65041 .3412 .65692 .35123 .65124 .34514 .64447 Mtetra
0 1 .236 r
.34514 .64447 .35123 .65124 .3613 .64524 .35525 .63821 Mtetra
0 1 .2 r
.35525 .63821 .3613 .64524 .3714 .63894 .36539 .63163 Mtetra
0 1 .161 r
.36539 .63163 .3714 .63894 .38153 .63233 .37555 .62474 Mtetra
0 1 .118 r
.37555 .62474 .38153 .63233 .39169 .62542 .38575 .61753 Mtetra
0 1 .073 r
.38575 .61753 .39169 .62542 .40187 .61822 .39597 .61003 Mtetra
0 1 .024 r
.39597 .61003 .40187 .61822 .41208 .61075 .40621 .60223 Mtetra
.028 1 0 r
.40621 .60223 .41208 .61075 .4223 .603 .41646 .59413 Mtetra
.082 1 0 r
.41646 .59413 .4223 .603 .43254 .59498 .42674 .58576 Mtetra
.139 1 0 r
.42674 .58576 .43254 .59498 .4428 .58672 .43703 .57711 Mtetra
.199 1 0 r
.43703 .57711 .4428 .58672 .45307 .57822 .44733 .5682 Mtetra
.262 1 0 r
.44733 .5682 .45307 .57822 .46335 .5695 .45763 .55903 Mtetra
.327 1 0 r
.45763 .55903 .46335 .5695 .47363 .56057 .46795 .54963 Mtetra
.395 1 0 r
.46795 .54963 .47363 .56057 .48392 .55147 .47826 .54002 Mtetra
.464 1 0 r
.47826 .54002 .48392 .55147 .49421 .54223 .48858 .53022 Mtetra
.535 1 0 r
.48858 .53022 .49421 .54223 .50451 .5329 .4989 .52029 Mtetra
.607 1 0 r
.4989 .52029 .50451 .5329 .51481 .52352 .50921 .51026 Mtetra
.679 1 0 r
.50921 .51026 .51481 .52352 .5251 .51419 .51952 .50024 Mtetra
.75 1 0 r
.51952 .50024 .5251 .51419 .5354 .50498 .52983 .49034 Mtetra
.82 1 0 r
.52983 .49034 .5354 .50498 .5457 .49601 .54013 .48069 Mtetra
.885 1 0 r
.54013 .48069 .5457 .49601 .55601 .4874 .55044 .47147 Mtetra
.946 1 0 r
.55044 .47147 .55601 .4874 .56632 .47923 .56075 .4628 Mtetra
1 .999 0 r
.56075 .4628 .56632 .47923 .57666 .47157 .57108 .45478 Mtetra
1 .951 0 r
.57108 .45478 .57666 .47157 .58701 .46445 .58143 .44745 Mtetra
1 .91 0 r
.58143 .44745 .58701 .46445 .59739 .45785 .59181 .44075 Mtetra
1 .876 0 r
.59181 .44075 .59739 .45785 .6078 .45174 .60221 .43461 Mtetra
1 .847 0 r
.60221 .43461 .6078 .45174 .61825 .44606 .61265 .42895 Mtetra
1 .823 0 r
.61265 .42895 .61825 .44606 .62873 .44075 .62313 .42369 Mtetra
1 .803 0 r
.62313 .42369 .62873 .44075 .63925 .43576 .63365 .41876 Mtetra
1 .787 0 r
.63365 .41876 .63925 .43576 .64981 .43105 .64421 .4141 Mtetra
1 .773 0 r
.64421 .4141 .64981 .43105 .66042 .42657 .65481 .40967 Mtetra
1 .763 0 r
.65481 .40967 .66042 .42657 .67106 .4223 .66545 .40543 Mtetra
1 .754 0 r
.66545 .40543 .67106 .4223 .68175 .41821 .67614 .40136 Mtetra
1 .748 0 r
.67614 .40136 .68175 .41821 .69249 .41427 .68687 .39744 Mtetra
1 .743 0 r
.68687 .39744 .69249 .41427 .70327 .41049 .69764 .39364 Mtetra
1 .74 0 r
.69764 .39364 .70327 .41049 .7141 .40683 .70846 .38997 Mtetra
1 .738 0 r
.70846 .38997 .7141 .40683 .72498 .4033 .71933 .3864 Mtetra
.71933 .3864 .72498 .4033 .7359 .3999 .73025 .38294 Mtetra
1 .74 0 r
.73025 .38294 .7359 .3999 .74688 .3966 .74122 .37958 Mtetra
1 .742 0 r
.74122 .37958 .74688 .3966 .75792 .39342 .75224 .37631 Mtetra
1 .746 0 r
.75224 .37631 .75792 .39342 .769 .39036 .76331 .37314 Mtetra
1 .752 0 r
.76331 .37314 .769 .39036 .78014 .38741 .77444 .37007 Mtetra
1 .758 0 r
.77444 .37007 .78014 .38741 .79134 .38457 .78562 .3671 Mtetra
1 .767 0 r
.78562 .3671 .79134 .38457 .8026 .38186 .79686 .36422 Mtetra
1 .776 0 r
.79686 .36422 .8026 .38186 .81393 .37928 .80816 .36146 Mtetra
1 .787 0 r
.80816 .36146 .81393 .37928 .82531 .37683 .81952 .3588 Mtetra
1 .799 0 r
.81952 .3588 .82531 .37683 .83677 .37451 .83094 .35626 Mtetra
1 .813 0 r
.83094 .35626 .83677 .37451 .84829 .37234 .84243 .35384 Mtetra
1 .829 0 r
.84243 .35384 .84829 .37234 .85989 .37032 .85399 .35155 Mtetra
1 .846 0 r
.85399 .35155 .85989 .37032 .87156 .36846 .86561 .34938 Mtetra
1 .865 0 r
.86561 .34938 .87156 .36846 .88331 .36677 .87732 .34736 Mtetra
0 1 .409 r
.24968 .6809 .25616 .6854 .26583 .68231 .2594 .67754 Mtetra
0 1 .403 r
.2594 .67754 .26583 .68231 .27557 .67883 .26917 .67381 Mtetra
0 1 .393 r
.26917 .67381 .27557 .67883 .28536 .67498 .27901 .66971 Mtetra
0 1 .379 r
.27901 .66971 .28536 .67498 .29521 .67077 .28889 .66524 Mtetra
0 1 .361 r
.28889 .66524 .29521 .67077 .30511 .6662 .29883 .66042 Mtetra
0 1 .34 r
.29883 .66042 .30511 .6662 .31505 .66127 .30881 .65525 Mtetra
0 1 .315 r
.30881 .65525 .31505 .66127 .32504 .65601 .31884 .64974 Mtetra
0 1 .287 r
.31884 .64974 .32504 .65601 .33507 .65041 .32891 .64388 Mtetra
0 1 .255 r
.32891 .64388 .33507 .65041 .34514 .64447 .33902 .63769 Mtetra
0 1 .22 r
.33902 .63769 .34514 .64447 .35525 .63821 .34916 .63116 Mtetra
0 1 .181 r
.34916 .63116 .35525 .63821 .36539 .63163 .35934 .6243 Mtetra
0 1 .139 r
.35934 .6243 .36539 .63163 .37555 .62474 .36954 .61713 Mtetra
0 1 .094 r
.36954 .61713 .37555 .62474 .38575 .61753 .37977 .60963 Mtetra
0 1 .046 r
.37977 .60963 .38575 .61753 .39597 .61003 .39003 .60181 Mtetra
.006 1 0 r
.39003 .60181 .39597 .61003 .40621 .60223 .4003 .59369 Mtetra
.061 1 0 r
.4003 .59369 .40621 .60223 .41646 .59413 .41059 .58526 Mtetra
.119 1 0 r
.41059 .58526 .41646 .59413 .42674 .58576 .4209 .57652 Mtetra
.18 1 0 r
.4209 .57652 .42674 .58576 .43703 .57711 .43123 .56749 Mtetra
.244 1 0 r
.43123 .56749 .43703 .57711 .44733 .5682 .44156 .55816 Mtetra
.312 1 0 r
.44156 .55816 .44733 .5682 .45763 .55903 .4519 .54855 Mtetra
.382 1 0 r
.4519 .54855 .45763 .55903 .46795 .54963 .46224 .53867 Mtetra
.454 1 0 r
.46224 .53867 .46795 .54963 .47826 .54002 .47258 .52852 Mtetra
.529 1 0 r
.47258 .52852 .47826 .54002 .48858 .53022 .48293 .51814 Mtetra
.607 1 0 r
.48293 .51814 .48858 .53022 .4989 .52029 .49327 .50755 Mtetra
.686 1 0 r
.49327 .50755 .4989 .52029 .50921 .51026 .5036 .49681 Mtetra
.766 1 0 r
.5036 .49681 .50921 .51026 .51952 .50024 .51392 .48601 Mtetra
.845 1 0 r
.51392 .48601 .51952 .50024 .52983 .49034 .52424 .47528 Mtetra
.923 1 0 r
.52424 .47528 .52983 .49034 .54013 .48069 .53455 .4648 Mtetra
.997 1 0 r
.53455 .4648 .54013 .48069 .55044 .47147 .54486 .45483 Mtetra
1 .936 0 r
.54486 .45483 .55044 .47147 .56075 .4628 .55517 .44557 Mtetra
1 .876 0 r
.55517 .44557 .56075 .4628 .57108 .45478 .56549 .43719 Mtetra
1 .825 0 r
.56549 .43719 .57108 .45478 .58143 .44745 .57583 .42968 Mtetra
1 .783 0 r
.57583 .42968 .58143 .44745 .59181 .44075 .5862 .42296 Mtetra
1 .748 0 r
.5862 .42296 .59181 .44075 .60221 .43461 .59661 .41689 Mtetra
1 .72 0 r
.59661 .41689 .60221 .43461 .61265 .42895 .60704 .41133 Mtetra
1 .697 0 r
.60704 .41133 .61265 .42895 .62313 .42369 .61752 .40619 Mtetra
1 .678 0 r
.61752 .40619 .62313 .42369 .63365 .41876 .62803 .40137 Mtetra
1 .663 0 r
.62803 .40137 .63365 .41876 .64421 .4141 .63859 .39681 Mtetra
1 .651 0 r
.63859 .39681 .64421 .4141 .65481 .40967 .64918 .39247 Mtetra
1 .641 0 r
.64918 .39247 .65481 .40967 .66545 .40543 .65982 .38829 Mtetra
1 .634 0 r
.65982 .38829 .66545 .40543 .67614 .40136 .6705 .38427 Mtetra
1 .628 0 r
.6705 .38427 .67614 .40136 .68687 .39744 .68123 .38037 Mtetra
1 .624 0 r
.68123 .38037 .68687 .39744 .69764 .39364 .692 .37658 Mtetra
1 .621 0 r
.692 .37658 .69764 .39364 .70846 .38997 .70281 .37289 Mtetra
1 .619 0 r
.70281 .37289 .70846 .38997 .71933 .3864 .71367 .36929 Mtetra
.71367 .36929 .71933 .3864 .73025 .38294 .72458 .36578 Mtetra
1 .62 0 r
.72458 .36578 .73025 .38294 .74122 .37958 .73554 .36235 Mtetra
1 .622 0 r
.73554 .36235 .74122 .37958 .75224 .37631 .74655 .359 Mtetra
1 .626 0 r
.74655 .359 .75224 .37631 .76331 .37314 .7576 .35572 Mtetra
1 .63 0 r
.7576 .35572 .76331 .37314 .77444 .37007 .76871 .35253 Mtetra
1 .636 0 r
.76871 .35253 .77444 .37007 .78562 .3671 .77988 .34941 Mtetra
1 .643 0 r
.77988 .34941 .78562 .3671 .79686 .36422 .79109 .34638 Mtetra
1 .651 0 r
.79109 .34638 .79686 .36422 .80816 .36146 .80237 .34343 Mtetra
1 .66 0 r
.80237 .34343 .80816 .36146 .81952 .3588 .8137 .34056 Mtetra
1 .67 0 r
.8137 .34056 .81952 .3588 .83094 .35626 .82509 .33779 Mtetra
1 .682 0 r
.82509 .33779 .83094 .35626 .84243 .35384 .83655 .33511 Mtetra
1 .695 0 r
.83655 .33511 .84243 .35384 .85399 .35155 .84806 .33254 Mtetra
1 .71 0 r
.84806 .33254 .85399 .35155 .86561 .34938 .85965 .33007 Mtetra
1 .726 0 r
.85965 .33007 .86561 .34938 .87732 .34736 .8713 .32771 Mtetra
0 1 .415 r
.24315 .67642 .24968 .6809 .2594 .67754 .25291 .67279 Mtetra
0 1 .407 r
.25291 .67279 .2594 .67754 .26917 .67381 .26273 .6688 Mtetra
0 1 .394 r
.26273 .6688 .26917 .67381 .27901 .66971 .2726 .66444 Mtetra
0 1 .378 r
.2726 .66444 .27901 .66971 .28889 .66524 .28253 .65972 Mtetra
0 1 .358 r
.28253 .65972 .28889 .66524 .29883 .66042 .29251 .65465 Mtetra
0 1 .334 r
.29251 .65465 .29883 .66042 .30881 .65525 .30253 .64922 Mtetra
0 1 .307 r
.30253 .64922 .30881 .65525 .31884 .64974 .3126 .64346 Mtetra
0 1 .276 r
.3126 .64346 .31884 .64974 .32891 .64388 .32271 .63734 Mtetra
0 1 .242 r
.32271 .63734 .32891 .64388 .33902 .63769 .33285 .63089 Mtetra
0 1 .204 r
.33285 .63089 .33902 .63769 .34916 .63116 .34304 .6241 Mtetra
0 1 .163 r
.34304 .6241 .34916 .63116 .35934 .6243 .35325 .61697 Mtetra
0 1 .118 r
.35325 .61697 .35934 .6243 .36954 .61713 .36349 .60951 Mtetra
0 1 .07 r
.36349 .60951 .36954 .61713 .37977 .60963 .37376 .60172 Mtetra
0 1 .019 r
.37376 .60172 .37977 .60963 .39003 .60181 .38405 .5936 Mtetra
.036 1 0 r
.38405 .5936 .39003 .60181 .4003 .59369 .39436 .58516 Mtetra
.094 1 0 r
.39436 .58516 .4003 .59369 .41059 .58526 .40469 .57639 Mtetra
.156 1 0 r
.40469 .57639 .41059 .58526 .4209 .57652 .41504 .5673 Mtetra
.221 1 0 r
.41504 .5673 .4209 .57652 .43123 .56749 .4254 .55788 Mtetra
.289 1 0 r
.4254 .55788 .43123 .56749 .44156 .55816 .43576 .54815 Mtetra
.361 1 0 r
.43576 .54815 .44156 .55816 .4519 .54855 .44613 .53809 Mtetra
.435 1 0 r
.44613 .53809 .4519 .54855 .46224 .53867 .45651 .52772 Mtetra
.514 1 0 r
.45651 .52772 .46224 .53867 .47258 .52852 .46688 .51704 Mtetra
.595 1 0 r
.46688 .51704 .47258 .52852 .48293 .51814 .47725 .50605 Mtetra
.679 1 0 r
.47725 .50605 .48293 .51814 .49327 .50755 .48762 .49478 Mtetra
.766 1 0 r
.48762 .49478 .49327 .50755 .5036 .49681 .49798 .48326 Mtetra
.854 1 0 r
.49798 .48326 .5036 .49681 .51392 .48601 .50832 .47156 Mtetra
.944 1 0 r
.50832 .47156 .51392 .48601 .52424 .47528 .51865 .45982 Mtetra
1 .968 0 r
.51865 .45982 .52424 .47528 .53455 .4648 .52897 .44829 Mtetra
1 .884 0 r
.52897 .44829 .53455 .4648 .54486 .45483 .53928 .43733 Mtetra
1 .808 0 r
.53928 .43733 .54486 .45483 .55517 .44557 .54958 .42735 Mtetra
1 .743 0 r
.54958 .42735 .55517 .44557 .56549 .43719 .55989 .4186 Mtetra
1 .689 0 r
.55989 .4186 .56549 .43719 .57583 .42968 .57023 .41104 Mtetra
1 .647 0 r
.57023 .41104 .57583 .42968 .5862 .42296 .58059 .40443 Mtetra
1 .613 0 r
.58059 .40443 .5862 .42296 .59661 .41689 .59099 .39856 Mtetra
1 .587 0 r
.59099 .39856 .59661 .41689 .60704 .41133 .60142 .39322 Mtetra
1 .566 0 r
.60142 .39322 .60704 .41133 .61752 .40619 .6119 .38828 Mtetra
1 .549 0 r
.6119 .38828 .61752 .40619 .62803 .40137 .62241 .38364 Mtetra
1 .536 0 r
.62241 .38364 .62803 .40137 .63859 .39681 .63296 .37923 Mtetra
1 .525 0 r
.63296 .37923 .63859 .39681 .64918 .39247 .64355 .375 Mtetra
1 .517 0 r
.64355 .375 .64918 .39247 .65982 .38829 .65418 .37092 Mtetra
1 .51 0 r
.65418 .37092 .65982 .38829 .6705 .38427 .66486 .36696 Mtetra
1 .505 0 r
.66486 .36696 .6705 .38427 .68123 .38037 .67558 .3631 Mtetra
1 .502 0 r
.67558 .3631 .68123 .38037 .692 .37658 .68634 .35933 Mtetra
1 .499 0 r
.68634 .35933 .692 .37658 .70281 .37289 .69715 .35563 Mtetra
1 .498 0 r
.69715 .35563 .70281 .37289 .71367 .36929 .708 .35201 Mtetra
.708 .35201 .71367 .36929 .72458 .36578 .7189 .34845 Mtetra
1 .499 0 r
.7189 .34845 .72458 .36578 .73554 .36235 .72985 .34495 Mtetra
1 .5 0 r
.72985 .34495 .73554 .36235 .74655 .359 .74084 .34152 Mtetra
1 .503 0 r
.74084 .34152 .74655 .359 .7576 .35572 .75188 .33814 Mtetra
1 .507 0 r
.75188 .33814 .7576 .35572 .76871 .35253 .76298 .33482 Mtetra
1 .511 0 r
.76298 .33482 .76871 .35253 .77988 .34941 .77412 .33156 Mtetra
1 .517 0 r
.77412 .33156 .77988 .34941 .79109 .34638 .78532 .32836 Mtetra
1 .523 0 r
.78532 .32836 .79109 .34638 .80237 .34343 .79656 .32522 Mtetra
1 .531 0 r
.79656 .32522 .80237 .34343 .8137 .34056 .80787 .32215 Mtetra
1 .539 0 r
.80787 .32215 .8137 .34056 .82509 .33779 .81923 .31914 Mtetra
1 .548 0 r
.81923 .31914 .82509 .33779 .83655 .33511 .83064 .31621 Mtetra
1 .559 0 r
.83064 .31621 .83655 .33511 .84806 .33254 .84212 .31335 Mtetra
1 .571 0 r
.84212 .31335 .84806 .33254 .85965 .33007 .85366 .31057 Mtetra
1 .584 0 r
.85366 .31057 .85965 .33007 .8713 .32771 .86526 .30787 Mtetra
0 1 .423 r
.23656 .67196 .24315 .67642 .25291 .67279 .24637 .66805 Mtetra
0 1 .411 r
.24637 .66805 .25291 .67279 .26273 .6688 .25623 .66378 Mtetra
0 1 .396 r
.25623 .66378 .26273 .6688 .2726 .66444 .26615 .65916 Mtetra
0 1 .377 r
.26615 .65916 .2726 .66444 .28253 .65972 .27612 .65419 Mtetra
0 1 .355 r
.27612 .65419 .28253 .65972 .29251 .65465 .28614 .64886 Mtetra
0 1 .329 r
.28614 .64886 .29251 .65465 .30253 .64922 .29621 .64319 Mtetra
0 1 .299 r
.29621 .64319 .30253 .64922 .3126 .64346 .30631 .63717 Mtetra
0 1 .266 r
.30631 .63717 .3126 .64346 .32271 .63734 .31646 .6308 Mtetra
0 1 .229 r
.31646 .6308 .32271 .63734 .33285 .63089 .32665 .62409 Mtetra
0 1 .189 r
.32665 .62409 .33285 .63089 .34304 .6241 .33687 .61704 Mtetra
0 1 .145 r
.33687 .61704 .34304 .6241 .35325 .61697 .34712 .60964 Mtetra
0 1 .098 r
.34712 .60964 .35325 .61697 .36349 .60951 .3574 .60191 Mtetra
0 1 .047 r
.3574 .60191 .36349 .60951 .37376 .60172 .36771 .59383 Mtetra
.007 1 0 r
.36771 .59383 .37376 .60172 .38405 .5936 .37804 .58541 Mtetra
.065 1 0 r
.37804 .58541 .38405 .5936 .39436 .58516 .38839 .57666 Mtetra
.127 1 0 r
.38839 .57666 .39436 .58516 .40469 .57639 .39876 .56756 Mtetra
.192 1 0 r
.39876 .56756 .40469 .57639 .41504 .5673 .40914 .55812 Mtetra
.26 1 0 r
.40914 .55812 .41504 .5673 .4254 .55788 .41953 .54833 Mtetra
.333 1 0 r
.41953 .54833 .4254 .55788 .43576 .54815 .42994 .5382 Mtetra
.408 1 0 r
.42994 .5382 .43576 .54815 .44613 .53809 .44034 .52771 Mtetra
.488 1 0 r
.44034 .52771 .44613 .53809 .45651 .52772 .45075 .51687 Mtetra
.572 1 0 r
.45075 .51687 .45651 .52772 .46688 .51704 .46116 .50565 Mtetra
.659 1 0 r
.46116 .50565 .46688 .51704 .47725 .50605 .47156 .49406 Mtetra
.75 1 0 r
.47156 .49406 .47725 .50605 .48762 .49478 .48196 .48208 Mtetra
.845 1 0 r
.48196 .48208 .48762 .49478 .49798 .48326 .49234 .46973 Mtetra
.944 1 0 r
.49234 .46973 .49798 .48326 .50832 .47156 .50271 .45703 Mtetra
1 .955 0 r
.50271 .45703 .50832 .47156 .51865 .45982 .51306 .44407 Mtetra
1 .854 0 r
.51306 .44407 .51865 .45982 .52897 .44829 .52338 .43111 Mtetra
1 .756 0 r
.52338 .43111 .52897 .44829 .53928 .43733 .53369 .41874 Mtetra
1 .668 0 r
.53369 .41874 .53928 .43733 .54958 .42735 .54398 .40779 Mtetra
1 .596 0 r
.54398 .40779 .54958 .42735 .55989 .4186 .55429 .39874 Mtetra
1 .541 0 r
.55429 .39874 .55989 .4186 .57023 .41104 .56461 .39136 Mtetra
1 .5 0 r
.56461 .39136 .57023 .41104 .58059 .40443 .57497 .38513 Mtetra
1 .47 0 r
.57497 .38513 .58059 .40443 .59099 .39856 .58536 .37964 Mtetra
1 .447 0 r
.58536 .37964 .59099 .39856 .60142 .39322 .59579 .37466 Mtetra
1 .43 0 r
.59579 .37466 .60142 .39322 .6119 .38828 .60626 .37002 Mtetra
1 .416 0 r
.60626 .37002 .6119 .38828 .62241 .38364 .61677 .36562 Mtetra
1 .405 0 r
.61677 .36562 .62241 .38364 .63296 .37923 .62732 .3614 Mtetra
1 .397 0 r
.62732 .3614 .63296 .37923 .64355 .375 .63791 .35733 Mtetra
1 .39 0 r
.63791 .35733 .64355 .375 .65418 .37092 .64854 .35336 Mtetra
1 .385 0 r
.64854 .35336 .65418 .37092 .66486 .36696 .65921 .34948 Mtetra
1 .381 0 r
.65921 .34948 .66486 .36696 .67558 .3631 .66992 .34567 Mtetra
1 .378 0 r
.66992 .34567 .67558 .3631 .68634 .35933 .68068 .34193 Mtetra
1 .376 0 r
.68068 .34193 .68634 .35933 .69715 .35563 .69148 .33823 Mtetra
1 .375 0 r
.69148 .33823 .69715 .35563 .708 .35201 .70232 .33459 Mtetra
.70232 .33459 .708 .35201 .7189 .34845 .71321 .33099 Mtetra
.71321 .33099 .7189 .34845 .72985 .34495 .72415 .32743 Mtetra
1 .377 0 r
.72415 .32743 .72985 .34495 .74084 .34152 .73513 .32391 Mtetra
1 .379 0 r
.73513 .32391 .74084 .34152 .75188 .33814 .74615 .32042 Mtetra
1 .381 0 r
.74615 .32042 .75188 .33814 .76298 .33482 .75723 .31698 Mtetra
1 .385 0 r
.75723 .31698 .76298 .33482 .77412 .33156 .76835 .31357 Mtetra
1 .389 0 r
.76835 .31357 .77412 .33156 .78532 .32836 .77953 .31021 Mtetra
1 .394 0 r
.77953 .31021 .78532 .32836 .79656 .32522 .79075 .30688 Mtetra
1 .399 0 r
.79075 .30688 .79656 .32522 .80787 .32215 .80202 .3036 Mtetra
1 .406 0 r
.80202 .3036 .80787 .32215 .81923 .31914 .81335 .30036 Mtetra
1 .413 0 r
.81335 .30036 .81923 .31914 .83064 .31621 .82473 .29716 Mtetra
1 .421 0 r
.82473 .29716 .83064 .31621 .84212 .31335 .83617 .29402 Mtetra
1 .43 0 r
.83617 .29402 .84212 .31335 .85366 .31057 .84766 .29092 Mtetra
1 .44 0 r
.84766 .29092 .85366 .31057 .86526 .30787 .85921 .28788 Mtetra
0 1 .43 r
.22992 .6675 .23656 .67196 .24637 .66805 .23978 .66331 Mtetra
0 1 .416 r
.23978 .66331 .24637 .66805 .25623 .66378 .24969 .65877 Mtetra
0 1 .399 r
.24969 .65877 .25623 .66378 .26615 .65916 .25965 .65388 Mtetra
0 1 .377 r
.25965 .65388 .26615 .65916 .27612 .65419 .26967 .64865 Mtetra
0 1 .352 r
.26967 .64865 .27612 .65419 .28614 .64886 .27973 .64307 Mtetra
0 1 .324 r
.27973 .64307 .28614 .64886 .29621 .64319 .28984 .63715 Mtetra
0 1 .292 r
.28984 .63715 .29621 .64319 .30631 .63717 .29999 .63087 Mtetra
0 1 .256 r
.29999 .63087 .30631 .63717 .31646 .6308 .31018 .62426 Mtetra
0 1 .217 r
.31018 .62426 .31646 .6308 .32665 .62409 .3204 .61729 Mtetra
0 1 .174 r
.3204 .61729 .32665 .62409 .33687 .61704 .33067 .60998 Mtetra
0 1 .128 r
.33067 .60998 .33687 .61704 .34712 .60964 .34096 .60233 Mtetra
0 1 .078 r
.34096 .60233 .34712 .60964 .3574 .60191 .35128 .59432 Mtetra
0 1 .025 r
.35128 .59432 .3574 .60191 .36771 .59383 .36163 .58597 Mtetra
.033 1 0 r
.36163 .58597 .36771 .59383 .37804 .58541 .372 .57726 Mtetra
.093 1 0 r
.372 .57726 .37804 .58541 .38839 .57666 .38239 .5682 Mtetra
.158 1 0 r
.38239 .5682 .38839 .57666 .39876 .56756 .39279 .55879 Mtetra
.226 1 0 r
.39279 .55879 .39876 .56756 .40914 .55812 .40321 .54902 Mtetra
.299 1 0 r
.40321 .54902 .40914 .55812 .41953 .54833 .41364 .53888 Mtetra
.375 1 0 r
.41364 .53888 .41953 .54833 .42994 .5382 .42408 .52836 Mtetra
.455 1 0 r
.42408 .52836 .42994 .5382 .44034 .52771 .43452 .51746 Mtetra
.539 1 0 r
.43452 .51746 .44034 .52771 .45075 .51687 .44497 .50616 Mtetra
.628 1 0 r
.44497 .50616 .45075 .51687 .46116 .50565 .45541 .49444 Mtetra
.721 1 0 r
.45541 .49444 .46116 .50565 .47156 .49406 .46585 .48226 Mtetra
.82 1 0 r
.46585 .48226 .47156 .49406 .48196 .48208 .47627 .46961 Mtetra
.923 1 0 r
.47627 .46961 .48196 .48208 .49234 .46973 .48669 .45642 Mtetra
1 .968 0 r
.48669 .45642 .49234 .46973 .50271 .45703 .49708 .44266 Mtetra
1 .854 0 r
.49708 .44266 .50271 .45703 .51306 .44407 .50745 .42827 Mtetra
1 .735 0 r
.50745 .42827 .51306 .44407 .52338 .43111 .5178 .41336 Mtetra
1 .617 0 r
.5178 .41336 .52338 .43111 .53369 .41874 .5281 .39862 Mtetra
1 .511 0 r
.5281 .39862 .53369 .41874 .54398 .40779 .53839 .38612 Mtetra
1 .431 0 r
.53839 .38612 .54398 .40779 .55429 .39874 .54868 .37717 Mtetra
1 .378 0 r
.54868 .37717 .55429 .39874 .56461 .39136 .55899 .37053 Mtetra
1 .343 0 r
.55899 .37053 .56461 .39136 .57497 .38513 .56935 .36506 Mtetra
1 .319 0 r
.56935 .36506 .57497 .38513 .58536 .37964 .57974 .3602 Mtetra
1 .302 0 r
.57974 .3602 .58536 .37964 .59579 .37466 .59016 .35572 Mtetra
1 .289 0 r
.59016 .35572 .59579 .37466 .60626 .37002 .60063 .35146 Mtetra
1 .28 0 r
.60063 .35146 .60626 .37002 .61677 .36562 .61113 .34737 Mtetra
1 .272 0 r
.61113 .34737 .61677 .36562 .62732 .3614 .62168 .34339 Mtetra
1 .266 0 r
.62168 .34339 .62732 .3614 .63791 .35733 .63226 .33949 Mtetra
1 .261 0 r
.63226 .33949 .63791 .35733 .64854 .35336 .64289 .33566 Mtetra
1 .258 0 r
.64289 .33566 .64854 .35336 .65921 .34948 .65355 .33187 Mtetra
1 .255 0 r
.65355 .33187 .65921 .34948 .66992 .34567 .66426 .32813 Mtetra
1 .253 0 r
.66426 .32813 .66992 .34567 .68068 .34193 .67501 .32442 Mtetra
1 .252 0 r
.67501 .32442 .68068 .34193 .69148 .33823 .6858 .32073 Mtetra
1 .251 0 r
.6858 .32073 .69148 .33823 .70232 .33459 .69664 .31707 Mtetra
.69664 .31707 .70232 .33459 .71321 .33099 .70752 .31343 Mtetra
.70752 .31343 .71321 .33099 .72415 .32743 .71844 .30981 Mtetra
1 .252 0 r
.71844 .30981 .72415 .32743 .73513 .32391 .72941 .3062 Mtetra
1 .253 0 r
.72941 .3062 .73513 .32391 .74615 .32042 .74042 .30262 Mtetra
1 .255 0 r
.74042 .30262 .74615 .32042 .75723 .31698 .75148 .29905 Mtetra
1 .257 0 r
.75148 .29905 .75723 .31698 .76835 .31357 .76258 .2955 Mtetra
1 .26 0 r
.76258 .2955 .76835 .31357 .77953 .31021 .77373 .29196 Mtetra
1 .263 0 r
.77373 .29196 .77953 .31021 .79075 .30688 .78493 .28845 Mtetra
1 .267 0 r
.78493 .28845 .79075 .30688 .80202 .3036 .79617 .28495 Mtetra
1 .271 0 r
.79617 .28495 .80202 .3036 .81335 .30036 .80747 .28148 Mtetra
1 .276 0 r
.80747 .28148 .81335 .30036 .82473 .29716 .81881 .27802 Mtetra
1 .281 0 r
.81881 .27802 .82473 .29716 .83617 .29402 .83021 .27459 Mtetra
1 .287 0 r
.83021 .27459 .83617 .29402 .84766 .29092 .84166 .27118 Mtetra
1 .294 0 r
.84166 .27118 .84766 .29092 .85921 .28788 .85316 .2678 Mtetra
0 1 .438 r
.22324 .66302 .22992 .6675 .23978 .66331 .23314 .65854 Mtetra
0 1 .422 r
.23314 .65854 .23978 .66331 .24969 .65877 .2431 .65373 Mtetra
0 1 .401 r
.2431 .65373 .24969 .65877 .25965 .65388 .25311 .64858 Mtetra
0 1 .377 r
.25311 .64858 .25965 .65388 .26967 .64865 .26316 .6431 Mtetra
0 1 .35 r
.26316 .6431 .26967 .64865 .27973 .64307 .27327 .63727 Mtetra
0 1 .319 r
.27327 .63727 .27973 .64307 .28984 .63715 .28342 .6311 Mtetra
0 1 .285 r
.28342 .6311 .28984 .63715 .29999 .63087 .29361 .62458 Mtetra
0 1 .247 r
.29361 .62458 .29999 .63087 .31018 .62426 .30385 .61772 Mtetra
0 1 .205 r
.30385 .61772 .31018 .62426 .3204 .61729 .31412 .61051 Mtetra
0 1 .16 r
.31412 .61051 .3204 .61729 .33067 .60998 .32442 .60295 Mtetra
0 1 .111 r
.32442 .60295 .33067 .60998 .34096 .60233 .33475 .59504 Mtetra
0 1 .059 r
.33475 .59504 .34096 .60233 .35128 .59432 .34511 .58677 Mtetra
0 1 .003 r
.34511 .58677 .35128 .59432 .36163 .58597 .3555 .57815 Mtetra
.057 1 0 r
.3555 .57815 .36163 .58597 .372 .57726 .36591 .56917 Mtetra
.121 1 0 r
.36591 .56917 .372 .57726 .38239 .5682 .37634 .55982 Mtetra
.188 1 0 r
.37634 .55982 .38239 .5682 .39279 .55879 .38679 .55011 Mtetra
.26 1 0 r
.38679 .55011 .39279 .55879 .40321 .54902 .39725 .54002 Mtetra
.335 1 0 r
.39725 .54002 .40321 .54902 .41364 .53888 .40771 .52954 Mtetra
.415 1 0 r
.40771 .52954 .41364 .53888 .42408 .52836 .41819 .51867 Mtetra
.499 1 0 r
.41819 .51867 .42408 .52836 .43452 .51746 .42867 .50739 Mtetra
.588 1 0 r
.42867 .50739 .43452 .51746 .44497 .50616 .43915 .49567 Mtetra
.682 1 0 r
.43915 .49567 .44497 .50616 .45541 .49444 .44963 .48348 Mtetra
.781 1 0 r
.44963 .48348 .45541 .49444 .46585 .48226 .4601 .47078 Mtetra
.885 1 0 r
.4601 .47078 .46585 .48226 .47627 .46961 .47057 .45751 Mtetra
.997 1 0 r
.47057 .45751 .47627 .46961 .48669 .45642 .48101 .44357 Mtetra
1 .884 0 r
.48101 .44357 .48669 .45642 .49708 .44266 .49144 .42882 Mtetra
1 .756 0 r
.49144 .42882 .49708 .44266 .50745 .42827 .50184 .41301 Mtetra
1 .617 0 r
.50184 .41301 .50745 .42827 .5178 .41336 .51221 .39573 Mtetra
1 .465 0 r
.51221 .39573 .5178 .41336 .5281 .39862 .52253 .37634 Mtetra
1 .324 0 r
.52253 .37634 .5281 .39862 .53839 .38612 .53279 .3603 Mtetra
1 .235 0 r
.53279 .3603 .53839 .38612 .54868 .37717 .54307 .35347 Mtetra
1 .196 0 r
.54307 .35347 .54868 .37717 .55899 .37053 .55338 .34865 Mtetra
1 .175 0 r
.55338 .34865 .55899 .37053 .56935 .36506 .56372 .3444 Mtetra
1 .162 0 r
.56372 .3444 .56935 .36506 .57974 .3602 .57411 .3404 Mtetra
1 .152 0 r
.57411 .3404 .57974 .3602 .59016 .35572 .58453 .33653 Mtetra
1 .146 0 r
.58453 .33653 .59016 .35572 .60063 .35146 .59499 .33273 Mtetra
1 .14 0 r
.59499 .33273 .60063 .35146 .61113 .34737 .60549 .32898 Mtetra
1 .136 0 r
.60549 .32898 .61113 .34737 .62168 .34339 .61603 .32526 Mtetra
1 .133 0 r
.61603 .32526 .62168 .34339 .63226 .33949 .62661 .32156 Mtetra
1 .131 0 r
.62661 .32156 .63226 .33949 .64289 .33566 .63723 .31787 Mtetra
1 .129 0 r
.63723 .31787 .64289 .33566 .65355 .33187 .64789 .31419 Mtetra
1 .128 0 r
.64789 .31419 .65355 .33187 .66426 .32813 .65859 .31051 Mtetra
1 .127 0 r
.65859 .31051 .66426 .32813 .67501 .32442 .66934 .30684 Mtetra
1 .126 0 r
.66934 .30684 .67501 .32442 .6858 .32073 .68012 .30317 Mtetra
.68012 .30317 .6858 .32073 .69664 .31707 .69095 .29949 Mtetra
.69095 .29949 .69664 .31707 .70752 .31343 .70182 .29581 Mtetra
.70182 .29581 .70752 .31343 .71844 .30981 .71273 .29213 Mtetra
.71273 .29213 .71844 .30981 .72941 .3062 .72368 .28845 Mtetra
1 .127 0 r
.72368 .28845 .72941 .3062 .74042 .30262 .73468 .28476 Mtetra
1 .128 0 r
.73468 .28476 .74042 .30262 .75148 .29905 .74572 .28107 Mtetra
1 .129 0 r
.74572 .28107 .75148 .29905 .76258 .2955 .7568 .27737 Mtetra
1 .13 0 r
.7568 .27737 .76258 .2955 .77373 .29196 .76793 .27367 Mtetra
1 .132 0 r
.76793 .27367 .77373 .29196 .78493 .28845 .7791 .26996 Mtetra
1 .134 0 r
.7791 .26996 .78493 .28845 .79617 .28495 .79032 .26626 Mtetra
1 .136 0 r
.79032 .26626 .79617 .28495 .80747 .28148 .80158 .26255 Mtetra
1 .138 0 r
.80158 .26255 .80747 .28148 .81881 .27802 .81289 .25883 Mtetra
1 .141 0 r
.81289 .25883 .81881 .27802 .83021 .27459 .82425 .25512 Mtetra
1 .144 0 r
.82425 .25512 .83021 .27459 .84166 .27118 .83565 .2514 Mtetra
1 .147 0 r
.83565 .2514 .84166 .27118 .85316 .2678 .8471 .24768 Mtetra
0 1 .447 r
.2165 .65851 .22324 .66302 .23314 .65854 .22645 .65375 Mtetra
0 1 .427 r
.22645 .65375 .23314 .65854 .2431 .65373 .23646 .64867 Mtetra
0 1 .404 r
.23646 .64867 .2431 .65373 .25311 .64858 .24651 .64326 Mtetra
0 1 .378 r
.24651 .64326 .25311 .64858 .26316 .6431 .25662 .63752 Mtetra
0 1 .348 r
.25662 .63752 .26316 .6431 .27327 .63727 .26677 .63145 Mtetra
0 1 .315 r
.26677 .63145 .27327 .63727 .28342 .6311 .27696 .62504 Mtetra
0 1 .278 r
.27696 .62504 .28342 .6311 .29361 .62458 .2872 .61828 Mtetra
0 1 .238 r
.2872 .61828 .29361 .62458 .30385 .61772 .29747 .61118 Mtetra
0 1 .194 r
.29747 .61118 .30385 .61772 .31412 .61051 .30778 .60374 Mtetra
0 1 .147 r
.30778 .60374 .31412 .61051 .32442 .60295 .31813 .59593 Mtetra
0 1 .096 r
.31813 .59593 .32442 .60295 .33475 .59504 .3285 .58778 Mtetra
0 1 .041 r
.3285 .58778 .33475 .59504 .34511 .58677 .33891 .57926 Mtetra
.018 1 0 r
.33891 .57926 .34511 .58677 .3555 .57815 .34934 .57038 Mtetra
.08 1 0 r
.34934 .57038 .3555 .57815 .36591 .56917 .35979 .56114 Mtetra
.147 1 0 r
.35979 .56114 .36591 .56917 .37634 .55982 .37026 .55152 Mtetra
.217 1 0 r
.37026 .55152 .37634 .55982 .38679 .55011 .38074 .54153 Mtetra
.292 1 0 r
.38074 .54153 .38679 .55011 .39725 .54002 .39124 .53114 Mtetra
.37 1 0 r
.39124 .53114 .39725 .54002 .40771 .52954 .40175 .52036 Mtetra
.453 1 0 r
.40175 .52036 .40771 .52954 .41819 .51867 .41227 .50917 Mtetra
.541 1 0 r
.41227 .50917 .41819 .51867 .42867 .50739 .42278 .49754 Mtetra
.634 1 0 r
.42278 .49754 .42867 .50739 .43915 .49567 .4333 .48545 Mtetra
.732 1 0 r
.4333 .48545 .43915 .49567 .44963 .48348 .44382 .47286 Mtetra
.836 1 0 r
.44382 .47286 .44963 .48348 .4601 .47078 .45433 .45971 Mtetra
.946 1 0 r
.45433 .45971 .4601 .47078 .47057 .45751 .46483 .44594 Mtetra
1 .936 0 r
.46483 .44594 .47057 .45751 .48101 .44357 .47531 .43141 Mtetra
1 .808 0 r
.47531 .43141 .48101 .44357 .49144 .42882 .48577 .41593 Mtetra
1 .668 0 r
.48577 .41593 .49144 .42882 .50184 .41301 .49621 .39914 Mtetra
1 .511 0 r
.49621 .39914 .50184 .41301 .51221 .39573 .50661 .38031 Mtetra
1 .324 0 r
.50661 .38031 .51221 .39573 .52253 .37634 .51697 .35736 Mtetra
1 .111 0 r
.51697 .35736 .52253 .37634 .53279 .3603 .52724 .34126 Mtetra
1 0 .066 r
.52724 .34126 .53279 .3603 .54307 .35347 .53751 .33776 Mtetra
1 0 .181 r
.53751 .33776 .54307 .35347 .55338 .34865 .54783 .33424 Mtetra
1 0 .269 r
.54783 .33424 .55338 .34865 .56372 .3444 .55818 .33071 Mtetra
1 0 .345 r
.55818 .33071 .56372 .3444 .57411 .3404 .56858 .32716 Mtetra
1 0 .414 r
.56858 .32716 .57411 .3404 .58453 .33653 .57901 .32361 Mtetra
1 0 .476 r
.57901 .32361 .58453 .33653 .59499 .33273 .58948 .32004 Mtetra
1 0 .534 r
.58948 .32004 .59499 .33273 .60549 .32898 .59999 .31645 Mtetra
1 0 .588 r
.59999 .31645 .60549 .32898 .61603 .32526 .61054 .31285 Mtetra
1 0 .639 r
.61054 .31285 .61603 .32526 .62661 .32156 .62113 .30924 Mtetra
1 0 .687 r
.62113 .30924 .62661 .32156 .63723 .31787 .63176 .30561 Mtetra
1 0 .732 r
.63176 .30561 .63723 .31787 .64789 .31419 .64244 .30197 Mtetra
1 0 .774 r
.64244 .30197 .64789 .31419 .65859 .31051 .65315 .29832 Mtetra
1 0 .815 r
.65315 .29832 .65859 .31051 .66934 .30684 .6639 .29465 Mtetra
1 0 .853 r
.6639 .29465 .66934 .30684 .68012 .30317 .6747 .29097 Mtetra
1 0 .889 r
.6747 .29097 .68012 .30317 .69095 .29949 .68553 .28728 Mtetra
1 0 .923 r
.68553 .28728 .69095 .29949 .70182 .29581 .69641 .28357 Mtetra
1 0 .955 r
.69641 .28357 .70182 .29581 .71273 .29213 .70733 .27984 Mtetra
1 0 .984 r
.70733 .27984 .71273 .29213 .72368 .28845 .71829 .27611 Mtetra
.988 0 1 r
.71829 .27611 .72368 .28845 .73468 .28476 .72929 .27235 Mtetra
.962 0 1 r
.72929 .27235 .73468 .28476 .74572 .28107 .74034 .26859 Mtetra
.938 0 1 r
.74034 .26859 .74572 .28107 .7568 .27737 .75143 .2648 Mtetra
.916 0 1 r
.75143 .2648 .7568 .27737 .76793 .27367 .76256 .26101 Mtetra
.895 0 1 r
.76256 .26101 .76793 .27367 .7791 .26996 .77374 .2572 Mtetra
.877 0 1 r
.77374 .2572 .7791 .26996 .79032 .26626 .78496 .25337 Mtetra
.86 0 1 r
.78496 .25337 .79032 .26626 .80158 .26255 .79622 .24953 Mtetra
.846 0 1 r
.79622 .24953 .80158 .26255 .81289 .25883 .80753 .24567 Mtetra
.833 0 1 r
.80753 .24567 .81289 .25883 .82425 .25512 .81888 .2418 Mtetra
.821 0 1 r
.81888 .2418 .82425 .25512 .83565 .2514 .83028 .23791 Mtetra
.812 0 1 r
.83028 .23791 .83565 .2514 .8471 .24768 .84172 .23401 Mtetra
0 1 .455 r
.20971 .65394 .2165 .65851 .22645 .65375 .21972 .64891 Mtetra
0 1 .432 r
.21972 .64891 .22645 .65375 .23646 .64867 .22977 .64356 Mtetra
0 1 .407 r
.22977 .64356 .23646 .64867 .24651 .64326 .23987 .6379 Mtetra
0 1 .378 r
.23987 .6379 .24651 .64326 .25662 .63752 .25002 .63192 Mtetra
0 1 .346 r
.25002 .63192 .25662 .63752 .26677 .63145 .26022 .62561 Mtetra
0 1 .311 r
.26022 .62561 .26677 .63145 .27696 .62504 .27046 .61897 Mtetra
0 1 .272 r
.27046 .61897 .27696 .62504 .2872 .61828 .28074 .61199 Mtetra
0 1 .23 r
.28074 .61199 .2872 .61828 .29747 .61118 .29105 .60466 Mtetra
0 1 .184 r
.29105 .60466 .29747 .61118 .30778 .60374 .30141 .59698 Mtetra
0 1 .134 r
.30141 .59698 .30778 .60374 .31813 .59593 .3118 .58895 Mtetra
0 1 .081 r
.3118 .58895 .31813 .59593 .3285 .58778 .32221 .58056 Mtetra
0 1 .023 r
.32221 .58056 .3285 .58778 .33891 .57926 .33266 .57181 Mtetra
.038 1 0 r
.33266 .57181 .33891 .57926 .34934 .57038 .34313 .56269 Mtetra
.102 1 0 r
.34313 .56269 .34934 .57038 .35979 .56114 .35362 .5532 Mtetra
.171 1 0 r
.35362 .5532 .35979 .56114 .37026 .55152 .36413 .54333 Mtetra
.244 1 0 r
.36413 .54333 .37026 .55152 .38074 .54153 .37466 .53307 Mtetra
.321 1 0 r
.37466 .53307 .38074 .54153 .39124 .53114 .3852 .52242 Mtetra
.403 1 0 r
.3852 .52242 .39124 .53114 .40175 .52036 .39575 .51135 Mtetra
.489 1 0 r
.39575 .51135 .40175 .52036 .41227 .50917 .4063 .49987 Mtetra
.58 1 0 r
.4063 .49987 .41227 .50917 .42278 .49754 .41686 .48794 Mtetra
.676 1 0 r
.41686 .48794 .42278 .49754 .4333 .48545 .42742 .47553 Mtetra
.778 1 0 r
.42742 .47553 .4333 .48545 .44382 .47286 .43797 .46261 Mtetra
.886 1 0 r
.43797 .46261 .44382 .47286 .45433 .45971 .44852 .44912 Mtetra
1 .999 0 r
.44852 .44912 .45433 .45971 .46483 .44594 .45906 .43498 Mtetra
1 .876 0 r
.45906 .43498 .46483 .44594 .47531 .43141 .46958 .42008 Mtetra
1 .743 0 r
.46958 .42008 .47531 .43141 .48577 .41593 .48008 .40422 Mtetra
1 .596 0 r
.48008 .40422 .48577 .41593 .49621 .39914 .49055 .38714 Mtetra
1 .431 0 r
.49055 .38714 .49621 .39914 .50661 .38031 .50098 .36839 Mtetra
1 .235 0 r
.50098 .36839 .50661 .38031 .51697 .35736 .51137 .34756 Mtetra
1 0 0 r
.51137 .34756 .51697 .35736 .52724 .34126 .52167 .33478 Mtetra
0 1 .462 r
.20288 .64931 .20971 .65394 .21972 .64891 .21293 .644 Mtetra
0 1 .438 r
.21293 .644 .21972 .64891 .22977 .64356 .22303 .63841 Mtetra
0 1 .41 r
.22303 .63841 .22977 .64356 .23987 .6379 .23318 .6325 Mtetra
0 1 .379 r
.23318 .6325 .23987 .6379 .25002 .63192 .24338 .62629 Mtetra
0 1 .345 r
.24338 .62629 .25002 .63192 .26022 .62561 .25362 .61975 Mtetra
0 1 .307 r
.25362 .61975 .26022 .62561 .27046 .61897 .26391 .61289 Mtetra
0 1 .266 r
.26391 .61289 .27046 .61897 .28074 .61199 .27423 .60569 Mtetra
0 1 .222 r
.27423 .60569 .28074 .61199 .29105 .60466 .28459 .59814 Mtetra
0 1 .174 r
.28459 .59814 .29105 .60466 .30141 .59698 .29499 .59025 Mtetra
0 1 .122 r
.29499 .59025 .30141 .59698 .3118 .58895 .30542 .582 Mtetra
0 1 .066 r
.30542 .582 .3118 .58895 .32221 .58056 .31588 .57339 Mtetra
0 1 .007 r
.31588 .57339 .32221 .58056 .33266 .57181 .32637 .56442 Mtetra
.056 1 0 r
.32637 .56442 .33266 .57181 .34313 .56269 .33688 .55507 Mtetra
.123 1 0 r
.33688 .55507 .34313 .56269 .35362 .5532 .34741 .54535 Mtetra
.194 1 0 r
.34741 .54535 .35362 .5532 .36413 .54333 .35796 .53524 Mtetra
.27 1 0 r
.35796 .53524 .36413 .54333 .37466 .53307 .36853 .52475 Mtetra
.349 1 0 r
.36853 .52475 .37466 .53307 .3852 .52242 .37911 .51385 Mtetra
.433 1 0 r
.37911 .51385 .3852 .52242 .39575 .51135 .3897 .50254 Mtetra
.522 1 0 r
.3897 .50254 .39575 .51135 .4063 .49987 .4003 .4908 Mtetra
.616 1 0 r
.4003 .4908 .4063 .49987 .41686 .48794 .4109 .47861 Mtetra
.715 1 0 r
.4109 .47861 .41686 .48794 .42742 .47553 .42149 .46595 Mtetra
.819 1 0 r
.42149 .46595 .42742 .47553 .43797 .46261 .43209 .45277 Mtetra
.93 1 0 r
.43209 .45277 .43797 .46261 .44852 .44912 .44267 .43904 Mtetra
1 .951 0 r
.44267 .43904 .44852 .44912 .45906 .43498 .45325 .42467 Mtetra
1 .825 0 r
.45325 .42467 .45906 .43498 .46958 .42008 .4638 .40959 Mtetra
1 .689 0 r
.4638 .40959 .46958 .42008 .48008 .40422 .47434 .39367 Mtetra
1 .541 0 r
.47434 .39367 .48008 .40422 .49055 .38714 .48484 .37676 Mtetra
1 .378 0 r
.48484 .37676 .49055 .38714 .50098 .36839 .49531 .35875 Mtetra
1 .196 0 r
.49531 .35875 .50098 .36839 .51137 .34756 .50573 .33974 Mtetra
1 0 0 r
.50573 .33974 .51137 .34756 .52167 .33478 .51607 .32826 Mtetra
0 1 .47 r
.196 .64458 .20288 .64931 .21293 .644 .2061 .63902 Mtetra
0 1 .442 r
.2061 .63902 .21293 .644 .22303 .63841 .21625 .63318 Mtetra
0 1 .412 r
.21625 .63318 .22303 .63841 .23318 .6325 .22645 .62705 Mtetra
0 1 .379 r
.22645 .62705 .23318 .6325 .24338 .62629 .23669 .62062 Mtetra
0 1 .343 r
.23669 .62062 .24338 .62629 .25362 .61975 .24698 .61387 Mtetra
0 1 .303 r
.24698 .61387 .25362 .61975 .26391 .61289 .25731 .60679 Mtetra
0 1 .261 r
.25731 .60679 .26391 .61289 .27423 .60569 .26767 .59938 Mtetra
0 1 .214 r
.26767 .59938 .27423 .60569 .28459 .59814 .27808 .59164 Mtetra
0 1 .164 r
.27808 .59164 .28459 .59814 .29499 .59025 .28852 .58354 Mtetra
0 1 .11 r
.28852 .58354 .29499 .59025 .30542 .582 .29899 .57509 Mtetra
0 1 .053 r
.29899 .57509 .30542 .582 .31588 .57339 .3095 .56627 Mtetra
.008 1 0 r
.3095 .56627 .31588 .57339 .32637 .56442 .32003 .55709 Mtetra
.073 1 0 r
.32003 .55709 .32637 .56442 .33688 .55507 .33058 .54753 Mtetra
.142 1 0 r
.33058 .54753 .33688 .55507 .34741 .54535 .34116 .5376 Mtetra
.216 1 0 r
.34116 .5376 .34741 .54535 .35796 .53524 .35175 .52728 Mtetra
.293 1 0 r
.35175 .52728 .35796 .53524 .36853 .52475 .36236 .51657 Mtetra
.375 1 0 r
.36236 .51657 .36853 .52475 .37911 .51385 .37298 .50545 Mtetra
.461 1 0 r
.37298 .50545 .37911 .51385 .3897 .50254 .38362 .49392 Mtetra
.552 1 0 r
.38362 .49392 .3897 .50254 .4003 .4908 .39425 .48197 Mtetra
.648 1 0 r
.39425 .48197 .4003 .4908 .4109 .47861 .40489 .46957 Mtetra
.75 1 0 r
.40489 .46957 .4109 .47861 .42149 .46595 .41553 .4567 Mtetra
.857 1 0 r
.41553 .4567 .42149 .46595 .43209 .45277 .42616 .44334 Mtetra
.97 1 0 r
.42616 .44334 .43209 .45277 .44267 .43904 .43678 .42944 Mtetra
1 .91 0 r
.43678 .42944 .44267 .43904 .45325 .42467 .44739 .41496 Mtetra
1 .783 0 r
.44739 .41496 .45325 .42467 .4638 .40959 .45799 .39985 Mtetra
1 .647 0 r
.45799 .39985 .4638 .40959 .47434 .39367 .46855 .38405 Mtetra
1 .5 0 r
.46855 .38405 .47434 .39367 .48484 .37676 .47909 .3675 Mtetra
1 .343 0 r
.47909 .3675 .48484 .37676 .49531 .35875 .4896 .35025 Mtetra
1 .175 0 r
.4896 .35025 .49531 .35875 .50573 .33974 .50005 .33245 Mtetra
1 0 0 r
.50005 .33245 .50573 .33974 .51607 .32826 .51043 .32168 Mtetra
0 1 .476 r
.18908 .63974 .196 .64458 .2061 .63902 .19923 .63394 Mtetra
0 1 .447 r
.19923 .63394 .2061 .63902 .21625 .63318 .20943 .62788 Mtetra
0 1 .415 r
.20943 .62788 .21625 .63318 .22645 .62705 .21967 .62153 Mtetra
0 1 .38 r
.21967 .62153 .22645 .62705 .23669 .62062 .22996 .61489 Mtetra
0 1 .341 r
.22996 .61489 .23669 .62062 .24698 .61387 .24029 .60795 Mtetra
0 1 .3 r
.24029 .60795 .24698 .61387 .25731 .60679 .25066 .60068 Mtetra
0 1 .255 r
.25066 .60068 .25731 .60679 .26767 .59938 .26107 .59308 Mtetra
0 1 .207 r
.26107 .59308 .26767 .59938 .27808 .59164 .27152 .58514 Mtetra
0 1 .155 r
.27152 .58514 .27808 .59164 .28852 .58354 .282 .57685 Mtetra
0 1 .1 r
.282 .57685 .28852 .58354 .29899 .57509 .29252 .56821 Mtetra
0 1 .041 r
.29252 .56821 .29899 .57509 .3095 .56627 .30307 .55921 Mtetra
.022 1 0 r
.30307 .55921 .3095 .56627 .32003 .55709 .31364 .54983 Mtetra
.089 1 0 r
.31364 .54983 .32003 .55709 .33058 .54753 .32424 .54009 Mtetra
.16 1 0 r
.32424 .54009 .33058 .54753 .34116 .5376 .33486 .52996 Mtetra
.235 1 0 r
.33486 .52996 .34116 .5376 .35175 .52728 .34549 .51945 Mtetra
.315 1 0 r
.34549 .51945 .35175 .52728 .36236 .51657 .35615 .50854 Mtetra
.398 1 0 r
.35615 .50854 .36236 .51657 .37298 .50545 .36681 .49723 Mtetra
.487 1 0 r
.36681 .49723 .37298 .50545 .38362 .49392 .37748 .48551 Mtetra
.58 1 0 r
.37748 .48551 .38362 .49392 .39425 .48197 .38816 .47337 Mtetra
.677 1 0 r
.38816 .47337 .39425 .48197 .40489 .46957 .39884 .4608 Mtetra
.78 1 0 r
.39884 .4608 .40489 .46957 .41553 .4567 .40952 .44778 Mtetra
.889 1 0 r
.40952 .44778 .41553 .4567 .42616 .44334 .42019 .43428 Mtetra
1 .997 0 r
.42019 .43428 .42616 .44334 .43678 .42944 .43085 .4203 Mtetra
1 .876 0 r
.43085 .4203 .43678 .42944 .44739 .41496 .4415 .40579 Mtetra
1 .748 0 r
.4415 .40579 .44739 .41496 .45799 .39985 .45213 .39073 Mtetra
1 .613 0 r
.45213 .39073 .45799 .39985 .46855 .38405 .46273 .37512 Mtetra
1 .47 0 r
.46273 .37512 .46855 .38405 .47909 .3675 .4733 .35896 Mtetra
1 .319 0 r
.4733 .35896 .47909 .3675 .4896 .35025 .48384 .34233 Mtetra
1 .162 0 r
.48384 .34233 .4896 .35025 .50005 .33245 .49434 .32538 Mtetra
1 0 0 r
.49434 .32538 .50005 .33245 .51043 .32168 .50474 .31507 Mtetra
0 1 .482 r
.18211 .63476 .18908 .63974 .19923 .63394 .19231 .62875 Mtetra
0 1 .451 r
.19231 .62875 .19923 .63394 .20943 .62788 .20256 .62248 Mtetra
0 1 .417 r
.20256 .62248 .20943 .62788 .21967 .62153 .21285 .61594 Mtetra
0 1 .38 r
.21285 .61594 .21967 .62153 .22996 .61489 .22318 .60912 Mtetra
0 1 .34 r
.22318 .60912 .22996 .61489 .24029 .60795 .23355 .60199 Mtetra
0 1 .297 r
.23355 .60199 .24029 .60795 .25066 .60068 .24397 .59454 Mtetra
0 1 .25 r
.24397 .59454 .25066 .60068 .26107 .59308 .25442 .58677 Mtetra
0 1 .201 r
.25442 .58677 .26107 .59308 .27152 .58514 .26491 .57866 Mtetra
0 1 .147 r
.26491 .57866 .27152 .58514 .282 .57685 .27544 .5702 Mtetra
0 1 .09 r
.27544 .5702 .282 .57685 .29252 .56821 .286 .56138 Mtetra
0 1 .029 r
.286 .56138 .29252 .56821 .30307 .55921 .29659 .5522 Mtetra
.035 1 0 r
.29659 .5522 .30307 .55921 .31364 .54983 .30721 .54266 Mtetra
.104 1 0 r
.30721 .54266 .31364 .54983 .32424 .54009 .31785 .53273 Mtetra
.176 1 0 r
.31785 .53273 .32424 .54009 .33486 .52996 .32851 .52243 Mtetra
.253 1 0 r
.32851 .52243 .33486 .52996 .34549 .51945 .33919 .51174 Mtetra
.334 1 0 r
.33919 .51174 .34549 .51945 .35615 .50854 .34988 .50066 Mtetra
.42 1 0 r
.34988 .50066 .35615 .50854 .36681 .49723 .36059 .48918 Mtetra
.509 1 0 r
.36059 .48918 .36681 .49723 .37748 .48551 .3713 .4773 Mtetra
.604 1 0 r
.3713 .4773 .37748 .48551 .38816 .47337 .38202 .46501 Mtetra
.703 1 0 r
.38202 .46501 .38816 .47337 .39884 .4608 .39274 .4523 Mtetra
.808 1 0 r
.39274 .4523 .39884 .4608 .40952 .44778 .40346 .43916 Mtetra
.917 1 0 r
.40346 .43916 .40952 .44778 .42019 .43428 .41417 .42558 Mtetra
1 .968 0 r
.41417 .42558 .42019 .43428 .43085 .4203 .42487 .41155 Mtetra
1 .847 0 r
.42487 .41155 .43085 .4203 .4415 .40579 .43555 .39706 Mtetra
1 .72 0 r
.43555 .39706 .4415 .40579 .45213 .39073 .44622 .3821 Mtetra
1 .587 0 r
.44622 .3821 .45213 .39073 .46273 .37512 .45686 .3667 Mtetra
1 .447 0 r
.45686 .3667 .46273 .37512 .4733 .35896 .46747 .35089 Mtetra
1 .302 0 r
.46747 .35089 .4733 .35896 .48384 .34233 .47805 .33475 Mtetra
1 .152 0 r
.47805 .33475 .48384 .34233 .49434 .32538 .48858 .31841 Mtetra
1 0 0 r
.48858 .31841 .49434 .32538 .50474 .31507 .49902 .3084 Mtetra
0 1 .487 r
.1751 .62964 .18211 .63476 .19231 .62875 .18535 .62343 Mtetra
0 1 .454 r
.18535 .62343 .19231 .62875 .20256 .62248 .19564 .61698 Mtetra
0 1 .418 r
.19564 .61698 .20256 .62248 .21285 .61594 .20598 .61027 Mtetra
0 1 .38 r
.20598 .61027 .21285 .61594 .22318 .60912 .21635 .60328 Mtetra
0 1 .338 r
.21635 .60328 .22318 .60912 .23355 .60199 .22677 .59598 Mtetra
0 1 .294 r
.22677 .59598 .23355 .60199 .24397 .59454 .23723 .58838 Mtetra
0 1 .246 r
.23723 .58838 .24397 .59454 .25442 .58677 .24772 .58045 Mtetra
0 1 .195 r
.24772 .58045 .25442 .58677 .26491 .57866 .25826 .57218 Mtetra
0 1 .14 r
.25826 .57218 .26491 .57866 .27544 .5702 .26883 .56357 Mtetra
0 1 .081 r
.26883 .56357 .27544 .5702 .286 .56138 .27943 .5546 Mtetra
0 1 .019 r
.27943 .5546 .286 .56138 .29659 .5522 .29006 .54526 Mtetra
.047 1 0 r
.29006 .54526 .29659 .5522 .30721 .54266 .30072 .53556 Mtetra
.117 1 0 r
.30072 .53556 .30721 .54266 .31785 .53273 .3114 .52547 Mtetra
.191 1 0 r
.3114 .52547 .31785 .53273 .32851 .52243 .32211 .51501 Mtetra
.269 1 0 r
.32211 .51501 .32851 .52243 .33919 .51174 .33283 .50417 Mtetra
.352 1 0 r
.33283 .50417 .33919 .51174 .34988 .50066 .34357 .49294 Mtetra
.438 1 0 r
.34357 .49294 .34988 .50066 .36059 .48918 .35432 .48131 Mtetra
.53 1 0 r
.35432 .48131 .36059 .48918 .3713 .4773 .36508 .46929 Mtetra
.625 1 0 r
.36508 .46929 .3713 .4773 .38202 .46501 .37584 .45687 Mtetra
.726 1 0 r
.37584 .45687 .38202 .46501 .39274 .4523 .3866 .44405 Mtetra
.831 1 0 r
.3866 .44405 .39274 .4523 .40346 .43916 .39735 .43082 Mtetra
.941 1 0 r
.39735 .43082 .40346 .43916 .41417 .42558 .40811 .41719 Mtetra
1 .943 0 r
.40811 .41719 .41417 .42558 .42487 .41155 .41884 .40314 Mtetra
1 .823 0 r
.41884 .40314 .42487 .41155 .43555 .39706 .42957 .38869 Mtetra
1 .697 0 r
.42957 .38869 .43555 .39706 .44622 .3821 .44027 .37385 Mtetra
1 .566 0 r
.44027 .37385 .44622 .3821 .45686 .3667 .45095 .35864 Mtetra
1 .43 0 r
.45095 .35864 .45686 .3667 .46747 .35089 .4616 .34312 Mtetra
1 .289 0 r
.4616 .34312 .46747 .35089 .47805 .33475 .47221 .32736 Mtetra
1 .146 0 r
.47221 .32736 .47805 .33475 .48858 .31841 .48279 .31147 Mtetra
1 0 0 r
.48279 .31147 .48858 .31841 .49902 .3084 .49326 .30169 Mtetra
0 1 .491 r
.16806 .62435 .1751 .62964 .18535 .62343 .17835 .61797 Mtetra
0 1 .456 r
.17835 .61797 .18535 .62343 .19564 .61698 .18868 .61137 Mtetra
0 1 .419 r
.18868 .61137 .19564 .61698 .20598 .61027 .19906 .60451 Mtetra
0 1 .379 r
.19906 .60451 .20598 .61027 .21635 .60328 .20948 .59737 Mtetra
0 1 .336 r
.20948 .59737 .21635 .60328 .22677 .59598 .21994 .58994 Mtetra
0 1 .291 r
.21994 .58994 .22677 .59598 .23723 .58838 .23044 .58219 Mtetra
0 1 .242 r
.23044 .58219 .23723 .58838 .24772 .58045 .24098 .57413 Mtetra
0 1 .189 r
.24098 .57413 .24772 .58045 .25826 .57218 .25155 .56572 Mtetra
0 1 .133 r
.25155 .56572 .25826 .57218 .26883 .56357 .26217 .55697 Mtetra
0 1 .073 r
.26217 .55697 .26883 .56357 .27943 .5546 .27281 .54786 Mtetra
0 1 .01 r
.27281 .54786 .27943 .5546 .29006 .54526 .28348 .53838 Mtetra
.057 1 0 r
.28348 .53838 .29006 .54526 .30072 .53556 .29419 .52853 Mtetra
.129 1 0 r
.29419 .52853 .30072 .53556 .3114 .52547 .30491 .51831 Mtetra
.204 1 0 r
.30491 .51831 .3114 .52547 .32211 .51501 .31566 .50771 Mtetra
.283 1 0 r
.31566 .50771 .32211 .51501 .33283 .50417 .32643 .49673 Mtetra
.367 1 0 r
.32643 .49673 .33283 .50417 .34357 .49294 .33721 .48536 Mtetra
.455 1 0 r
.33721 .48536 .34357 .49294 .35432 .48131 .348 .47361 Mtetra
.547 1 0 r
.348 .47361 .35432 .48131 .36508 .46929 .3588 .46147 Mtetra
.644 1 0 r
.3588 .46147 .36508 .46929 .37584 .45687 .3696 .44894 Mtetra
.745 1 0 r
.3696 .44894 .37584 .45687 .3866 .44405 .3804 .43603 Mtetra
.851 1 0 r
.3804 .43603 .3866 .44405 .39735 .43082 .3912 .42274 Mtetra
.962 1 0 r
.3912 .42274 .39735 .43082 .40811 .41719 .40199 .40907 Mtetra
1 .923 0 r
.40199 .40907 .40811 .41719 .41884 .40314 .41277 .39502 Mtetra
1 .803 0 r
.41277 .39502 .41884 .40314 .42957 .38869 .42353 .38062 Mtetra
1 .678 0 r
.42353 .38062 .42957 .38869 .44027 .37385 .43428 .36589 Mtetra
1 .549 0 r
.43428 .36589 .44027 .37385 .45095 .35864 .44499 .35085 Mtetra
1 .416 0 r
.44499 .35085 .45095 .35864 .4616 .34312 .45568 .33557 Mtetra
1 .28 0 r
.45568 .33557 .4616 .34312 .47221 .32736 .46633 .32011 Mtetra
1 .14 0 r
.46633 .32011 .47221 .32736 .48279 .31147 .47695 .30455 Mtetra
1 0 0 r
.47695 .30455 .48279 .31147 .49326 .30169 .48746 .29494 Mtetra
0 1 .493 r
.16098 .61888 .16806 .62435 .17835 .61797 .17131 .61237 Mtetra
0 1 .457 r
.17131 .61237 .17835 .61797 .18868 .61137 .18168 .60563 Mtetra
0 1 .419 r
.18168 .60563 .18868 .61137 .19906 .60451 .1921 .59865 Mtetra
0 1 .378 r
.1921 .59865 .19906 .60451 .20948 .59737 .20256 .59139 Mtetra
0 1 .334 r
.20256 .59139 .20948 .59737 .21994 .58994 .21306 .58384 Mtetra
0 1 .288 r
.21306 .58384 .21994 .58994 .23044 .58219 .2236 .57598 Mtetra
0 1 .238 r
.2236 .57598 .23044 .58219 .24098 .57413 .23418 .5678 Mtetra
0 1 .184 r
.23418 .5678 .24098 .57413 .25155 .56572 .2448 .55927 Mtetra
0 1 .127 r
.2448 .55927 .25155 .56572 .26217 .55697 .25545 .5504 Mtetra
0 1 .066 r
.25545 .5504 .26217 .55697 .27281 .54786 .26614 .54117 Mtetra
0 1 .002 r
.26614 .54117 .27281 .54786 .28348 .53838 .27685 .53157 Mtetra
.066 1 0 r
.27685 .53157 .28348 .53838 .29419 .52853 .2876 .5216 Mtetra
.139 1 0 r
.2876 .5216 .29419 .52853 .30491 .51831 .29837 .51125 Mtetra
.215 1 0 r
.29837 .51125 .30491 .51831 .31566 .50771 .30916 .50052 Mtetra
.296 1 0 r
.30916 .50052 .31566 .50771 .32643 .49673 .31997 .48942 Mtetra
.38 1 0 r
.31997 .48942 .32643 .49673 .33721 .48536 .33079 .47793 Mtetra
.469 1 0 r
.33079 .47793 .33721 .48536 .348 .47361 .34163 .46607 Mtetra
.563 1 0 r
.34163 .46607 .348 .47361 .3588 .46147 .35247 .45383 Mtetra
.66 1 0 r
.35247 .45383 .3588 .46147 .3696 .44894 .36331 .44121 Mtetra
.762 1 0 r
.36331 .44121 .3696 .44894 .3804 .43603 .37416 .42822 Mtetra
.868 1 0 r
.37416 .42822 .3804 .43603 .3912 .42274 .385 .41488 Mtetra
.979 1 0 r
.385 .41488 .3912 .42274 .40199 .40907 .39583 .40118 Mtetra
1 .906 0 r
.39583 .40118 .40199 .40907 .41277 .39502 .40665 .38714 Mtetra
1 .787 0 r
.40665 .38714 .41277 .39502 .42353 .38062 .41745 .37279 Mtetra
1 .663 0 r
.41745 .37279 .42353 .38062 .43428 .36589 .42823 .35815 Mtetra
1 .536 0 r
.42823 .35815 .43428 .36589 .44499 .35085 .43899 .34326 Mtetra
1 .405 0 r
.43899 .34326 .44499 .35085 .45568 .33557 .44972 .32816 Mtetra
1 .272 0 r
.44972 .32816 .45568 .33557 .46633 .32011 .46041 .31293 Mtetra
1 .136 0 r
.46041 .31293 .46633 .32011 .47695 .30455 .47107 .29763 Mtetra
1 0 0 r
.47107 .29763 .47695 .30455 .48746 .29494 .48161 .28813 Mtetra
0 1 .495 r
.15386 .61322 .16098 .61888 .17131 .61237 .16423 .6066 Mtetra
0 1 .458 r
.16423 .6066 .17131 .61237 .18168 .60563 .17464 .59977 Mtetra
0 1 .419 r
.17464 .59977 .18168 .60563 .1921 .59865 .1851 .59269 Mtetra
0 1 .377 r
.1851 .59269 .1921 .59865 .20256 .59139 .19559 .58534 Mtetra
0 1 .332 r
.19559 .58534 .20256 .59139 .21306 .58384 .20613 .5777 Mtetra
0 1 .285 r
.20613 .5777 .21306 .58384 .2236 .57598 .21671 .56974 Mtetra
0 1 .234 r
.21671 .56974 .2236 .57598 .23418 .5678 .22733 .56146 Mtetra
0 1 .18 r
.22733 .56146 .23418 .5678 .2448 .55927 .23799 .55284 Mtetra
0 1 .122 r
.23799 .55284 .2448 .55927 .25545 .5504 .24868 .54386 Mtetra
0 1 .06 r
.24868 .54386 .25545 .5504 .26614 .54117 .25941 .53453 Mtetra
.005 1 0 r
.25941 .53453 .26614 .54117 .27685 .53157 .27017 .52482 Mtetra
.074 1 0 r
.27017 .52482 .27685 .53157 .2876 .5216 .28096 .51474 Mtetra
.148 1 0 r
.28096 .51474 .2876 .5216 .29837 .51125 .29177 .50429 Mtetra
.225 1 0 r
.29177 .50429 .29837 .51125 .30916 .50052 .3026 .49345 Mtetra
.306 1 0 r
.3026 .49345 .30916 .50052 .31997 .48942 .31346 .48224 Mtetra
.392 1 0 r
.31346 .48224 .31997 .48942 .33079 .47793 .32432 .47065 Mtetra
.482 1 0 r
.32432 .47065 .33079 .47793 .34163 .46607 .3352 .45868 Mtetra
.576 1 0 r
.3352 .45868 .34163 .46607 .35247 .45383 .34609 .44635 Mtetra
.674 1 0 r
.34609 .44635 .35247 .45383 .36331 .44121 .35698 .43366 Mtetra
.776 1 0 r
.35698 .43366 .36331 .44121 .37416 .42822 .36786 .42061 Mtetra
.883 1 0 r
.36786 .42061 .37416 .42822 .385 .41488 .37875 .40722 Mtetra
.993 1 0 r
.37875 .40722 .385 .41488 .39583 .40118 .38962 .3935 Mtetra
1 .892 0 r
.38962 .3935 .39583 .40118 .40665 .38714 .40048 .37947 Mtetra
1 .773 0 r
.40048 .37947 .40665 .38714 .41745 .37279 .41132 .36516 Mtetra
1 .651 0 r
.41132 .36516 .41745 .37279 .42823 .35815 .42215 .35059 Mtetra
1 .525 0 r
.42215 .35059 .42823 .35815 .43899 .34326 .43294 .33581 Mtetra
1 .397 0 r
.43294 .33581 .43899 .34326 .44972 .32816 .44371 .32086 Mtetra
1 .266 0 r
.44371 .32086 .44972 .32816 .46041 .31293 .45445 .3058 Mtetra
1 .133 0 r
.45445 .3058 .46041 .31293 .47107 .29763 .46515 .29069 Mtetra
1 0 0 r
.46515 .29069 .47107 .29763 .48161 .28813 .47573 .28128 Mtetra
0 1 .494 r
.14671 .60735 .15386 .61322 .16423 .6066 .15711 .60067 Mtetra
0 1 .457 r
.15711 .60067 .16423 .6066 .17464 .59977 .16756 .59377 Mtetra
0 1 .417 r
.16756 .59377 .17464 .59977 .1851 .59269 .17805 .58663 Mtetra
0 1 .375 r
.17805 .58663 .1851 .59269 .19559 .58534 .18858 .57921 Mtetra
0 1 .33 r
.18858 .57921 .19559 .58534 .20613 .5777 .19916 .5715 Mtetra
0 1 .282 r
.19916 .5715 .20613 .5777 .21671 .56974 .20977 .56348 Mtetra
0 1 .23 r
.20977 .56348 .21671 .56974 .22733 .56146 .22043 .55512 Mtetra
0 1 .176 r
.22043 .55512 .22733 .56146 .23799 .55284 .23113 .54642 Mtetra
0 1 .117 r
.23113 .54642 .23799 .55284 .24868 .54386 .24186 .53736 Mtetra
0 1 .055 r
.24186 .53736 .24868 .54386 .25941 .53453 .25263 .52794 Mtetra
.011 1 0 r
.25263 .52794 .25941 .53453 .27017 .52482 .26343 .51815 Mtetra
.081 1 0 r
.26343 .51815 .27017 .52482 .28096 .51474 .27426 .50797 Mtetra
.155 1 0 r
.27426 .50797 .28096 .51474 .29177 .50429 .28512 .49742 Mtetra
.233 1 0 r
.28512 .49742 .29177 .50429 .3026 .49345 .29599 .48649 Mtetra
.315 1 0 r
.29599 .48649 .3026 .49345 .31346 .48224 .30689 .47518 Mtetra
.401 1 0 r
.30689 .47518 .31346 .48224 .32432 .47065 .3178 .4635 Mtetra
.492 1 0 r
.3178 .4635 .32432 .47065 .3352 .45868 .32872 .45145 Mtetra
.586 1 0 r
.32872 .45145 .3352 .45868 .34609 .44635 .33965 .43903 Mtetra
.685 1 0 r
.33965 .43903 .34609 .44635 .35698 .43366 .35058 .42627 Mtetra
.788 1 0 r
.35058 .42627 .35698 .43366 .36786 .42061 .36152 .41316 Mtetra
.894 1 0 r
.36152 .41316 .36786 .42061 .37875 .40722 .37244 .39973 Mtetra
1 .995 0 r
.37244 .39973 .37875 .40722 .38962 .3935 .38336 .38599 Mtetra
1 .881 0 r
.38336 .38599 .38962 .3935 .40048 .37947 .39426 .37197 Mtetra
1 .763 0 r
.39426 .37197 .40048 .37947 .41132 .36516 .40515 .35768 Mtetra
1 .641 0 r
.40515 .35768 .41132 .36516 .42215 .35059 .41601 .34317 Mtetra
1 .517 0 r
.41601 .34317 .42215 .35059 .43294 .33581 .42685 .32848 Mtetra
1 .39 0 r
.42685 .32848 .43294 .33581 .44371 .32086 .43766 .31363 Mtetra
1 .261 0 r
.43766 .31363 .44371 .32086 .45445 .3058 .44844 .2987 Mtetra
1 .131 0 r
.44844 .2987 .45445 .3058 .46515 .29069 .45919 .28373 Mtetra
1 0 0 r
.45919 .28373 .46515 .29069 .47573 .28128 .4698 .27438 Mtetra
0 1 .493 r
.13952 .60127 .14671 .60735 .15711 .60067 .14996 .59456 Mtetra
0 1 .455 r
.14996 .59456 .15711 .60067 .16756 .59377 .16044 .58764 Mtetra
0 1 .415 r
.16044 .58764 .16756 .59377 .17805 .58663 .17096 .58046 Mtetra
0 1 .373 r
.17096 .58046 .17805 .58663 .18858 .57921 .18152 .57301 Mtetra
0 1 .327 r
.18152 .57301 .18858 .57921 .19916 .5715 .19213 .56526 Mtetra
0 1 .279 r
.19213 .56526 .19916 .5715 .20977 .56348 .20278 .55719 Mtetra
0 1 .227 r
.20278 .55719 .20977 .56348 .22043 .55512 .21348 .54879 Mtetra
0 1 .172 r
.21348 .54879 .22043 .55512 .23113 .54642 .22421 .54003 Mtetra
0 1 .113 r
.22421 .54003 .23113 .54642 .24186 .53736 .23499 .53091 Mtetra
0 1 .051 r
.23499 .53091 .24186 .53736 .25263 .52794 .24579 .52142 Mtetra
.016 1 0 r
.24579 .52142 .25263 .52794 .26343 .51815 .25664 .51155 Mtetra
.086 1 0 r
.25664 .51155 .26343 .51815 .27426 .50797 .26751 .50129 Mtetra
.161 1 0 r
.26751 .50129 .27426 .50797 .28512 .49742 .27841 .49066 Mtetra
.239 1 0 r
.27841 .49066 .28512 .49742 .29599 .48649 .28933 .47965 Mtetra
.322 1 0 r
.28933 .47965 .29599 .48649 .30689 .47518 .30027 .46825 Mtetra
.409 1 0 r
.30027 .46825 .30689 .47518 .3178 .4635 .31122 .45649 Mtetra
.5 1 0 r
.31122 .45649 .3178 .4635 .32872 .45145 .32219 .44436 Mtetra
.595 1 0 r
.32219 .44436 .32872 .45145 .33965 .43903 .33316 .43187 Mtetra
.694 1 0 r
.33316 .43187 .33965 .43903 .35058 .42627 .34414 .41904 Mtetra
.797 1 0 r
.34414 .41904 .35058 .42627 .36152 .41316 .35512 .40588 Mtetra
.904 1 0 r
.35512 .40588 .36152 .41316 .37244 .39973 .36609 .39241 Mtetra
1 .986 0 r
.36609 .39241 .37244 .39973 .38336 .38599 .37705 .37864 Mtetra
1 .872 0 r
.37705 .37864 .38336 .38599 .39426 .37197 .38799 .36461 Mtetra
1 .754 0 r
.38799 .36461 .39426 .37197 .40515 .35768 .39892 .35034 Mtetra
1 .634 0 r
.39892 .35034 .40515 .35768 .41601 .34317 .40983 .33587 Mtetra
1 .51 0 r
.40983 .33587 .41601 .34317 .42685 .32848 .42071 .32123 Mtetra
1 .385 0 r
.42071 .32123 .42685 .32848 .43766 .31363 .43157 .30646 Mtetra
1 .258 0 r
.43157 .30646 .43766 .31363 .44844 .2987 .44239 .29162 Mtetra
1 .129 0 r
.44239 .29162 .44844 .2987 .45919 .28373 .45318 .27674 Mtetra
1 0 0 r
.45318 .27674 .45919 .28373 .4698 .27438 .46383 .26742 Mtetra
0 1 .489 r
.13231 .59498 .13952 .60127 .14996 .59456 .14277 .58828 Mtetra
0 1 .452 r
.14277 .58828 .14996 .59456 .16044 .58764 .15327 .58137 Mtetra
0 1 .412 r
.15327 .58137 .16044 .58764 .17096 .58046 .16382 .5742 Mtetra
0 1 .37 r
.16382 .5742 .17096 .58046 .18152 .57301 .17442 .56674 Mtetra
0 1 .325 r
.17442 .56674 .18152 .57301 .19213 .56526 .18506 .55898 Mtetra
0 1 .276 r
.18506 .55898 .19213 .56526 .20278 .55719 .19574 .55089 Mtetra
0 1 .225 r
.19574 .55089 .20278 .55719 .21348 .54879 .20647 .54246 Mtetra
0 1 .169 r
.20647 .54246 .21348 .54879 .22421 .54003 .21724 .53366 Mtetra
0 1 .11 r
.21724 .53366 .22421 .54003 .23499 .53091 .22805 .5245 Mtetra
0 1 .047 r
.22805 .5245 .23499 .53091 .24579 .52142 .2389 .51495 Mtetra
.019 1 0 r
.2389 .51495 .24579 .52142 .25664 .51155 .24978 .50502 Mtetra
.09 1 0 r
.24978 .50502 .25664 .51155 .26751 .50129 .2607 .49471 Mtetra
.165 1 0 r
.2607 .49471 .26751 .50129 .27841 .49066 .27164 .484 Mtetra
.244 1 0 r
.27164 .484 .27841 .49066 .28933 .47965 .2826 .47292 Mtetra
.327 1 0 r
.2826 .47292 .28933 .47965 .30027 .46825 .29359 .46145 Mtetra
.414 1 0 r
.29359 .46145 .30027 .46825 .31122 .45649 .30459 .44961 Mtetra
.506 1 0 r
.30459 .44961 .31122 .45649 .32219 .44436 .3156 .4374 Mtetra
.601 1 0 r
.3156 .4374 .32219 .44436 .33316 .43187 .32662 .42485 Mtetra
.701 1 0 r
.32662 .42485 .33316 .43187 .34414 .41904 .33764 .41195 Mtetra
.804 1 0 r
.33764 .41195 .34414 .41904 .35512 .40588 .34866 .39874 Mtetra
.911 1 0 r
.34866 .39874 .35512 .40588 .36609 .39241 .35968 .38522 Mtetra
1 .979 0 r
.35968 .38522 .36609 .39241 .37705 .37864 .37068 .37143 Mtetra
1 .865 0 r
.37068 .37143 .37705 .37864 .38799 .36461 .38167 .35738 Mtetra
1 .748 0 r
.38167 .35738 .38799 .36461 .39892 .35034 .39265 .34311 Mtetra
1 .628 0 r
.39265 .34311 .39892 .35034 .40983 .33587 .4036 .32866 Mtetra
1 .505 0 r
.4036 .32866 .40983 .33587 .42071 .32123 .41453 .31405 Mtetra
1 .381 0 r
.41453 .31405 .42071 .32123 .43157 .30646 .42543 .29932 Mtetra
1 .255 0 r
.42543 .29932 .43157 .30646 .44239 .29162 .4363 .28453 Mtetra
1 .128 0 r
.4363 .28453 .44239 .29162 .45318 .27674 .44714 .26972 Mtetra
1 0 0 r
.44714 .26972 .45318 .27674 .46383 .26742 .45782 .26042 Mtetra
0 1 .484 r
.12506 .58848 .13231 .59498 .14277 .58828 .13554 .58184 Mtetra
0 1 .448 r
.13554 .58184 .14277 .58828 .15327 .58137 .14607 .57497 Mtetra
0 1 .409 r
.14607 .57497 .15327 .58137 .16382 .5742 .15664 .56784 Mtetra
0 1 .367 r
.15664 .56784 .16382 .5742 .17442 .56674 .16726 .56041 Mtetra
0 1 .322 r
.16726 .56041 .17442 .56674 .18506 .55898 .17793 .55267 Mtetra
0 1 .274 r
.17793 .55267 .18506 .55898 .19574 .55089 .18865 .54458 Mtetra
0 1 .222 r
.18865 .54458 .19574 .55089 .20647 .54246 .19941 .53614 Mtetra
0 1 .167 r
.19941 .53614 .20647 .54246 .21724 .53366 .21021 .52733 Mtetra
0 1 .108 r
.21021 .52733 .21724 .53366 .22805 .5245 .22106 .51814 Mtetra
0 1 .045 r
.22106 .51814 .22805 .5245 .2389 .51495 .23195 .50856 Mtetra
.022 1 0 r
.23195 .50856 .2389 .51495 .24978 .50502 .24287 .49859 Mtetra
.093 1 0 r
.24287 .49859 .24978 .50502 .2607 .49471 .25382 .48822 Mtetra
.168 1 0 r
.25382 .48822 .2607 .49471 .27164 .484 .26481 .47746 Mtetra
.247 1 0 r
.26481 .47746 .27164 .484 .2826 .47292 .27581 .4663 Mtetra
.331 1 0 r
.27581 .4663 .2826 .47292 .29359 .46145 .28684 .45477 Mtetra
.418 1 0 r
.28684 .45477 .29359 .46145 .30459 .44961 .29789 .44286 Mtetra
.51 1 0 r
.29789 .44286 .30459 .44961 .3156 .4374 .30895 .43058 Mtetra
.606 1 0 r
.30895 .43058 .3156 .4374 .32662 .42485 .32001 .41796 Mtetra
.705 1 0 r
.32001 .41796 .32662 .42485 .33764 .41195 .33108 .40501 Mtetra
.809 1 0 r
.33108 .40501 .33764 .41195 .34866 .39874 .34215 .39173 Mtetra
.916 1 0 r
.34215 .39173 .34866 .39874 .35968 .38522 .35321 .37817 Mtetra
1 .974 0 r
.35321 .37817 .35968 .38522 .37068 .37143 .36427 .36434 Mtetra
1 .86 0 r
.36427 .36434 .37068 .37143 .38167 .35738 .3753 .35026 Mtetra
1 .743 0 r
.3753 .35026 .38167 .35738 .39265 .34311 .38632 .33598 Mtetra
1 .624 0 r
.38632 .33598 .39265 .34311 .4036 .32866 .39732 .32152 Mtetra
1 .502 0 r
.39732 .32152 .4036 .32866 .41453 .31405 .4083 .30692 Mtetra
1 .378 0 r
.4083 .30692 .41453 .31405 .42543 .29932 .41924 .29221 Mtetra
1 .253 0 r
.41924 .29221 .42543 .29932 .4363 .28453 .43016 .27745 Mtetra
1 .127 0 r
.43016 .27745 .4363 .28453 .44714 .26972 .44104 .26267 Mtetra
1 0 0 r
.44104 .26267 .44714 .26972 .45782 .26042 .45176 .25337 Mtetra
0 1 .478 r
.11778 .58178 .12506 .58848 .13554 .58184 .12828 .57523 Mtetra
0 1 .442 r
.12828 .57523 .13554 .58184 .14607 .57497 .13882 .56845 Mtetra
0 1 .404 r
.13882 .56845 .14607 .57497 .15664 .56784 .14941 .56139 Mtetra
0 1 .363 r
.14941 .56139 .15664 .56784 .16726 .56041 .16006 .55403 Mtetra
0 1 .319 r
.16006 .55403 .16726 .56041 .17793 .55267 .17075 .54633 Mtetra
0 1 .272 r
.17075 .54633 .17793 .55267 .18865 .54458 .18149 .53828 Mtetra
0 1 .221 r
.18149 .53828 .18865 .54458 .19941 .53614 .19228 .52986 Mtetra
0 1 .166 r
.19228 .52986 .19941 .53614 .21021 .52733 .20312 .52105 Mtetra
0 1 .107 r
.20312 .52105 .21021 .52733 .22106 .51814 .21401 .51185 Mtetra
0 1 .044 r
.21401 .51185 .22106 .51814 .23195 .50856 .22493 .50225 Mtetra
.022 1 0 r
.22493 .50225 .23195 .50856 .24287 .49859 .23589 .49224 Mtetra
.093 1 0 r
.23589 .49224 .24287 .49859 .25382 .48822 .24689 .48183 Mtetra
.169 1 0 r
.24689 .48183 .25382 .48822 .26481 .47746 .25791 .47102 Mtetra
.248 1 0 r
.25791 .47102 .26481 .47746 .27581 .4663 .26897 .45981 Mtetra
.332 1 0 r
.26897 .45981 .27581 .4663 .28684 .45477 .28004 .44822 Mtetra
.42 1 0 r
.28004 .44822 .28684 .45477 .29789 .44286 .29113 .43624 Mtetra
.512 1 0 r
.29113 .43624 .29789 .44286 .30895 .43058 .30224 .4239 Mtetra
.608 1 0 r
.30224 .4239 .30895 .43058 .32001 .41796 .31335 .41121 Mtetra
.708 1 0 r
.31335 .41121 .32001 .41796 .33108 .40501 .32447 .39819 Mtetra
.812 1 0 r
.32447 .39819 .33108 .40501 .34215 .39173 .33558 .38486 Mtetra
.919 1 0 r
.33558 .38486 .34215 .39173 .35321 .37817 .34669 .37124 Mtetra
1 .97 0 r
.34669 .37124 .35321 .37817 .36427 .36434 .35779 .35736 Mtetra
1 .857 0 r
.35779 .35736 .36427 .36434 .3753 .35026 .36888 .34324 Mtetra
1 .74 0 r
.36888 .34324 .3753 .35026 .38632 .33598 .37995 .32893 Mtetra
1 .621 0 r
.37995 .32893 .38632 .33598 .39732 .32152 .391 .31445 Mtetra
1 .499 0 r
.391 .31445 .39732 .32152 .4083 .30692 .40202 .29983 Mtetra
1 .376 0 r
.40202 .29983 .4083 .30692 .41924 .29221 .41301 .28512 Mtetra
1 .252 0 r
.41301 .28512 .41924 .29221 .43016 .27745 .42398 .27036 Mtetra
1 .126 0 r
.42398 .27036 .43016 .27745 .44104 .26267 .43491 .25558 Mtetra
1 0 0 r
.43491 .25558 .44104 .26267 .45176 .25337 .44566 .24627 Mtetra
0 1 .471 r
.11047 .57488 .11778 .58178 .12828 .57523 .12097 .56848 Mtetra
0 1 .436 r
.12097 .56848 .12828 .57523 .13882 .56845 .13153 .56182 Mtetra
0 1 .4 r
.13153 .56182 .13882 .56845 .14941 .56139 .14214 .55488 Mtetra
0 1 .36 r
.14214 .55488 .14941 .56139 .16006 .55403 .1528 .5476 Mtetra
0 1 .317 r
.1528 .5476 .16006 .55403 .17075 .54633 .16351 .53998 Mtetra
0 1 .27 r
.16351 .53998 .17075 .54633 .18149 .53828 .17428 .53199 Mtetra
0 1 .22 r
.17428 .53199 .18149 .53828 .19228 .52986 .1851 .5236 Mtetra
0 1 .166 r
.1851 .5236 .19228 .52986 .20312 .52105 .19597 .51482 Mtetra
0 1 .107 r
.19597 .51482 .20312 .52105 .21401 .51185 .20689 .50563 Mtetra
0 1 .045 r
.20689 .50563 .21401 .51185 .22493 .50225 .21785 .49603 Mtetra
.022 1 0 r
.21785 .49603 .22493 .50225 .23589 .49224 .22885 .486 Mtetra
.093 1 0 r
.22885 .486 .23589 .49224 .24689 .48183 .23989 .47556 Mtetra
.168 1 0 r
.23989 .47556 .24689 .48183 .25791 .47102 .25096 .46471 Mtetra
.248 1 0 r
.25096 .46471 .25791 .47102 .26897 .45981 .26205 .45345 Mtetra
.332 1 0 r
.26205 .45345 .26897 .45981 .28004 .44822 .27317 .4418 Mtetra
.42 1 0 r
.27317 .4418 .28004 .44822 .29113 .43624 .28431 .42976 Mtetra
.512 1 0 r
.28431 .42976 .29113 .43624 .30224 .4239 .29547 .41735 Mtetra
.609 1 0 r
.29547 .41735 .30224 .4239 .31335 .41121 .30663 .40459 Mtetra
.709 1 0 r
.30663 .40459 .31335 .41121 .32447 .39819 .31779 .3915 Mtetra
.813 1 0 r
.31779 .3915 .32447 .39819 .33558 .38486 .32896 .37811 Mtetra
.92 1 0 r
.32896 .37811 .33558 .38486 .34669 .37124 .34012 .36442 Mtetra
1 .969 0 r
.34012 .36442 .34669 .37124 .35779 .35736 .35127 .35048 Mtetra
1 .855 0 r
.35127 .35048 .35779 .35736 .36888 .34324 .3624 .33632 Mtetra
1 .738 0 r
.3624 .33632 .36888 .34324 .37995 .32893 .37352 .32195 Mtetra
1 .619 0 r
.37352 .32195 .37995 .32893 .391 .31445 .38462 .30743 Mtetra
1 .498 0 r
.38462 .30743 .391 .31445 .40202 .29983 .39569 .29278 Mtetra
1 .375 0 r
.39569 .29278 .40202 .29983 .41301 .28512 .40673 .27804 Mtetra
1 .251 0 r
.40673 .27804 .41301 .28512 .42398 .27036 .41775 .26325 Mtetra
1 .126 0 r
.41775 .26325 .42398 .27036 .43491 .25558 .42873 .24845 Mtetra
1 0 0 r
.42873 .24845 .43491 .25558 .44566 .24627 .43952 .23911 Mtetra
0 1 .462 r
.10312 .5678 .11047 .57488 .12097 .56848 .11363 .56159 Mtetra
0 1 .429 r
.11363 .56159 .12097 .56848 .13153 .56182 .12419 .55511 Mtetra
0 1 .394 r
.12419 .55511 .13153 .56182 .14214 .55488 .13481 .5483 Mtetra
0 1 .356 r
.13481 .5483 .14214 .55488 .1528 .5476 .14548 .54116 Mtetra
0 1 .314 r
.14548 .54116 .1528 .5476 .16351 .53998 .15622 .53364 Mtetra
0 1 .269 r
.15622 .53364 .16351 .53998 .17428 .53199 .16701 .52573 Mtetra
0 1 .22 r
.16701 .52573 .17428 .53199 .1851 .5236 .17785 .51741 Mtetra
0 1 .166 r
.17785 .51741 .1851 .5236 .19597 .51482 .18875 .50867 Mtetra
0 1 .109 r
.18875 .50867 .19597 .51482 .20689 .50563 .1997 .4995 Mtetra
0 1 .047 r
.1997 .4995 .20689 .50563 .21785 .49603 .2107 .48991 Mtetra
.02 1 0 r
.2107 .48991 .21785 .49603 .22885 .486 .22174 .47987 Mtetra
.091 1 0 r
.22174 .47987 .22885 .486 .23989 .47556 .23282 .46941 Mtetra
.166 1 0 r
.23282 .46941 .23989 .47556 .25096 .46471 .24393 .45853 Mtetra
.245 1 0 r
.24393 .45853 .25096 .46471 .26205 .45345 .25507 .44722 Mtetra
.33 1 0 r
.25507 .44722 .26205 .45345 .27317 .4418 .26624 .43551 Mtetra
.418 1 0 r
.26624 .43551 .27317 .4418 .28431 .42976 .27743 .42341 Mtetra
.51 1 0 r
.27743 .42341 .28431 .42976 .29547 .41735 .28863 .41094 Mtetra
.607 1 0 r
.28863 .41094 .29547 .41735 .30663 .40459 .29984 .39811 Mtetra
.708 1 0 r
.29984 .39811 .30663 .40459 .31779 .3915 .31106 .38495 Mtetra
.812 1 0 r
.31106 .38495 .31779 .3915 .32896 .37811 .32227 .37147 Mtetra
.92 1 0 r
.32227 .37147 .32896 .37811 .34012 .36442 .33348 .35772 Mtetra
1 .969 0 r
.33348 .35772 .34012 .36442 .35127 .35048 .34469 .34371 Mtetra
1 .855 0 r
.34469 .34371 .35127 .35048 .3624 .33632 .35587 .32947 Mtetra
1 .738 0 r
.35587 .32947 .3624 .33632 .37352 .32195 .36704 .31504 Mtetra
1 .619 0 r
.36704 .31504 .37352 .32195 .38462 .30743 .37819 .30046 Mtetra
1 .498 0 r
.37819 .30046 .38462 .30743 .39569 .29278 .38931 .28575 Mtetra
1 .375 0 r
.38931 .28575 .39569 .29278 .40673 .27804 .40041 .27096 Mtetra
1 .251 0 r
.40041 .27096 .40673 .27804 .41775 .26325 .41147 .25612 Mtetra
1 .126 0 r
.41147 .25612 .41775 .26325 .42873 .24845 .4225 .24128 Mtetra
1 0 0 r
.4225 .24128 .42873 .24845 .43952 .23911 .43333 .2319 Mtetra
0 1 .452 r
.09574 .56057 .10312 .5678 .11363 .56159 .10624 .5546 Mtetra
0 1 .422 r
.10624 .5546 .11363 .56159 .12419 .55511 .1168 .54832 Mtetra
0 1 .389 r
.1168 .54832 .12419 .55511 .13481 .5483 .12742 .5417 Mtetra
0 1 .353 r
.12742 .5417 .13481 .5483 .14548 .54116 .13811 .53471 Mtetra
0 1 .313 r
.13811 .53471 .14548 .54116 .15622 .53364 .14886 .52732 Mtetra
0 1 .269 r
.14886 .52732 .15622 .53364 .16701 .52573 .15967 .51952 Mtetra
0 1 .221 r
.15967 .51952 .16701 .52573 .17785 .51741 .17054 .51128 Mtetra
0 1 .168 r
.17054 .51128 .17785 .51741 .18875 .50867 .18147 .5026 Mtetra
0 1 .111 r
.18147 .5026 .18875 .50867 .1997 .4995 .19245 .49348 Mtetra
0 1 .05 r
.19245 .49348 .1997 .4995 .2107 .48991 .20348 .4839 Mtetra
.016 1 0 r
.20348 .4839 .2107 .48991 .22174 .47987 .21456 .47387 Mtetra
.086 1 0 r
.21456 .47387 .22174 .47987 .23282 .46941 .22568 .4634 Mtetra
.162 1 0 r
.22568 .4634 .23282 .46941 .24393 .45853 .23684 .45248 Mtetra
.241 1 0 r
.23684 .45248 .24393 .45853 .25507 .44722 .24803 .44114 Mtetra
.325 1 0 r
.24803 .44114 .25507 .44722 .26624 .43551 .25924 .42937 Mtetra
.414 1 0 r
.25924 .42937 .26624 .43551 .27743 .42341 .27048 .41721 Mtetra
.507 1 0 r
.27048 .41721 .27743 .42341 .28863 .41094 .28173 .40467 Mtetra
.604 1 0 r
.28173 .40467 .28863 .41094 .29984 .39811 .29299 .39176 Mtetra
.704 1 0 r
.29299 .39176 .29984 .39811 .31106 .38495 .30426 .37852 Mtetra
.809 1 0 r
.30426 .37852 .31106 .38495 .32227 .37147 .31553 .36496 Mtetra
.917 1 0 r
.31553 .36496 .32227 .37147 .33348 .35772 .32679 .35112 Mtetra
1 .971 0 r
.32679 .35112 .33348 .35772 .34469 .34371 .33805 .33702 Mtetra
1 .857 0 r
.33805 .33702 .34469 .34371 .35587 .32947 .34929 .32271 Mtetra
1 .74 0 r
.34929 .32271 .35587 .32947 .36704 .31504 .36051 .3082 Mtetra
1 .62 0 r
.36051 .3082 .36704 .31504 .37819 .30046 .37171 .29354 Mtetra
1 .499 0 r
.37171 .29354 .37819 .30046 .38931 .28575 .38288 .27875 Mtetra
1 .375 0 r
.38288 .27875 .38931 .28575 .40041 .27096 .39403 .26389 Mtetra
1 .251 0 r
.39403 .26389 .40041 .27096 .41147 .25612 .40514 .24898 Mtetra
1 .126 0 r
.40514 .24898 .41147 .25612 .4225 .24128 .41623 .23407 Mtetra
1 0 0 r
.41623 .23407 .4225 .24128 .43333 .2319 .4271 .22464 Mtetra
0 1 .441 r
.08832 .5532 .09574 .56057 .10624 .5546 .09881 .54751 Mtetra
0 1 .414 r
.09881 .54751 .10624 .5546 .1168 .54832 .10936 .54148 Mtetra
0 1 .384 r
.10936 .54148 .1168 .54832 .12742 .5417 .11998 .53508 Mtetra
0 1 .35 r
.11998 .53508 .12742 .5417 .13811 .53471 .13068 .52828 Mtetra
0 1 .312 r
.13068 .52828 .13811 .53471 .14886 .52732 .14144 .52105 Mtetra
0 1 .269 r
.14144 .52105 .14886 .52732 .15967 .51952 .15227 .51338 Mtetra
0 1 .223 r
.15227 .51338 .15967 .51952 .17054 .51128 .16316 .50525 Mtetra
0 1 .171 r
.16316 .50525 .17054 .51128 .18147 .5026 .17411 .49665 Mtetra
0 1 .116 r
.17411 .49665 .18147 .5026 .19245 .49348 .18512 .48758 Mtetra
0 1 .055 r
.18512 .48758 .19245 .49348 .20348 .4839 .19619 .47803 Mtetra
.01 1 0 r
.19619 .47803 .20348 .4839 .21456 .47387 .20731 .46801 Mtetra
.08 1 0 r
.20731 .46801 .21456 .47387 .22568 .4634 .21847 .45753 Mtetra
.155 1 0 r
.21847 .45753 .22568 .4634 .23684 .45248 .22967 .44659 Mtetra
.235 1 0 r
.22967 .44659 .23684 .45248 .24803 .44114 .2409 .4352 Mtetra
.319 1 0 r
.2409 .4352 .24803 .44114 .25924 .42937 .25217 .42339 Mtetra
.408 1 0 r
.25217 .42339 .25924 .42937 .27048 .41721 .26345 .41116 Mtetra
.501 1 0 r
.26345 .41116 .27048 .41721 .28173 .40467 .27476 .39854 Mtetra
.598 1 0 r
.27476 .39854 .28173 .40467 .29299 .39176 .28607 .38555 Mtetra
.699 1 0 r
.28607 .38555 .29299 .39176 .30426 .37852 .2974 .37222 Mtetra
.804 1 0 r
.2974 .37222 .30426 .37852 .31553 .36496 .30872 .35857 Mtetra
.913 1 0 r
.30872 .35857 .31553 .36496 .32679 .35112 .32004 .34463 Mtetra
1 .975 0 r
.32004 .34463 .32679 .35112 .33805 .33702 .33135 .33044 Mtetra
1 .86 0 r
.33135 .33044 .33805 .33702 .34929 .32271 .34264 .31602 Mtetra
1 .742 0 r
.34264 .31602 .34929 .32271 .36051 .3082 .35392 .30141 Mtetra
1 .622 0 r
.35392 .30141 .36051 .3082 .37171 .29354 .36518 .28665 Mtetra
1 .5 0 r
.36518 .28665 .37171 .29354 .38288 .27875 .3764 .27178 Mtetra
1 .377 0 r
.3764 .27178 .38288 .27875 .39403 .26389 .3876 .25682 Mtetra
1 .252 0 r
.3876 .25682 .39403 .26389 .40514 .24898 .39877 .24182 Mtetra
1 .126 0 r
.39877 .24182 .40514 .24898 .41623 .23407 .40991 .22681 Mtetra
1 0 0 r
.40991 .22681 .41623 .23407 .4271 .22464 .42082 .21733 Mtetra
0 1 .43 r
.08086 .54574 .08832 .5532 .09881 .54751 .09132 .54038 Mtetra
0 1 .406 r
.09132 .54038 .09881 .54751 .10936 .54148 .10187 .53464 Mtetra
0 1 .379 r
.10187 .53464 .10936 .54148 .11998 .53508 .11248 .52849 Mtetra
0 1 .347 r
.11248 .52849 .11998 .53508 .13068 .52828 .12318 .5219 Mtetra
0 1 .312 r
.12318 .5219 .13068 .52828 .14144 .52105 .13394 .51486 Mtetra
0 1 .271 r
.13394 .51486 .14144 .52105 .15227 .51338 .14479 .50734 Mtetra
0 1 .226 r
.14479 .50734 .15227 .51338 .16316 .50525 .1557 .49933 Mtetra
0 1 .176 r
.1557 .49933 .16316 .50525 .17411 .49665 .16668 .49082 Mtetra
0 1 .122 r
.16668 .49082 .17411 .49665 .18512 .48758 .17772 .48182 Mtetra
0 1 .062 r
.17772 .48182 .18512 .48758 .19619 .47803 .18882 .47231 Mtetra
.003 1 0 r
.18882 .47231 .19619 .47803 .20731 .46801 .19998 .46231 Mtetra
.072 1 0 r
.19998 .46231 .20731 .46801 .21847 .45753 .21118 .45183 Mtetra
.147 1 0 r
.21118 .45183 .21847 .45753 .22967 .44659 .22243 .44086 Mtetra
.226 1 0 r
.22243 .44086 .22967 .44659 .2409 .4352 .23371 .42944 Mtetra
.311 1 0 r
.23371 .42944 .2409 .4352 .25217 .42339 .24502 .41756 Mtetra
.399 1 0 r
.24502 .41756 .25217 .42339 .26345 .41116 .25636 .40526 Mtetra
.493 1 0 r
.25636 .40526 .26345 .41116 .27476 .39854 .26772 .39256 Mtetra
.59 1 0 r
.26772 .39256 .27476 .39854 .28607 .38555 .27909 .37948 Mtetra
.692 1 0 r
.27909 .37948 .28607 .38555 .2974 .37222 .29047 .36605 Mtetra
.798 1 0 r
.29047 .36605 .2974 .37222 .30872 .35857 .30185 .35229 Mtetra
.907 1 0 r
.30185 .35229 .30872 .35857 .32004 .34463 .31322 .33825 Mtetra
1 .98 0 r
.31322 .33825 .32004 .34463 .33135 .33044 .32459 .32394 Mtetra
1 .865 0 r
.32459 .32394 .33135 .33044 .34264 .31602 .33594 .30941 Mtetra
1 .746 0 r
.33594 .30941 .34264 .31602 .35392 .30141 .34727 .29469 Mtetra
1 .626 0 r
.34727 .29469 .35392 .30141 .36518 .28665 .35859 .27981 Mtetra
1 .503 0 r
.35859 .27981 .36518 .28665 .3764 .27178 .36987 .26482 Mtetra
1 .379 0 r
.36987 .26482 .3764 .27178 .3876 .25682 .38113 .24975 Mtetra
1 .253 0 r
.38113 .24975 .3876 .25682 .39877 .24182 .39235 .23463 Mtetra
1 .127 0 r
.39235 .23463 .39877 .24182 .40991 .22681 .40354 .21952 Mtetra
1 0 0 r
.40354 .21952 .40991 .22681 .42082 .21733 .41449 .20996 Mtetra
0 1 .419 r
.07335 .53822 .08086 .54574 .09132 .54038 .08378 .53323 Mtetra
0 1 .399 r
.08378 .53323 .09132 .54038 .10187 .53464 .09431 .52781 Mtetra
0 1 .375 r
.09431 .52781 .10187 .53464 .11248 .52849 .10491 .52195 Mtetra
0 1 .346 r
.10491 .52195 .11248 .52849 .12318 .5219 .1156 .51561 Mtetra
0 1 .313 r
.1156 .51561 .12318 .5219 .13394 .51486 .12638 .50877 Mtetra
0 1 .275 r
.12638 .50877 .13394 .51486 .14479 .50734 .13723 .50142 Mtetra
0 1 .231 r
.13723 .50142 .14479 .50734 .1557 .49933 .14816 .49355 Mtetra
0 1 .183 r
.14816 .49355 .1557 .49933 .16668 .49082 .15916 .48516 Mtetra
0 1 .13 r
.15916 .48516 .16668 .49082 .17772 .48182 .17024 .47623 Mtetra
0 1 .071 r
.17024 .47623 .17772 .48182 .18882 .47231 .18137 .46677 Mtetra
0 1 .007 r
.18137 .46677 .18882 .47231 .19998 .46231 .19256 .4568 Mtetra
.062 1 0 r
.19256 .4568 .19998 .46231 .21118 .45183 .20381 .44631 Mtetra
.136 1 0 r
.20381 .44631 .21118 .45183 .22243 .44086 .2151 .43532 Mtetra
.216 1 0 r
.2151 .43532 .22243 .44086 .23371 .42944 .22643 .42385 Mtetra
.3 1 0 r
.22643 .42385 .23371 .42944 .24502 .41756 .2378 .41191 Mtetra
.389 1 0 r
.2378 .41191 .24502 .41756 .25636 .40526 .24919 .39954 Mtetra
.483 1 0 r
.24919 .39954 .25636 .40526 .26772 .39256 .2606 .38675 Mtetra
.581 1 0 r
.2606 .38675 .26772 .39256 .27909 .37948 .27203 .37357 Mtetra
.683 1 0 r
.27203 .37357 .27909 .37948 .29047 .36605 .28347 .36002 Mtetra
.789 1 0 r
.28347 .36002 .29047 .36605 .30185 .35229 .2949 .34615 Mtetra
.899 1 0 r
.2949 .34615 .30185 .35229 .31322 .33825 .30634 .33198 Mtetra
1 .987 0 r
.30634 .33198 .31322 .33825 .32459 .32394 .31777 .31755 Mtetra
1 .871 0 r
.31777 .31755 .32459 .32394 .33594 .30941 .32918 .30288 Mtetra
1 .752 0 r
.32918 .30288 .33594 .30941 .34727 .29469 .34057 .28803 Mtetra
1 .63 0 r
.34057 .28803 .34727 .29469 .35859 .27981 .35194 .27302 Mtetra
1 .507 0 r
.35194 .27302 .35859 .27981 .36987 .26482 .36329 .25789 Mtetra
1 .381 0 r
.36329 .25789 .36987 .26482 .38113 .24975 .3746 .24268 Mtetra
1 .255 0 r
.3746 .24268 .38113 .24975 .39235 .23463 .38588 .22743 Mtetra
1 .128 0 r
.38588 .22743 .39235 .23463 .40354 .21952 .39713 .21218 Mtetra
1 0 0 r
.39713 .21218 .40354 .21952 .41449 .20996 .40812 .20254 Mtetra
0 1 .409 r
.06578 .53069 .07335 .53822 .08378 .53323 .07618 .5261 Mtetra
0 1 .392 r
.07618 .5261 .08378 .53323 .09431 .52781 .08668 .52105 Mtetra
0 1 .372 r
.08668 .52105 .09431 .52781 .10491 .52195 .09727 .5155 Mtetra
0 1 .346 r
.09727 .5155 .10491 .52195 .1156 .51561 .10795 .50943 Mtetra
0 1 .316 r
.10795 .50943 .1156 .51561 .12638 .50877 .11873 .50283 Mtetra
0 1 .28 r
.11873 .50283 .12638 .50877 .13723 .50142 .12959 .49567 Mtetra
0 1 .239 r
.12959 .49567 .13723 .50142 .14816 .49355 .14054 .48795 Mtetra
0 1 .192 r
.14054 .48795 .14816 .49355 .15916 .48516 .15156 .47967 Mtetra
0 1 .14 r
.15156 .47967 .15916 .48516 .17024 .47623 .16266 .47083 Mtetra
0 1 .083 r
.16266 .47083 .17024 .47623 .18137 .46677 .17383 .46143 Mtetra
0 1 .019 r
.17383 .46143 .18137 .46677 .19256 .4568 .18506 .45148 Mtetra
.049 1 0 r
.18506 .45148 .19256 .4568 .20381 .44631 .19635 .44099 Mtetra
.123 1 0 r
.19635 .44099 .20381 .44631 .2151 .43532 .20769 .42997 Mtetra
.202 1 0 r
.20769 .42997 .2151 .43532 .22643 .42385 .21907 .41846 Mtetra
.287 1 0 r
.21907 .41846 .22643 .42385 .2378 .41191 .23049 .40646 Mtetra
.376 1 0 r
.23049 .40646 .2378 .41191 .24919 .39954 .24194 .394 Mtetra
.47 1 0 r
.24194 .394 .24919 .39954 .2606 .38675 .25341 .38111 Mtetra
.569 1 0 r
.25341 .38111 .2606 .38675 .27203 .37357 .2649 .36781 Mtetra
.672 1 0 r
.2649 .36781 .27203 .37357 .28347 .36002 .27639 .35415 Mtetra
.779 1 0 r
.27639 .35415 .28347 .36002 .2949 .34615 .28789 .34014 Mtetra
.89 1 0 r
.28789 .34014 .2949 .34615 .30634 .33198 .29939 .32583 Mtetra
1 .996 0 r
.29939 .32583 .30634 .33198 .31777 .31755 .31088 .31125 Mtetra
1 .879 0 r
.31088 .31125 .31777 .31755 .32918 .30288 .32235 .29643 Mtetra
1 .758 0 r
.32235 .29643 .32918 .30288 .34057 .28803 .33381 .28142 Mtetra
1 .636 0 r
.33381 .28142 .34057 .28803 .35194 .27302 .34524 .26626 Mtetra
1 .511 0 r
.34524 .26626 .35194 .27302 .36329 .25789 .35665 .25097 Mtetra
1 .385 0 r
.35665 .25097 .36329 .25789 .3746 .24268 .36802 .23561 Mtetra
1 .257 0 r
.36802 .23561 .3746 .24268 .38588 .22743 .37936 .2202 Mtetra
1 .129 0 r
.37936 .2202 .38588 .22743 .39713 .21218 .39066 .20479 Mtetra
1 0 0 r
.39066 .20479 .39713 .21218 .40812 .20254 .4017 .19507 Mtetra
0 1 .399 r
.05815 .52319 .06578 .53069 .07618 .5261 .06851 .51905 Mtetra
0 1 .387 r
.06851 .51905 .07618 .5261 .08668 .52105 .07897 .51439 Mtetra
0 1 .37 r
.07897 .51439 .08668 .52105 .09727 .5155 .08954 .50918 Mtetra
0 1 .348 r
.08954 .50918 .09727 .5155 .10795 .50943 .10022 .50341 Mtetra
0 1 .32 r
.10022 .50341 .10795 .50943 .11873 .50283 .11099 .49706 Mtetra
0 1 .287 r
.11099 .49706 .11873 .50283 .12959 .49567 .12186 .49011 Mtetra
0 1 .248 r
.12186 .49011 .12959 .49567 .14054 .48795 .13282 .48256 Mtetra
0 1 .204 r
.13282 .48256 .14054 .48795 .15156 .47967 .14387 .47441 Mtetra
0 1 .153 r
.14387 .47441 .15156 .47967 .16266 .47083 .155 .46565 Mtetra
0 1 .097 r
.155 .46565 .16266 .47083 .17383 .46143 .1662 .45631 Mtetra
0 1 .034 r
.1662 .45631 .17383 .46143 .18506 .45148 .17747 .44638 Mtetra
.034 1 0 r
.17747 .44638 .18506 .45148 .19635 .44099 .18881 .43589 Mtetra
.107 1 0 r
.18881 .43589 .19635 .44099 .20769 .42997 .20019 .42485 Mtetra
.186 1 0 r
.20019 .42485 .20769 .42997 .21907 .41846 .21163 .41328 Mtetra
.271 1 0 r
.21163 .41328 .21907 .41846 .23049 .40646 .2231 .4012 Mtetra
.361 1 0 r
.2231 .4012 .23049 .40646 .24194 .394 .23461 .38865 Mtetra
.455 1 0 r
.23461 .38865 .24194 .394 .25341 .38111 .24614 .37565 Mtetra
.554 1 0 r
.24614 .37565 .25341 .38111 .2649 .36781 .25769 .36223 Mtetra
.658 1 0 r
.25769 .36223 .2649 .36781 .27639 .35415 .26925 .34843 Mtetra
.766 1 0 r
.26925 .34843 .27639 .35415 .28789 .34014 .28081 .33427 Mtetra
.878 1 0 r
.28081 .33427 .28789 .34014 .29939 .32583 .29237 .3198 Mtetra
.993 1 0 r
.29237 .3198 .29939 .32583 .31088 .31125 .30393 .30506 Mtetra
1 .888 0 r
.30393 .30506 .31088 .31125 .32235 .29643 .31547 .29007 Mtetra
1 .767 0 r
.31547 .29007 .32235 .29643 .33381 .28142 .32699 .27489 Mtetra
1 .643 0 r
.32699 .27489 .33381 .28142 .34524 .26626 .33848 .25954 Mtetra
1 .517 0 r
.33848 .25954 .34524 .26626 .35665 .25097 .34995 .24408 Mtetra
1 .389 0 r
.34995 .24408 .35665 .25097 .36802 .23561 .36139 .22853 Mtetra
1 .26 0 r
.36139 .22853 .36802 .23561 .37936 .2202 .37279 .21295 Mtetra
1 .13 0 r
.37279 .21295 .37936 .2202 .39066 .20479 .38415 .19736 Mtetra
1 0 0 r
.38415 .19736 .39066 .20479 .4017 .19507 .39523 .18753 Mtetra
0 1 .39 r
.05044 .51578 .05815 .52319 .06851 .51905 .06075 .51212 Mtetra
0 1 .383 r
.06075 .51212 .06851 .51905 .07897 .51439 .07118 .50789 Mtetra
0 1 .37 r
.07118 .50789 .07897 .51439 .08954 .50918 .08173 .50305 Mtetra
0 1 .352 r
.08173 .50305 .08954 .50918 .10022 .50341 .09239 .4976 Mtetra
0 1 .328 r
.09239 .4976 .10022 .50341 .11099 .49706 .10316 .49151 Mtetra
0 1 .297 r
.10316 .49151 .11099 .49706 .12186 .49011 .11403 .48478 Mtetra
0 1 .261 r
.11403 .48478 .12186 .49011 .13282 .48256 .125 .47741 Mtetra
0 1 .218 r
.125 .47741 .13282 .48256 .14387 .47441 .13607 .46939 Mtetra
0 1 .169 r
.13607 .46939 .14387 .47441 .155 .46565 .14723 .46073 Mtetra
0 1 .114 r
.14723 .46073 .155 .46565 .1662 .45631 .15847 .45145 Mtetra
0 1 .052 r
.15847 .45145 .1662 .45631 .17747 .44638 .16978 .44154 Mtetra
.015 1 0 r
.16978 .44154 .17747 .44638 .18881 .43589 .18116 .43105 Mtetra
.089 1 0 r
.18116 .43105 .18881 .43589 .20019 .42485 .1926 .41997 Mtetra
.168 1 0 r
.1926 .41997 .20019 .42485 .21163 .41328 .20409 .40834 Mtetra
.252 1 0 r
.20409 .40834 .21163 .41328 .2231 .4012 .21562 .39618 Mtetra
.342 1 0 r
.21562 .39618 .2231 .4012 .23461 .38865 .22719 .38352 Mtetra
.438 1 0 r
.22719 .38352 .23461 .38865 .24614 .37565 .23878 .37039 Mtetra
.538 1 0 r
.23878 .37039 .24614 .37565 .25769 .36223 .25039 .35683 Mtetra
.642 1 0 r
.25039 .35683 .25769 .36223 .26925 .34843 .26202 .34287 Mtetra
.751 1 0 r
.26202 .34287 .26925 .34843 .28081 .33427 .27365 .32855 Mtetra
.865 1 0 r
.27365 .32855 .28081 .33427 .29237 .3198 .28528 .3139 Mtetra
.981 1 0 r
.28528 .3139 .29237 .3198 .30393 .30506 .2969 .29897 Mtetra
1 .899 0 r
.2969 .29897 .30393 .30506 .31547 .29007 .30851 .2838 Mtetra
1 .776 0 r
.30851 .2838 .31547 .29007 .32699 .27489 .3201 .26842 Mtetra
1 .651 0 r
.3201 .26842 .32699 .27489 .33848 .25954 .33166 .25287 Mtetra
1 .523 0 r
.33166 .25287 .33848 .25954 .34995 .24408 .3432 .23721 Mtetra
1 .394 0 r
.3432 .23721 .34995 .24408 .36139 .22853 .3547 .22146 Mtetra
1 .263 0 r
.3547 .22146 .36139 .22853 .37279 .21295 .36617 .20568 Mtetra
1 .132 0 r
.36617 .20568 .37279 .21295 .38415 .19736 .37759 .18989 Mtetra
1 0 0 r
.37759 .18989 .38415 .19736 .39523 .18753 .38871 .17995 Mtetra
0 1 .384 r
.04266 .50853 .05044 .51578 .06075 .51212 .05291 .50538 Mtetra
0 1 .381 r
.05291 .50538 .06075 .51212 .07118 .50789 .0633 .50159 Mtetra
0 1 .373 r
.0633 .50159 .07118 .50789 .08173 .50305 .07381 .49715 Mtetra
0 1 .359 r
.07381 .49715 .08173 .50305 .09239 .4976 .08446 .49203 Mtetra
0 1 .338 r
.08446 .49203 .09239 .4976 .10316 .49151 .09522 .48622 Mtetra
0 1 .31 r
.09522 .48622 .10316 .49151 .11403 .48478 .10609 .47973 Mtetra
0 1 .276 r
.10609 .47973 .11403 .48478 .125 .47741 .11708 .47254 Mtetra
0 1 .235 r
.11708 .47254 .125 .47741 .13607 .46939 .12817 .46466 Mtetra
0 1 .188 r
.12817 .46466 .13607 .46939 .14723 .46073 .13936 .4561 Mtetra
0 1 .134 r
.13936 .4561 .14723 .46073 .15847 .45145 .15063 .44687 Mtetra
0 1 .073 r
.15063 .44687 .15847 .45145 .16978 .44154 .16199 .43699 Mtetra
0 1 .006 r
.16199 .43699 .16978 .44154 .18116 .43105 .17342 .42647 Mtetra
.067 1 0 r
.17342 .42647 .18116 .43105 .1926 .41997 .18491 .41535 Mtetra
.146 1 0 r
.18491 .41535 .1926 .41997 .20409 .40834 .19645 .40365 Mtetra
.231 1 0 r
.19645 .40365 .20409 .40834 .21562 .39618 .20805 .39139 Mtetra
.321 1 0 r
.20805 .39139 .21562 .39618 .22719 .38352 .21968 .37861 Mtetra
.417 1 0 r
.21968 .37861 .22719 .38352 .23878 .37039 .23134 .36535 Mtetra
.518 1 0 r
.23134 .36535 .23878 .37039 .25039 .35683 .24302 .35163 Mtetra
.624 1 0 r
.24302 .35163 .25039 .35683 .26202 .34287 .25471 .33749 Mtetra
.735 1 0 r
.25471 .33749 .26202 .34287 .27365 .32855 .26642 .32299 Mtetra
.849 1 0 r
.26642 .32299 .27365 .32855 .28528 .3139 .27812 .30814 Mtetra
.967 1 0 r
.27812 .30814 .28528 .3139 .2969 .29897 .28981 .29301 Mtetra
1 .911 0 r
.28981 .29301 .2969 .29897 .30851 .2838 .30149 .27762 Mtetra
1 .787 0 r
.30149 .27762 .30851 .2838 .3201 .26842 .31315 .26202 Mtetra
1 .66 0 r
.31315 .26202 .3201 .26842 .33166 .25287 .32478 .24625 Mtetra
1 .531 0 r
.32478 .24625 .33166 .25287 .3432 .23721 .33639 .23036 Mtetra
1 .399 0 r
.33639 .23036 .3432 .23721 .3547 .22146 .34796 .21439 Mtetra
1 .267 0 r
.34796 .21439 .3547 .22146 .36617 .20568 .35949 .19838 Mtetra
1 .134 0 r
.35949 .19838 .36617 .20568 .37759 .18989 .37098 .18237 Mtetra
1 0 0 r
.37098 .18237 .37759 .18989 .38871 .17995 .38215 .1723 Mtetra
0 1 .379 r
.03477 .50149 .04266 .50853 .05291 .50538 .04497 .49888 Mtetra
0 1 .383 r
.04497 .49888 .05291 .50538 .0633 .50159 .05531 .49557 Mtetra
0 1 .379 r
.05531 .49557 .0633 .50159 .07381 .49715 .06579 .49154 Mtetra
0 1 .369 r
.06579 .49154 .07381 .49715 .08446 .49203 .07641 .48677 Mtetra
0 1 .351 r
.07641 .48677 .08446 .49203 .09522 .48622 .08716 .48125 Mtetra
0 1 .327 r
.08716 .48125 .09522 .48622 .10609 .47973 .09804 .47499 Mtetra
0 1 .295 r
.09804 .47499 .10609 .47973 .11708 .47254 .10904 .46799 Mtetra
0 1 .256 r
.10904 .46799 .11708 .47254 .12817 .46466 .12016 .46025 Mtetra
0 1 .21 r
.12016 .46025 .12817 .46466 .13936 .4561 .13137 .45178 Mtetra
0 1 .157 r
.13137 .45178 .13936 .4561 .15063 .44687 .14268 .44261 Mtetra
0 1 .098 r
.14268 .44261 .15063 .44687 .16199 .43699 .15408 .43274 Mtetra
0 1 .031 r
.15408 .43274 .16199 .43699 .17342 .42647 .16556 .4222 Mtetra
.042 1 0 r
.16556 .4222 .17342 .42647 .18491 .41535 .17711 .41103 Mtetra
.121 1 0 r
.17711 .41103 .18491 .41535 .19645 .40365 .18871 .39924 Mtetra
.206 1 0 r
.18871 .39924 .19645 .40365 .20805 .39139 .20037 .38687 Mtetra
.298 1 0 r
.20037 .38687 .20805 .39139 .21968 .37861 .21207 .37395 Mtetra
.394 1 0 r
.21207 .37395 .21968 .37861 .23134 .36535 .2238 .36053 Mtetra
.496 1 0 r
.2238 .36053 .23134 .36535 .24302 .35163 .23555 .34663 Mtetra
.603 1 0 r
.23555 .34663 .24302 .35163 .25471 .33749 .24732 .33231 Mtetra
.715 1 0 r
.24732 .33231 .25471 .33749 .26642 .32299 .2591 .31759 Mtetra
.831 1 0 r
.2591 .31759 .26642 .32299 .27812 .30814 .27087 .30253 Mtetra
.951 1 0 r
.27087 .30253 .27812 .30814 .28981 .29301 .28264 .28716 Mtetra
1 .926 0 r
.28264 .28716 .28981 .29301 .30149 .27762 .2944 .27154 Mtetra
1 .799 0 r
.2944 .27154 .30149 .27762 .31315 .26202 .30613 .2557 Mtetra
1 .67 0 r
.30613 .2557 .31315 .26202 .32478 .24625 .31784 .23969 Mtetra
1 .539 0 r
.31784 .23969 .32478 .24625 .33639 .23036 .32952 .22355 Mtetra
1 .406 0 r
.32952 .22355 .33639 .23036 .34796 .21439 .34116 .20733 Mtetra
1 .271 0 r
.34116 .20733 .34796 .21439 .35949 .19838 .35276 .19107 Mtetra
1 .136 0 r
.35276 .19107 .35949 .19838 .37098 .18237 .36432 .17481 Mtetra
1 0 0 r
.36432 .17481 .37098 .18237 .38215 .1723 .37554 .1646 Mtetra
0 1 .379 r
.02678 .49475 .03477 .50149 .04497 .49888 .03691 .4927 Mtetra
0 1 .387 r
.03691 .4927 .04497 .49888 .05531 .49557 .0472 .48988 Mtetra
0 1 .389 r
.0472 .48988 .05531 .49557 .06579 .49154 .05764 .48627 Mtetra
0 1 .382 r
.05764 .48627 .06579 .49154 .07641 .48677 .06824 .48186 Mtetra
0 1 .368 r
.06824 .48186 .07641 .48677 .08716 .48125 .07898 .47665 Mtetra
0 1 .347 r
.07898 .47665 .08716 .48125 .09804 .47499 .08987 .47063 Mtetra
0 1 .318 r
.08987 .47063 .09804 .47499 .10904 .46799 .10088 .46381 Mtetra
0 1 .281 r
.10088 .46381 .10904 .46799 .12016 .46025 .11201 .45621 Mtetra
0 1 .237 r
.11201 .45621 .12016 .46025 .13137 .45178 .12326 .44783 Mtetra
0 1 .185 r
.12326 .44783 .13137 .45178 .14268 .44261 .13461 .4387 Mtetra
0 1 .126 r
.13461 .4387 .14268 .44261 .15408 .43274 .14606 .42884 Mtetra
0 1 .06 r
.14606 .42884 .15408 .43274 .16556 .4222 .15759 .41827 Mtetra
.013 1 0 r
.15759 .41827 .16556 .4222 .17711 .41103 .1692 .40702 Mtetra
.092 1 0 r
.1692 .40702 .17711 .41103 .18871 .39924 .18087 .39513 Mtetra
.178 1 0 r
.18087 .39513 .18871 .39924 .20037 .38687 .19259 .38263 Mtetra
.27 1 0 r
.19259 .38263 .20037 .38687 .21207 .37395 .20436 .36956 Mtetra
.368 1 0 r
.20436 .36956 .21207 .37395 .2238 .36053 .21616 .35596 Mtetra
.472 1 0 r
.21616 .35596 .2238 .36053 .23555 .34663 .22799 .34187 Mtetra
.58 1 0 r
.22799 .34187 .23555 .34663 .24732 .33231 .23984 .32733 Mtetra
.693 1 0 r
.23984 .32733 .24732 .33231 .2591 .31759 .2517 .31238 Mtetra
.811 1 0 r
.2517 .31238 .2591 .31759 .27087 .30253 .26355 .29707 Mtetra
.933 1 0 r
.26355 .29707 .27087 .30253 .28264 .28716 .2754 .28145 Mtetra
1 .942 0 r
.2754 .28145 .28264 .28716 .2944 .27154 .28723 .26557 Mtetra
1 .813 0 r
.28723 .26557 .2944 .27154 .30613 .2557 .29905 .24946 Mtetra
1 .682 0 r
.29905 .24946 .30613 .2557 .31784 .23969 .31083 .23318 Mtetra
1 .548 0 r
.31083 .23318 .31784 .23969 .32952 .22355 .32258 .21676 Mtetra
1 .413 0 r
.32258 .21676 .32952 .22355 .34116 .20733 .3343 .20027 Mtetra
1 .276 0 r
.3343 .20027 .34116 .20733 .35276 .19107 .34598 .18373 Mtetra
1 .138 0 r
.34598 .18373 .35276 .19107 .36432 .17481 .35761 .1672 Mtetra
1 0 0 r
.35761 .1672 .36432 .17481 .37554 .1646 .36887 .15684 Mtetra
0 1 .382 r
.01867 .48837 .02678 .49475 .03691 .4927 .02872 .4869 Mtetra
0 1 .396 r
.02872 .4869 .03691 .4927 .0472 .48988 .03896 .48459 Mtetra
0 1 .402 r
.03896 .48459 .0472 .48988 .05764 .48627 .04936 .48142 Mtetra
0 1 .4 r
.04936 .48142 .05764 .48627 .06824 .48186 .05994 .47737 Mtetra
0 1 .39 r
.05994 .47737 .06824 .48186 .07898 .47665 .07067 .47246 Mtetra
0 1 .372 r
.07067 .47246 .07898 .47665 .08987 .47063 .08155 .46669 Mtetra
0 1 .345 r
.08155 .46669 .08987 .47063 .10088 .46381 .09258 .46006 Mtetra
0 1 .31 r
.09258 .46006 .10088 .46381 .11201 .45621 .10374 .45258 Mtetra
0 1 .267 r
.10374 .45258 .11201 .45621 .12326 .44783 .11502 .44429 Mtetra
0 1 .217 r
.11502 .44429 .12326 .44783 .13461 .4387 .12641 .43519 Mtetra
0 1 .159 r
.12641 .43519 .13461 .4387 .14606 .42884 .13791 .42532 Mtetra
0 1 .093 r
.13791 .42532 .14606 .42884 .15759 .41827 .1495 .4147 Mtetra
0 1 .02 r
.1495 .4147 .15759 .41827 .1692 .40702 .16117 .40336 Mtetra
.06 1 0 r
.16117 .40336 .1692 .40702 .18087 .39513 .1729 .39136 Mtetra
.147 1 0 r
.1729 .39136 .18087 .39513 .19259 .38263 .1847 .37871 Mtetra
.24 1 0 r
.1847 .37871 .19259 .38263 .20436 .36956 .19654 .36546 Mtetra
.339 1 0 r
.19654 .36546 .20436 .36956 .21616 .35596 .20843 .35166 Mtetra
.444 1 0 r
.20843 .35166 .21616 .35596 .22799 .34187 .22034 .33734 Mtetra
.554 1 0 r
.22034 .33734 .22799 .34187 .23984 .32733 .23227 .32256 Mtetra
.669 1 0 r
.23227 .32256 .23984 .32733 .2517 .31238 .24421 .30736 Mtetra
.789 1 0 r
.24421 .30736 .2517 .31238 .26355 .29707 .25615 .29178 Mtetra
.912 1 0 r
.25615 .29178 .26355 .29707 .2754 .28145 .26808 .27589 Mtetra
1 .96 0 r
.26808 .27589 .2754 .28145 .28723 .26557 .27999 .25971 Mtetra
1 .829 0 r
.27999 .25971 .28723 .26557 .29905 .24946 .29189 .24331 Mtetra
1 .695 0 r
.29189 .24331 .29905 .24946 .31083 .23318 .30376 .22673 Mtetra
1 .559 0 r
.30376 .22673 .31083 .23318 .32258 .21676 .31559 .21001 Mtetra
1 .421 0 r
.31559 .21001 .32258 .21676 .3343 .20027 .32738 .19321 Mtetra
1 .281 0 r
.32738 .19321 .3343 .20027 .34598 .18373 .33914 .17637 Mtetra
1 .141 0 r
.33914 .17637 .34598 .18373 .35761 .1672 .35084 .15954 Mtetra
1 0 0 r
.35084 .15954 .35761 .1672 .36887 .15684 .36216 .14902 Mtetra
0 1 .389 r
.01041 .48244 .01867 .48837 .02872 .4869 .02039 .48157 Mtetra
0 1 .41 r
.02039 .48157 .02872 .4869 .03896 .48459 .03057 .47977 Mtetra
0 1 .421 r
.03057 .47977 .03896 .48459 .04936 .48142 .04093 .47704 Mtetra
0 1 .423 r
.04093 .47704 .04936 .48142 .05994 .47737 .05148 .47337 Mtetra
0 1 .417 r
.05148 .47337 .05994 .47737 .07067 .47246 .0622 .46876 Mtetra
0 1 .401 r
.0622 .46876 .07067 .47246 .08155 .46669 .07309 .46322 Mtetra
0 1 .377 r
.07309 .46322 .08155 .46669 .09258 .46006 .08413 .45677 Mtetra
0 1 .344 r
.08413 .45677 .09258 .46006 .10374 .45258 .09532 .44942 Mtetra
0 1 .303 r
.09532 .44942 .10374 .45258 .11502 .44429 .10663 .44119 Mtetra
0 1 .253 r
.10663 .44119 .11502 .44429 .12641 .43519 .11807 .43211 Mtetra
0 1 .196 r
.11807 .43211 .12641 .43519 .13791 .42532 .12962 .42221 Mtetra
0 1 .13 r
.12962 .42221 .13791 .42532 .1495 .4147 .14127 .41152 Mtetra
0 1 .057 r
.14127 .41152 .1495 .4147 .16117 .40336 .15301 .40009 Mtetra
.024 1 0 r
.15301 .40009 .16117 .40336 .1729 .39136 .16482 .38794 Mtetra
.111 1 0 r
.16482 .38794 .1729 .39136 .1847 .37871 .17669 .37512 Mtetra
.205 1 0 r
.17669 .37512 .1847 .37871 .19654 .36546 .18862 .36167 Mtetra
.306 1 0 r
.18862 .36167 .19654 .36546 .20843 .35166 .20058 .34764 Mtetra
.412 1 0 r
.20058 .34764 .20843 .35166 .22034 .33734 .21258 .33308 Mtetra
.525 1 0 r
.21258 .33308 .22034 .33734 .23227 .32256 .2246 .31803 Mtetra
.642 1 0 r
.2246 .31803 .23227 .32256 .24421 .30736 .23662 .30254 Mtetra
.764 1 0 r
.23662 .30254 .24421 .30736 .25615 .29178 .24865 .28667 Mtetra
.89 1 0 r
.24865 .28667 .25615 .29178 .26808 .27589 .26067 .27047 Mtetra
1 .98 0 r
.26067 .27047 .26808 .27589 .27999 .25971 .27268 .25398 Mtetra
1 .846 0 r
.27268 .25398 .27999 .25971 .29189 .24331 .28466 .23725 Mtetra
1 .71 0 r
.28466 .23725 .29189 .24331 .30376 .22673 .29661 .22034 Mtetra
1 .571 0 r
.29661 .22034 .30376 .22673 .31559 .21001 .30853 .2033 Mtetra
1 .43 0 r
.30853 .2033 .31559 .21001 .32738 .19321 .32041 .18617 Mtetra
1 .287 0 r
.32041 .18617 .32738 .19321 .33914 .17637 .33224 .169 Mtetra
1 .144 0 r
.33224 .169 .33914 .17637 .35084 .15954 .34402 .15184 Mtetra
1 0 0 r
.34402 .15184 .35084 .15954 .36216 .14902 .35539 .14114 Mtetra
0 1 .403 r
.00199 .47705 .01041 .48244 .02039 .48157 .01189 .47678 Mtetra
0 1 .429 r
.01189 .47678 .02039 .48157 .03057 .47977 .02201 .47551 Mtetra
0 1 .445 r
.02201 .47551 .03057 .47977 .04093 .47704 .03233 .47321 Mtetra
0 1 .452 r
.03233 .47321 .04093 .47704 .05148 .47337 .04286 .46991 Mtetra
0 1 .449 r
.04286 .46991 .05148 .47337 .0622 .46876 .05357 .4656 Mtetra
0 1 .436 r
.05357 .4656 .0622 .46876 .07309 .46322 .06446 .46029 Mtetra
0 1 .414 r
.06446 .46029 .07309 .46322 .08413 .45677 .07552 .454 Mtetra
0 1 .383 r
.07552 .454 .08413 .45677 .09532 .44942 .08674 .44676 Mtetra
0 1 .343 r
.08674 .44676 .09532 .44942 .10663 .44119 .09809 .43858 Mtetra
0 1 .295 r
.09809 .43858 .10663 .44119 .11807 .43211 .10958 .4295 Mtetra
0 1 .237 r
.10958 .4295 .11807 .43211 .12962 .42221 .12119 .41956 Mtetra
0 1 .172 r
.12119 .41956 .12962 .42221 .14127 .41152 .13291 .40878 Mtetra
0 1 .098 r
.13291 .40878 .14127 .41152 .15301 .40009 .14471 .39722 Mtetra
0 1 .017 r
.14471 .39722 .15301 .40009 .16482 .38794 .1566 .3849 Mtetra
.072 1 0 r
.1566 .3849 .16482 .38794 .17669 .37512 .16856 .37188 Mtetra
.167 1 0 r
.16856 .37188 .17669 .37512 .18862 .36167 .18057 .35821 Mtetra
.27 1 0 r
.18057 .35821 .18862 .36167 .20058 .34764 .19262 .34393 Mtetra
.378 1 0 r
.19262 .34393 .20058 .34764 .21258 .33308 .20471 .32909 Mtetra
.492 1 0 r
.20471 .32909 .21258 .33308 .2246 .31803 .21682 .31375 Mtetra
.612 1 0 r
.21682 .31375 .2246 .31803 .23662 .30254 .22894 .29795 Mtetra
.736 1 0 r
.22894 .29795 .23662 .30254 .24865 .28667 .24106 .28175 Mtetra
.865 1 0 r
.24106 .28175 .24865 .28667 .26067 .27047 .25318 .26521 Mtetra
.998 1 0 r
.25318 .26521 .26067 .27047 .27268 .25398 .26528 .24837 Mtetra
1 .865 0 r
.26528 .24837 .27268 .25398 .28466 .23725 .27735 .23129 Mtetra
1 .726 0 r
.27735 .23129 .28466 .23725 .29661 .22034 .2894 .21403 Mtetra
1 .584 0 r
.2894 .21403 .29661 .22034 .30853 .2033 .30141 .19662 Mtetra
1 .44 0 r
.30141 .19662 .30853 .2033 .32041 .18617 .31337 .17913 Mtetra
1 .294 0 r
.31337 .17913 .32041 .18617 .33224 .169 .32529 .16161 Mtetra
1 .147 0 r
.32529 .16161 .33224 .169 .34402 .15184 .33715 .14409 Mtetra
1 0 0 r
.33715 .14409 .34402 .15184 .35539 .14114 .34857 .1332 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.06351 .24482 m
.06826 .24934 L
s
[(-1)] .054 .23578 1 .95078 Mshowa
.19951 .19156 m
.20405 .1963 L
s
[(-0.5)] .19044 .18208 .957 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.49481 .07594 m
.4988 .08114 L
s
[(0.5)] .48682 .06553 .76746 1 Mshowa
.65547 .01303 m
.65913 .01847 L
s
[(1)] .64814 .00214 .6727 1 Mshowa
.125 Mabswid
.09013 .23439 m
.09296 .23713 L
s
.11704 .22386 m
.11985 .22662 L
s
.14424 .21321 m
.14702 .216 L
s
.17173 .20244 m
.17448 .20526 L
s
.2276 .18057 m
.23029 .18344 L
s
.25599 .16945 m
.25866 .17235 L
s
.2847 .15821 m
.28733 .16113 L
s
.31372 .14684 m
.31632 .1498 L
s
.37274 .12374 m
.37527 .12675 L
s
.40274 .11199 m
.40524 .11502 L
s
.43308 .10011 m
.43555 .10317 L
s
.46377 .08809 m
.4662 .09118 L
s
.5262 .06364 m
.52856 .0668 L
s
.55796 .05121 m
.56028 .05439 L
s
.59008 .03863 m
.59236 .04184 L
s
.62258 .0259 m
.62482 .02914 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{174.875, 141.812},
  ImageMargins->{{38, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002^0000S@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooojkG002^e`00[]L00:kG002^e`00[]L00:kG
002^e`00[]L0077G100ie`00LmL00`3Ge`0he`00LmL00`3Ge`0he`00LmL00`3Ge`0he`00LmL00`3G
e`0he`00LML303[G001ce`030=OG013G100Te`00N]L200cG00<0emL08mL007SG0P000mL0000;e`03
0=OG02?G001ee`<00mL200?G1004e`030=OG02?G001@e`801=L00`3Ge`02e`<05ML20003e`3G00?G
00<0e`002]L00`3Ge`0Se`00CmL0103Ge`0;e`030=OG00oG0`08e`@01mL302GG001?e`040=OG00_G
00<0emL03ML200_G00@0emL02ML00`3Ge`0Se`00CmL0103Ge`08e`<03ML300gG00D0emOG000^e`00
CmL0103Ge`08e`030=OG00[G0`0@e`040=OGe`80;ML004oG00@0emL02=L00`3Ge`08e`<04]L00`3G
e`02e`030=OG02_G001@e`802ML400CG0`0Fe`030=OG00;G00<0emL0:]L0067G0P000mL0e`0Fe`03
0=OG00;G00<0emL0:]L004CG0P0He`<06mL00`3Ge`03e`030=OG02WG0013e`040=OG01GG0P000mL0
e`0Ke`030=OG00CG00<0emL0:=L004?G00@0emL04]L3023G00<0emL01=L00`3Ge`0Xe`00@mL0103G
e`0@e`808mL00`3Ge`04e`80:ML004?G00@0emL03ML302GG00<0emL01]L00`3Ge`09e`801=L00`3G
e`02e`<03mL004?G00@0emL02mL202SG00<0emL01]L00`3Ge`08e`040=OG00_G00<0emL03=L004CG
0P09e`@0:ML00`3Ge`06e`802ML0103Ge`0;e`030=OG00cG001=e`80;ML00`3Ge`08e`030=OG00@0
0]L0103Ge`08e`<03mL002CG0P04e`030=OG00;G0`0He`<0;mL00`3Ge`08e`030=OG00KG00@0emL0
2=L00`3Ge`0?e`008mL0103Ge`0;e`030=OG01;G100ae`030=OG00SG0P07e`040=OG00SG00<0emL0
3mL002?G00@0emL02mL00`3Ge`0@e`8000?G];@00[@`e`030=OG00[G00<0emL01ML200WG100>e`00
7ML400;G00@0emL02=L3013G10000mNj^P03]33G00<0emL02]L00`3Ge`0Re`008mL0103Ge`08e`03
0=OG00kG0P04e`04];Zd^P>d;mL00`3Ge`0:e`808mL002?G00@0emL02=L00`3Ge`0;e`<01]L00l2j
^P02^P>d;]L00`3Ge`0;e`030=OG027G000Te`802ML400SG0`08e`06^/2d^[Bj0k@]e`030=OG00cG
00<0emL08=L003SG0`0:e`08^/2j^[Bj];X3]2cG00<0emL03=L2027G000Je`@06=L20003e`3G00WG
0/002;[0^[Zd^[Bj0[@]e`030=OG00cG00<0emL07mL001cG00<0emL05=L300gG00K0a/36^/02^P04
];Zd^P:d;=L00`3Ge`0=e`030=OG01kG000Le`030=OG017G0`0@e`03a/3000;01;X00kBj]003]2_G
00<0emL03ML201oG000De`@01=L00`3Ge`0?e`@04=L3aPC000Jj`;Zj];X4]2[G00<0emL03]L00`3G
e`04e`805mL001cG00<0emL03=L301?G0lH00l36`003`0Bj00>d^[@00k@Ye`030=OG00oG00<0emL0
0]L0103Ge`0Fe`006]L300_G0`0Fe`03c<K600?61<001[[0^[Zd^PBd:=L00`3Ge`0?e`800mL0103G
e`0Fe`007=L00`3Ge`07e`@05]L02<K<a/K0a/361<04^P03];Zd00>d9mL00`3Ge`0@e`050=OGe`00
0]L00`3Ge`0De`009=L201[G00?Ba/`01/H4`006^/2j^[Bj1;@Ve`030=OG017G00@0emL00]L00`3G
e`0De`008ML301_G00GBc<c6c002aP04`<K0aP?01KX00kBj]002]2GG0P0?e`BE00CG0=L00]L00`3G
e`0De`007]L401cG00OBc=;<d/K<00;600C0a/361<001[[0^[Zd^P>d8ML300;G00<0emL02ML02KVE
^IFiUKWG0002e`805mL001gG0P0Ne`;B1L`02<K<a/K0a/360/06^P03];Zd00:d7ML300GG00<0emL0
1mL00iFiU@03U@04];Zd^P806]L001OG0P04e`807ML5dP0<c=;<c<K<a/c0a/361<001[[0^[Zd^P:d
6mL200WG00<0emL00mL02IFiUKVE^KBj]004^P;G00<0emL05mL001KG00@0emL00mL00`3G000Le`03
[];B00?B1<`4aP06`<K0a[[01[X01;Bj];@Ge`<03=L04P3GUKVE^IFi];Zd^[Bj];Zd^P;G00<0emL0
5mL001KG00@0emL00mL0103Ge`0Je`03[]:^00GB1<`02<K<a/c0a/361<001[[0];Zd^P:d4mL300kG
0[T03@2i^KZd^[Bj];Zd^[@00[X01<2j`=L201SG000Fe`040=OG00;G0P03e`030=OG01KG00Z^dZkB
[];<d/cB1<`4aP06`<K0a[[01;X01;Bj];X2]0oG0`0>e`Fi00X0^KZd^[Bj];Zd1[X01L2jemL001SG
000Fe`040=OG00;G00<0emL00mL00`3Ge`0Ee`:^1m800lcBc003c008a/c6c<36`<H4`006^/2d^[Bj
0[@;e`<03]L00kRi^@04^@0C^[@0];Zd^[C0^/2j`;[0^/2j`003e`030=OG01GG000Fe`040=OG00;G
0P05e`805=L00jj:[P03[P0;dZkBc=;<d/K<a/`01<H01/36`<2j`0Bj00>d^[@00k@8e`803mL2^00<
^KRi^;Zd^[Bj]02d2KX6`0;G0P05e`801=L00`3Ge`02e`<00mL001OG0P03e`801mL00`3Ge`0@e`::
1:h5dP04c=;<dPC<00K6c<K6`<H6`004^/2d^PBd1=L300kG0[P05;Vh^KBj];Zd^[Bj]<00`;[0^/2j
2<000lK0e`02e`030=OG00;G00@0emL02mL1007G0ML000CG0P04e`030=OG00;G1002e`<01=L00`3G
e`07e`030=OG00kG18X6[P?B00S<d/cBa/c6c0C600?0a/001<03^P03];Zd00>d0`0>e`0>^;Nh]kRd
^[Bj];Zd^[@5^P040;Zj^P[00lH2e`800mL0103Ge`0;e`400ML1e`000mL0103Ge`08e`030=OG00KG
00D0emOG000:e`030=OG00cG00J:IZj:[XX2[P04dZkB[P?B00C<d/cB1<`3aP03c<3600C000Jj`;[0
];X30003]=OG00_G0[L05[Rg^;Bj];Zd^[Bj]<2j`;[0^/2j`009`0K61=L0103Ge`02e`030=OG00KG
0`03e`000mL0103Ge`09e`030=OG00GG00D0emOG000;e`030=OG00[G00R:IXYV[XZ^RP:^00CB[]:^
0m802<cBc=;6c<K<1<H00l36`003`0:j0`000kZd]002]0WG0[H03;Nf]kBj];Zd^[Bj]0Rj00?0^/00
0/000`30`002`008a/36`<K0a/02aPCG00@0emL00]L00`3Ge`06e`030=OG00?G0003e`040=OG00[G
00@0emOG0`03e`030=OG00_G00<0emL02ML00fJ:RP03RPF^00CB[]:^0m801<cBc=84c006a/c6c<36
0l020003`;Zj00>j0k@5e`Bf01:g];Zd^[Bj];Zd`;[0^/2j`;X8`0040<36`0W60l`3e`8000GG0=OG
0008e`030=OG00?G0003e`040=OG00_G00@0emL01ML200gG00<0emL01mL00d9VIP06RP08[XZ^[]:^
dZh3dPK<00?6c<H00lH01<000002`006^/2j^[Bj0k@2e`04]KBe]@>f00Nd^[Bj];Zd00Rj00S0^/2j
`;[0^P;000S6`030a/36`0;600O<a/c6c<K<00GG00@0e`002ML400;G0003e`040=OG00SG00@0emL0
0]L00`3Ge`03e`030=OG00gG00<0emL01ML5IP06RVJ:RZj:1:h00m:^dP04dP04c=;<dPC<00C60000
0lH2`003a[[000Bj0k@01KFd]KFf00Jj00Vd^[[0^/2j`;X02/002<K0a/36`0300/H02<c6c<K<a/c6
0/`5e`030=OG013G0004e`802]L200?G1002e`030=OG00kG00<0emL01=L2@PAV00>:IXX00hX4[P04
dZkB[P?B1L`300;600C0a/361<000k[0^P03^P04];Zd]0:j00Fd^[Bj]008^PG000^j`;[6`<K0a/36
`003aP030<K600;600C<a/c61<`00m;<e`04e`030=OG00oG000Ke`030=OG00oG00<0emL00]L00fI2
IP03IP03RVJ:00>:00>^RZh00jh7dP04c00000C<00?6c<H00lH01/36`<2j`0Bj00>d^[X01[X01/2j
`;[0^PS000S6`<K0a/36`0;600S<a/c6c03<aPC<00OBc=;<d/cB00KG00<0emL03]L000WG0P04e`03
0=OG00;G0`04e`030=OG013G00<0emL0148026I2IVJ:IXYV0XX00jj:[P03[P05dZkB[]800P001LcB
c<c600;<0lH00l36`005`003^/2j00Nj00Jd`;[0^/02^PO000S6`<K0a/36`0[600?<0<`02L`00m;<
e`04e`804=L000SG00@0emL02mL00`3Ge`0201?G00<0@T800T800fI2IP03IPJ:00>^RZh00jh01=80
0003dP03c=;<00G<00?6c<H00lH00l36`002`0:j00?0^/000[X4`004^/30aPG000S6`<K0a/36`0K6
00?<a/`01/`00`3<c002c003d/cB00CB1mL00`3Ge`0=e`002=L0103Ge`0;e`030=OG00804]L37PA2
00=V@VH01FH4RP03[XZ^00<00Zh5dP03c=;<00G<00?6c<H00lH02<36^/2j`;[00[X2`003^/2j00S0
00K6`<K0a/0:aP06c<K<a/c60/`01P3<d/cBc0KB1mL00`3Ge`0=e`002=L0103Ge`08e`<00mL00`3G
e`0@e`<N148016I2IT82IP03RVJ:00B:0`02[P03dZkB00KB00?<d/`00l`01<K<c<`6aP04`<JjaP?0
00[6`<30a/36`<K01LH02<3<a/c6c<K<0/H9c005d/cBc0002]88e`030=OG00;G1006e`002=L0103G
e`08e`030=OG00?G00<0emL03mL77PA200=V@VH00fH018X00002RP03[XZ^00F^1M800lcBc003c003
a/c600?600?0a/H01/001LK0a/3600G000K6`<K0a/08aP0Kc<K<a/c6c<KBc=;<d/cBc03<d/cB[]:^
dZkB00OG0P05e`030=OG00GG0008e`040=OG00SG00<0emL00mL00`3Ge`0?e`067ahN7T8N14800fI2
IP03IP8000>:IXX00hX00jj:[P05[PWB00S<d/c<a/c6c0;600O0a/K6`<K000c600K<a/c6c<H:c00<
d/cBc=;<d/cBc=801m800jkB[P08e`030=OG00?G00<0emL01ML000WG0P09e`@00]L00`3Ge`0>e`03
7ahN00<N00A27T8N148300=V00>:IXX00hX00jj:[P05[PGB00?<d/`00/`01M;6c<K<00?600K<`<K0
a/03aP03`<K600K600?<a/H00/H2c005a/c6c<H02<`00m;<dP06dP060=:^dZkB1:h00h[Ge`06e`03
0=OG00;G00<0emL01ML001WG0P0>e`8O00<N7ah011h4@P<000=2IVH016H00hYVRP03RP03[XZ^00>^
00?B[]802=83c005d/K<a/`01LH01lc6c<K<a/`00/H4c003a/c600S<00SBc=;<d/cBc0_B00@0dZkB
1Zh8e`800mL00`3Ge`05e`000]L200CG00<0emL00mL00`3Ge`02e`<00mL00`3Ge`0<e`8O2Ah30005
7T92IT801VH00hYVRP03RP03[XZ^00>^00?B[]800]801ZkBd];<dPC<00C6c<K<1LH01Lc6a/K<00?6
00C<a/c62<`01M;<d/cB00?<2M801:kB[]82[P030:j^00F^00>:emL01mL00`3G000200OG00001ML0
emL000WG00<0emL01ML00`3Ge`0200cG1Ql37P<000<N@Qh014800fI2IP05IP03RVJ:00>:00>^RZh0
0jh00m:^dP0:dP[<00G6c<c<aP06c003d/c<00?<00SBc=;<d/cBc0_B00R^dZkB[]:^00:^00B:[XZ^
0hX8e`800]L00`3Ge`05e`0000GG0=OG000:e`030=OG00CG00@0emL03=L021lP7alN7ahO0P037P04
@Qi27PA200=V@VH00fH018YVRVH4RP03[XZ^00N^1M801<cBc=88c005a/c<c<H03<`01=;<d/`9dP0:
[]:^dZkB[]:^dP:^00R:[XX0RZj:[PB:1=L40003e`3G00WG00001ML0emL000[G00@0emOG0`03e`03
0=OG00SG0b047`<000<O7Qh00ah0148N@Qh4@P03IT9V00=V00B:IXYV18X00jj:[P03[P03dZj^00[B
00K<d/cBc=85c003d/cB00CB00?<d]805M8;[P0508Z^RZh00hX01=L00005e`030=OG00SG00001ML0
emL000_G00@0emL01=L200WG0b027`<000<O7Ql02Ah00d8N@P03@P03IT9V00=V00B:IXYV1XX00jj:
[P03[P04dZj^[P?B00R^d];Bc=;<dP?<00[Bc=;<d/cBc=;<0m800lcBdP07dP08[]:^dZkB[]8:[PB:
00T0RXZ:IXYVRVH02=L00`3Ge`08e`0000GG0=OG0008e`040=OG00;G00<0emL00mL00`3Ge`05e`@P
0`057`037QlN00@N00=27T801D8016I2IT84IP04RVJ:IPB:00>^RZh01Jh00m:^dP0>dP05c=;Bd/`0
4M800jkBdP03dP04[]:^dPB^00R:[XZ^RZj:[P::00<0RXX00hX00fJ:e`07e`030=OG00SG0002e`80
2ML400;G10000mL00005e`<P0`000b0O7`027`067QlN7ahO2Ah00d8N@P03@P04IT9V@P9V00J:IXYV
RVH4RP03[XZ^00F^00CB[Zj^1M800jkB[P0?dP03[];B00?B00J^dZkB[]88[P06RZj:[XZ^1XX00fJ:
0005IP03@VKG00OG00<0emL01mL001SG0P04e`048B0000<P00<O81l01al011hO7Ql37P03@Qi200E2
00IV@VI2IT82IP04RVJ:IP::00J^RXZ:[XX6[P04dZkB[Q?B00>^d]800m801:kB[]87[P0;dXZ^RZj:
[XZ^RZh01XX01VJ:IP1VRPEV2=L00`3Ge`07e`004ML400?G00<082000R0300@P00<O81l01al00ahO
7P0:7P03@Qi200=200AV@VI21VH00hYVRP05RP03[XZ^00V^00?B[Zh00jh01m:^dZkB[]800jh00m:^
dP0<[P08RZj:[XZ^RZh8RP0<IXYVRVJ:IP12IT9V0T88e`030=OG00OG000Ce`030=OG00;G00<0e`00
0P0880067b0O81lP11l01QhO7QlN7`DN00=27T800d801VI2IT9V@P9V00J:IXYVRVH6RP03[XZ^00N^
01?B[]:^dZkB[]:^dZkB[]:^dZkB00>^00?B[Zh01:h028Z^RZj:[XZ^38X00fJ:IP04IP0606IV@VI2
2=L00`3Ge`07e`004mL00`3Ge`02e`800]L680067b0O81lP1Ql011hO7Ql;7P03@Qi200=200IV@VI2
IT84IP04RVJ:IPJ:00J^RZj:[XXG[P03RZj:00>^00J:[XZ^RZh:RP03IXYV00UV00A2049V0T88e`03
0=OG00OG000Ce`030=OG00?G00@0emOG22001QlP7b0O80HO00<N7ah021h00d8N@P05@P03IT9V00EV
00J:IXYVRVH2RP0:[XZ:RZj:[XZ^RPj^00?B[Zh00Zh00hZ^RP03[P06RZj:[XZ^28X02VJ:IXYVRVJ:
IXX4IP06@VI2IP1V1487e`030=OG00OG000Ce`030=OG00CG0P02e`0<7b0P81lP7b0O81lP1Ql011hO
7Ql;7P03@Qi200E200AV@VI21VH018YVRVH8RP0G[XZ^RZj:[XZ^RZj:[XZ^RZj:[XZ^RZh01HX00jj:
RP06RP08IXYVRVJ:IXX4IP08@VI2IT9V@VH2@P050492@Qh01mL00`3Ge`07e`004ML300SG00<0emL0
2R0011lP7b087`TN00=27T801D800fI2IP02IP0;@VIVRVJ:IXYVRVH038X00jj:[P02[P05RZj^[XX0
0jh00hZ^RP02RP03[XZ^00R:00IVRVJ:IXX<IP03@VI200E200D0@Qi27P06e`030=OG00OG000Ce`03
0=OG00OG00<0emL0120021lP7b0O81lP1Ql011hO7Ql;7P03@Qi200E200IV@VI2IT86IP06RVJ:IXYV
48X00jj:RP08RP03IXYV00>:00IVRVJ:IXX:IP04@VI2IPQ200@N01i20Qh7e`030=OG00KG000Ne`03
0=OG00XP00@O81lP21l37P0:7ahN7T8N@Qi27PI200=V@VH00VH00d9VIP04IP06RVJ:IXYV2XX01Jj:
RXZ^00R:00=VRXX01HX016J:IXX:IP08@VI2IT9V@VH6@P047T8N00@N1]L00`3Ge`06e`007mL20003
eb0P008P00PO81lP7b0O80HO00HN7ahO7Ql97P06@Qi27T8N148026I2IT9V@VI22VH028YVRVJ:IXYV
0hX036J:RXYVRVJ:IXYVRPEV00>:IVH01VH0249V@VI2IT9V1T801Qi27T8N@P<N00@07QhN1]L00`3G
e`06e`008ML00`3G800980047b0O80PO00@N7ahO0ah01T8N7Qi27P=200LN@T9V@VI200EV00=2IVH0
0VH01XYVRVJ:IP>:00=VRVH00hX04VJ:RXYVRVJ:IXYVRVJ:IXYVRPIV00Y2IT9V@VI2IT9V248011i2
7T857P0401hO7PGG00<0emL01]L002;G00<082001b0011lP7b067`067QlN7ahO2ah00d8N@P02@P03
7T9200A200IV@VI2IT8@IP05RVIVIXX02VH00d9V@P03IP06@VI2IT9V248021i27T8N@Qi221h0100N
7Ql5e`030=OG00KG000Se`04024P8@PP00HO81lP7b067`047QlN7`LN00A27T8N24802VI2IT9V@VI2
IT88IP05RVIVIXX00fH01HYVIVJ:00YV00a2IT9V@VI2IT9V@VH8@P037T8N00PN00@O7Ql00Ql5e`03
0=OG00KG000Te`03020P00LP00@O81lP1Ql01QhO7QlN7`/N00Q27T8N@Qi27PY200YV@VI2IT9V@VI2
0fH01D9V@VI200=V00Q2IT9V@VI2IP=200=V@VH024801Qi27T8N@Q4N00<O01l01ML00`3Ge`06e`00
9]L01B4P8B0Q00HP00HO81lP7b067`047QlN7`TN00A27T8N248026I2IT9V@VI20fH00d9V@P03IP03
@VI200=V00=2IT800fH0249V@VI2IT9V1D800fI2@P06@P087T8N@Qi27T857P067ahO7QlN0Ql00`0O
7`04e`030=OG00KG000We`03020P00HP00@O81lP1Ql021hO7alN7ahO3Ah01T8N@Qi27Pi200=V@VH0
0d801FI2@T9V00E200=V@T8024801Qi27T8N@QDN00@O7QlN0Ql00`0Oe`04e`030=OG00GG000Xe`05
020Q824022001QlP7b0O80HO00@N7ahO2Ah0248N@Qi27T8N34800fI2IP03@P05IT92@VH00d800fI2
@P08@P037T8N00E200HN@Qi27T877P087ahO7QlN7ah67`0481l07`CG00<0emL01ML002WG00<08240
1R0021lP7b0O81lP1Ql011hO7QlC7P08@Qi27T8N@Qh5@P037T9200E200DN@T927P05@P087T92@Qi2
7T8G7P047ahO7PHO00<P7`001=L00`3Ge`05e`00:]L01`0P8B0Q8240220011lP7b067`067QlN7ahO
2Ah0348N@Qi27T8N@Qi27PE200<N@T803D803Qi2@T8N@Qi27T8N@Qi22ah021lN7ahO7QlN2Ql0120O
8004e`030=OG00GG000/e`03824P00DP00PO81lP7b0O80HO00HN7ahO7QlE7P0G@Qi27T8N@Qi27T8N
@Qi27T8N@Qi27T806Ah01QlN7ahO7P`O00@P7b000mL00`3Ge`05e`00;ML01P0Q824P8@PP00@O81lP
21l01QhO7QlN7`dN01]27T8N@Qi27T8N@Qi27T8N@Qi27T8N@Qi27T803Ah00alN7`037P067ahO7QlN
2Ql01R0O81lP7`DP00@0emL01mL002kG00<08B001B0021lP7b0O81lP21l01QhO7QlN7cTN00hO7QlN
7ahO7QlN7ahO7PPO00HP7b0O81l280040=OG00OG000_e`06024P8B0Q22001QlP7b0O80PO00`N7ahO
7QlN7ahO7QlU7P0:7ahO7QlN7ahO7Q0O00HP7b0O81l880030=L000OG000ae`038B0P00HP00HO81lP
7b0:7`0:7QlN7ahO7QlN7b/N00`O7QlN7ahO7QlN7ah<7`0681lP7b0O22000`3G0006e`00<]L01@0P
8B0Q00PP00PO81lP7b0O80hO00`N7ahO7QlN7ahO7Ql37P037ahO00<N01HO7QhN7ahO7QlN7ahO7QlN
7ahO7QlN3Ql02R0O81lP7b0O81l<80048B0000KG000ce`03020P00HP00PO81lP7b0O80hO010N7ahO
7QlN7ahO7QlN7ahO0ah00alN7P057P0F7ahO7QlN7ahO7QlN7ahO7QlN7ahO7P`O00hP7b0O81lP7b0O
81lP7`PP00?G00001]L003CG0P000b4P800<80067b0O81lP4Ql05AhO7alN7ahO7QlN7ahO7QlN7ahO
7P0D7`0:81lP7b0O81lP7a4P1ML200KG000fe`03020P00DP00XO81lP7b0O81lP4Ql05ahO7QlN7ahO
7QlN7ahO7QlN7ahO7QlN00DO00<N7al03Ql02R0O81lP7b0O81l380037b0P00HP1ML400SG000ge`04
0=LP8@`P00`O81lP7b0O81lP7b0W7`0@81lP7b0O81lP7b0O81lP7a0P1=L400cG000he`030=LP00LP
018O81lP7b0O81lP7b0O81lP7b0Y7`0>81lP7b0O81lP7b0O81l>8003e`0000804=L003WG0P000mLP
800?800B7b0O81lP7b0O81lP7b0O81lP0al00b0O7`037`0D81lO7b0O81lP7b0O81lP7b0O81lB8009
8B0Q824P8B3G00<05=L003_G00<08200220051lP7b0O81lP7b0O81lP7b0O81lP1Al00b0O7`0?7`0B
81lO7b0O81lP7b0O81lP7b0O420401OG000le`030=LP01PP01lO81lP7b0O81lP7b0O81lP7b0O81lP
7b0O81lP7b0O018P00PQ824P8B0Q80<06mL003gG00<0eb003200<AlP7b0O81lP7b0O81lP7b0O81lP
7b0O81lP7b0O81lP7b0O81lP7b0O81lP7b0O81l032000b4P8@0301oG000ne`8000?G82007R000alP
800380057b0P81l052002B4P8B0Q824P8@0202?G0010e`030=LP01DP01dO81lP7b0O81lP7b0O81lP
7b0O81lP7b0O81lP7`0<80058B0Q82400P0Ve`00@ML00`3Ge`0f80088B0Q824P8B0202[G0012e`03
0=OG024P00DO820P7`0A8004e`0002kG0013e`030=OG030P00<Q8=L0100ae`00A=L20003eb0P02TP
0mL403GG0016e`030=LP00LP00TQ824P8B0Q82404b05e`@0>ML004OG00<0emL07R06e`<0?ML004SG
00<0eb001b001b4P8B0Q82403205e`@0@=L004WG0P000mLP800C80GG1014e`00BmL00`3G800?80GG
1018e`00C=L00`3Ge`0;80GG0`1<e`00CML00`3Ge`0680GG101?e`00C]L20003e`3G00CG101Ce`00
D=L20003e`000080EmL0057G0P1Ke`00[]L00:kG002^e`00[]L00:kG002^e`00[]L00001\
\>"],
  ImageRangeCache->{{{0, 173.875}, {140.812, 0}} -> {-0.16023, -0.044532, \
0.00663002, 0.00663002}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[CP]\), "\n", 
    \(CP = 
      ContourPlot[fxy[x, y], {x, \(-1. \), 1. }, {y, \(-1. \), 1. }, 
        Contours -> 10, \nContourShading -> False]\)}], "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -24 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.5)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.5)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-1)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-0.5)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(0.5)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.98077 .82316 m
.91503 .84341 L
.91209 .85106 L
.84341 .86659 L
.77473 .87194 L
.70604 .87091 L
.63736 .86555 L
.56868 .85571 L
.51238 .84341 L
.5 .83977 L
.43132 .81403 L
.36264 .77642 L
.36001 .77473 L
.29396 .72113 L
.27887 .70604 L
.22527 .63999 L
.22358 .63736 L
.18597 .56868 L
.16023 .5 L
.15659 .48762 L
.14429 .43132 L
.13445 .36264 L
.12909 .29396 L
.12806 .22527 L
.13341 .15659 L
.14894 .08791 L
.15659 .08497 L
.17684 .01923 L
s
.98077 .72825 m
.91209 .74555 L
.84341 .75649 L
.77473 .76096 L
.70604 .75953 L
.63736 .75227 L
.56868 .73822 L
.5 .71522 L
.47899 .70604 L
.43132 .67901 L
.37814 .63736 L
.36264 .62186 L
.32099 .56868 L
.29396 .52101 L
.28478 .5 L
.26178 .43132 L
.24773 .36264 L
.24047 .29396 L
.23904 .22527 L
.24351 .15659 L
.25445 .08791 L
.27175 .01923 L
s
.98077 .65545 m
.91209 .66633 L
.84341 .6733 L
.77473 .67591 L
.70604 .67385 L
.63736 .66641 L
.56868 .6518 L
.52365 .63736 L
.5 .62598 L
.43132 .57927 L
.42073 .56868 L
.37402 .5 L
.36264 .47635 L
.3482 .43132 L
.33359 .36264 L
.32615 .29396 L
.32409 .22527 L
.3267 .15659 L
.33367 .08791 L
.34455 .01923 L
s
.98077 .57889 m
.91209 .58214 L
.84341 .58487 L
.77473 .58679 L
.70604 .58735 L
.63736 .58553 L
.56868 .57906 L
.51574 .56868 L
.5 .56197 L
.44053 .5 L
.43132 .48426 L
.41687 .43132 L
.40503 .36264 L
.39928 .29396 L
.39747 .22527 L
.39873 .15659 L
.40262 .08791 L
.40875 .01923 L
s
.98077 .56136 m
.91209 .56181 L
.84341 .56186 L
.77473 .56142 L
.70604 .56026 L
.63736 .55775 L
.56868 .55176 L
.5 .52401 L
.48234 .5 L
.47302 .43132 L
.4683 .36264 L
.46605 .29396 L
.46531 .22527 L
.46569 .15659 L
.46697 .08791 L
.46901 .01923 L
s
.98077 .55064 m
.91209 .55049 L
.84341 .54976 L
.77473 .54825 L
.70604 .54558 L
.63736 .54075 L
.56868 .53049 L
.51594 .5 L
.52442 .43132 L
.52871 .36264 L
.53075 .29396 L
.53143 .22527 L
.53109 .15659 L
.52993 .08791 L
.52808 .01923 L
s
.98077 .54045 m
.91209 .53977 L
.84341 .53828 L
.77473 .53569 L
.70604 .53138 L
.63736 .52372 L
.56868 .50655 L
.55699 .5 L
.56868 .44592 L
.58011 .43132 L
.59171 .36264 L
.59733 .29396 L
.5991 .22527 L
.59789 .15659 L
.59414 .08791 L
.58823 .01923 L
s
.98077 .53038 m
.91209 .52913 L
.84341 .52681 L
.77473 .52296 L
.70604 .51653 L
.63736 .50438 L
.62216 .5 L
.63736 .44155 L
.64808 .43132 L
.66262 .36264 L
.67003 .29396 L
.6721 .22527 L
.66957 .15659 L
.66277 .08791 L
.65217 .01923 L
s
.98077 .52004 m
.91209 .51812 L
.84341 .51476 L
.77473 .50915 L
.71026 .5 L
.73343 .43132 L
.74757 .36264 L
.75487 .29396 L
.75634 .22527 L
.75195 .15659 L
.74124 .08791 L
.72437 .01923 L
s
.98077 .50891 m
.91209 .50607 L
.84341 .5011 L
.83211 .5 L
.84341 .43391 L
.84883 .43132 L
.85895 .36264 L
.86442 .29396 L
.86539 .22527 L
.85999 .15659 L
.84544 .08791 L
.84341 .0861 L
.81709 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016PP10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG6mL00?oG6mL00?oG6mL00?oG6mL00?oG
6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL0027G100de`801=L00`3Ge`02e`<0<]L203GG
0P04e`030=OG00;G0`0ce`@01ML002?G00<0emL0<]L0103Ge`0;e`030=OG02kG00@0emL0<mL0103G
e`0;e`030=OG03;G00<0emL01=L002?G00<0emL0<]L0103Ge`0;e`030=OG02kG00@0emL0<mL0103G
e`0;e`030=OG03;G00<0emL01=L001_G1004e`030=OG02cG1002e`040=OG00SG0`0ae`040=OG03?G
00@0emL02=L303GG00<0emL01=L002?G00<0emL0<]L0103Ge`08e`030=OG037G00@0emL0<mL0103G
e`08e`030=OG03GG00<0emL01=L0027G0`0de`040=OG00SG00<0emL0<ML0103Ge`0ce`040=OG00SG
00<0emL0<mL300KG000Se`030=OG03?G0P09e`@0<ML203GG0P09e`@0==L00`3Ge`04e`00omLKe`00
omLKe`00omLKe`006mOn007G000Ke`030=OG00;G00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL0
2ML00`3Ge`0:e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL02]L00`3Ge`09e`03
0=OG00WG00<0emL02ML00`3Ge`09e`030=OG00[G00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL0
2ML00`3Ge`09e`030=OG00;G0@01e`006mL00`3Ge`02e`030=OG03[G00<0emL0>]L00`3Ge`0je`03
0=OG03WG00<0emL00]L1007G000Ce`@01=L00`3Ge`3je`400ML001GG00<0emL00mL00`3Ge`3je`40
0ML001GG00<0emL00mL202_G00<0emL05ML00`3Ge`0?e`030=OG00gG00<0emL03ML00`3Ge`0<e`03
0=OG00cG00<0emL03ML00`3Ge`0?e`030=OG01GG00<0emL0:]L2007G000=e`@01=L00`3Ge`03e`03
0=OG02[G00<0emL05ML00`3Ge`0?e`030=OG00gG00<0emL03ML00`3Ge`0<e`030=OG00cG00<0emL0
3ML00`3Ge`0?e`030=OG01GG00<0emL0:mL1007G000Ee`030=OG00?G00<0emL0:ML00`3Ge`0Ee`03
0=OG013G00<0emL03ML00`3Ge`0=e`030=OG00cG00<0emL03=L00`3Ge`0=e`030=OG013G00<0emL0
5ML00`3Ge`0Ze`400ML001?G0`05e`030=OG02WG00<0emL05ML00`3Ge`0?e`030=OG00kG00<0emL0
3ML00`3Ge`0<e`030=OG00cG00<0emL03ML00`3Ge`0@e`030=OG01GG00<0emL0:]L1007G000Ee`03
0=OG00?G00<0emL0:ML00`3Ge`0Ee`030=OG00oG00<0emL03]L00`3Ge`0=e`030=OG00cG00<0emL0
3=L00`3Ge`0>e`030=OG00oG00<0emL05]L00`3Ge`0Ye`400ML001_G00<0emL0:=L00`3Ge`0Fe`03
0=OG00oG00<0emL03]L00`3Ge`0=e`030=OG00cG00<0emL03=L00`3Ge`0>e`030=OG00oG00<0emL0
5]L00`3Ge`0Ye`400ML001_G00<0emL0:=L00`3Ge`0Ee`030=OG013G00<0emL03]L00`3Ge`0=e`03
0=OG00cG00<0emL03=L00`3Ge`0>e`030=OG013G00<0emL05ML00`3Ge`0Ye`400ML001_G00<0emL0
:=L00`3Ge`0Ee`030=OG013G00<0emL03]L00`3Ge`0=e`030=OG00cG00<0emL03=L00`3Ge`0>e`03
0=OG013G00<0emL05]L00`3Ge`0Xe`400ML001_G00<0emL09mL00`3Ge`0Fe`030=OG013G00<0emL0
3]L00`3Ge`0=e`030=OG00cG00<0emL03=L00`3Ge`0>e`030=OG013G00<0emL05]L00`3Ge`0Xe`40
0ML001_G00<0emL09mL00`3Ge`0Ee`030=OG013G00<0emL03]L00`3Ge`0=e`030=OG00gG00<0emL0
3=L00`3Ge`0>e`030=OG013G00<0emL05mL00`3Ge`0We`400ML001_G00<0emL09]L00`3Ge`0Fe`03
0=OG013G00<0emL03]L00`3Ge`0=e`030=OG00gG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL0
5]L00`3Ge`0We`400ML001_G00<0emL09]L00`3Ge`0Fe`030=OG013G00<0emL03]L00`3Ge`0=e`03
0=OG00gG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL05mL00`3Ge`0Ve`400ML001_G0P0We`03
0=OG01KG00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00kG00<0emL0
4=L00`3Ge`0Ge`030=OG02GG0P01e`006mL00`3Ge`0Ue`030=OG01KG00<0emL04ML00`3Ge`0>e`03
0=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00kG00<0emL04ML00`3Ge`0Fe`030=OG02KG0@01e`00
6mL00`3Ge`0Ue`030=OG01KG00<0emL04ML00`3Ge`0>e`030=OG00gG00<0emL03ML00`3Ge`0=e`03
0=OG00kG00<0emL04ML00`3Ge`0Ge`030=OG02GG0@01e`006mL00`3Ge`0Ue`030=OG01KG00<0emL0
4=L00`3Ge`0?e`030=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00kG00<0emL04ML00`3Ge`0Ge`03
0=OG02GG0@01e`006mL00`3Ge`0Te`030=OG01OG00<0emL04=L00`3Ge`0?e`030=OG00gG00<0emL0
3ML00`3Ge`0=e`030=OG00oG00<0emL04=L00`3Ge`0He`030=OG02CG0@01e`006mL00`3Ge`0Te`03
0=OG01KG00<0emL04ML00`3Ge`0?e`030=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00oG00<0emL0
4ML00`3Ge`0Ge`030=OG02CG0@01e`006mL00`3Ge`0Re`806ML00`3Ge`0Ae`030=OG00oG00<0emL0
3ML00`3Ge`0=e`030=OG00gG00<0emL03mL00`3Ge`0Ae`030=OG01OG00<0emL09=L1007G000Ke`03
0=OG02;G00<0emL06=L00`3Ge`0Ae`030=OG00oG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL0
3mL00`3Ge`0Ae`030=OG01OG00<0emL09=L1007G000Ke`030=OG02;G00<0emL06=L00`3Ge`0Ae`03
0=OG00oG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL03mL00`3Ge`0Ae`030=OG01OG00<0emL0
9=L1007G000Ke`030=OG027G00<0emL06=L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0=e`03
0=OG00gG00<0emL03mL00`3Ge`0Ae`030=OG01SG00<0emL08mL1007G000Ke`030=OG027G00<0emL0
6=L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL03mL00`3Ge`0Ae`03
0=OG01SG00<0emL08mL1007G000Ke`030=OG027G00<0emL06=L00`3Ge`0Be`030=OG00oG00<0emL0
3ML00`3Ge`0=e`030=OG00gG00<0emL04=L00`3Ge`0Ae`030=OG01OG00<0emL08mL1007G000Ke`03
0=OG027G00<0emL06=L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL0
4=L00`3Ge`0Ae`030=OG01OG00<0emL08mL1007G000Ke`808]L00`3Ge`0He`030=OG01;G00<0emL0
3mL00`3Ge`0=e`030=OG00gG00<0emL03ML00`3Ge`0@e`030=OG017G00<0emL06=L00`3Ge`0Qe`80
0ML001_G00<0emL08ML00`3Ge`0He`030=OG01;G00<0emL03mL00`3Ge`0=e`030=OG00gG00<0emL0
3ML00`3Ge`0@e`030=OG017G00<0emL06=L00`3Ge`0Re`400ML001_G00<0emL08=L00`3Ge`0He`03
0=OG01;G00<0emL03mL00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0?e`030=OG017G00<0emL0
6=L00`3Ge`0Re`400ML001_G00<0emL08=L00`3Ge`0He`030=OG01;G00<0emL03mL00`3Ge`0>e`03
0=OG00gG00<0emL03]L00`3Ge`0?e`030=OG017G00<0emL06=L00`3Ge`0Re`400ML001_G00<0emL0
8=L00`3Ge`0He`030=OG01;G00<0emL03mL00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0?e`03
0=OG017G00<0emL06ML00`3Ge`0Qe`400ML001_G00<0emL08=L00`3Ge`0He`030=OG01;G00<0emL0
3mL00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0?e`030=OG017G00<0emL06ML00`3Ge`0Qe`40
0ML001_G00<0emL08=L00`3Ge`0He`030=OG01;G00<0emL03mL00`3Ge`0>e`030=OG00gG00<0emL0
3]L00`3Ge`0@e`030=OG017G00<0emL06=L00`3Ge`0Qe`400ML001_G00<0emL08=L00`3Ge`0He`03
0=OG01;G00<0emL03mL00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`030=OG017G00<0emL0
6=L00`3Ge`0Qe`400ML001_G00<0emL07mL00`3Ge`0He`030=OG01?G00<0emL03mL00`3Ge`0>e`03
0=OG00gG00<0emL03]L00`3Ge`0@e`030=OG017G00<0emL06ML00`3Ge`0Pe`400ML001_G00<0emL0
7mL00`3Ge`0He`030=OG01?G00<0emL03mL00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`03
0=OG017G00<0emL06ML00`3Ge`0Pe`400ML001_G00<0emL07mL00`3Ge`0He`030=OG01?G00<0emL0
3mL00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`030=OG017G00<0emL06ML00`3Ge`0Pe`40
0ML001_G00<0emL07mL00`3Ge`0He`030=OG01?G00<0emL03mL00`3Ge`0>e`030=OG00gG00<0emL0
3]L00`3Ge`0@e`030=OG017G00<0emL06ML00`3Ge`0Pe`400ML001_G0P0Pe`030=OG01SG00<0emL0
4mL00`3Ge`0?e`030=OG00kG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL04ML00`3Ge`0Ie`03
0=OG01oG0P01e`006mL00`3Ge`0Oe`030=OG01SG00<0emL04mL00`3Ge`0?e`030=OG00kG00<0emL0
3ML00`3Ge`0>e`030=OG013G00<0emL04ML00`3Ge`0Ie`030=OG023G0@01e`006mL00`3Ge`0Oe`03
0=OG01SG00<0emL04mL00`3Ge`0?e`030=OG00kG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL0
4ML00`3Ge`0Ie`030=OG023G0@01e`006mL00`3Ge`0Ne`030=OG01WG00<0emL04mL00`3Ge`0?e`03
0=OG00kG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL04]L00`3Ge`0He`030=OG023G0@01e`00
6mL00`3Ge`0Ne`030=OG01WG00<0emL04mL00`3Ge`0?e`030=OG00kG00<0emL03ML00`3Ge`0>e`03
0=OG013G00<0emL04]L00`3Ge`0He`030=OG023G0@01e`006mL00`3Ge`0Ne`030=OG01WG00<0emL0
4mL00`3Ge`0?e`030=OG00kG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL04]L00`3Ge`0He`03
0=OG023G0@01e`006mL00`3Ge`0Ne`030=OG01WG00<0emL04mL00`3Ge`0?e`030=OG00kG00<0emL0
3ML00`3Ge`0>e`030=OG013G00<0emL04]L00`3Ge`0He`030=OG023G0@01e`006mL00`3Ge`0Ne`03
0=OG01SG00<0emL04mL00`3Ge`0@e`030=OG00kG00<0emL03ML00`3Ge`0?e`030=OG00oG00<0emL0
4]L00`3Ge`0Ie`030=OG01oG0@01e`006mL00`3Ge`0Ne`030=OG01SG00<0emL04mL00`3Ge`0@e`03
0=OG00kG00<0emL03ML00`3Ge`0?e`030=OG00oG00<0emL04]L00`3Ge`0Ie`030=OG01oG0@01e`00
6mL00`3Ge`0Ne`030=OG01SG00<0emL04mL00`3Ge`0@e`030=OG00kG00<0emL03ML00`3Ge`0?e`03
0=OG00oG00<0emL04]L00`3Ge`0Ie`030=OG01oG0@01e`006mL00`3Ge`0Ne`030=OG01SG00<0emL0
4mL00`3Ge`0@e`030=OG00kG00<0emL03ML00`3Ge`0?e`030=OG00oG00<0emL04]L00`3Ge`0Ie`03
0=OG01oG0@01e`006mL00`3Ge`0Me`030=OG01WG00<0emL04mL00`3Ge`0@e`030=OG00kG00<0emL0
3ML00`3Ge`0?e`030=OG00oG00<0emL04mL00`3Ge`0He`030=OG01oG0@01e`006mL201kG00<0emL0
6ML00`3Ge`0Ce`030=OG013G00<0emL03]L00`3Ge`0=e`030=OG00oG00<0emL03mL00`3Ge`0Ce`03
0=OG01SG00<0emL07]L2007G000Ke`030=OG01gG00<0emL06ML00`3Ge`0Ce`030=OG013G00<0emL0
3]L00`3Ge`0=e`030=OG00oG00<0emL03mL00`3Ge`0Ce`030=OG01SG00<0emL07mL1007G000Ke`03
0=OG01gG00<0emL06ML00`3Ge`0Ce`030=OG013G00<0emL03]L00`3Ge`0=e`030=OG00oG00<0emL0
3mL00`3Ge`0Ce`030=OG01SG00<0emL07mL1007G000Ke`030=OG01gG00<0emL06ML00`3Ge`0Ce`03
0=OG013G00<0emL03]L00`3Ge`0=e`030=OG00oG00<0emL03mL00`3Ge`0Ce`030=OG01SG00<0emL0
7mL1007G000Ke`030=OG01gG00<0emL06ML00`3Ge`0Ce`030=OG013G00<0emL03]L00`3Ge`0=e`03
0=OG00oG00<0emL03mL00`3Ge`0Ce`030=OG01SG00<0emL07mL1007G000Ke`030=OG01gG00<0emL0
6ML00`3Ge`0Ce`030=OG013G00<0emL03]L00`3Ge`0=e`030=OG00oG00<0emL03mL00`3Ge`0Ce`03
0=OG01SG00<0emL07mL1007G000Ke`030=OG01gG00<0emL06ML00`3Ge`0Ce`030=OG013G00<0emL0
3]L00`3Ge`0=e`030=OG00oG00<0emL03mL00`3Ge`0Ce`030=OG01SG00<0emL07mL1007G000Ke`03
0=OG01gG00<0emL06ML00`3Ge`0Ce`030=OG013G00<0emL03]L00`3Ge`0=e`030=OG00oG00<0emL0
3mL00`3Ge`0Ce`030=OG01SG00<0emL07mL1007G000Ke`030=OG01gG00<0emL06ML00`3Ge`0Ce`03
0=OG013G00<0emL03]L00`3Ge`0=e`030=OG00oG00<0emL03mL00`3Ge`0Ce`030=OG01SG00<0emL0
7mL1007G000Ke`030=OG01gG00<0emL06ML00`3Ge`0Ce`030=OG013G00<0emL03]L00`3Ge`0=e`03
0=OG00oG00<0emL03mL00`3Ge`0Ce`030=OG01SG00<0emL07mL1007G0008e`801=L00`3Ge`02e`<0
1ML00`3Ge`0Me`030=OG01WG00<0emL04mL00`3Ge`0@e`030=OG00kG00<0emL03ML00`3Ge`0?e`03
0=OG00oG00<0emL04mL00`3Ge`0He`030=OG01oG0@01e`001mL0103Ge`0;e`030=OG00;G00<0emL0
7ML00`3Ge`0Ie`030=OG01?G00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL03mL00`3Ge`0?e`03
0=OG01?G00<0emL06=L00`3Ge`0Oe`400ML000OG00@0emL02mL00`3Ge`02e`807]L00`3Ge`0Ie`03
0=OG01?G00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`030=OG01;G00<0emL0
6ML00`3Ge`0Ne`800ML00003e`0000800]L0103Ge`08e`<01ML00`3Ge`0Me`030=OG01[G00<0emL0
4]L00`3Ge`0@e`030=OG00kG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL04]L00`3Ge`0Ie`03
0=OG01oG0@01e`001mL0103Ge`08e`030=OG00GG00<0emL07ML00`3Ge`0Je`030=OG01;G00<0emL0
4=L00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`030=OG01;G00<0emL06ML00`3Ge`0Oe`40
0ML000OG00@0emL02=L00`3Ge`05e`030=OG01gG00<0emL06]L00`3Ge`0Be`030=OG013G00<0emL0
3]L00`3Ge`0=e`030=OG00kG00<0emL04=L00`3Ge`0Be`030=OG01WG00<0emL07mL1007G0008e`80
2ML400CG00<0emL07ML00`3Ge`0Je`030=OG01;G00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL0
3]L00`3Ge`0@e`030=OG01;G00<0emL06ML00`3Ge`0Oe`400ML001_G00<0emL07ML00`3Ge`0Je`03
0=OG01;G00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`030=OG01;G00<0emL0
6ML00`3Ge`0Oe`400ML001_G00<0emL07ML00`3Ge`0Je`030=OG01;G00<0emL04=L00`3Ge`0>e`03
0=OG00gG00<0emL03]L00`3Ge`0@e`030=OG01;G00<0emL06ML00`3Ge`0Oe`400ML001_G00<0emL0
7ML00`3Ge`0Je`030=OG01;G00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`03
0=OG01;G00<0emL06ML00`3Ge`0Oe`400ML001_G00<0emL07ML00`3Ge`0Je`030=OG01;G00<0emL0
4=L00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`030=OG01;G00<0emL06ML00`3Ge`0Oe`40
0ML001_G00<0emL07ML00`3Ge`0Je`030=OG01;G00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL0
3]L00`3Ge`0@e`030=OG01;G00<0emL06ML00`3Ge`0Oe`400ML001_G00<0emL07ML00`3Ge`0Je`03
0=OG01;G00<0emL04=L00`3Ge`0>e`030=OG00gG00<0emL03]L00`3Ge`0@e`030=OG01;G00<0emL0
6ML00`3Ge`0Oe`400ML001_G00<0emL07ML00`3Ge`0Je`030=OG01;G00<0emL04=L00`3Ge`0>e`03
0=OG00gG00<0emL03]L00`3Ge`0@e`030=OG01;G00<0emL06ML00`3Ge`0Oe`400ML001_G0P0Ne`03
0=OG01[G00<0emL04]L00`3Ge`0@e`030=OG00kG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL0
4]L00`3Ge`0Ie`030=OG01kG0P01e`006mL00`3Ge`0Me`030=OG01[G00<0emL04]L00`3Ge`0@e`03
0=OG00kG00<0emL03ML00`3Ge`0>e`030=OG013G00<0emL04]L00`3Ge`0Ie`030=OG01oG0@01e`00
6mL00`3Ge`0Ne`030=OG01[G00<0emL04]L00`3Ge`0?e`030=OG00kG00<0emL03ML00`3Ge`0>e`03
0=OG00oG00<0emL04]L00`3Ge`0Je`030=OG01oG0@01e`006mL00`3Ge`0Ne`030=OG01[G00<0emL0
4]L00`3Ge`0?e`030=OG00kG00<0emL03ML00`3Ge`0>e`030=OG00oG00<0emL04]L00`3Ge`0Je`03
0=OG01oG0@01e`006mL00`3Ge`0Ne`030=OG01[G00<0emL04]L00`3Ge`0?e`030=OG00kG00<0emL0
3ML00`3Ge`0>e`030=OG00oG00<0emL04]L00`3Ge`0Je`030=OG01oG0@01e`006mL00`3Ge`0Ne`03
0=OG01[G00<0emL04]L00`3Ge`0?e`030=OG00kG00<0emL03ML00`3Ge`0>e`030=OG00oG00<0emL0
4]L00`3Ge`0Je`030=OG01oG0@01e`006mL00`3Ge`0Ne`030=OG01[G00<0emL04]L00`3Ge`0@e`03
0=OG00gG00<0emL03ML00`3Ge`0=e`030=OG013G00<0emL04]L00`3Ge`0Ie`030=OG023G0@01e`00
6mL00`3Ge`0Ne`030=OG01[G00<0emL04]L00`3Ge`0@e`030=OG00gG00<0emL03ML00`3Ge`0=e`03
0=OG013G00<0emL04]L00`3Ge`0Ie`030=OG023G0@01e`006mL00`3Ge`0Ne`030=OG01[G00<0emL0
4]L00`3Ge`0@e`030=OG00gG00<0emL03ML00`3Ge`0=e`030=OG013G00<0emL04]L00`3Ge`0Ie`03
0=OG023G0@01e`006mL00`3Ge`0Ne`030=OG01[G00<0emL04]L00`3Ge`0@e`030=OG00gG00<0emL0
3ML00`3Ge`0=e`030=OG013G00<0emL04]L00`3Ge`0Ie`030=OG023G0@01e`006mL00`3Ge`0Oe`03
0=OG01[G00<0emL04]L00`3Ge`0?e`030=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00oG00<0emL0
4]L00`3Ge`0Je`030=OG023G0@01e`006mL00`3Ge`0Oe`030=OG01[G00<0emL04]L00`3Ge`0?e`03
0=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00oG00<0emL04]L00`3Ge`0Je`030=OG023G0@01e`00
6mL2023G00<0emL06]L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL0
3mL00`3Ge`0Be`030=OG01[G00<0emL07mL2007G000Ke`030=OG01oG00<0emL06]L00`3Ge`0Be`03
0=OG00oG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL03mL00`3Ge`0Be`030=OG01[G00<0emL0
8=L1007G000Ke`030=OG01oG00<0emL06]L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0=e`03
0=OG00gG00<0emL03mL00`3Ge`0Be`030=OG01[G00<0emL08=L1007G000Ke`030=OG01oG00<0emL0
6]L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL03mL00`3Ge`0Be`03
0=OG01[G00<0emL08=L1007G000Ke`030=OG01oG00<0emL06]L00`3Ge`0Be`030=OG00oG00<0emL0
3ML00`3Ge`0=e`030=OG00gG00<0emL03mL00`3Ge`0Be`030=OG01[G00<0emL08=L1007G000Ke`03
0=OG01oG00<0emL06]L00`3Ge`0Ce`030=OG00kG00<0emL03ML00`3Ge`0=e`030=OG00cG00<0emL0
3mL00`3Ge`0Be`030=OG01[G00<0emL08ML1007G000Ke`030=OG01oG00<0emL06mL00`3Ge`0Be`03
0=OG00oG00<0emL03=L00`3Ge`0=e`030=OG00cG00<0emL03mL00`3Ge`0Be`030=OG01[G00<0emL0
8ML1007G000Ke`030=OG023G00<0emL06]L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0<e`03
0=OG00cG00<0emL03mL00`3Ge`0Be`030=OG01[G00<0emL08ML1007G000Ke`030=OG023G00<0emL0
6]L00`3Ge`0Be`030=OG00oG00<0emL03ML00`3Ge`0<e`030=OG00cG00<0emL03mL00`3Ge`0Be`03
0=OG01[G00<0emL08ML1007G000Ke`030=OG023G00<0emL06]L00`3Ge`0Ce`030=OG00kG00<0emL0
3ML00`3Ge`0<e`030=OG00cG00<0emL03]L00`3Ge`0Ce`030=OG01[G00<0emL08ML1007G000Ke`03
0=OG023G00<0emL06]L00`3Ge`0Ce`030=OG00kG00<0emL03ML00`3Ge`0<e`030=OG00cG00<0emL0
3]L00`3Ge`0Ce`030=OG01[G00<0emL08ML1007G000Ke`030=OG023G00<0emL06]L00`3Ge`0Ce`03
0=OG00kG00<0emL03ML00`3Ge`0;e`030=OG00cG00<0emL03mL00`3Ge`0Be`030=OG01[G00<0emL0
8]L1007G000Ke`030=OG023G00<0emL06mL00`3Ge`0Be`030=OG00oG00<0emL03=L00`3Ge`0;e`03
0=OG00cG00<0emL03mL00`3Ge`0Be`030=OG01[G00<0emL08]L1007G000Ke`808ML00`3Ge`0Ke`03
0=OG01;G00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL03=L00`3Ge`0?e`030=OG01;G00<0emL0
6]L00`3Ge`0Qe`800ML001_G00<0emL08=L00`3Ge`0Ke`030=OG01?G00<0emL03]L00`3Ge`0<e`03
0=OG00_G00<0emL03=L00`3Ge`0>e`030=OG01?G00<0emL06]L00`3Ge`0Re`400ML001_G00<0emL0
8=L00`3Ge`0Ke`030=OG01?G00<0emL03]L00`3Ge`0<e`030=OG00_G00<0emL03=L00`3Ge`0>e`03
0=OG01?G00<0emL06]L00`3Ge`0Re`400ML001_G00<0emL08ML00`3Ge`0Je`030=OG01?G00<0emL0
3]L00`3Ge`0=e`030=OG00[G00<0emL03=L00`3Ge`0>e`030=OG01?G00<0emL06]L00`3Ge`0Re`40
0ML001_G00<0emL08ML00`3Ge`0Je`030=OG01?G00<0emL03]L00`3Ge`0=e`030=OG00[G00<0emL0
2mL00`3Ge`0?e`030=OG01;G00<0emL06]L00`3Ge`0Se`400ML001_G00<0emL08ML00`3Ge`0Ke`03
0=OG01?G00<0emL03]L00`3Ge`0<e`030=OG00[G00<0emL02mL00`3Ge`0>e`030=OG01?G00<0emL0
6]L00`3Ge`0Se`400ML001_G00<0emL08ML00`3Ge`0Ke`030=OG01?G00<0emL03]L00`3Ge`0<e`03
0=OG00[G00<0emL02mL00`3Ge`0>e`030=OG01?G00<0emL06]L00`3Ge`0Se`400ML001_G00<0emL0
8ML00`3Ge`0Ke`030=OG01?G00<0emL03]L00`3Ge`0<e`030=OG00[G00<0emL02mL00`3Ge`0>e`03
0=OG01?G00<0emL06ML202GG0@01e`006mL00`3Ge`0Qe`030=OG01_G00<0emL04mL00`3Ge`0>e`03
0=OG00cG00<0emL02]L00`3Ge`0:e`030=OG00gG0P0Fe`030=OG01WG00<0emL09=L1007G000Ke`03
0=OG027G00<0emL07=L00`3Ge`0Ce`030=OG00kG00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL0
3ML00`3Ge`0Ee`030=OG01[G00<0emL09=L1007G000Ke`030=OG02;G00<0emL06mL00`3Ge`0Ce`03
0=OG00kG00<0emL02mL00`3Ge`0:e`030=OG00SG00<0emL03]L00`3Ge`0Ee`030=OG01WG00<0emL0
9ML1007G000Ke`030=OG02;G00<0emL06mL00`3Ge`0Ce`030=OG00kG00<0emL02mL00`3Ge`0:e`03
0=OG00SG00<0emL03]L00`3Ge`0Ee`030=OG01WG00<0emL09ML1007G000Ke`808mL00`3Ge`0Le`03
0=OG01?G00<0emL03]L00`3Ge`0;e`030=OG00SG00<0emL02ML00`3Ge`0=e`030=OG01GG00<0emL0
6]L00`3Ge`0Te`800ML001_G00<0emL08]L00`3Ge`0Le`030=OG01?G00<0emL03]L00`3Ge`0;e`03
0=OG00SG00<0emL02=L00`3Ge`0>e`030=OG01GG00<0emL06]L00`3Ge`0Ue`400ML001_G00<0emL0
8]L00`3Ge`0Le`030=OG01CG00<0emL03ML00`3Ge`0;e`030=OG00SG00<0emL02=L00`3Ge`0>e`03
0=OG01GG00<0emL06]L00`3Ge`0Ue`400ML001_G00<0emL08mL00`3Ge`0Le`030=OG01?G00<0emL0
3ML00`3Ge`0;e`030=OG00SG00<0emL02=L00`3Ge`0>e`030=OG01CG00<0emL06mL00`3Ge`0Ue`40
0ML001_G00<0emL08mL00`3Ge`0Le`030=OG01?G00<0emL03]L00`3Ge`0:e`030=OG00SG00<0emL0
2=L00`3Ge`0>e`030=OG01CG00<0emL06]L00`3Ge`0Ve`400ML001_G00<0emL08mL00`3Ge`0Me`03
0=OG01?G00<0emL03ML00`3Ge`0:e`030=OG00SG00<0emL01mL00`3Ge`0>e`030=OG01CG00<0emL0
6mL00`3Ge`0Ve`400ML001_G00<0emL08mL00`3Ge`0Me`030=OG01?G00<0emL03ML00`3Ge`0:e`03
0=OG00SG00<0emL01mL00`3Ge`0>e`030=OG01CG00<0emL06mL00`3Ge`0Ve`400ML001_G00<0emL0
9=L00`3Ge`0Le`030=OG01?G00<0emL03]L00`3Ge`09e`030=OG00SG00<0emL01mL00`3Ge`0>e`03
0=OG01CG00<0emL06mL00`3Ge`0Ve`400ML001_G00<0emL09=L00`3Ge`0Me`030=OG01?G00<0emL0
3ML00`3Ge`0:e`030=OG00KG00<0emL02=L00`3Ge`0>e`030=OG01?G00<0emL07=L00`3Ge`0Ve`40
0ML001_G00<0emL09=L00`3Ge`0Me`030=OG01?G00<0emL03ML00`3Ge`0:e`030=OG00KG00<0emL0
2=L00`3Ge`0>e`030=OG01?G00<0emL07=L00`3Ge`0Ve`400ML001CG0P05e`030=OG02CG00<0emL0
7ML00`3Ge`0De`030=OG00gG00<0emL02ML00`3Ge`06e`030=OG00OG00<0emL03]L00`3Ge`0De`03
0=OG01_G00<0emL09mL1007G000Ce`040=OG00CG00<0emL09ML00`3Ge`0Me`030=OG01?G00<0emL0
3ML00`3Ge`09e`030=OG00KG00<0emL01mL00`3Ge`0>e`030=OG01?G00<0emL07=L00`3Ge`0We`40
0ML001?G00@0emL01=L202KG00<0emL07ML00`3Ge`0De`030=OG00gG00<0emL02=L00`3Ge`06e`03
0=OG00OG00<0emL03]L201CG100Ke`P08ML2007G000Ce`040=OG00CG00<0emL09ML00`3Ge`0Me`03
0=OG01GG00<0emL03ML00`3Ge`08e`030=OG00KG0P08e`804=L401CG200Ke`P06]L1007G000Ce`04
0=OG00CG00<0emL09]L00`3Ge`0Me`030=OG01CG00<0emL03]L00`3Ge`08e`030=OG00OG0P08e`<0
4ML601KG2@0JeaH01=L1007G000Ce`040=OG00CG00<0emL09]L00`3Ge`0Me`030=OG01GG00<0emL0
3]L00`3Ge`07e`030=OG00WG00<0emL02=L401?G1P0Ie`T0:mL1007G000De`801ML00`3Ge`0We`03
0=OG01gG00<0emL05=L00`3Ge`0?e`030=OG00OG00<0emL02ML200cG100Ee`P06]L=01kG0@01e`00
6mL00`3Ge`0We`030=OG01gG00<0emL05ML00`3Ge`0?e`030=OG00OG00<0emL02]L00`3Ge`0=e`@0
6ML801oG6P04e`400ML001_G00<0emL09mL00`3Ge`0Ne`030=OG01GG00<0emL03mL00`3Ge`07e`80
2mL2017G1`0Je`d0<=L1007G000Ke`030=OG02SG00<0emL07ML00`3Ge`0Ee`030=OG013G00<0emL0
2=L200_G0P0Fe`T07]LS00gG0@01e`006mL00`3Ge`0Xe`030=OG01kG00<0emL05ML00`3Ge`0@e`03
0=OG00WG0`0:e`D06]L=03CG2@04e`400ML001_G00<0emL0:=L00`3Ge`0Ne`030=OG01GG00<0emL0
4ML00`3Ge`0;e`803ML801oG4@0`e`400ML001_G00<0emL0:ML00`3Ge`0Ne`030=OG01GG00<0emL0
4ML00`3Ge`0<e`804mL902OG;004e`400ML001_G00<0emL0:ML00`3Ge`0Ne`030=OG01KG00<0emL0
4ML00`3Ge`0=e`<06ML904kG0@01e`006mL202_G00<0emL07]L00`3Ge`0Ee`030=OG01;G00<0emL0
3mL2023G7P0_e`800ML001_G00<0emL0:]L00`3Ge`0Ne`030=OG01KG00<0emL04]L00`3Ge`0@e`H0
>=L/00CG0@01e`006mL00`3Ge`0Ze`030=OG01oG00<0emL05]L00`3Ge`0Be`030=OG01GG201Pe`40
0ML001_G00<0emL0:mL00`3Ge`0Ne`030=OG01KG00<0emL04mL00`3Ge`0Leal0@ML1007G000Ke`03
0=OG02_G00<0emL07mL00`3Ge`0Fe`030=OG01?G00<0emL0>]Lm00CG0@01e`006mL00`3Ge`0/e`03
0=OG01kG00<0emL05]L00`3Ge`0De`80NmL1007G000Ke`030=OG02cG00<0emL07mL00`3Ge`0Fe`03
0=OG01GG1@1fe`400ML001_G00<0emL0;ML00`3Ge`0Oe`030=OG01KG0P0Je`H0L=L1007G000Ke`03
0=OG02gG00<0emL08=L00`3Ge`0Ge`030=OG01gG201Ke`T01=L1007G000Ke`030=OG02kG00<0emL0
8=L00`3Ge`0Ge`809ML804;G4@0=e`400ML001_G00<0emL0;]L00`3Ge`0Pe`030=OG01WG00<0emL0
:]M201kG0@01e`006mL00`3Ge`0_e`030=OG023G00<0emL06ML208[G0@01e`006mL2033G00<0emL0
8ML00`3Ge`0Je`030=OG08KG0P01e`006mL00`3Ge`0`e`030=OG027G00<0emL06]L208OG0@01e`00
6mL00`3Ge`0`e`030=OG02;G00<0emL06mL00`3Ge`24e`400ML001_G00<0emL0<ML00`3Ge`0Re`03
0=OG01_G0P24e`400ML001_G00<0emL0<ML00`3Ge`0Re`030=OG01gG00<0emL0PML1007G000Ke`03
0=OG03;G00<0emL08]L00`3Ge`0Me`80PML1007G000Ke`030=OG03;G00<0emL08mL00`3Ge`0Ne`03
0=OG07kG0@01e`006mL00`3Ge`0ce`030=OG02?G00<0emL07]L207kG0@01e`006mL00`3Ge`0ce`03
0=OG02CG00<0emL07mL00`3Ge`1ke`400ML001_G00<0emL0==L00`3Ge`0Te`030=OG01oG0P1ke`40
0ML001_G00<0emL0==L00`3Ge`0Ue`030=OG023G0P1ie`400ML001_G00<0emL0=ML00`3Ge`0Ue`03
0=OG027G0`1fe`400ML001_G00<0emL0=]L00`3Ge`0Ue`030=OG02?G0`1ce`400ML001_G0P0he`03
0=OG02GG0P0Ve`80L=L2007G000Ke`030=OG03SG00<0emL09]L00`3Ge`0Ue`<0K]L1007G000Ke`03
0=OG03SG00<0emL09mL00`3Ge`0We`@0J]L1007G000Ke`030=OG03WG00<0emL09mL202_G1P1Ke`D0
1=L1007G000Ke`030=OG03[G00<0emL0:=L00`3Ge`0^e`H0CML800WG0@01e`006mL00`3Ge`0ke`03
0=OG02SG00<0emL0<mL703gG2@0Ae`400ML001_G00<0emL0?=L00`3Ge`0Xe`80>]L902cG200Je`40
0ML001_G00<0emL0?=L00`3Ge`0Ze`030=OG043G3@0Be`d08]L1007G000Ke`030=OG03gG00<0emL0
:]L00`3Ge`1<ea80;mL1007G000Ke`030=OG03kG00<0emL0:]L208gG0@01e`006mL00`3Ge`0oe`03
0=OG02_G0P2;e`400ML001_G00<0emL0@=L00`3Ge`0/e`030=OG08SG0@01e`006mL204;G00<0emL0
;=L208OG0P01e`006mL00`3Ge`11e`030=OG02kG0P26e`400ML001_G00<0emL0@]L00`3Ge`0_e`80
Q=L1007G000Ke`030=OG04?G00<0emL0<=L00`3Ge`21e`400ML001_G00<0emL0A=L00`3Ge`0`e`80
PML1007G000Ke`030=OG04GG00<0emL0<ML207oG0@01e`006mL00`3Ge`16e`030=OG03;G0`1le`40
0ML001_G00<0emL0AmL00`3Ge`0de`<0NML1007G000Ke`030=OG04SG00<0emL0=]L307KG0@01e`00
6mL00`3Ge`19e`80>ML206gG0`04e`400ML000SG0P04e`030=OG00;G0`05e`030=OG04_G00<0emL0
>=L306KG1007e`400ML000OG00@0emL02mL00`3Ge`02e`030=OG04cG00<0emL0>]L305oG100;e`40
0ML000OG00@0emL02mL00`3Ge`02e`80C]L00`3Ge`0le`@0EmL400kG0P01e`001mL0103Ge`08e`<0
1ML00`3Ge`1>e`030=OG03oG1P1<e`D04mL1007G0007e`040=OG00SG00<0emL01ML00`3Ge`1?e`80
AML6043G1P0He`400ML000OG00@0emL02=L00`3Ge`05e`030=OG057G00<0emL0B=L703?G1P0Ne`40
0ML000SG0P09e`@01=L00`3Ge`1Be`030=OG04kG2@0Oe`/09=L1007G000Ke`030=OG05?G00<0emL0
E]LO02oG0@01e`006mL00`3Ge`1De`030=OG0:?G0@01e`006mL00`3Ge`1Ee`80XmL1007G000Ke`03
0=OG05OG00<0emL0X=L1007G000Ke`030=OG05SG0P2Pe`400ML001_G00<0emL0F]L209kG0@01e`00
6mL00`3Ge`1Le`80W=L1007G000Ke`80GmL00`3Ge`2He`800ML001_G00<0emL0GmL209WG0@01e`00
6mL00`3Ge`1Qe`80UmL1007G000Ke`030=OG06?G0P2Ee`400ML001_G00<0emL0IML00`3Ge`2Be`40
0ML001_G00<0emL0I]L209;G0@01e`006mL00`3Ge`1Xe`80T=L1007G000Ke`030=OG06[G0P2>e`40
0ML001_G00<0emL0K=L308_G0@01e`006mL00`3Ge`1_e`<0P]L200CG0@01e`006mL00`3Ge`1be`<0
O=L300KG0@01e`006mL00`3Ge`1ee`<0M]L300WG0@01e`006mL207WG0`1_e`@02mL2007G000Ke`03
0=OG07_G0`1Ye`<04=L1007G000Ke`030=OG07kG101Se`804mL1007G000Ke`030=OG08;G101Ne`03
0=OG01?G0@01e`006mL00`3Ge`26e`D0EmL301GG0@01e`006mL00`3Ge`2;e`D0C]L401SG0@01e`00
6mL00`3Ge`2@e`H0A=L401cG0@01e`006mL00`3Ge`2Fe`H0>]L4023G0@01e`006mL00`3Ge`2Le`/0
9=L;02CG0@01e`006mL00`3Ge`2Web@0;mL1007G000Ke`030=OG0?[G0@01e`006mL00`3Ge`3je`40
0ML001_G00<0emL0n]L1007G000Ke`80n]L2007G000Ke`030=OG0?[G0@01e`006mL00`3Ge`3je`40
0ML001_G00<0emL0n]L1007G000Ke`030=OG0?[G0@01e`006mL00`3Ge`3je`400ML001_G00<0emL0
n]L1007G000Ke`030=OG0?[G0@01e`006mL00`3Ge`3je`400ML001_G00<0emL0n]L1007G000Ke`03
0=OG0?[G0@01e`006mL00`3Ge`3je`400ML001_G0P3je`800ML001_G00<0emL0n]L1007G000Ke`03
0=OG0?[G0@01e`006mL00`3Ge`3je`400ML001_G00<0emL0n]L1007G000Ke`030=OG0?[G0@01e`00
6mL00`3Ge`3je`400ML001_G00<0emL0n]L1007G000Ke`030=OG0?[G0@01e`006mL00`3Ge`3je`40
0ML001?G1004e`030=OG0?[G0@01e`005ML00`3Ge`03e`030=OG0?[G0@01e`005ML00`3Ge`03e`80
n]L2007G000Ee`030=OG00?G00<0emL0n]L1007G000Ee`030=OG00?G00<0emL0n]L1007G000Ce`<0
1ML00`3Ge`02e`030=OG03[G00<0emL0>]L00`3Ge`0je`030=OG03WG00<0emL00]L1007G000Ee`03
0=OG00?G00<0emL00]L00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00[G00<0emL0
2ML00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`0:e`030=OG00WG00<0emL02ML00`3Ge`09e`03
0=OG00WG00<0emL02]L00`3Ge`09e`030=OG00WG00<0emL02ML00`3Ge`09e`030=OG00WG00<0emL0
0]L1007G000Keoh00ML00?oG6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL00?oG6mL00001
\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-1.26278, -1.2018, 0.00819863, \
0.00819863}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[plot1,CP,DisplayFunction->$DisplayFunction,Axes->False]", "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.025 w
.97619 .5 Mdot
.97619 .61905 Mdot
.97619 .7381 Mdot
.97619 .85714 Mdot
.97619 .97619 Mdot
.7381 .97619 Mdot
.5 .97619 Mdot
.2619 .97619 Mdot
.02381 .97619 Mdot
.5 Mabswid
[ ] 0 setdash
.97619 .82008 m
.91108 .84014 L
.90816 .84771 L
.84014 .8631 L
.77211 .86839 L
.70408 .86737 L
.63605 .86207 L
.56803 .85232 L
.51226 .84014 L
.5 .83653 L
.43197 .81104 L
.36395 .77378 L
.36134 .77211 L
.29592 .71902 L
.28098 .70408 L
.22789 .63866 L
.22622 .63605 L
.18896 .56803 L
.16347 .5 L
.15986 .48774 L
.14768 .43197 L
.13793 .36395 L
.13263 .29592 L
.13161 .22789 L
.1369 .15986 L
.15229 .09184 L
.15986 .08892 L
.17992 .02381 L
s
.97619 .72607 m
.90816 .74321 L
.84014 .75405 L
.77211 .75848 L
.70408 .75706 L
.63605 .74987 L
.56803 .73595 L
.5 .71317 L
.47919 .70408 L
.43197 .67731 L
.3793 .63605 L
.36395 .6207 L
.32269 .56803 L
.29592 .52081 L
.28683 .5 L
.26405 .43197 L
.25013 .36395 L
.24294 .29592 L
.24152 .22789 L
.24595 .15986 L
.25679 .09184 L
.27393 .02381 L
s
.97619 .65397 m
.90816 .66475 L
.84014 .67165 L
.77211 .67424 L
.70408 .6722 L
.63605 .66482 L
.56803 .65036 L
.52342 .63605 L
.5 .62478 L
.43197 .57851 L
.42149 .56803 L
.37522 .5 L
.36395 .47658 L
.34964 .43197 L
.33518 .36395 L
.3278 .29592 L
.32576 .22789 L
.32835 .15986 L
.33525 .09184 L
.34603 .02381 L
s
.97619 .57814 m
.90816 .58136 L
.84014 .58407 L
.77211 .58597 L
.70408 .58652 L
.63605 .58471 L
.56803 .5783 L
.51559 .56803 L
.5 .56138 L
.4411 .5 L
.43197 .48441 L
.41766 .43197 L
.40594 .36395 L
.40024 .29592 L
.39845 .22789 L
.3997 .15986 L
.40355 .09184 L
.40962 .02381 L
s
.97619 .56077 m
.90816 .56122 L
.84014 .56127 L
.77211 .56083 L
.70408 .55969 L
.63605 .5572 L
.56803 .55127 L
.5 .52378 L
.48251 .5 L
.47327 .43197 L
.4686 .36395 L
.46638 .29592 L
.46564 .22789 L
.46601 .15986 L
.46729 .09184 L
.46931 .02381 L
s
.97619 .55015 m
.90816 .55001 L
.84014 .54928 L
.77211 .54779 L
.70408 .54515 L
.63605 .54037 L
.56803 .5302 L
.51579 .5 L
.52419 .43197 L
.52844 .36395 L
.53046 .29592 L
.53113 .22789 L
.53079 .15986 L
.52964 .09184 L
.52781 .02381 L
s
.97619 .54007 m
.90816 .53939 L
.84014 .53791 L
.77211 .53535 L
.70408 .53108 L
.63605 .5235 L
.56803 .50649 L
.55644 .5 L
.56803 .44644 L
.57935 .43197 L
.59084 .36395 L
.5964 .29592 L
.59816 .22789 L
.59696 .15986 L
.59324 .09184 L
.58739 .02381 L
s
.97619 .53009 m
.90816 .52885 L
.84014 .52656 L
.77211 .52274 L
.70408 .51637 L
.63605 .50434 L
.621 .5 L
.63605 .44211 L
.64667 .43197 L
.66108 .36395 L
.66841 .29592 L
.67046 .22789 L
.66795 .15986 L
.66122 .09184 L
.65072 .02381 L
s
.97619 .51985 m
.90816 .51795 L
.84014 .51462 L
.77211 .50906 L
.70826 .5 L
.7312 .43197 L
.74521 .36395 L
.75244 .29592 L
.7539 .22789 L
.74955 .15986 L
.73894 .09184 L
.72223 .02381 L
s
.97619 .50882 m
.90816 .50601 L
.84014 .50109 L
.82895 .5 L
.84014 .43454 L
.8455 .43197 L
.85554 .36395 L
.86095 .29592 L
.86191 .22789 L
.85656 .15986 L
.84215 .09184 L
.84014 .09005 L
.81407 .02381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 175},
  ImageMargins->{{38, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_0000[`P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooojoG002_e`00[mL00:oG002_e`007mL00`3G
e`0=e`030=OG00[G00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`08e`030=OG00WG
00<0emL03ML00`3Ge`0Oe`007mL00`3Ge`0=e`030=OG00[G00<0emL02=L00`3Ge`07e`030=OG00OG
00<0emL02=L00`3Ge`08e`030=OG00WG00<0emL03ML00`3Ge`0Oe`007]L00`3Ge`0=e`030=OG00_G
00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL03ML00`3G
e`0Ne`007]L00`3Ge`0=e`030=OG00[G00<0emL02ML00`3Ge`07e`030=OG00OG00<0emL02=L00`3G
e`09e`030=OG00WG00<0emL03ML00`3Ge`0Ne`007]L00`3Ge`0=e`030=OG00[G00<0emL02ML00`3G
e`07e`030=OG00OG00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03]L00`3Ge`0Me`007ML00`3G
e`0>e`030=OG00[G00<0emL02ML00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`09e`030=OG00WG
00<0emL03]L00`3Ge`0Me`007ML00`3Ge`0=e`030=OG00_G00<0emL02=L00`3Ge`08e`030=OG00SG
00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL03]L00`3Ge`0Le`007=L00`3Ge`0>e`030=OG00_G
00<0emL02=L00`3Ge`08e`030=OG00SG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL03]L00`3G
e`0Le`007=L00`3Ge`0>e`030=OG00_G00<0emL02=L00`3Ge`08e`030=OG00SG00<0emL02=L00`3G
e`08e`030=OG00[G00<0emL03mL00`3Ge`0Ke`007=L00`3Ge`0>e`030=OG00[G00<0emL02ML00`3G
e`08e`030=OG00SG00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03mL00`3Ge`0Ke`006mL00`3G
e`0>e`030=OG00_G00<0emL02ML00`3Ge`08e`030=OG00SG00<0emL02=L00`3Ge`09e`030=OG00[G
00<0emL03mL00`3Ge`0Je`006]L2013G00<0emL02mL00`3Ge`09e`030=OG00SG00<0emL02=L00`3G
e`08e`030=OG00WG00<0emL02]L00`3Ge`0?e`030=OG01[G000Je`030=OG00oG00<0emL02mL00`3G
e`09e`030=OG00SG00<0emL02=L00`3Ge`08e`030=OG00WG00<0emL02]L00`3Ge`0?e`030=OG01[G
000Ie`030=OG013G00<0emL02mL00`3Ge`09e`030=OG00SG00<0emL02=L00`3Ge`08e`030=OG00WG
00<0emL02]L00`3Ge`0?e`030=OG01[G000Ie`030=OG00oG00<0emL03=L00`3Ge`09e`030=OG00SG
00<0emL02=L00`3Ge`08e`030=OG00WG00<0emL02]L00`3Ge`0@e`030=OG01WG000Ie`030=OG00oG
00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL02=L00`3Ge`08e`030=OG00WG00<0emL02mL00`3G
e`0?e`030=OG01WG000Ie`030=OG00oG00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL02=L00`3G
e`08e`030=OG00WG00<0emL02mL00`3Ge`0?e`030=OG01WG000He`030=OG013G00<0emL02mL00`3G
e`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00WG00<0emL02mL00`3Ge`0?e`030=OG01WG
000He`030=OG013G00<0emL02mL00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G
00<0emL02]L00`3Ge`0@e`030=OG01SG000He`030=OG013G00<0emL02mL00`3Ge`09e`030=OG00WG
00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02]L00`3Ge`0@e`030=OG01SG000He`030=OG00oG
00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02]L00`3G
e`0@e`030=OG01SG000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3G
e`08e`030=OG00[G00<0emL02mL00`3Ge`0?e`030=OG01SG000Ge`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG
000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G
00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG
00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G
00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3G
e`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3G
e`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG
000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G
00<0emL02mL00`3Ge`0@e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG
00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Fe`030=OG017G
00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03=L00`3G
e`0?e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3G
e`09e`030=OG00WG00<0emL03=L00`3Ge`0?e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3G
e`0:e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0?e`030=OG01OG
000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG
00<0emL03=L00`3Ge`0?e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG
00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0?e`030=OG01OG000Fe`030=OG017G
00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03=L00`3G
e`0?e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3G
e`09e`030=OG00WG00<0emL03=L00`3Ge`0?e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3G
e`0:e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0?e`030=OG01OG
000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG
00<0emL03=L00`3Ge`0?e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG
00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03=L00`3Ge`0?e`030=OG01OG000Fe`030=OG017G
00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3Ge`09e`030=OG00WG00<0emL03=L00`3G
e`0?e`030=OG01OG000Fe`030=OG017G00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL02=L00`3G
e`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG
000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G
00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG
00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G
00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3G
e`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3G
e`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG
000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G
00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG
00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G
00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3G
e`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL02=L00`3G
e`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG000Ge`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00WG00<0emL02=L00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01OG
000Ge`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00WG00<0emL01mL00`3Ge`08e`030=OG00[G
00<0emL02mL00`3Ge`0@e`030=OG01SG000He`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00SG
00<0emL01mL00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01SG000He`030=OG013G
00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00[G00<0emL02mL00`3G
e`0@e`030=OG01SG000He`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01mL00`3G
e`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01SG000He`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01SG
000He`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00[G
00<0emL02mL00`3Ge`0@e`030=OG01SG000He`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00SG
00<0emL01mL00`3Ge`08e`030=OG00[G00<0emL02mL00`3Ge`0@e`030=OG01SG000He`030=OG013G
00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01mL00`3Ge`08e`030=OG00[G00<0emL02mL00`3G
e`0@e`030=OG01SG000He`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01mL00`3G
e`08e`030=OG00WG00<0emL03=L00`3Ge`0@e`030=OG01SG000He`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00SG00<0emL01mL00`3Ge`07e`030=OG00[G00<0emL02mL00`3Ge`0Ae`030=OG01SG
000He`030=OG017G00<0emL03=L00`3Ge`09e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00[G
00<0emL02mL00`3Ge`0Ae`030=OG01SG000He`030=OG017G00<0emL03=L00`3Ge`09e`030=OG00OG
00<0emL01mL00`3Ge`07e`030=OG00[G00<0emL02mL00`3Ge`0Ae`030=OG01SG000He`030=OG017G
00<0emL03=L00`3Ge`09e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00WG00<0emL03=L00`3G
e`0@e`030=OG01WG000Ie`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01]L00`3G
e`07e`030=OG00WG00<0emL03=L00`3Ge`0@e`030=OG01WG000Ie`030=OG013G00<0emL03=L00`3G
e`09e`030=OG00SG00<0emL01]L00`3Ge`07e`030=OG00WG00<0emL03=L00`3Ge`0@e`030=OG01WG
000Ie`030=OG013G00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01]L00`3Ge`06e`030=OG00[G
00<0emL02mL00`3Ge`0Ae`030=OG01WG000Ie`030=OG017G00<0emL03=L00`3Ge`09e`030=OG00OG
00<0emL01]L00`3Ge`06e`030=OG00WG00<0emL03=L00`3Ge`0Ae`030=OG01WG000Ie`030=OG017G
00<0emL03=L00`3Ge`09e`030=OG00OG00<0emL01]L00`3Ge`06e`030=OG00WG00<0emL03=L00`3G
e`0Ae`030=OG01WG000Ie`030=OG017G00<0emL03=L00`3Ge`09e`030=OG00OG00<0emL01]L00`3G
e`06e`030=OG00WG00<0emL03=L00`3Ge`0@e`806mL001WG00<0emL04ML00`3Ge`0<e`030=OG00WG
00<0emL01mL00`3Ge`06e`030=OG00GG00<0emL02=L200oG00<0emL04=L00`3Ge`0Je`006ML00`3G
e`0Be`030=OG00cG00<0emL02ML00`3Ge`06e`030=OG00KG00<0emL01=L00`3Ge`09e`030=OG00gG
00<0emL04ML00`3Ge`0Je`006]L00`3Ge`0Ae`030=OG00cG00<0emL02ML00`3Ge`06e`030=OG00GG
00<0emL01ML00`3Ge`09e`030=OG00gG00<0emL04=L00`3Ge`0Ke`006]L00`3Ge`0Ae`030=OG00gG
00<0emL02=L00`3Ge`06e`030=OG00GG00<0emL01ML00`3Ge`08e`030=OG00kG00<0emL04=L00`3G
e`0Ke`006]L00`3Ge`0Be`030=OG00cG00<0emL02ML00`3Ge`05e`030=OG00GG00<0emL01=L00`3G
e`09e`030=OG00gG00<0emL04ML00`3Ge`0Ke`006]L00`3Ge`0Be`030=OG00gG00<0emL02=L00`3G
e`06e`030=OG00CG00<0emL01=L00`3Ge`09e`030=OG00gG00<0emL04ML00`3Ge`0Ke`006mL00`3G
e`0Be`030=OG00cG00<0emL02=L00`3Ge`06e`030=OG00CG00<0emL01=L00`3Ge`09e`030=OG00cG
00<0emL04]L00`3Ge`0Ke`006mL00`3Ge`0Be`030=OG00cG00<0emL02ML00`3Ge`05e`030=OG00CG
00<0emL01=L00`3Ge`09e`030=OG00cG00<0emL04]L00`3Ge`0Ke`006mL00`3Ge`0Be`030=OG00gG
00<0emL02=L00`3Ge`05e`030=OG00?G00<0emL01=L00`3Ge`09e`030=OG00gG00<0emL04ML00`3G
e`0Le`006mL00`3Ge`0Ce`030=OG00cG00<0emL02=L00`3Ge`05e`030=OG00?G00<0emL01=L00`3G
e`09e`030=OG00cG00<0emL04]L00`3Ge`0Fe`<00mL001cG00<0emL04]L00`3Ge`0=e`030=OG00SG
00<0emL01=L00`3Ge`03e`030=OG00CG00<0emL02ML00`3Ge`0<e`<04]L00`3Ge`0Ee`@00mL001cG
00<0emL04]L00`3Ge`0>e`030=OG00SG00<0emL01=L00`3Ge`03e`801ML00`3Ge`09e`@03ML600gG
1`0Ae`<00mL001gG00<0emL04]L00`3Ge`0=e`030=OG00WG00<0emL01=L00`3Ge`04e`030=OG00?G
0P0=e`H03ML800cG4`04e`007ML00`3Ge`0Be`030=OG00kG00<0emL02ML00`3Ge`03e`030=OG00GG
0P05e`@03mL900cG300Ge`007ML00`3Ge`0Ce`030=OG00kG00<0emL02ML00`3Ge`03e`030=OG00KG
00<0emL01]L401CG300<ea801ML001kG00<0emL04mL00`3Ge`0=e`030=OG00[G00<0emL00mL200OG
0P0:e`P06=L<01OG000Ne`030=OG01?G00<0emL03]L00`3Ge`0:e`030=OG00CG0`06e`<03mL<01SG
4P05e`007]L00`3Ge`0De`030=OG00kG00<0emL02]L00`3Ge`06e`801mL601GG:P05e`007mL00`3G
e`0Ce`030=OG00kG00<0emL02mL00`3Ge`07e`<02]LE02oG000Oe`030=OG01CG00<0emL03]L00`3G
e`0;e`030=OG00WG1`0HebX01ML001oG00<0emL05ML00`3Ge`0>e`030=OG00_G00<0emL03mL<03_G
000Pe`030=OG01CG00<0emL03]L00`3Ge`0<e`030=OG01[G=P05e`008=L00`3Ge`0Ee`030=OG00kG
00<0emL03=L405?G000Qe`030=OG01GG00<0emL03]L00`3Ge`0?e`@0CmL0027G00<0emL05]L00`3G
e`0>e`030=OG01;G200le`H01ML002;G00<0emL05ML00`3Ge`0?e`806]L<00gG8`0;e`008]L00`3G
e`0Fe`030=OG013G00<0emL08mL=02kG000Se`030=OG01KG00<0emL04=L205kG000Se`030=OG01OG
00<0emL04ML00`3Ge`1Ke`009=L00`3Ge`0Fe`030=OG01;G0P1Ke`009ML00`3Ge`0Fe`030=OG01?G
00<0emL0D]L300?G000Ue`030=OG01OG00<0emL04mL2057G1003e`009]L00`3Ge`0Ge`030=OG01CG
00<0emL0CmL300?G000Ve`030=OG01SG00<0emL05=L2053G00<0emL00]L002OG00<0emL06=L00`3G
e`0Ee`<0D]L002OG00<0emL06ML00`3Ge`0Ge`80D=L002SG00<0emL06ML201WG0P1>e`00:ML00`3G
e`0Je`030=OG01SG1012e`<01ML002WG00<0emL06mL00`3Ge`0Ke`H0=]L600SG000Ze`030=OG01_G
0P0Qe`T09ML800kG000[e`030=OG01cG00<0emL09mL<00gG300Fe`00;=L00`3Ge`0Le`030=OG03;G
3@0Re`00;ML00`3Ge`0Le`80HML002kG00<0emL07ML00`3Ge`1Ne`00;]L00`3Ge`0Ne`80G]L002oG
00<0emL07mL205cG000`e`030=OG023G00<0emL0FML0037G00<0emL08=L205WG000be`030=OG027G
0`1Fe`00<mL00`3Ge`0Se`<0DmL003CG00<0emL09ML204[G0P05e`00=ML202OG0`13e`@000CG0000
0mL003OG00<0emL09mL403_G1004e`@00mL003SG00<0emL0:]L6037G1009e`<00mL003WG00<0emL0
;mL902;G1P0>e`030=OG00;G000je`030=OG03OG8P0Ie`00>mL207;G000me`030=OG06oG000ne`80
KmL0043G0P1]e`00@]L206_G0014e`030=OG06SG0015e`80J=L004OG0P1Ve`00BML206CG001;e`80
H]L004gG0`1He`801ML0053G0`1Be`<01mL005?G0`1=e`802]L005KG0P18e`<03=L005SG1012e`80
3mL005cG100me`802]L300?G001Pe`P0<ML400_G1003e`00J=L<027G100@e`<00mL007CG300=e`P0
5ML00`3Ge`02e`00P=L=02;G002_e`00[mL00:oG002_e`00[mL00:oG002_e`00[mL00:oG002_e`00
[mL00:oG002_e`00[mL00:oG002_e`000mL302KG0`0We`<09]L302OG0`03e`000]L402GG100Ve`@0
9ML402KG1003e`000mL302KG0`0We`<09]L302OG0`03e`001=L00`3Ge`0Ve`030=OG02OG00<0emL0
9]L00`3Ge`0We`030=OG00;G002_e`00[mL00001\
\>"],
  ImageRangeCache->{{{0, 174}, {174, 0}} -> {-1.05001, -1.05001, 0.0120691, \
0.0120691}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[CP,SG,DisplayFunction->$DisplayFunction,Frame->False]", "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .82008 m
.91108 .84014 L
.90816 .84771 L
.84014 .8631 L
.77211 .86839 L
.70408 .86737 L
.63605 .86207 L
.56803 .85232 L
.51226 .84014 L
.5 .83653 L
.43197 .81104 L
.36395 .77378 L
.36134 .77211 L
.29592 .71902 L
.28098 .70408 L
.22789 .63866 L
.22622 .63605 L
.18896 .56803 L
.16347 .5 L
.15986 .48774 L
.14768 .43197 L
.13793 .36395 L
.13263 .29592 L
.13161 .22789 L
.1369 .15986 L
.15229 .09184 L
.15986 .08892 L
.17992 .02381 L
s
.97619 .72607 m
.90816 .74321 L
.84014 .75405 L
.77211 .75848 L
.70408 .75706 L
.63605 .74987 L
.56803 .73595 L
.5 .71317 L
.47919 .70408 L
.43197 .67731 L
.3793 .63605 L
.36395 .6207 L
.32269 .56803 L
.29592 .52081 L
.28683 .5 L
.26405 .43197 L
.25013 .36395 L
.24294 .29592 L
.24152 .22789 L
.24595 .15986 L
.25679 .09184 L
.27393 .02381 L
s
.97619 .65397 m
.90816 .66475 L
.84014 .67165 L
.77211 .67424 L
.70408 .6722 L
.63605 .66482 L
.56803 .65036 L
.52342 .63605 L
.5 .62478 L
.43197 .57851 L
.42149 .56803 L
.37522 .5 L
.36395 .47658 L
.34964 .43197 L
.33518 .36395 L
.3278 .29592 L
.32576 .22789 L
.32835 .15986 L
.33525 .09184 L
.34603 .02381 L
s
.97619 .57814 m
.90816 .58136 L
.84014 .58407 L
.77211 .58597 L
.70408 .58652 L
.63605 .58471 L
.56803 .5783 L
.51559 .56803 L
.5 .56138 L
.4411 .5 L
.43197 .48441 L
.41766 .43197 L
.40594 .36395 L
.40024 .29592 L
.39845 .22789 L
.3997 .15986 L
.40355 .09184 L
.40962 .02381 L
s
.97619 .56077 m
.90816 .56122 L
.84014 .56127 L
.77211 .56083 L
.70408 .55969 L
.63605 .5572 L
.56803 .55127 L
.5 .52378 L
.48251 .5 L
.47327 .43197 L
.4686 .36395 L
.46638 .29592 L
.46564 .22789 L
.46601 .15986 L
.46729 .09184 L
.46931 .02381 L
s
.97619 .55015 m
.90816 .55001 L
.84014 .54928 L
.77211 .54779 L
.70408 .54515 L
.63605 .54037 L
.56803 .5302 L
.51579 .5 L
.52419 .43197 L
.52844 .36395 L
.53046 .29592 L
.53113 .22789 L
.53079 .15986 L
.52964 .09184 L
.52781 .02381 L
s
.97619 .54007 m
.90816 .53939 L
.84014 .53791 L
.77211 .53535 L
.70408 .53108 L
.63605 .5235 L
.56803 .50649 L
.55644 .5 L
.56803 .44644 L
.57935 .43197 L
.59084 .36395 L
.5964 .29592 L
.59816 .22789 L
.59696 .15986 L
.59324 .09184 L
.58739 .02381 L
s
.97619 .53009 m
.90816 .52885 L
.84014 .52656 L
.77211 .52274 L
.70408 .51637 L
.63605 .50434 L
.621 .5 L
.63605 .44211 L
.64667 .43197 L
.66108 .36395 L
.66841 .29592 L
.67046 .22789 L
.66795 .15986 L
.66122 .09184 L
.65072 .02381 L
s
.97619 .51985 m
.90816 .51795 L
.84014 .51462 L
.77211 .50906 L
.70826 .5 L
.7312 .43197 L
.74521 .36395 L
.75244 .29592 L
.7539 .22789 L
.74955 .15986 L
.73894 .09184 L
.72223 .02381 L
s
.97619 .50882 m
.90816 .50601 L
.84014 .50109 L
.82895 .5 L
.84014 .43454 L
.8455 .43197 L
.85554 .36395 L
.86095 .29592 L
.86191 .22789 L
.85656 .15986 L
.84215 .09184 L
.84014 .09005 L
.81407 .02381 L
s
.97619 .5 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.5 .02381 L
.5 .5 L
.97619 .5 L
s
.025 w
.97619 .5 Mdot
.97619 .61905 Mdot
.97619 .7381 Mdot
.97619 .85714 Mdot
.97619 .97619 Mdot
.7381 .97619 Mdot
.5 .97619 Mdot
.2619 .97619 Mdot
.02381 .97619 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  Magnification->0.75,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003C0000d`P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooom?G003Ce`00dmL00=?G003Ce`001MMU00GG
00<0emL02ML00`3Ge`0:e`030=OG00gG00<0emL04=L00`3Ge`0Ue`001ML00`3Ge`0Me`030=OG017G
00<0emL03=L00`3Ge`0;e`030=OG00WG00<0emL01=L00`3Ge`03e`030=OG00WG00<0emL02]L00`3G
e`0=e`030=OG013G00<0emL09ML000GG00<0emL07=L00`3Ge`0Be`030=OG00cG00<0emL02mL00`3G
e`09e`030=OG00CG00<0emL00mL00`3Ge`09e`030=OG00[G00<0emL03ML00`3Ge`0Ae`030=OG02CG
0005e`030=OG01cG00<0emL04ML00`3Ge`0=e`030=OG00_G00<0emL02ML00`3Ge`04e`030=OG00?G
00<0emL02ML00`3Ge`0;e`030=OG00gG00<0emL04=L00`3Ge`0Te`001ML00`3Ge`0Le`030=OG017G
00<0emL03=L00`3Ge`0;e`030=OG00[G00<0emL01=L00`3Ge`03e`030=OG00WG00<0emL02mL00`3G
e`0=e`030=OG013G00<0emL09=L000GG00<0emL07=L00`3Ge`0Ae`030=OG00cG00<0emL02mL00`3G
e`0:e`030=OG00CG00<0emL00mL00`3Ge`09e`030=OG00_G00<0emL03ML00`3Ge`0Ae`030=OG02?G
0005e`030=OG01_G00<0emL04]L00`3Ge`0<e`030=OG00_G00<0emL02]L00`3Ge`04e`030=OG00?G
00<0emL02ML00`3Ge`0;e`030=OG00gG00<0emL04ML00`3Ge`0Se`001ML00`3Ge`0Ke`030=OG017G
00<0emL03ML00`3Ge`0;e`030=OG00[G00<0emL01=L00`3Ge`03e`030=OG00WG00<0emL02mL00`3G
e`0=e`030=OG017G00<0emL08mL000GG00<0emL06mL00`3Ge`0Ae`030=OG00gG00<0emL02mL00`3G
e`0:e`030=OG00CG00<0emL00mL00`3Ge`0:e`030=OG00_G00<0emL03ML00`3Ge`0Ae`030=OG02;G
0005e`030=OG01[G00<0emL04]L00`3Ge`0=e`030=OG00_G00<0emL02]L00`3Ge`04e`030=OG00?G
00<0emL02]L00`3Ge`0;e`030=OG00gG00<0emL04ML00`3Ge`0Re`001ML00`3Ge`0Je`030=OG01;G
00<0emL03ML00`3Ge`0;e`030=OG00[G00<0emL01=L00`3Ge`03e`030=OG00[G00<0emL02mL00`3G
e`0=e`030=OG01;G00<0emL08ML000GG00<0emL06]L00`3Ge`0Be`030=OG00cG00<0emL02mL00`3G
e`0;e`030=OG00CG00<0emL00mL00`3Ge`0:e`030=OG00_G00<0emL03ML00`3Ge`0Be`030=OG027G
0005e`030=OG01[G00<0emL04ML00`3Ge`0=e`030=OG00_G00<0emL02mL00`3Ge`04e`030=OG00?G
00<0emL02]L00`3Ge`0<e`030=OG00gG00<0emL04ML00`3Ge`0Qe`001ML00`3Ge`0Ie`030=OG01;G
00<0emL03ML00`3Ge`0;e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00[G00<0emL03=L00`3G
e`0=e`030=OG01;G00<0emL08=L000GG00<0emL06=L201CG00<0emL03ML00`3Ge`0;e`030=OG00_G
00<0emL01=L00`3Ge`03e`030=OG00[G00<0emL03=L00`3Ge`0=e`030=OG01;G0P0Qe`001ML00`3G
e`0He`030=OG01?G00<0emL03ML00`3Ge`0;e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00[G
00<0emL03=L00`3Ge`0=e`030=OG01?G00<0emL07mL000GG00<0emL05mL00`3Ge`0De`030=OG00gG
00<0emL02mL00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0:e`030=OG00cG00<0emL03ML00`3G
e`0Ce`030=OG01oG0005e`030=OG01OG00<0emL04mL00`3Ge`0>e`030=OG00_G00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02]L00`3Ge`0<e`030=OG00gG00<0emL05=L00`3Ge`0Ne`001ML00`3G
e`0Ge`030=OG01?G00<0emL03]L00`3Ge`0;e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00[G
00<0emL03=L00`3Ge`0>e`030=OG01?G00<0emL07]L000GG00<0emL05mL00`3Ge`0Ce`030=OG00kG
00<0emL02mL00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0:e`030=OG00cG00<0emL03]L00`3G
e`0Ce`030=OG01kG0005e`030=OG01KG00<0emL05=L00`3Ge`0>e`030=OG00_G00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02]L00`3Ge`0<e`030=OG00kG00<0emL04mL00`3Ge`0Ne`001ML00`3G
e`0Fe`030=OG01CG00<0emL03]L00`3Ge`0;e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00[G
00<0emL03=L00`3Ge`0>e`030=OG01?G00<0emL07]L000GG00<0emL05]L00`3Ge`0Ce`030=OG00kG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03ML00`3G
e`0De`030=OG01gG0005e`030=OG01KG00<0emL04mL00`3Ge`0>e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00gG00<0emL05=L00`3Ge`0Me`001ML00`3G
e`0Ee`030=OG01CG00<0emL03]L00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0=e`030=OG01CG00<0emL07ML000GG00<0emL05ML00`3Ge`0De`030=OG00kG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03ML00`3G
e`0De`030=OG01gG0005e`030=OG01GG00<0emL05=L00`3Ge`0>e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00kG00<0emL04mL00`3Ge`0Me`001ML00`3G
e`0Ee`030=OG01?G00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0>e`030=OG01CG00<0emL07=L000GG00<0emL05=L00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03]L00`3G
e`0De`030=OG01cG0005e`030=OG01CG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00kG00<0emL05=L00`3Ge`0Le`001ML00`3G
e`0De`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0>e`030=OG01CG00<0emL07=L000GG00<0emL05=L00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03]L00`3G
e`0De`030=OG01cG0005e`030=OG01CG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00kG00<0emL05=L00`3Ge`0Le`001ML00`3G
e`0De`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0>e`030=OG01CG00<0emL07=L000GG00<0emL05=L00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03]L00`3G
e`0De`030=OG01cG0005e`030=OG01CG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00kG00<0emL05=L00`3Ge`0Le`001ML00`3G
e`0Ce`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00cG00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0>e`030=OG01CG00<0emL07=L000GG00<0emL04mL00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0<e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00gG00<0emL03]L00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL03=L00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0=e`030=OG00kG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00cG00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03ML00`3Ge`0>e`030=OG01CG00<0emL06mL000GG00<0emL04mL00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0<e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00gG00<0emL03]L00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL03=L00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0=e`030=OG00kG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00cG00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03ML00`3Ge`0>e`030=OG01CG00<0emL06mL000GG00<0emL04mL00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0<e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00gG00<0emL03]L00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL03=L00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0=e`030=OG00kG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00cG00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03ML00`3Ge`0>e`030=OG01CG00<0emL06mL000GG00<0emL04mL00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0<e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00gG00<0emL03]L00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL03=L00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0=e`030=OG00kG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00cG00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03ML00`3Ge`0>e`030=OG01CG00<0emL06mL000GG00<0emL04mL00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0<e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00gG00<0emL03]L00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL03=L00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00oG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01GG00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0?e`030=OG01CG00<0emL06mL000GG00<0emL04mL00`3Ge`0Ee`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03mL00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05ML00`3Ge`0?e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00oG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01GG00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0?e`030=OG01CG00<0emL06mL000GG00<0emL04mL00`3Ge`0Ee`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03mL00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05ML00`3Ge`0?e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00oG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01GG00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0?e`030=OG01CG00<0emL06mL000GG00<0emL04mL00`3Ge`0Ee`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03mL00`3G
e`0De`030=OG01_G0005e`030=OG01?G00<0emL05ML00`3Ge`0?e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00oG00<0emL05=L00`3Ge`0Ke`001ML00`3G
e`0Ce`030=OG01GG00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0?e`030=OG01CG00<0emL06mL000GG00<0emL05=L00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01_G0005e`030=OG01CG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02mL00`3G
e`04e`030=OG00?G00<0emL02mL00`3Ge`0<e`030=OG00kG00<0emL05ML00`3Ge`0Ke`001ML00`3G
e`0De`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00_G00<0emL01=L00`3Ge`03e`030=OG00_G
00<0emL03=L00`3Ge`0>e`030=OG01GG00<0emL06mL000GG00<0emL05=L00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0;e`030=OG00CG00<0emL00mL00`3Ge`0;e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01_G0005e`030=OG01CG00<0emL05ML00`3Ge`0?e`030=OG00cG00<0emL02]L00`3G
e`04e`030=OG00?G00<0emL02]L00`3Ge`0<e`030=OG00oG00<0emL05=L00`3Ge`0Le`001ML00`3G
e`0De`030=OG01GG00<0emL03mL00`3Ge`0<e`030=OG00[G00<0emL01=L00`3Ge`03e`030=OG00[G
00<0emL03=L00`3Ge`0?e`030=OG01CG00<0emL07=L000GG00<0emL05=L00`3Ge`0Ee`030=OG00oG
00<0emL03=L00`3Ge`0:e`030=OG00CG00<0emL00mL00`3Ge`0:e`030=OG00cG00<0emL03mL00`3G
e`0De`030=OG01cG0005e`030=OG01CG00<0emL05ML00`3Ge`0?e`030=OG00cG00<0emL02]L00`3G
e`04e`030=OG00?G00<0emL02]L00`3Ge`0<e`030=OG00oG00<0emL05=L00`3Ge`0Le`001ML00`3G
e`0Ee`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00[G00<0emL01=L00`3Ge`03e`030=OG00[G
00<0emL03=L00`3Ge`0>e`030=OG01GG00<0emL07=L000GG00<0emL05ML00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0:e`030=OG00CG00<0emL00mL00`3Ge`0:e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01cG0005e`030=OG01GG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02]L00`3G
e`04e`030=OG00?G00<0emL02]L00`3Ge`0<e`030=OG00kG00<0emL05ML00`3Ge`0Le`001ML00`3G
e`0Ee`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00[G00<0emL01=L00`3Ge`03e`030=OG00[G
00<0emL03=L00`3Ge`0>e`030=OG01GG00<0emL07=L000GG00<0emL05ML00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`0:e`030=OG00CG00<0emL00mL00`3Ge`0:e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01cG0005e`030=OG01GG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02]L00`3G
e`04e`030=OG00?G00<0emL02]L00`3Ge`0<e`030=OG00kG00<0emL05ML00`3Ge`0Le`001ML00`3G
e`0Ee`030=OG01GG00<0emL03mL00`3Ge`0;e`030=OG00[G00<0emL01=L00`3Ge`03e`030=OG00WG
00<0emL03=L00`3Ge`0>e`030=OG01GG00<0emL07ML000GG00<0emL05]L00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`09e`030=OG00CG00<0emL00mL00`3Ge`09e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01gG0005e`030=OG01KG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02ML00`3G
e`04e`030=OG00?G00<0emL02ML00`3Ge`0<e`030=OG00kG00<0emL05ML00`3Ge`0Me`001ML00`3G
e`0Fe`030=OG01CG00<0emL03mL00`3Ge`0<e`030=OG00WG00<0emL01=L00`3Ge`03e`030=OG00WG
00<0emL03=L00`3Ge`0>e`030=OG01GG00<0emL07ML000GG00<0emL05]L00`3Ge`0De`030=OG00oG
00<0emL03=L00`3Ge`09e`030=OG00CG00<0emL00]L00`3Ge`09e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01kG0005e`030=OG01KG00<0emL05ML00`3Ge`0?e`030=OG00_G00<0emL02]L00`3G
e`03e`030=OG00;G00<0emL02ML00`3Ge`0<e`030=OG00kG00<0emL05ML00`3Ge`0Ne`001ML00`3G
e`0Fe`030=OG01GG00<0emL03mL00`3Ge`0;e`030=OG00[G00<0emL00mL00`3Ge`02e`030=OG00WG
00<0emL03=L00`3Ge`0>e`030=OG01GG00<0emL07]L000GG00<0emL05]L00`3Ge`0Ee`030=OG00oG
00<0emL02mL00`3Ge`0:e`030=OG00?G00<0emL00]L00`3Ge`09e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01kG0005e`030=OG01OG00<0emL05=L00`3Ge`0?e`030=OG00cG00<0emL02ML00`3G
e`03e`030=OG00;G00<0emL02ML00`3Ge`0<e`030=OG00kG00<0emL05ML00`3Ge`0Ne`001ML00`3G
e`0Ge`030=OG01GG00<0emL03mL00`3Ge`0;e`030=OG00WG00<0emL00mL00`3Ge`02e`030=OG00SG
00<0emL03=L00`3Ge`0>e`030=OG01GG00<0emL07mL000GG00<0emL05mL00`3Ge`0Ee`030=OG00oG
00<0emL02mL00`3Ge`09e`030=OG00?G00<0emL00]L00`3Ge`08e`030=OG00cG00<0emL03]L00`3G
e`0Ee`030=OG01oG0005e`030=OG01OG00<0emL05ML00`3Ge`0?e`030=OG00_G00<0emL02ML00`3G
e`03e`030=OG00;G00<0emL02=L00`3Ge`0<e`030=OG00kG00<0emL05=L2027G0005e`030=OG01OG
00<0emL05ML00`3Ge`0?e`030=OG00_G00<0emL02ML00`3Ge`03e`030=OG00;G00<0emL01mL00`3G
e`0;e`804ML00`3Ge`0De`030=OG023G0005e`030=OG01OG00<0emL05]L00`3Ge`0?e`030=OG00_G
00<0emL02=L00`3Ge`03e`030=OG00;G00<0emL01mL00`3Ge`0:e`030=OG013G00<0emL05ML00`3G
e`0Pe`001ML00`3Ge`0Ge`030=OG01KG00<0emL03mL00`3Ge`0;e`030=OG00SG00<0emL00mL00`3G
e`02e`030=OG00KG00<0emL02mL00`3Ge`0@e`030=OG01GG00<0emL08=L000GG00<0emL06=L00`3G
e`0Ee`030=OG00oG00<0emL02mL00`3Ge`09e`030=OG00;G00D0emOG0009e`030=OG00[G00<0emL0
4ML00`3Ge`0De`030=OG027G0005e`030=OG01SG00<0emL05]L00`3Ge`0?e`030=OG00[G00<0emL0
2ML00`3Ge`02e`050=OGe`002ML00`3Ge`0:e`030=OG017G00<0emL05=L00`3Ge`0Qe`001ML00`3G
e`0He`030=OG01KG00<0emL03mL00`3Ge`0;e`030=OG00SG00<0emL00]L01@3GemL000SG00<0emL0
2mL00`3Ge`0@e`030=OG01GG00<0emL08ML000GG00<0emL06=L00`3Ge`0Fe`030=OG00oG00<0emL0
2mL00`3Ge`08e`030=OG00;G00D0emOG0008e`030=OG00_G00<0emL04=L00`3Ge`0Ee`030=OG027G
0005e`030=OG01SG00<0emL05mL00`3Ge`0?e`030=OG00[G00<0emL02=L00`3Ge`02e`050=OGe`00
2=L00`3Ge`0:e`030=OG017G00<0emL05ML00`3Ge`0Qe`001ML00`3Ge`0He`030=OG01OG00<0emL0
3mL00`3Ge`0:e`030=OG00SG00<0emL00]L01@3GemL000SG00<0emL02]L00`3Ge`0@e`030=OG01KG
00<0emL08ML000GG00<0emL06ML00`3Ge`0Ge`030=OG00kG00<0emL02mL00`3Ge`07e`030=OG00;G
00D0emOG0008e`030=OG00[G00<0emL04=L00`3Ge`0Fe`030=OG027G0005e`030=OG01WG00<0emL0
5mL00`3Ge`0?e`030=OG00[G00<0emL02=L01@3GemL000;G00<0emL01mL00`3Ge`0:e`030=OG013G
00<0emL05ML00`3Ge`0Re`001ML00`3Ge`0Ie`030=OG01OG00<0emL03mL00`3Ge`0;e`030=OG00OG
00D0emOG0002e`030=OG00KG00<0emL02]L00`3Ge`0Ae`030=OG01GG00<0emL06mL400?G0005e`03
0=OG01WG00<0emL06=L00`3Ge`0?e`030=OG00[G00<0emL01mL01@3GemL000;G00<0emL01]L00`3G
e`0:e`030=OG013G00<0emL05]L00`3Ge`0Ke`@00mL000GG00<0emL06]L00`3Ge`0Ge`030=OG00oG
00<0emL02mL00`3Ge`06e`040=OGefL00mL000GG00<0emL06]L00`3Ge`0Ge`030=OG013G00<0emL0
2mL00`3Ge`06e`030=OG00CG0P07e`030=OG00_G100Ae`H05ML8013G1003e`001ML00`3Ge`0Ke`03
0=OG01OG00<0emL03mL00`3Ge`0<e`030=OG00KG00<0emL01ML00`3Ge`05e`<03]L501;G2P0Cea80
1ML000GG00<0emL06mL00`3Ge`0Ge`030=OG013G00<0emL03=L00`3Ge`05e`030=OG00KG0P08e`@0
3mL501OG3`0Ee`030=OG00?G0005e`030=OG01_G00<0emL06=L00`3Ge`0@e`030=OG00cG00<0emL0
1ML00`3Ge`07e`802]L500oG2@0MeaH01ML000GG00<0emL07=L00`3Ge`0Ge`030=OG013G00<0emL0
3ML00`3Ge`05e`802ML00`3Ge`0<e`H04]L>02CG00<0emL00mL000GG00<0emL07=L00`3Ge`0Ge`03
0=OG017G00<0emL03ML00`3Ge`06e`802=L201;G200Head01mL00`3Ge`03e`001ML00`3Ge`0Le`03
0=OG01SG00<0emL04ML00`3Ge`0=e`030=OG00OG0P08e`@05]L:02_G2005e`001ML00`3Ge`0Me`03
0=OG01OG00<0emL04ML00`3Ge`0>e`030=OG00SG0`09e`L06MLM01GG00<0emL00mL000GG00<0emL0
7ML00`3Ge`0He`030=OG017G00<0emL03]L00`3Ge`0:e`803]L;02_G5P05e`001ML00`3Ge`0Me`03
0=OG01SG00<0emL04]L00`3Ge`0>e`030=OG00_G0P0Gea`09=L00`3Ge`03e`001ML00`3Ge`0Ne`03
0=OG01SG00<0emL04ML00`3Ge`0?e`030=OG00cG200[ebD01ML000GG00<0emL07]L00`3Ge`0He`03
0=OG01;G00<0emL03mL00`3Ge`0Ce`l0@=L00`3Ge`03e`001ML00`3Ge`0Ne`030=OG01WG00<0emL0
4]L00`3Ge`0?e`030=OG027G@@05e`001ML00`3Ge`0Oe`030=OG01SG00<0emL04]L00`3Ge`0@e`80
HML00`3Ge`03e`001ML00`3Ge`0Oe`030=OG01WG00<0emL04]L00`3Ge`0Ae`<0G]L00`3Ge`03e`00
1ML00`3Ge`0Pe`030=OG01WG00<0emL04]L00`3Ge`0Ce`H0F=L00`3Ge`03e`001ML00`3Ge`0Pe`03
0=OG01[G00<0emL04]L00`3Ge`0He`T0>]LF00GG0005e`030=OG027G00<0emL06ML00`3Ge`0Ce`80
8MLj01GG00<0emL00mL000GG00<0emL08ML00`3Ge`0Je`030=OG01CG00<0emL0KML00`3Ge`03e`00
1ML00`3Ge`0Re`030=OG01[G00<0emL05=L206gG00<0emL00mL000GG00<0emL08]L00`3Ge`0Ke`03
0=OG01GG00<0emL0J]L00`3Ge`03e`001ML00`3Ge`0Se`030=OG01_G00<0emL05ML206[G00<0emL0
0mL000GG00<0emL09=L00`3Ge`0Ke`030=OG01KG00<0emL0I]L400?G0005e`030=OG02CG00<0emL0
6mL00`3Ge`0Ge`80I]L400?G0005e`030=OG02GG00<0emL06mL00`3Ge`0He`030=OG06?G1003e`00
1ML00`3Ge`0Ue`030=OG01cG00<0emL06=L206?G1003e`001ML00`3Ge`0Ve`030=OG01cG00<0emL0
6ML206;G00<0emL00mL000GG00<0emL09]L00`3Ge`0Me`030=OG01[G0P1Pe`030=OG00?G0005e`03
0=OG02OG00<0emL07ML00`3Ge`0Ke`<0GML00`3Ge`03e`001ML00`3Ge`0Xe`030=OG01gG00<0emL0
7ML305[G00<0emL00mL000GG00<0emL0:ML00`3Ge`0Me`808=L305OG00<0emL00mL000GG00<0emL0
:]L00`3Ge`0Ne`030=OG023G101Ce`030=OG00?G0005e`030=OG02[G00<0emL07mL00`3Ge`0Se`@0
C=L400GG0005e`030=OG02_G00<0emL07mL00`3Ge`0Ve`D0@=L700?G00<0emL00mL000GG00<0emL0
;=L00`3Ge`0Oe`030=OG02[G2P0[e`/02]L00`3Ge`03e`001ML00`3Ge`0]e`030=OG01oG0P0de`h0
3mL>01GG00<0emL00mL000GG00<0emL0;]L00`3Ge`0Pe`030=OG03oG3`0Se`030=OG00?G0005e`03
0=OG02oG00<0emL08=L00`3Ge`1`e`030=OG00?G0005e`030=OG033G00<0emL08=L2073G00<0emL0
0mL000GG00<0emL0<=L00`3Ge`0Re`80K]L00`3Ge`03e`001ML00`3Ge`0ae`030=OG02?G0P1/e`03
0=OG00?G0005e`030=OG03;G00<0emL09=L206[G00<0emL00mL000GG00<0emL0<mL00`3Ge`0Ue`<0
ImL00`3Ge`03e`001ML00`3Ge`0de`030=OG02OG0P1Ue`030=OG00?G0005e`030=OG03GG00<0emL0
:=L306;G00<0emL00mL000GG00<0emL0=]L00`3Ge`0Ze`<0GmL00`3Ge`03e`001ML00`3Ge`0ge`03
0=OG02cG0P1Me`030=OG00?G0005e`030=OG03SG00<0emL0;ML305SG1@03e`001ML00`3Ge`0ie`80
<=L3057G10000mL0000200?G0005e`030=OG03_G00<0emL0<=L404SG1@05e`@00mL000GG00<0emL0
?=L00`3Ge`0ce`@0?mL500[G1003e`001ML00`3Ge`0me`030=OG03KG1@0ee`D04=L00`3Ge`03e`00
1ML00`3Ge`0ne`030=OG03[G2P0Ve`D05ML00`3Ge`03e`001ML00`3Ge`0oe`030=OG04?G3P0?e`T0
6]L00`3Ge`03e`001ML00`3Ge`10e`80DML?02?G00<0emL00mL000GG00<0emL0@]L00`3Ge`20e`03
0=OG00?G0005e`030=OG04?G00<0emL0OmL00`3Ge`03e`001ML00`3Ge`14e`030=OG07kG00<0emL0
0mL000GG00<0emL0AML207kG00<0emL00mL000GG00<0emL0AmL207cG00<0emL00mL000GG00<0emL0
BML207[G00<0emL00mL000GG00<0emL0BmL00`3Ge`1ge`030=OG00?G0005e`030=OG04cG0P1ge`03
0=OG00?G0005e`030=OG04kG0P1ee`030=OG00?G0005e`030=OG053G0P1ce`030=OG00?G0005e`03
0=OG05;G0P1ae`030=OG00?G0005e`030=OG05CG0`1^e`030=OG00?G0005e`030=OG05OG0`1Ze`80
1ML000GG00<0emL0F]L306?G10000mL0e`04e`001ML00`3Ge`1Me`<0GML300GG00<0emL00mL000GG
00<0emL0H=L205OG1008e`030=OG00?G0005e`030=OG06;G101Ae`803=L00`3Ge`03e`001ML00`3G
e`1Ve`H0B]L200gG00<0emL00mL000GG00<0emL0K=L703oG100>e`@00mL000GG00<0emL0LmL703CG
100Be`@00mL000GG00<0emL0N]L702WG100Fe`@00mL000GG00<0emL0PML801WG200Je`@00mL000GG
00<0emL0RMLI02?G00<0emL00mL000GG00<0emL0aML00`3Ge`03e`001ML00`3Ge`35e`030=OG00?G
0005e`030=OG0<GG00<0emL00mL000GG00<0emL0aML00`3Ge`03e`001ML00`3Ge`35e`030=OG00?G
0005e`030=OG0<GG00<0emL00mL000GG00<0emL0aML00`3Ge`03e`001ML00`3Ge`35e`030=OG00?G
0005e`030=OG0<GG00<0emL00mL000GG00<0emL0aML00`3Ge`03e`001ML00`3Ge`35e`030=OG00?G
0005e`030=OG0<GG00<0emL00mL000GG00<0emL0aML00`3Ge`03e`001ML00`3Ge`35e`030=OG00?G
0005e`030=OG0<GG00<0emL00mL000GG00<0emL0aML00`3Ge`03e`001ML00`3Ge`35e`030=OG00?G
0005e`030=OG0<GG00<0emL00mL000GG00<0emL0aML00`3Ge`03e`001ML00`3Ge`35e`030=OG00?G
0003e`@0;mL402kG100^e`@0;]L400?G0003eld00mL000?G100_e`@0;]L402kG100^e`@00mL000?G
100_e`@0;]L402kG100^e`@00mL00=?G003Ce`00dmL00001\
\>"],
  ImageRangeCache->{{{0, 210.5}, {210.5, 0}} -> {-1.05001, -1.05001, \
0.00748227, 0.00748227}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[GraphicsArray[{plot1, CP}]]\)], "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0238095 0.952381 [
[.02381 .01131 -6 -9 ]
[.02381 .01131 6 0 ]
[.2619 .01131 -12 -9 ]
[.2619 .01131 12 0 ]
[.7381 .01131 -9 -9 ]
[.7381 .01131 9 0 ]
[.97619 .01131 -3 -9 ]
[.97619 .01131 3 0 ]
[.4875 .21429 -18 -4.5 ]
[.4875 .21429 0 4.5 ]
[.4875 .40476 -18 -4.5 ]
[.4875 .40476 0 4.5 ]
[.4875 .59524 -18 -4.5 ]
[.4875 .59524 0 4.5 ]
[.4875 .78571 -18 -4.5 ]
[.4875 .78571 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .02381 m
.02381 .03006 L
s
[(-1)] .02381 .01131 0 1 Mshowa
.2619 .02381 m
.2619 .03006 L
s
[(-0.5)] .2619 .01131 0 1 Mshowa
.7381 .02381 m
.7381 .03006 L
s
[(0.5)] .7381 .01131 0 1 Mshowa
.97619 .02381 m
.97619 .03006 L
s
[(1)] .97619 .01131 0 1 Mshowa
.125 Mabswid
.07143 .02381 m
.07143 .02756 L
s
.11905 .02381 m
.11905 .02756 L
s
.16667 .02381 m
.16667 .02756 L
s
.21429 .02381 m
.21429 .02756 L
s
.30952 .02381 m
.30952 .02756 L
s
.35714 .02381 m
.35714 .02756 L
s
.40476 .02381 m
.40476 .02756 L
s
.45238 .02381 m
.45238 .02756 L
s
.54762 .02381 m
.54762 .02756 L
s
.59524 .02381 m
.59524 .02756 L
s
.64286 .02381 m
.64286 .02756 L
s
.69048 .02381 m
.69048 .02756 L
s
.78571 .02381 m
.78571 .02756 L
s
.83333 .02381 m
.83333 .02756 L
s
.88095 .02381 m
.88095 .02756 L
s
.92857 .02381 m
.92857 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
.5 .21429 m
.50625 .21429 L
s
[(0.2)] .4875 .21429 1 0 Mshowa
.5 .40476 m
.50625 .40476 L
s
[(0.4)] .4875 .40476 1 0 Mshowa
.5 .59524 m
.50625 .59524 L
s
[(0.6)] .4875 .59524 1 0 Mshowa
.5 .78571 m
.50625 .78571 L
s
[(0.8)] .4875 .78571 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(1)] .4875 .97619 1 0 Mshowa
.125 Mabswid
.5 .07143 m
.50375 .07143 L
s
.5 .11905 m
.50375 .11905 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .30952 m
.50375 .30952 L
s
.5 .35714 m
.50375 .35714 L
s
.5 .45238 m
.50375 .45238 L
s
.5 .5 m
.50375 .5 L
s
.5 .54762 m
.50375 .54762 L
s
.5 .64286 m
.50375 .64286 L
s
.5 .69048 m
.50375 .69048 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .83333 m
.50375 .83333 L
s
.5 .88095 m
.50375 .88095 L
s
.5 .92857 m
.50375 .92857 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.97619 .02381 Mdot
.97619 .2619 Mdot
.97619 .5 Mdot
.97619 .7381 Mdot
.97619 .97619 Mdot
.7381 .97619 Mdot
.5 .97619 Mdot
.2619 .97619 Mdot
.02381 .97619 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -24 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.5)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.5)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-1)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-0.5)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(0.5)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.98077 .82316 m
.91503 .84341 L
.91209 .85106 L
.84341 .86659 L
.77473 .87194 L
.70604 .87091 L
.63736 .86555 L
.56868 .85571 L
.51238 .84341 L
.5 .83977 L
.43132 .81403 L
.36264 .77642 L
.36001 .77473 L
.29396 .72113 L
.27887 .70604 L
.22527 .63999 L
.22358 .63736 L
.18597 .56868 L
.16023 .5 L
.15659 .48762 L
.14429 .43132 L
.13445 .36264 L
.12909 .29396 L
.12806 .22527 L
.13341 .15659 L
.14894 .08791 L
.15659 .08497 L
.17684 .01923 L
s
.98077 .72825 m
.91209 .74555 L
.84341 .75649 L
.77473 .76096 L
.70604 .75953 L
.63736 .75227 L
.56868 .73822 L
.5 .71522 L
.47899 .70604 L
.43132 .67901 L
.37814 .63736 L
.36264 .62186 L
.32099 .56868 L
.29396 .52101 L
.28478 .5 L
.26178 .43132 L
.24773 .36264 L
.24047 .29396 L
.23904 .22527 L
.24351 .15659 L
.25445 .08791 L
.27175 .01923 L
s
.98077 .65545 m
.91209 .66633 L
.84341 .6733 L
.77473 .67591 L
.70604 .67385 L
.63736 .66641 L
.56868 .6518 L
.52365 .63736 L
.5 .62598 L
.43132 .57927 L
.42073 .56868 L
.37402 .5 L
.36264 .47635 L
.3482 .43132 L
.33359 .36264 L
.32615 .29396 L
.32409 .22527 L
.3267 .15659 L
.33367 .08791 L
.34455 .01923 L
s
.98077 .57889 m
.91209 .58214 L
.84341 .58487 L
.77473 .58679 L
.70604 .58735 L
.63736 .58553 L
.56868 .57906 L
.51574 .56868 L
.5 .56197 L
.44053 .5 L
.43132 .48426 L
.41687 .43132 L
.40503 .36264 L
.39928 .29396 L
.39747 .22527 L
.39873 .15659 L
.40262 .08791 L
.40875 .01923 L
s
.98077 .56136 m
.91209 .56181 L
.84341 .56186 L
.77473 .56142 L
.70604 .56026 L
.63736 .55775 L
.56868 .55176 L
.5 .52401 L
.48234 .5 L
.47302 .43132 L
.4683 .36264 L
.46605 .29396 L
.46531 .22527 L
.46569 .15659 L
.46697 .08791 L
.46901 .01923 L
s
.98077 .55064 m
.91209 .55049 L
.84341 .54976 L
.77473 .54825 L
.70604 .54558 L
.63736 .54075 L
.56868 .53049 L
.51594 .5 L
.52442 .43132 L
.52871 .36264 L
.53075 .29396 L
.53143 .22527 L
.53109 .15659 L
.52993 .08791 L
.52808 .01923 L
s
.98077 .54045 m
.91209 .53977 L
.84341 .53828 L
.77473 .53569 L
.70604 .53138 L
.63736 .52372 L
.56868 .50655 L
.55699 .5 L
.56868 .44592 L
.58011 .43132 L
.59171 .36264 L
.59733 .29396 L
.5991 .22527 L
.59789 .15659 L
.59414 .08791 L
.58823 .01923 L
s
.98077 .53038 m
.91209 .52913 L
.84341 .52681 L
.77473 .52296 L
.70604 .51653 L
.63736 .50438 L
.62216 .5 L
.63736 .44155 L
.64808 .43132 L
.66262 .36264 L
.67003 .29396 L
.6721 .22527 L
.66957 .15659 L
.66277 .08791 L
.65217 .01923 L
s
.98077 .52004 m
.91209 .51812 L
.84341 .51476 L
.77473 .50915 L
.71026 .5 L
.73343 .43132 L
.74757 .36264 L
.75487 .29396 L
.75634 .22527 L
.75195 .15659 L
.74124 .08791 L
.72437 .01923 L
s
.98077 .50891 m
.91209 .50607 L
.84341 .5011 L
.83211 .5 L
.84341 .43391 L
.84883 .43132 L
.85895 .36264 L
.86442 .29396 L
.86539 .22527 L
.85999 .15659 L
.84544 .08791 L
.84341 .0861 L
.81709 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 134.25},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000QPP10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG6mL00?oG6mL00?oG6mL00?oG6mL00?oG
6mL0017G100Ce`801=L00`3Ge`02e`<09mL200CG00<0emL00]L301?G102He`004mL00`3Ge`0Ae`04
0=OG00_G00<0emL08mL0103Ge`0;e`030=OG01;G00<0emL0UmL001?G00<0emL04ML0103Ge`0;e`03
0=OG02?G00@0emL02mL00`3Ge`0Be`030=OG09OG000;e`@01=L00`3Ge`0;e`@00]L0103Ge`08e`<0
9]L0103Ge`08e`<05ML00`3Ge`2Ge`004mL00`3Ge`0Ae`040=OG00SG00<0emL09]L0103Ge`08e`03
0=OG01GG00<0emL0UmL0017G0`0Ce`040=OG00SG00<0emL09]L0103Ge`08e`030=OG01?G0`2Ie`00
4mL00`3Ge`0Be`802ML4017G00<0emL04]L200WG100De`030=OG09OG0018e`030=OG06CG100?e`80
1=L00`3Ge`02e`<03ML2013G0P04e`030=OG00;G0`0?e`@02]L004SG00<0emL0I]L00`3Ge`0=e`04
0=OG00_G00<0emL02ML0103Ge`0>e`040=OG00_G00<0emL03]L00`3Ge`09e`003MMf02kG00<0emL0
3ML0103Ge`0;e`030=OG00WG00@0emL03]L0103Ge`0;e`030=OG00kG00<0emL02ML0013G00<0emL0
6ML00`3Ge`0Ie`030=OG01WG00<0emL06ML00`3Ge`0Ve`@01=L00`3Ge`07e`@00]L0103Ge`08e`<0
3=L0103Ge`0>e`040=OG00SG0`0Ae`030=OG00WG0018e`030=OG06KG00<0emL03ML0103Ge`08e`03
0=OG00cG00@0emL03]L0103Ge`08e`030=OG017G00<0emL02ML004SG00<0emL0I=L300oG00@0emL0
2=L00`3Ge`0<e`040=OG00kG00@0emL02=L00`3Ge`0?e`<02mL004SG00<0emL0I]L00`3Ge`0>e`80
2ML400cG0P0@e`802ML4013G00<0emL02ML004SG00<0emL0cmL004SG00<0emL0F]L400?GI@09e`00
B=L00`3Ge`1Le`030=OG00;G00<0e`000mL00`3Ge`02e`030=OG00;G00<0emL00]L00`3Ge`02e`03
0=OG00;G00D0emOG0004e`030=OG00;G00<0emL00]L00`3Ge`02e`030=OG00;G00D0emOG0004e`03
0=OG00;G00<0emL00]L00`3Ge`02e`030=OG00;G00D0emOG0004e`030=L000WG0018e`030=OG05cG
00<0emL00]L00`3Ge`0>e`030=OG00OG00<0emL01=L00`3Ge`04e`030=OG00?G00<0emL00mL00`3G
e`03e`030=OG00?G00<0emL01=L00`3Ge`07e`030=OG00oG00<0emL01mL004SG00<0emL0E=L400CG
00<0emL00]L00`3Ge`0>e`030=OG00OG00<0emL01=L00`3Ge`04e`030=OG00?G00<0emL00mL00`3G
e`03e`030=OG00?G00<0emL01=L00`3Ge`07e`030=OG00oG00<0emL01mL004SG00<0emL0G=L00`3G
e`02e`030=OG00gG00<0emL01mL00`3Ge`05e`030=OG00CG00<0emL00mL00`3Ge`03e`030=OG00?G
00<0emL00mL00`3Ge`05e`030=OG00OG00<0emL03]L00`3Ge`07e`00B=L00`3Ge`1Je`<01=L00`3G
e`0=e`030=OG00OG00<0emL01ML00`3Ge`04e`030=OG00?G00<0emL00mL00`3Ge`03e`030=OG00?G
00<0emL01ML00`3Ge`07e`030=OG00kG00<0emL01mL004SG00<0emL0G=L00`3Ge`02e`030=OG00gG
00<0emL01mL00`3Ge`04e`030=OG00CG00<0emL01=L00`3Ge`03e`030=OG00?G00<0emL01=L00`3G
e`04e`030=OG00OG00<0emL03]L00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG00gG00<0emL01mL00`3G
e`04e`030=OG00CG00<0emL01=L00`3Ge`03e`030=OG00?G00<0emL01=L00`3Ge`04e`030=OG00OG
00<0emL03]L00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG00cG00<0emL01mL00`3Ge`05e`030=OG00CG
00<0emL01=L00`3Ge`03e`030=OG00?G00<0emL01=L00`3Ge`05e`030=OG00OG00<0emL03ML00`3G
e`07e`00B=L00`3Ge`1Qe`030=OG00cG00<0emL01mL00`3Ge`05e`030=OG00CG00<0emL01=L00`3G
e`03e`030=OG00?G00<0emL01=L00`3Ge`05e`030=OG00OG0P0>e`030=OG00OG0018e`030=OG067G
00<0emL03=L00`3Ge`07e`030=OG00GG00<0emL01=L00`3Ge`04e`030=OG00?G00<0emL00mL00`3G
e`04e`030=OG00GG00<0emL02=L00`3Ge`0<e`030=OG00OG0018e`030=OG067G00<0emL02mL00`3G
e`08e`030=OG00GG00<0emL01=L00`3Ge`04e`030=OG00?G00<0emL00mL00`3Ge`04e`030=OG00GG
00<0emL02=L00`3Ge`0<e`030=OG00OG0018e`030=OG067G00<0emL02mL00`3Ge`08e`030=OG00GG
00<0emL01=L00`3Ge`04e`030=OG00?G00<0emL00mL00`3Ge`04e`030=OG00GG00<0emL02=L00`3G
e`0<e`030=OG00OG0018e`030=OG067G00<0emL02mL00`3Ge`07e`030=OG00GG00<0emL01ML00`3G
e`03e`030=OG00CG00<0emL01=L00`3Ge`04e`030=OG00GG00<0emL02=L00`3Ge`0;e`030=OG00OG
000fe`801=L00`3Ge`02e`@00mL00`3Ge`1Qe`030=OG00_G00<0emL01mL00`3Ge`05e`030=OG00GG
00<0emL00mL00`3Ge`04e`030=OG00CG00<0emL01=L00`3Ge`05e`030=OG00SG00<0emL02mL00`3G
e`07e`00=ML0103Ge`08e`030=OG00CG00<0emL0HML00`3Ge`0:e`030=OG00SG00<0emL01ML00`3G
e`05e`030=OG00?G00<0emL01=L00`3Ge`04e`030=OG00CG00<0emL01ML00`3Ge`08e`030=OG00_G
00<0emL01mL003GG00@0emL02ML00`3Ge`03e`030=OG067G00<0emL02]L00`3Ge`08e`030=OG00GG
00<0emL01ML00`3Ge`03e`030=OG00CG00<0emL01=L00`3Ge`04e`030=OG00GG00<0emL02=L00`3G
e`0;e`030=OG00OG000ee`040=OG00[G00<0emL00]L00`3Ge`1Qe`030=OG00[G00<0emL02=L00`3G
e`05e`030=OG00GG00<0emL00mL00`3Ge`04e`030=OG00CG00<0emL01=L00`3Ge`05e`030=OG00SG
00<0emL02mL00`3Ge`07e`00=ML0103Ge`0;e`050=OGe`00HmL00`3Ge`0:e`030=OG00SG00<0emL0
1ML00`3Ge`05e`030=OG00?G00<0emL01=L00`3Ge`04e`030=OG00CG00<0emL01ML00`3Ge`08e`03
0=OG00_G00<0emL01mL003GG00@0emL02=L0103Ge`03e`030=OG067G00<0emL02]L00`3Ge`08e`03
0=OG00GG00<0emL01ML00`3Ge`03e`030=OG00CG00<0emL01=L00`3Ge`04e`030=OG00GG00<0emL0
2=L00`3Ge`0;e`030=OG00OG000fe`802]L200CG00<0emL0HML00`3Ge`09e`030=OG00WG00<0emL0
1ML00`3Ge`05e`030=OG00?G00<0emL01=L00`3Ge`04e`030=OG00CG00<0emL01]L00`3Ge`08e`03
0=OG00[G00<0emL01mL004SG00<0emL0HML00`3Ge`09e`030=OG00WG00<0emL01ML00`3Ge`05e`03
0=OG00?G00<0emL01=L00`3Ge`04e`030=OG00CG00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL0
1mL004SG00<0emL0==L202_G00<0emL02ML00`3Ge`09e`030=OG00GG00<0emL01ML00`3Ge`03e`03
0=OG00CG00<0emL01=L00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0:e`030=OG00OG0018e`03
0=OG03GG00<0emL0:ML00`3Ge`09e`030=OG00WG00<0emL01ML00`3Ge`05e`030=OG00?G00<0emL0
1=L00`3Ge`04e`030=OG00CG00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL01mL004SG00<0emL0
HML00`3Ge`09e`030=OG00WG00<0emL01ML00`3Ge`05e`030=OG00?G00<0emL01=L00`3Ge`04e`03
0=OG00CG00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL01mL004SG00<0emL0CmL200CG00<0emL0
0]L300CG00<0emL02ML00`3Ge`09e`030=OG00GG00<0emL01ML00`3Ge`03e`030=OG00CG00<0emL0
1=L00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0:e`030=OG00OG0018e`030=OG04kG00@0emL0
2mL01@3GemL000_G00<0emL02ML00`3Ge`05e`030=OG00GG00<0emL00mL00`3Ge`04e`030=OG00CG
00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL02]L00`3Ge`07e`00B=L00`3Ge`1>e`040=OG00_G
00D0emOG000<e`030=OG00SG00<0emL01ML00`3Ge`05e`030=OG00?G00<0emL01=L00`3Ge`04e`03
0=OG00CG00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL01mL004SG00<0emL0B=L400;G00@0emL0
2=L300CG00<0emL02]L00`3Ge`08e`030=OG00GG00<0emL01ML00`3Ge`03e`030=OG00CG00<0emL0
1=L00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0:e`030=OG00OG0018e`030=OG04kG00@0emL0
2=L00`3Ge`04e`030=OG00[G00<0emL02=L00`3Ge`05e`030=OG00GG00<0emL00mL00`3Ge`04e`03
0=OG00CG00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL02]L00`3Ge`07e`00B=L00`3Ge`1>e`04
0=OG00SG00<0emL01=L00`3Ge`0:e`030=OG00SG00<0emL01ML00`3Ge`05e`030=OG00?G00<0emL0
1=L00`3Ge`04e`030=OG00CG00<0emL01]L00`3Ge`08e`030=OG00[G00<0emL01mL004SG00<0emL0
CmL200WG1003e`030=OG00[G00<0emL02=L00`3Ge`05e`030=OG00GG00<0emL00mL00`3Ge`04e`03
0=OG00CG00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL02]L00`3Ge`07e`00B=L00`3Ge`1Qe`03
0=OG00[G00<0emL02=L00`3Ge`05e`030=OG00GG00<0emL00mL00`3Ge`04e`030=OG00CG00<0emL0
1=L00`3Ge`06e`030=OG00SG00<0emL02]L00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG00[G00<0emL0
2=L00`3Ge`05e`030=OG00GG00<0emL00mL00`3Ge`04e`030=OG00CG00<0emL01=L00`3Ge`06e`03
0=OG00SG00<0emL02]L00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG00[G00<0emL02=L00`3Ge`06e`03
0=OG00CG00<0emL01=L00`3Ge`03e`030=OG00?G00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL0
2mL00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG00[G00<0emL02=L00`3Ge`06e`030=OG00CG00<0emL0
1=L00`3Ge`03e`030=OG00?G00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL02mL00`3Ge`07e`00
B=L00`3Ge`1Qe`030=OG00[G00<0emL02=L00`3Ge`06e`030=OG00CG00<0emL01=L00`3Ge`03e`03
0=OG00?G00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL02mL00`3Ge`07e`00=]L200CG00<0emL0
1=L00`3Ge`02e`030=OG067G00<0emL02]L00`3Ge`08e`030=OG00KG00<0emL01=L00`3Ge`04e`03
0=OG00?G00<0emL00mL00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0;e`030=OG00OG000ee`04
0=OG00[G00<0emL00]L00`3Ge`1Qe`030=OG00[G00<0emL02=L00`3Ge`06e`030=OG00CG00<0emL0
1=L00`3Ge`03e`030=OG00?G00<0emL01=L00`3Ge`06e`030=OG00SG00<0emL02mL00`3Ge`07e`00
=ML0103Ge`07e`D00mL00`3Ge`1Qe`030=OG00[G00<0emL02ML00`3Ge`06e`030=OG00CG00<0emL0
0mL00`3Ge`03e`030=OG00?G00<0emL01=L00`3Ge`05e`030=OG00WG00<0emL02mL00`3Ge`07e`00
=ML0103Ge`07e`040=OG00CG00<0emL0HML00`3Ge`0:e`030=OG00WG00<0emL01]L00`3Ge`04e`03
0=OG00?G00<0emL00mL00`3Ge`03e`030=OG00CG00<0emL01ML00`3Ge`09e`030=OG00_G00<0emL0
1mL003GG00@0emL02=L00`3G0004e`030=OG067G00<0emL02mL00`3Ge`08e`030=OG00KG00<0emL0
1=L00`3Ge`03e`030=OG00;G00<0emL00mL00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0<e`03
0=OG00OG000ee`040=OG00WG0P04e`030=OG067G00<0emL02mL00`3Ge`08e`030=OG00KG00<0emL0
1=L00`3Ge`03e`030=OG00;G00<0emL00mL00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0<e`03
0=OG00OG000fe`802mL00`3Ge`02e`030=OG067G00<0emL02mL00`3Ge`09e`030=OG00KG00<0emL0
1=L00`3Ge`02e`030=OG00;G00<0emL00mL00`3Ge`04e`030=OG00GG00<0emL02ML00`3Ge`0<e`03
0=OG00OG0018e`030=OG067G00<0emL02mL00`3Ge`09e`030=OG00KG00<0emL01=L00`3Ge`02e`03
0=OG00;G00<0emL00mL00`3Ge`04e`030=OG00GG00<0emL02=L200kG00<0emL01mL004SG00<0emL0
HML00`3Ge`0;e`030=OG00WG00<0emL01]L00`3Ge`04e`030=OG00;G00<0emL00]L00`3Ge`02e`03
0=OG00CG00<0emL01]L00`3Ge`08e`030=OG00gG00<0emL01mL004SG00<0emL0HML00`3Ge`0;e`03
0=OG00[G00<0emL01ML00`3Ge`04e`030=OG00;G00<0emL00]L00`3Ge`02e`030=OG00CG00<0emL0
1ML00`3Ge`09e`030=OG00gG00<0emL01mL004SG00<0emL0HML00`3Ge`0;e`030=OG00[G00<0emL0
1]L00`3Ge`04e`050=OGe`001=L00`3Ge`02e`030=OG00?G00<0emL01]L00`3Ge`09e`030=OG00gG
00<0emL01mL004SG00<0emL0HML00`3Ge`0<e`030=OG00WG00<0emL01]L00`3Ge`04e`030=OG00;G
00@0emL01=L00`3Ge`04e`030=OG00KG00<0emL02=L00`3Ge`0>e`030=OG00OG0018e`030=OG05_G
0P04e`030=OG00cG00<0emL02ML00`3Ge`06e`030=OG00CG00<0emL00]L0103Ge`04e`030=OG00CG
00<0emL01]L00`3Ge`08e`030=OG00kG00<0emL01mL004SG00<0emL0==L202CG00@0emL00mL00`3G
e`0<e`030=OG00[G00<0emL01]L00`3Ge`03e`030=OG00;G00@0emL01=L00`3Ge`03e`030=OG00KG
00<0emL02ML00`3Ge`0>e`030=OG00OG0018e`030=OG03GG00<0emL08]L0103Ge`03e`030=OG00gG
00<0emL02ML00`3Ge`06e`030=OG00CG00D0emOG0002e`030=OG00;G0`03e`H00mL400SG3005e`03
0=OG00OG0018e`030=OG05[G00@0emL00mL00`3Ge`0=e`030=OG00WG00<0emL01mL00`3Ge`04e`05
0=OGe`000]L200GG1005ea@01mL40003e`3G00SG0018e`030=OG05[G00@0emL00mL00`3Ge`0>e`03
0=OG00WG00<0emL01]L00`3Ge`05e`040=OGe`800]L200OG1@07eaP000?G0=L02=L004SG00<0emL0
F]L0103Ge`03e`030=OG00kG00<0emL02]L00`3Ge`06e`030=OG00GG00<0emL00]L200;G1@07e`d0
1mL;0003e`3G00SG0018e`030=OG05_G0P04e`030=OG00kG00<0emL02]L00`3Ge`07e`030=OG00GG
00<0emL00mL200GG3P06ea8000?G0=L02=L004SG00<0emL0HML00`3Ge`0>e`030=OG00_G00<0emL0
1mL00`3Ge`05e`030=OG00CG1@0>eaP000?G0=L02=L004SG00<0emL0HML00`3Ge`0?e`030=OG00[G
00<0emL01mL00`3Ge`06e`030=OG00SG9P000mL0e`08e`00B=L00`3Ge`1Qe`030=OG00oG00<0emL0
2mL00`3Ge`07e`030=OG00KG0`0^e`030=OG00OG000fe`801=L00`3Ge`03e`801=L00`3Ge`1Qe`03
0=OG013G00<0emL02mL00`3Ge`07e`030=OG00SG3P07eaP000?G0=L02=L003GG00@0emL02=L0103G
e`03e`030=OG067G00<0emL04=L00`3Ge`0<e`030=OG00OG0P0Fe`L06ML00`3Ge`07e`00=ML0103G
e`08e`040=OG00?G00<0emL0HML00`3Ge`0Ae`030=OG00_G00<0emL02ML203CG00<0emL01mL003GG
00@0emL02=L300CG00<0emL0HML00`3Ge`0Ae`030=OG00cG00<0emL02]L203;G00<0emL01mL003GG
00@0emL02=L00`3Ge`04e`030=OG067G00<0emL04]L00`3Ge`0<e`030=OG00_G00<0emL0;mL00`3G
e`07e`00=ML0103Ge`08e`030=OG00CG00<0emL0HML00`3Ge`0Be`030=OG00gG00<0emL02mL00`3G
e`0^e`030=OG00OG000fe`802]L300?G00<0emL0HML00`3Ge`0Ce`030=OG00gG00<0emL02mL302gG
00<0emL01mL004SG00<0emL0HML00`3Ge`0De`030=OG00gG00<0emL03ML602;G10000mL0e`08e`00
B=L00`3Ge`1Qe`030=OG01GG00<0emL03ML201?G1`0De`L01ML00`3Ge`07e`00B=L00`3Ge`1Qe`03
0=OG01KG00<0emL03]L00`3Ge`0Gea@03=L00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG01OG00<0emL0
3]L203OG00<0emL01mL004SG00<0emL0HML00`3Ge`0He`030=OG00oG0P0ee`030=OG00OG0018e`03
0=OG067G00<0emL06ML00`3Ge`0@e`80<mL00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG01WG00<0emL0
4]L3033G00<0emL01mL004SG00<0emL0CmL200CG00<0emL00]L300CG00<0emL06]L00`3Ge`0De`80
;]L00`3Ge`07e`00B=L00`3Ge`1>e`040=OG00_G00D0emOG000Me`805]L202OG10000mL0e`08e`00
B=L00`3Ge`1>e`040=OG00_G00D0emOG000Oe`030=OG01GG1@0Me`D01ML00`3Ge`07e`00B=L00`3G
e`1>e`040=OG00SG0`04e`030=OG01kG00<0emL06ML701;G100:e`030=OG00OG0018e`030=OG04kG
00@0emL02=L00`3Ge`04e`030=OG01oG0P0Pea803]L00`3Ge`07e`00B=L00`3Ge`0de`806=L0103G
e`08e`030=OG00CG00<0emL08ML00`3Ge`0me`030=OG00OG0018e`030=OG03GG00<0emL05mL200WG
1003e`030=OG027G0P0ne`030=OG00OG0018e`030=OG067G00<0emL08mL203cG00<0emL01mL003KG
0P04e`030=OG00?G0P04e`030=OG067G00<0emL09ML203[G00<0emL01mL003GG00@0emL02=L0103G
e`03e`030=OG067G00<0emL09mL303OG00<0emL01mL003GG00@0emL02=L0103Ge`03e`030=OG067G
00<0emL0:]L203;G0P000mL0e`08e`00=ML0103Ge`09e`801=L00`3Ge`1Qe`030=OG02cG0P0]e`<0
0mL00`3Ge`07e`00=ML0103Ge`08e`040=OG00?G00<0emL0HML00`3Ge`0^e`@09mL200KG00<0emL0
1mL003GG00@0emL02=L0103Ge`03e`030=OG067G00<0emL0<]L302;G0P08e`030=OG00OG000fe`80
2]L200CG00<0emL0HML00`3Ge`0ee`D06ML400[G00<0emL01mL004SG00<0emL0HML00`3Ge`0jeaT0
3]L00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG067G00<0emL01mL004SG00<0emL0HML00`3Ge`1Qe`03
0=OG00OG0018e`030=OG067G00<0emL0HML00`3Ge`07e`00B=L00`3Ge`1Qe`030=OG067G00<0emL0
1mL004SG00<0emL0HML00`3Ge`1Qe`030=OG00OG0018e`030=OG067G00<0emL0HML00`3Ge`07e`00
B=L00`3Ge`1Qe`030=OG067G00<0emL01mL004SG00<0emL0HML00`3Ge`1Qe`030=OG00OG0018e`03
0=OG05[G1003e`030=OG067G00<0emL01mL004SG00<0emL0G=L00`3Ge`02e`030=OG067G00<0emL0
1mL004SG00<0emL0G=L00`3Ge`02e`030=OG067G00<0emL01mL004SG00<0emL0G=L00`3Ge`02e`03
0=L001OG00<0emL05ML00`3Ge`0Ee`030=OG01GG00<0e`002ML004SG00<0emL0G=L00`3Ge`02efD0
2ML004SG00<0emL0F]L307;G0018e`030=OG05cG00<0emL0L=L0047G1003e`030=OG0<oG0013e`03
0=OG00;G00<0emL0cmL000oG0P0Je`805]L0103GemL201[G0P0Je`80VML0013G00<0emL06ML00`3G
e`0De`030=OG00;G00<0emL06ML00`3Ge`0Ie`030=OG09OG0013e`030=OG00;G00<0emL0cmL0047G
0`04e`030=OG0<oG0013e`030=OG0=CG003oea_G003oea_G003oea_G0000\
\>"],
  ImageRangeCache->{{{0, 281}, {133.25, 0}} -> {-0.0544185, -0.0238146, \
0.00750477, 0.00750477}, {{7.25, 134.125}, {130.062, 3.125}} -> {-1.28944, \
-0.121979, 0.0178624, 0.00893121}, {{146.812, 273.75}, {130.062, 3.125}} -> \
{-4.59724, -1.45751, 0.0206732, 0.0206732}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(* Definition of r(x,y) and f=phi(x,y) for the
plot in cartesian coordinates *)Clear[r,f,plot2,plot3]
r[x_,y_]:=N[Sqrt[x^2+y^2]]
f[x_,y_]:=N[ArcTan[x,y]] /;y>=0 ; 
f[x_,y_]:=2*Pi+N[ArcTan[x,y]] /; y<0
plot3=Plot3D[Sum[A[k]*BesselJ[2*(2*k-1)/3,3*r[x,y]]*
Sin[2*(2*k-1)*f[x,y]/3],{k,1,8}],
{x,-1.1,1.1},{y,-1.1,1.1}, PlotRange->{0.,1.05},
PlotPoints->30,Mesh->False,ClipFill->None] \
\>", "Input",
  FontSize->18],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.054 .23578 -12 -8.77849 ]
[.054 .23578 0 .22151 ]
[.19044 .18208 -23.484 -9 ]
[.19044 .18208 .51596 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.48682 .06553 -15.9072 -9 ]
[.48682 .06553 2.09282 0 ]
[.64814 .00214 -5.01809 -9 ]
[.64814 .00214 .98191 0 ]
[.71662 .0192 0 -6.23824 ]
[.71662 .0192 12 2.76176 ]
[.79014 .13178 0 -6.12821 ]
[.79014 .13178 24 2.87179 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.91668 .32556 0 -5.94523 ]
[.91668 .32556 18 3.05477 ]
[.97152 .40955 0 -5.86834 ]
[.97152 .40955 6 3.13166 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01654 .31258 -24 -2.78245 ]
[.01654 .31258 0 6.21755 ]
[.00784 .36708 -18 -2.82867 ]
[.00784 .36708 0 6.17133 ]
[-0.00116 .42352 -24 -2.8767 ]
[-0.00116 .42352 0 6.1233 ]
[-0.01049 .48199 -6 -2.92665 ]
[-0.01049 .48199 0 6.07335 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.06351 .24482 m
.06826 .24934 L
s
[(-1)] .054 .23578 1 .95078 Mshowa
.19951 .19156 m
.20405 .1963 L
s
[(-0.5)] .19044 .18208 .957 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.49481 .07594 m
.4988 .08114 L
s
[(0.5)] .48682 .06553 .76746 1 Mshowa
.65547 .01303 m
.65913 .01847 L
s
[(1)] .64814 .00214 .6727 1 Mshowa
.125 Mabswid
.09013 .23439 m
.09296 .23713 L
s
.11704 .22386 m
.11985 .22662 L
s
.14424 .21321 m
.14702 .216 L
s
.17173 .20244 m
.17448 .20526 L
s
.2276 .18057 m
.23029 .18344 L
s
.25599 .16945 m
.25866 .17235 L
s
.2847 .15821 m
.28733 .16113 L
s
.31372 .14684 m
.31632 .1498 L
s
.37274 .12374 m
.37527 .12675 L
s
.40274 .11199 m
.40524 .11502 L
s
.43308 .10011 m
.43555 .10317 L
s
.46377 .08809 m
.4662 .09118 L
s
.5262 .06364 m
.52856 .0668 L
s
.55796 .05121 m
.56028 .05439 L
s
.59008 .03863 m
.59236 .04184 L
s
.62258 .0259 m
.62482 .02914 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.70438 .02393 m
.69826 .0263 L
s
[(-1)] .71662 .0192 -1 .38628 Mshowa
.7778 .13624 m
.77163 .13848 L
s
[(-0.5)] .79014 .13178 -1 .36182 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.90419 .32957 m
.89794 .33158 L
s
[(0.5)] .91668 .32556 -1 .32116 Mshowa
.95897 .41336 m
.95269 .41527 L
s
[(1)] .97152 .40955 -1 .30408 Mshowa
.125 Mabswid
.71969 .04735 m
.71602 .04876 L
s
.73468 .07028 m
.731 .07167 L
s
.74936 .09273 m
.74567 .0941 L
s
.76373 .11471 m
.76003 .11606 L
s
.7916 .15734 m
.78789 .15866 L
s
.80511 .17801 m
.8014 .17932 L
s
.81836 .19827 m
.81464 .19957 L
s
.83134 .21814 m
.82762 .21942 L
s
.85656 .25671 m
.85283 .25797 L
s
.86881 .27545 m
.86507 .27669 L
s
.88083 .29383 m
.87709 .29506 L
s
.89262 .31187 m
.88887 .31308 L
s
.91555 .34695 m
.9118 .34814 L
s
.9267 .364 m
.92295 .36518 L
s
.93765 .38075 m
.93389 .38192 L
s
.94841 .39721 m
.94464 .39836 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.0288 .30791 m
.03493 .30557 L
s
[(0.25)] .01654 .31258 1 -0.38168 Mshowa
.02014 .36251 m
.02629 .36023 L
s
[(0.5)] .00784 .36708 1 -0.37141 Mshowa
.01118 .41906 m
.01735 .41684 L
s
[(0.75)] -0.00116 .42352 1 -0.36073 Mshowa
.0019 .47766 m
.00809 .47549 L
s
[(1)] -0.01049 .48199 1 -0.34963 Mshowa
.125 Mabswid
.03551 .26555 m
.03918 .26412 L
s
.03385 .27603 m
.03752 .27461 L
s
.03218 .28658 m
.03585 .28517 L
s
.03049 .29721 m
.03417 .2958 L
s
.02709 .31868 m
.03077 .31728 L
s
.02537 .32952 m
.02906 .32813 L
s
.02364 .34044 m
.02733 .33906 L
s
.0219 .35144 m
.02559 .35006 L
s
.01838 .37367 m
.02207 .3723 L
s
.0166 .3849 m
.02029 .38354 L
s
.01481 .3962 m
.0185 .39485 L
s
.013 .40759 m
.0167 .40625 L
s
.00935 .43061 m
.01306 .42929 L
s
.00751 .44225 m
.01122 .44093 L
s
.00565 .45397 m
.00936 .45265 L
s
.00378 .46577 m
.00749 .46446 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.44831 .57287 .45863 .5829 .47361 .79131 .46641 .56738 Mtetra
.014 0 .444 r
.46641 .56738 .47361 .79131 .49288 .78626 .48206 .77686 Mtetra
.95 .712 .543 r
.56088 .75604 .57133 .76572 .58729 .54419 .57774 .54604 Mtetra
.837 .995 .846 r
.57774 .54604 .58729 .54419 .60617 .53851 .59651 .52792 Mtetra
.69 .217 0 r
.65419 .51043 .66359 .52123 .68299 .5154 .6753 .54072 Mtetra
.91 .599 .443 r
.6753 .54072 .68299 .5154 .71419 .72832 .70445 .71814 Mtetra
.975 .717 .479 r
.78988 .69558 .79918 .70608 .80226 .47951 .79354 .46816 Mtetra
.95 .605 .216 r
.89738 .43667 .90557 .44843 .92668 .44208 .94573 .65443 Mtetra
.561 .337 .533 r
.94573 .65443 .92668 .44208 .977 .65952 .96868 .64837 Mtetra
.664 .741 .907 r
.45604 .55715 .46641 .56738 .48206 .77686 .47434 .55156 Mtetra
.014 0 .444 r
.47434 .55156 .48206 .77686 .50156 .77171 .49069 .76211 Mtetra
.645 .763 .934 r
.5503 .74623 .56088 .75604 .57774 .54604 .57046 .74087 Mtetra
0 0 .319 r
.57046 .74087 .57774 .54604 .59651 .52792 .58672 .5172 Mtetra
.962 .638 .349 r
.64467 .49948 .65419 .51043 .6753 .54072 .67155 .66709 Mtetra
.641 .388 .52 r
.67155 .66709 .6753 .54072 .70445 .71814 .69457 .70781 Mtetra
.95 .771 .626 r
.75874 .69072 .76828 .70128 .78988 .69558 .77602 .62422 Mtetra
.873 .626 .562 r
.77602 .62422 .78988 .69558 .79354 .46816 .7847 .45666 Mtetra
.95 .605 .216 r
.88907 .42475 .89738 .43667 .94573 .65443 .93716 .6432 Mtetra
.95 .621 .367 r
.46392 .54114 .47434 .55156 .49069 .76211 .48111 .63895 Mtetra
.065 .024 .496 r
.48111 .63895 .49069 .76211 .51041 .75686 .49949 .74706 Mtetra
.953 .712 .535 r
.55982 .73085 .57046 .74087 .58672 .5172 .57681 .50634 Mtetra
.964 .649 .373 r
.63503 .48839 .64467 .49948 .67155 .66709 .66338 .70303 Mtetra
.485 .174 .363 r
.66338 .70303 .67155 .66709 .69457 .70781 .68456 .69734 Mtetra
.973 .717 .486 r
.74906 .68001 .75874 .69072 .77602 .62422 .75521 .45134 Mtetra
.584 .398 .596 r
.75521 .45134 .77602 .62422 .7847 .45666 .77574 .44501 Mtetra
.954 .611 .233 r
.85937 .41924 .8679 .43123 .88907 .42475 .90543 .638 Mtetra
.557 .331 .528 r
.90543 .638 .88907 .42475 .93716 .6432 .92847 .63181 Mtetra
0 0 .22 r
.35203 .77409 .3733 .56907 .39118 .56356 .38033 .55328 Mtetra
.664 .741 .907 r
.45338 .53058 .46392 .54114 .48111 .63895 .47195 .52481 Mtetra
.731 .548 0 r
.47195 .52481 .48111 .63895 .49949 .74706 .48842 .73713 Mtetra
.953 .712 .535 r
.54904 .7207 .55982 .73085 .57681 .50634 .56677 .49534 Mtetra
.964 .649 .373 r
.62526 .47716 .63503 .48839 .66338 .70303 .65312 .69249 Mtetra
.973 .717 .486 r
.73924 .66915 .74906 .68001 .75521 .45134 .74603 .43962 Mtetra
.954 .611 .233 r
.85072 .40708 .85937 .41924 .90543 .638 .89648 .62654 Mtetra
.645 .763 .934 r
.34019 .76452 .35203 .77409 .38033 .55328 .35934 .75929 Mtetra
0 0 .22 r
.35934 .75929 .38033 .55328 .39841 .54767 .38749 .53719 Mtetra
.664 .741 .907 r
.46136 .51404 .47195 .52481 .48842 .73713 .48015 .50816 Mtetra
.001 0 .437 r
.48015 .50816 .48842 .73713 .50848 .73169 .49736 .72155 Mtetra
.953 .713 .538 r
.53811 .71041 .54904 .7207 .56677 .49534 .55672 .49654 Mtetra
.842 .99 .856 r
.55672 .49654 .56677 .49534 .58613 .48932 .57606 .4781 Mtetra
.964 .649 .373 r
.61537 .46578 .62526 .47716 .65312 .69249 .64271 .68181 Mtetra
.961 .75 .574 r
.7074 .66412 .71747 .67505 .73924 .66915 .72385 .56547 Mtetra
.809 .572 .58 r
.72385 .56547 .73924 .66915 .74603 .43962 .73673 .42774 Mtetra
.957 .616 .248 r
.82061 .40146 .82948 .41369 .85072 .40708 .86428 .62123 Mtetra
.553 .324 .523 r
.86428 .62123 .85072 .40708 .89648 .62654 .8874 .61491 Mtetra
.645 .763 .934 r
.34742 .74952 .35934 .75929 .38749 .53719 .3668 .74417 Mtetra
.267 .086 .44 r
.3668 .74417 .38749 .53719 .40577 .53146 .39075 .62477 Mtetra
0 0 .122 r
.39075 .62477 .40577 .53146 .42417 .5257 .41328 .51495 Mtetra
.955 .649 .414 r
.4695 .49718 .48015 .50816 .49736 .72155 .48658 .66592 Mtetra
.188 .181 .619 r
.48658 .66592 .49736 .72155 .51766 .716 .50648 .70564 Mtetra
.847 .788 .794 r
.50648 .70564 .51766 .716 .53811 .71041 .52702 .6817 Mtetra
.899 .682 .599 r
.52702 .6817 .53811 .71041 .55672 .49654 .54694 .57084 Mtetra
0 0 .255 r
.54694 .57084 .55672 .49654 .57606 .4781 .56617 .49241 Mtetra
.319 0 .052 r
.56617 .49241 .57606 .4781 .59564 .47196 .58601 .48693 Mtetra
.871 .524 .392 r
.58601 .48693 .59564 .47196 .61537 .46578 .60793 .5595 Mtetra
.761 .479 .505 r
.60793 .5595 .61537 .46578 .64271 .68181 .63216 .67097 Mtetra
.968 .731 .524 r
.69718 .65304 .7074 .66412 .72385 .56547 .71085 .49802 Mtetra
.799 .58 .605 r
.71085 .49802 .72385 .56547 .73673 .42774 .7273 .41571 Mtetra
.881 .481 .033 r
.7903 .3958 .79941 .4081 .82061 .40146 .81909 .47278 Mtetra
.82 .506 .459 r
.81909 .47278 .82061 .40146 .86428 .62123 .85494 .60952 Mtetra
.645 .763 .934 r
.35481 .7342 .3668 .74417 .39075 .62477 .37442 .72875 Mtetra
.533 .283 .482 r
.37442 .72875 .39075 .62477 .41328 .51495 .39417 .72325 Mtetra
0 0 .232 r
.39417 .72325 .41328 .51495 .43189 .50906 .42094 .4981 Mtetra
0 .012 .516 r
.43976 .4921 .45063 .50314 .4695 .49718 .45822 .5104 Mtetra
.896 .58 .441 r
.45822 .5104 .4695 .49718 .48658 .66592 .47585 .61647 Mtetra
0 0 .537 r
.47585 .61647 .48658 .66592 .50648 .70564 .49538 .66708 Mtetra
.666 .542 .704 r
.49538 .66708 .50648 .70564 .52702 .6817 .51589 .65404 Mtetra
.825 .659 .677 r
.51589 .65404 .52702 .6817 .54694 .57084 .53637 .60985 Mtetra
.045 0 .186 r
.53637 .60985 .54694 .57084 .56617 .49241 .55662 .57451 Mtetra
.544 .282 .468 r
.55662 .57451 .56617 .49241 .58601 .48693 .57719 .5735 Mtetra
.657 .382 .492 r
.57719 .5735 .58601 .48693 .60793 .5595 .59882 .6112 Mtetra
.727 .42 .459 r
.59882 .6112 .60793 .5595 .63216 .67097 .62146 .65998 Mtetra
.966 .738 .543 r
.68682 .64179 .69718 .65304 .71085 .49802 .70239 .51238 Mtetra
.997 .812 .456 r
.70239 .51238 .71085 .49802 .7273 .41571 .71775 .40351 Mtetra
.848 .432 0 r
.75981 .3901 .76915 .40248 .7903 .3958 .78661 .45253 Mtetra
.855 .533 .441 r
.78661 .45253 .7903 .3958 .81909 .47278 .82225 .60409 Mtetra
.539 .296 .495 r
.82225 .60409 .81909 .47278 .85494 .60952 .84545 .59764 Mtetra
.645 .763 .934 r
.38219 .71299 .39417 .72325 .42094 .4981 .40218 .70738 Mtetra
.46 .242 .495 r
.40218 .70738 .42094 .4981 .43976 .4921 .42365 .65621 Mtetra
.446 .224 .482 r
.42365 .65621 .43976 .4921 .45822 .5104 .44459 .6115 Mtetra
.605 .344 .495 r
.44459 .6115 .45822 .5104 .47585 .61647 .4641 .63093 Mtetra
.707 .307 .287 r
.4641 .63093 .47585 .61647 .49538 .66708 .48406 .65015 Mtetra
.582 .638 .871 r
.48406 .65015 .49538 .66708 .51589 .65404 .50459 .64819 Mtetra
.823 .877 .884 r
.50459 .64819 .51589 .65404 .53637 .60985 .52532 .63136 Mtetra
.163 0 .07 r
.52532 .63136 .53637 .60985 .55662 .57451 .54609 .61622 Mtetra
.525 .213 .38 r
.54609 .61622 .55662 .57451 .57719 .5735 .56708 .61584 Mtetra
.633 .315 .414 r
.56708 .61584 .57719 .5735 .59882 .6112 .58863 .63282 Mtetra
.658 .276 .31 r
.58863 .63282 .59882 .6112 .62146 .65998 .6106 .64884 Mtetra
.801 .801 .851 r
.65424 .63658 .66486 .6479 .68682 .64179 .67582 .61923 Mtetra
.902 .71 .633 r
.67582 .61923 .68682 .64179 .70239 .51238 .69487 .55086 Mtetra
0 0 .026 r
.69487 .55086 .70239 .51238 .71775 .40351 .71355 .48732 Mtetra
.469 .219 .452 r
.71355 .48732 .71775 .40351 .7387 .39683 .73446 .4681 Mtetra
.738 .435 .468 r
.73446 .4681 .7387 .39683 .75981 .3901 .7617 .53872 Mtetra
.65 .386 .507 r
.7617 .53872 .75981 .3901 .78661 .45253 .78934 .59863 Mtetra
.539 .297 .498 r
.78934 .59863 .78661 .45253 .82225 .60409 .81249 .59213 Mtetra
.645 .763 .934 r
.39014 .6969 .40218 .70738 .42365 .65621 .41037 .69117 Mtetra
0 0 .057 r
.41037 .69117 .42365 .65621 .44459 .6115 .43152 .65723 Mtetra
.423 .125 .352 r
.43152 .65723 .44459 .6115 .4641 .63093 .45203 .64516 Mtetra
.512 .072 .14 r
.45203 .64516 .4641 .63093 .48406 .65015 .47238 .64859 Mtetra
.14 .679 .84 r
.47238 .64859 .48406 .65015 .50459 .64819 .49304 .64805 Mtetra
.472 .889 .916 r
.49304 .64805 .50459 .64819 .52532 .63136 .51394 .64102 Mtetra
.058 0 0 r
.51394 .64102 .52532 .63136 .54609 .61622 .53499 .63316 Mtetra
.404 0 .116 r
.53499 .63316 .54609 .61622 .56708 .61584 .55622 .63049 Mtetra
.52 .08 .142 r
.55622 .63049 .56708 .61584 .58863 .63282 .57777 .63462 Mtetra
.263 0 0 r
.57777 .63462 .58863 .63282 .6106 .64884 .59959 .63753 Mtetra
.782 .798 .866 r
.64346 .62509 .65424 .63658 .67582 .61923 .66527 .60957 Mtetra
.88 .829 .793 r
.66527 .60957 .67582 .61923 .69487 .55086 .68658 .5822 Mtetra
.367 .036 .266 r
.68658 .5822 .69487 .55086 .71355 .48732 .70861 .57001 Mtetra
.635 .351 .47 r
.70861 .57001 .71355 .48732 .73446 .4681 .73329 .59963 Mtetra
.533 .287 .488 r
.73329 .59963 .73446 .4681 .7617 .53872 .75621 .59313 Mtetra
.494 .204 .401 r
.75621 .59313 .7617 .53872 .78934 .59863 .7793 .58659 Mtetra
.547 .355 .572 r
.29385 .49488 .29121 .72494 .3107 .71942 .31146 .50138 Mtetra
0 0 .346 r
.31146 .50138 .3107 .71942 .33034 .71385 .31785 .70347 Mtetra
.843 .782 .793 r
.37793 .68628 .39014 .6969 .41037 .69117 .39892 .66206 Mtetra
.746 .62 .719 r
.39892 .66206 .41037 .69117 .43152 .65723 .41982 .63906 Mtetra
.562 .616 .864 r
.41982 .63906 .43152 .65723 .45203 .64516 .44013 .63811 Mtetra
.089 .564 .905 r
.44013 .63811 .45203 .64516 .47238 .64859 .46055 .64298 Mtetra
.235 .686 .953 r
.46055 .64298 .47238 .64859 .49304 .64805 .4813 .64444 Mtetra
.46 .843 .985 r
.4813 .64444 .49304 .64805 .51394 .64102 .50233 .64043 Mtetra
.489 .895 .93 r
.50233 .64043 .51394 .64102 .53499 .63316 .52356 .63329 Mtetra
.438 .874 .896 r
.52356 .63329 .53499 .63316 .55622 .63049 .54493 .62632 Mtetra
.521 .863 .993 r
.54493 .62632 .55622 .63049 .57777 .63462 .56649 .62121 Mtetra
.605 .712 .92 r
.56649 .62121 .57777 .63462 .59959 .63753 .58825 .61719 Mtetra
.63 .633 .835 r
.58825 .61719 .59959 .63753 .62144 .63134 .61018 .61185 Mtetra
.671 .661 .832 r
.61018 .61185 .62144 .63134 .64346 .62509 .6322 .60343 Mtetra
.68 .645 .809 r
.6322 .60343 .64346 .62509 .66527 .60957 .65432 .59366 Mtetra
.605 .679 .893 r
.65432 .59366 .66527 .60957 .68658 .5822 .67684 .58979 Mtetra
.45 0 0 r
.67684 .58979 .68658 .5822 .70861 .57001 .69999 .59414 Mtetra
.394 .018 .202 r
.69999 .59414 .70861 .57001 .73329 .59963 .72285 .5876 Mtetra
.664 .741 .907 r
.28192 .48373 .29385 .49488 .31146 .50138 .30041 .47763 Mtetra
.641 .587 .778 r
.30041 .47763 .31146 .50138 .31785 .70347 .31903 .47149 Mtetra
.567 .369 .573 r
.31903 .47149 .31785 .70347 .33773 .69778 .33778 .4653 Mtetra
.33778 .4653 .33773 .69778 .35775 .69205 .35667 .45907 Mtetra
.546 .353 .571 r
.35667 .45907 .35775 .69205 .37793 .68628 .37512 .46525 Mtetra
.375 .222 .541 r
.37512 .46525 .37793 .68628 .39892 .66206 .39092 .54515 Mtetra
.373 .247 .577 r
.39092 .54515 .39892 .66206 .41982 .63906 .40907 .5894 Mtetra
.273 .254 .655 r
.40907 .5894 .41982 .63906 .44013 .63811 .42846 .61602 Mtetra
.164 .349 .802 r
.42846 .61602 .44013 .63811 .46055 .64298 .44865 .63076 Mtetra
.318 .597 .946 r
.44865 .63076 .46055 .64298 .4813 .64444 .46942 .63526 Mtetra
.583 .782 .974 r
.46942 .63526 .4813 .64444 .50233 .64043 .49057 .63117 Mtetra
.719 .818 .927 r
.49057 .63117 .50233 .64043 .52356 .63329 .51193 .62106 Mtetra
.752 .775 .871 r
.51193 .62106 .52356 .63329 .54493 .62632 .53339 .60793 Mtetra
.729 .692 .815 r
.53339 .60793 .54493 .62632 .56649 .62121 .55494 .5944 Mtetra
.687 .609 .764 r
.55494 .5944 .56649 .62121 .58825 .61719 .57659 .58219 Mtetra
.651 .551 .729 r
.57659 .58219 .58825 .61719 .61018 .61185 .59838 .57197 Mtetra
.625 .519 .714 r
.59838 .57197 .61018 .61185 .6322 .60343 .62036 .56421 Mtetra
.591 .501 .722 r
.62036 .56421 .6322 .60343 .65432 .59366 .64266 .56096 Mtetra
.485 .466 .762 r
.64266 .56096 .65432 .59366 .67684 .58979 .66558 .56734 Mtetra
.237 .396 .819 r
.66558 .56734 .67684 .58979 .69999 .59414 .68926 .58202 Mtetra
.664 .741 .907 r
.3449 .44745 .35667 .45907 .37512 .46525 .364 .4411 Mtetra
.006 .209 .72 r
.364 .4411 .37512 .46525 .39092 .54515 .38212 .46059 Mtetra
0 0 .392 r
.38212 .46059 .39092 .54515 .40907 .5894 .3981 .54843 Mtetra
0 0 .462 r
.3981 .54843 .40907 .5894 .42846 .61602 .41664 .59549 Mtetra
0 .122 .673 r
.41664 .59549 .42846 .61602 .44865 .63076 .43662 .61759 Mtetra
.304 .574 .935 r
.43662 .61759 .44865 .63076 .46942 .63526 .45742 .62283 Mtetra
.664 .749 .914 r
.45742 .62283 .46942 .63526 .49057 .63117 .4787 .61577 Mtetra
.765 .735 .825 r
.4787 .61577 .49057 .63117 .51193 .62106 .5002 .59979 Mtetra
.775 .683 .762 r
.5002 .59979 .51193 .62106 .53339 .60793 .52175 .57823 Mtetra
.747 .624 .722 r
.52175 .57823 .53339 .60793 .55494 .5944 .54326 .55503 Mtetra
.703 .566 .697 r
.54326 .55503 .55494 .5944 .57659 .58219 .56477 .53459 Mtetra
.656 .517 .683 r
.56477 .53459 .57659 .58219 .59838 .57197 .58637 .51971 Mtetra
.616 .483 .676 r
.58637 .51971 .59838 .57197 .62036 .56421 .60818 .5109 Mtetra
.575 .454 .678 r
.60818 .5109 .62036 .56421 .64266 .56096 .63036 .50885 Mtetra
.507 .413 .683 r
.63036 .50885 .64266 .56096 .66558 .56734 .65313 .51627 Mtetra
.375 .33 .68 r
.65313 .51627 .66558 .56734 .68926 .58202 .67693 .53803 Mtetra
.299 .303 .695 r
.67693 .53803 .68926 .58202 .71224 .57539 .70148 .56299 Mtetra
.581 .079 0 r
.35216 .42924 .364 .4411 .38212 .46059 .37022 .44943 Mtetra
.947 .609 .346 r
.37022 .44943 .38212 .46059 .3981 .54843 .38575 .54192 Mtetra
.9 .492 .209 r
.38575 .54192 .3981 .54843 .41664 .59549 .4042 .58969 Mtetra
.684 .141 0 r
.4042 .58969 .41664 .59549 .43662 .61759 .42426 .60953 Mtetra
.35 .708 .985 r
.42426 .60953 .43662 .61759 .45742 .62283 .44525 .61045 Mtetra
.752 .773 .87 r
.44525 .61045 .45742 .62283 .4787 .61577 .46674 .59721 Mtetra
.804 .713 .764 r
.46674 .59721 .4787 .61577 .5002 .59979 .48842 .57278 Mtetra
.8 .66 .708 r
.48842 .57278 .5002 .59979 .52175 .57823 .51009 .53996 Mtetra
.772 .607 .675 r
.51009 .53996 .52175 .57823 .54326 .55503 .53158 .50352 Mtetra
.717 .547 .659 r
.53158 .50352 .54326 .55503 .56477 .53459 .5529 .47289 Mtetra
.652 .49 .652 r
.5529 .47289 .56477 .53459 .58637 .51971 .57426 .4541 Mtetra
.609 .457 .649 r
.57426 .4541 .58637 .51971 .60818 .5109 .59582 .44403 Mtetra
.578 .434 .649 r
.59582 .44403 .60818 .5109 .63036 .50885 .61768 .44026 Mtetra
.542 .408 .648 r
.61768 .44026 .63036 .50885 .65313 .51627 .64 .44327 Mtetra
.494 .371 .641 r
.64 .44327 .65313 .51627 .67693 .53803 .66301 .4552 Mtetra
.439 .324 .626 r
.66301 .4552 .67693 .53803 .70148 .56299 .68704 .47903 Mtetra
.354 .266 .616 r
.68704 .47903 .70148 .56299 .72478 .5562 .71254 .51787 Mtetra
.343 .356 .73 r
.71254 .51787 .72478 .5562 .74827 .54935 .73761 .53656 Mtetra
.95 .62 .366 r
.34015 .41722 .35216 .42924 .37022 .44943 .35412 .51715 Mtetra
.719 .425 .479 r
.35412 .51715 .37022 .44943 .38575 .54192 .37142 .57447 Mtetra
.695 .353 .392 r
.37142 .57447 .38575 .54192 .4042 .58969 .39084 .60133 Mtetra
.548 .077 .089 r
.39084 .60133 .4042 .58969 .42426 .60953 .41148 .60821 Mtetra
.575 .923 .958 r
.41148 .60821 .42426 .60953 .44525 .61045 .43286 .59983 Mtetra
.834 .806 .823 r
.43286 .59983 .44525 .61045 .46674 .59721 .45466 .57811 Mtetra
.842 .717 .726 r
.45466 .57811 .46674 .59721 .48842 .57278 .47661 .54395 Mtetra
.833 .665 .675 r
.47661 .54395 .48842 .57278 .51009 .53996 .49847 .49786 Mtetra
.815 .622 .642 r
.49847 .49786 .51009 .53996 .53158 .50352 .52002 .44023 Mtetra
.742 .547 .631 r
.52002 .44023 .53158 .50352 .5529 .47289 .54112 .39278 Mtetra
.621 .449 .628 r
.54112 .39278 .5529 .47289 .57426 .4541 .56221 .3767 Mtetra
.595 .433 .632 r
.56221 .3767 .57426 .4541 .59582 .44403 .58348 .3678 Mtetra
.584 .426 .634 r
.58348 .3678 .59582 .44403 .61768 .44026 .60496 .36165 Mtetra
.572 .416 .632 r
.60496 .36165 .61768 .44026 .64 .44327 .6267 .3579 Mtetra
.558 .401 .625 r
.6267 .3579 .64 .44327 .66301 .4552 .64877 .35706 Mtetra
.543 .383 .614 r
.64877 .35706 .66301 .4552 .68704 .47903 .67128 .3599 Mtetra
.53 .364 .6 r
.67128 .3599 .68704 .47903 .71254 .51787 .69434 .36723 Mtetra
.521 .347 .587 r
.69434 .36723 .71254 .51787 .73761 .53656 .71811 .37972 Mtetra
.507 .337 .585 r
.71811 .37972 .73761 .53656 .76144 .52955 .74275 .39821 Mtetra
.475 .322 .594 r
.74275 .39821 .76144 .52955 .78546 .52248 .76856 .42452 Mtetra
.39 .282 .609 r
.76856 .42452 .78546 .52248 .80969 .51535 .7961 .46338 Mtetra
.291 .279 .674 r
.7961 .46338 .80969 .51535 .83412 .50816 .82387 .49472 Mtetra
.852 .398 .016 r
.23259 .43765 .24516 .4494 .26389 .44306 .24829 .46816 Mtetra
.876 .582 .486 r
.24829 .46816 .26389 .44306 .28275 .43667 .25644 .6019 Mtetra
.615 .358 .505 r
.25644 .6019 .28275 .43667 .30175 .43023 .27306 .6432 Mtetra
.526 .285 .492 r
.27306 .6432 .30175 .43023 .32088 .42375 .29356 .63705 Mtetra
.29356 .63705 .32088 .42375 .34015 .41722 .31421 .63086 Mtetra
.31421 .63086 .34015 .41722 .35412 .51715 .33503 .62461 Mtetra
.508 .245 .451 r
.33503 .62461 .35412 .51715 .37142 .57447 .35601 .61832 Mtetra
.447 .124 .324 r
.35601 .61832 .37142 .57447 .39084 .60133 .37716 .61197 Mtetra
.108 0 0 r
.37716 .61197 .39084 .60133 .41148 .60821 .39848 .60558 Mtetra
.792 .945 .924 r
.39848 .60558 .41148 .60821 .43286 .59983 .42024 .59018 Mtetra
.88 .811 .777 r
.42024 .59018 .43286 .59983 .45466 .57811 .44241 .56018 Mtetra
.871 .73 .703 r
.44241 .56018 .45466 .57811 .47661 .54395 .46469 .51771 Mtetra
.864 .686 .659 r
.46469 .51771 .47661 .54395 .49847 .49786 .48684 .46135 Mtetra
.859 .655 .625 r
.48684 .46135 .49847 .49786 .52002 .44023 .5086 .38684 Mtetra
.772 .577 .636 r
.5086 .38684 .52002 .44023 .54112 .39278 .52968 .3361 Mtetra
.599 .459 .663 r
.52968 .3361 .54112 .39278 .56221 .3767 .5507 .32891 Mtetra
.607 .482 .684 r
.5507 .32891 .56221 .3767 .58348 .3678 .57187 .32168 Mtetra
.609 .488 .689 r
.57187 .32168 .58348 .3678 .60496 .36165 .59321 .31438 Mtetra
.608 .485 .686 r
.59321 .31438 .60496 .36165 .6267 .3579 .61472 .30703 Mtetra
.605 .475 .677 r
.61472 .30703 .6267 .3579 .64877 .35706 .63639 .29962 Mtetra
.599 .459 .663 r
.63639 .29962 .64877 .35706 .67128 .3599 .65823 .29216 Mtetra
.592 .441 .645 r
.65823 .29216 .67128 .3599 .69434 .36723 .68024 .28463 Mtetra
.584 .421 .626 r
.68024 .28463 .69434 .36723 .71811 .37972 .70243 .27705 Mtetra
.577 .403 .609 r
.70243 .27705 .71811 .37972 .74275 .39821 .72479 .26941 Mtetra
.571 .388 .594 r
.72479 .26941 .74275 .39821 .76856 .42452 .74732 .2617 Mtetra
.566 .375 .582 r
.74732 .2617 .76856 .42452 .7961 .46338 .77004 .25394 Mtetra
.561 .364 .571 r
.77004 .25394 .7961 .46338 .82387 .49472 .79293 .24611 Mtetra
.558 .358 .565 r
.79293 .24611 .82387 .49472 .84866 .48736 .81601 .23822 Mtetra
.122 .056 .502 r
.81601 .23822 .84866 .48736 .87366 .47993 .86355 .46604 Mtetra
.523 .281 .489 r
.19876 .65024 .23259 .43765 .24829 .46816 .21887 .64414 Mtetra
.519 .272 .48 r
.21887 .64414 .24829 .46816 .25644 .6019 .23914 .638 Mtetra
.417 .071 .269 r
.23914 .638 .25644 .6019 .27306 .6432 .25957 .63181 Mtetra
.767 .788 .871 r
.38559 .59363 .39848 .60558 .42024 .59018 .40746 .57908 Mtetra
.887 .791 .748 r
.40746 .57908 .42024 .59018 .44241 .56018 .42998 .54411 Mtetra
.89 .743 .693 r
.42998 .54411 .44241 .56018 .46469 .51771 .45257 .4969 Mtetra
.892 .715 .656 r
.45257 .4969 .46469 .51771 .48684 .46135 .47502 .43655 Mtetra
.893 .698 .632 r
.47502 .43655 .48684 .46135 .5086 .38684 .49704 .36468 Mtetra
.855 .702 .691 r
.49704 .36468 .5086 .38684 .52968 .3361 .5183 .32279 Mtetra
.664 .741 .907 r
.80617 .22349 .81601 .23822 .86355 .46604 .82957 .21542 Mtetra
.787 .79 .855 r
.37251 .58151 .38559 .59363 .40746 .57908 .3946 .56474 Mtetra
.868 .762 .743 r
.3946 .56474 .40746 .57908 .42998 .54411 .4173 .53038 Mtetra
.903 .761 .693 r
.4173 .53038 .42998 .54411 .45257 .4969 .44018 .48205 Mtetra
.917 .747 .656 r
.44018 .48205 .45257 .4969 .47502 .43655 .46295 .42034 Mtetra
.922 .737 .634 r
.46295 .42034 .47502 .43655 .49704 .36468 .48529 .34956 Mtetra
.888 .756 .71 r
.48529 .34956 .49704 .36468 .5183 .32279 .50676 .3093 Mtetra
.797 .788 .844 r
.31613 .58253 .32962 .59464 .35098 .5881 .33822 .56455 Mtetra
.61 .605 .822 r
.33822 .56455 .35098 .5881 .37251 .58151 .35968 .55983 Mtetra
.689 .658 .814 r
.35968 .55983 .37251 .58151 .3946 .56474 .38162 .54889 Mtetra
.837 .751 .769 r
.38162 .54889 .3946 .56474 .4173 .53038 .40428 .52108 Mtetra
.923 .796 .702 r
.40428 .52108 .4173 .53038 .44018 .48205 .42742 .47388 Mtetra
.945 .785 .652 r
.42742 .47388 .44018 .48205 .46295 .42034 .45059 .41035 Mtetra
.946 .767 .628 r
.45059 .41035 .46295 .42034 .48529 .34956 .47334 .33707 Mtetra
.905 .779 .711 r
.47334 .33707 .48529 .34956 .50676 .3093 .49506 .29561 Mtetra
.927 .73 .615 r
.23877 .59012 .25277 .60211 .27372 .59564 .26721 .48865 Mtetra
.714 .503 .601 r
.26721 .48865 .27372 .59564 .29484 .58911 .29196 .42477 Mtetra
.48 .303 .563 r
.29196 .42477 .29484 .58911 .31613 .58253 .31068 .44451 Mtetra
.361 .221 .552 r
.31068 .44451 .31613 .58253 .33822 .56455 .32843 .48885 Mtetra
.241 .181 .586 r
.32843 .48885 .33822 .56455 .35968 .55983 .34738 .52593 Mtetra
.326 .368 .753 r
.34738 .52593 .35968 .55983 .38162 .54889 .36818 .53887 Mtetra
.803 .829 .872 r
.36818 .53887 .38162 .54889 .40428 .52108 .39064 .52142 Mtetra
.962 .88 .706 r
.39064 .52142 .40428 .52108 .42742 .47388 .41411 .47516 Mtetra
.978 .833 .632 r
.41411 .47516 .42742 .47388 .45059 .41035 .43783 .40705 Mtetra
.969 .793 .61 r
.43783 .40705 .45059 .41035 .47334 .33707 .46115 .32686 Mtetra
.924 .796 .701 r
.46115 .32686 .47334 .33707 .49506 .29561 .48319 .28172 Mtetra
.909 .739 .658 r
.16213 .59764 .17663 .60952 .19718 .6031 .18905 .52848 Mtetra
.855 .623 .586 r
.18905 .52848 .19718 .6031 .21789 .59664 .22517 .35571 Mtetra
.547 .342 .554 r
.22517 .35571 .21789 .59664 .23877 .59012 .24481 .34868 Mtetra
.24481 .34868 .23877 .59012 .26721 .48865 .26461 .34159 Mtetra
.557 .365 .577 r
.26461 .34159 .26721 .48865 .29196 .42477 .28455 .33445 Mtetra
.572 .401 .611 r
.28455 .33445 .29196 .42477 .31068 .44451 .30465 .32725 Mtetra
0 0 .424 r
.30465 .32725 .31068 .44451 .32843 .48885 .31868 .41782 Mtetra
0 0 .226 r
.31868 .41782 .32843 .48885 .34738 .52593 .33417 .50729 Mtetra
.619 .176 0 r
.33417 .50729 .34738 .52593 .36818 .53887 .3541 .53709 Mtetra
.498 .89 .954 r
.3541 .53709 .36818 .53887 .39064 .52142 .37631 .53009 Mtetra
.938 .965 .698 r
.37631 .53009 .39064 .52142 .41411 .47516 .39993 .49089 Mtetra
.994 .874 .566 r
.39993 .49089 .41411 .47516 .43783 .40705 .42452 .41266 Mtetra
.989 .814 .575 r
.42452 .41266 .43783 .40705 .46115 .32686 .44869 .31944 Mtetra
.946 .81 .678 r
.44869 .31944 .46115 .32686 .48319 .28172 .47114 .26763 Mtetra
.573 .118 0 r
.60306 .2204 .61442 .23517 .63691 .2272 .627 .25215 Mtetra
.921 .575 .364 r
.627 .25215 .63691 .2272 .65958 .21915 .65769 .42999 Mtetra
.527 .273 .473 r
.65769 .42999 .65958 .21915 .68244 .21105 .68298 .43337 Mtetra
.51 .261 .473 r
.68298 .43337 .68244 .21105 .70548 .20288 .70804 .42547 Mtetra
.70804 .42547 .70548 .20288 .72871 .19464 .73331 .4175 Mtetra
0 0 .331 r
.73331 .4175 .72871 .19464 .75213 .18633 .74154 .17081 Mtetra
.544 .338 .552 r
.15347 .36376 .14165 .60409 .16213 .59764 .17276 .35679 Mtetra
.17276 .35679 .16213 .59764 .18905 .52848 .19219 .34976 Mtetra
.55 .351 .564 r
.19219 .34976 .18905 .52848 .22517 .35571 .21178 .34268 Mtetra
.944 .588 .293 r
.29162 .31382 .30465 .32725 .31868 .41782 .30617 .39172 Mtetra
.969 .651 .341 r
.30617 .39172 .31868 .41782 .33417 .50729 .31816 .53117 Mtetra
.297 0 .069 r
.31816 .53117 .33417 .50729 .3541 .53709 .34031 .52411 Mtetra
.645 .763 .934 r
.36265 .517 .37631 .53009 .39993 .49089 .38517 .50982 Mtetra
.99 .881 .551 r
.38517 .50982 .39993 .49089 .42452 .41266 .41042 .43024 Mtetra
.999 .823 .526 r
.41042 .43024 .42452 .41266 .44869 .31944 .43588 .31561 Mtetra
.966 .818 .645 r
.43588 .31561 .44869 .31944 .47114 .26763 .45892 .25334 Mtetra
.948 .593 .225 r
.59153 .2054 .60306 .2204 .627 .25215 .61871 .34711 Mtetra
.715 .399 .443 r
.61871 .34711 .627 .25215 .65769 .42999 .64606 .42669 Mtetra
.508 .892 .96 r
.64606 .42669 .65769 .42999 .68298 .43337 .67104 .41873 Mtetra
.645 .763 .934 r
.72168 .4026 .73331 .4175 .74154 .17081 .74734 .39442 Mtetra
.506 .256 .469 r
.74734 .39442 .74154 .17081 .76529 .16231 .77323 .38617 Mtetra
.77323 .38617 .76529 .16231 .78924 .15373 .79936 .37785 Mtetra
.955 .644 .403 r
.27841 .30019 .29162 .31382 .30617 .39172 .28691 .45724 Mtetra
.726 .413 .449 r
.28691 .45724 .30617 .39172 .31816 .53117 .30405 .5181 Mtetra
.876 .789 .761 r
.3714 .49641 .38517 .50982 .41042 .43024 .39526 .46302 Mtetra
.999 .818 .475 r
.39526 .46302 .41042 .43024 .43588 .31561 .42265 .31619 Mtetra
.982 .818 .605 r
.42265 .31619 .43588 .31561 .45892 .25334 .44651 .23883 Mtetra
.942 .581 .204 r
.57983 .19017 .59153 .2054 .61871 .34711 .6062 .31745 Mtetra
.837 .481 0 r
.6062 .31745 .61871 .34711 .64606 .42669 .63377 .41194 Mtetra
.934 .56 .249 r
.24462 .29388 .25812 .3076 .27841 .30019 .25909 .35711 Mtetra
.846 .543 .477 r
.25909 .35711 .27841 .30019 .28691 .45724 .26754 .51204 Mtetra
.423 .097 .307 r
.26754 .51204 .28691 .45724 .30405 .5181 .28972 .50482 Mtetra
.645 .763 .934 r
.35742 .48279 .3714 .49641 .39526 .46302 .38037 .47532 Mtetra
.991 .781 .525 r
.38037 .47532 .39526 .46302 .42265 .31619 .40891 .32189 Mtetra
.991 .811 .566 r
.40891 .32189 .42265 .31619 .44651 .23883 .43393 .22411 Mtetra
.664 .741 .907 r
.56795 .17471 .57983 .19017 .6062 .31745 .59093 .16624 Mtetra
0 0 .25 r
.59093 .16624 .6062 .31745 .63377 .41194 .62127 .39695 Mtetra
.944 .594 .316 r
.21062 .28753 .2244 .30134 .24462 .29388 .2228 .3658 Mtetra
.815 .515 .482 r
.2228 .3658 .24462 .29388 .25909 .35711 .23076 .50593 Mtetra
.483 .215 .431 r
.23076 .50593 .25909 .35711 .26754 .51204 .25287 .49866 Mtetra
.953 .735 .572 r
.36629 .46137 .38037 .47532 .40891 .32189 .39453 .33358 Mtetra
.995 .801 .532 r
.39453 .33358 .40891 .32189 .43393 .22411 .42115 .20917 Mtetra
.664 .741 .907 r
.57899 .15042 .59093 .16624 .62127 .39695 .6023 .14174 Mtetra
0 0 .414 r
.6023 .14174 .62127 .39695 .64656 .38872 .63401 .37333 Mtetra
.95 .66 .453 r
.17638 .28114 .19046 .29503 .21062 .28753 .17187 .50704 Mtetra
.49 .232 .451 r
.17187 .50704 .21062 .28753 .2228 .3658 .19372 .49978 Mtetra
.474 .2 .417 r
.19372 .49978 .2228 .3658 .23076 .50593 .21575 .49246 Mtetra
.945 .748 .606 r
.35198 .44718 .36629 .46137 .39453 .33358 .37933 .35314 Mtetra
.997 .79 .503 r
.37933 .35314 .39453 .33358 .42115 .20917 .40818 .194 Mtetra
.664 .741 .907 r
.5903 .12553 .6023 .14174 .63401 .37333 .61394 .11665 Mtetra
0 0 .414 r
.61394 .11665 .63401 .37333 .65968 .36489 .64708 .3491 Mtetra
.946 .661 .465 r
.12191 .28231 .13637 .29618 .1563 .28869 .11306 .50816 Mtetra
.486 .226 .446 r
.11306 .50816 .1563 .28869 .17638 .28114 .13464 .50091 Mtetra
.13464 .50091 .17638 .28114 .17187 .50704 .15641 .49359 Mtetra
.908 .78 .707 r
.33743 .43277 .35198 .44718 .37933 .35314 .36295 .38543 Mtetra
.998 .782 .475 r
.36295 .38543 .37933 .35314 .40818 .194 .39501 .1786 Mtetra
.664 .741 .907 r
.60189 .10004 .61394 .11665 .64708 .3491 .62586 .09094 Mtetra
.53 .319 .538 r
.62586 .09094 .64708 .3491 .67315 .34043 .65005 .08176 Mtetra
0 0 .422 r
.65005 .08176 .67315 .34043 .69947 .33168 .68698 .31532 Mtetra
.942 .661 .477 r
.0675 .28347 .08234 .29733 .10205 .28985 .05433 .50927 Mtetra
.481 .22 .441 r
.05433 .50927 .10205 .28985 .12191 .28231 .07564 .50202 Mtetra
.07564 .50202 .12191 .28231 .11306 .50816 .09714 .49472 Mtetra
.645 .763 .934 r
.32265 .41812 .33743 .43277 .36295 .38543 .34631 .41008 Mtetra
.991 .759 .484 r
.34631 .41008 .36295 .38543 .39501 .1786 .38164 .16296 Mtetra
.664 .741 .907 r
.63809 .06459 .65005 .08176 .68698 .31532 .66262 .05518 Mtetra
.527 .315 .536 r
.66262 .05518 .68698 .31532 .71372 .30634 .68737 .04569 Mtetra
0 0 .429 r
.68737 .04569 .71372 .30634 .74071 .29727 .72836 .2803 Mtetra
.476 .213 .435 r
.01672 .50314 .0675 .28347 .05433 .50927 .03796 .49585 Mtetra
.962 .715 .516 r
.33141 .39505 .34631 .41008 .38164 .16296 .36807 .14709 Mtetra
.664 .741 .907 r
.67551 .02794 .68737 .04569 .72836 .2803 .70064 .0182 Mtetra
.962 .715 .516 r
.31626 .37977 .33141 .39505 .36807 .14709 .35428 .13096 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.06351 .24482 m
.06826 .24934 L
s
[(-1)] .054 .23578 1 .95078 Mshowa
.19951 .19156 m
.20405 .1963 L
s
[(-0.5)] .19044 .18208 .957 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.49481 .07594 m
.4988 .08114 L
s
[(0.5)] .48682 .06553 .76746 1 Mshowa
.65547 .01303 m
.65913 .01847 L
s
[(1)] .64814 .00214 .6727 1 Mshowa
.125 Mabswid
.09013 .23439 m
.09296 .23713 L
s
.11704 .22386 m
.11985 .22662 L
s
.14424 .21321 m
.14702 .216 L
s
.17173 .20244 m
.17448 .20526 L
s
.2276 .18057 m
.23029 .18344 L
s
.25599 .16945 m
.25866 .17235 L
s
.2847 .15821 m
.28733 .16113 L
s
.31372 .14684 m
.31632 .1498 L
s
.37274 .12374 m
.37527 .12675 L
s
.40274 .11199 m
.40524 .11502 L
s
.43308 .10011 m
.43555 .10317 L
s
.46377 .08809 m
.4662 .09118 L
s
.5262 .06364 m
.52856 .0668 L
s
.55796 .05121 m
.56028 .05439 L
s
.59008 .03863 m
.59236 .04184 L
s
.62258 .0259 m
.62482 .02914 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{174.875, 141.875},
  ImageMargins->{{38, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002^0000S@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooojkG002^e`00[]L00:kG002^e`00[]L00:kG
002^e`00[]L0077G100ie`00LmL00`3Ge`0he`00LmL00`3Ge`0he`00LmL00`3Ge`0he`00LmL00`3G
e`0he`00LML303[G001ce`030=OG013G100Te`00N]L200cG00<0emL08mL007SG0P000mL0000;e`03
0=OG02?G001ee`<00mL200?G1004e`030=OG02?G001@e`801=L00`3Ge`02e`<05ML20003e`3G00?G
00<0e`002]L00`3Ge`0Se`00CmL0103Ge`0;e`030=OG00oG0`06e`04RJd0[@801mL302GG001?e`04
0=OG00_G00<0emL03ML200[G00F208;G0009e`030=OG02?G001?e`040=OG00SG0`0=e`<03=L00jd0
[@02e`030=OG02cG001?e`040=OG00SG00<0emL02]L300oG00>208800]L202gG001?e`040=OG00SG
00<0emL02=L300kG00IeNgEk0:d3e`030=OG02_G001@e`802ML400CG0`0=e`0:RH:9PXU@Ne2900CG
00<0emL0:]L0067G0P000mL0e`0>e`09[HV]RG]eNhT000CG00<0emL0:]L004CG0P0He`<05=L028V2
RE1kD8T01ML00`3Ge`0Ye`00@mL0103Ge`0Ee`8000?G0=L05=L028V]RG]eNhT01]L00`3Ge`0Xe`00
@mL0103Ge`0Be`<05]L0351kD7^2RE1kD080R@GG00<0emL0:=L004?G00@0emL04=L201OG00j]RJee
NgF]RG]eN`80R@GG0P0Ye`00@mL0103Ge`0=e`<05mL048:9PXV2Ne1kPXU@Ne0208T7e`030=OG00WG
0P04e`030=OG00;G0`0?e`00@mL0103Ge`0;e`806mL03hV]RJeeNgF]RG]eN`80R@07e`030=OG00SG
00@0emL02mL00`3Ge`0<e`00A=L200WG100Me`0>PXV2Ne1kPXU@Ne1k08T7e`802ML0103Ge`0;e`03
0=OG00cG001=e`807ML04Zf9[HV]RJeeNgF]RG]eNgD0R@WG00<0emL01002e`040=OG00SG0`0?e`00
9=L200CG00<0emL00]L301SG0`0Pe`0ARH:9PXV2Ne1k0XU@Ne1k08T02ML00`3Ge`06e`040=OG00SG
00<0emL03mL002?G00@0emL02mL00`3Ge`0Be`@000?>emL08=L04:f9[HV]MG]e0XUkMG]e08T9e`80
1mL0103Ge`08e`030=OG00oG000Se`040=OG00_G00<0emL04=L200CG00??b=L08=L048:9PXV2Ne1k
0XV2Ne1k08T;e`030=OG00GG0P09e`@03]L001gG1002e`040=OG00SG0`0@e`@01ML00lk?cP0Me`0D
RJf9[HV]RJeeNgD2RJeeNgD0RJd:e`030=OG02;G000Se`040=OG00SG00<0emL03]L200WG00C?b<o8
7ML04h:9PXV2RH9kD7/2RH9kD7/0RH801mL01E1dD7@002?G000Se`040=OG00SG00<0emL02]L400_G
00C>clk?7]L04XV]RJd2[GEkM@:9[GEkM@02[@GG00MkD7]@Ne0002?G000Te`802ML400SG0`0<e`06
b<o8clS?6ML05XV2RH:9PXV20X9kD7]@RH9kD7/00X83e`0:D7A@M51dD7CG02;G000he`<03mL01/o>
clk?cQ[G01F]RJf9[HV]0Zf9NgEk0ZeeNgD00Zd00mL02Je@Ne1kD7]@e`02027G000Je`@06=L201;G
00O8clS?b<o>01[G01B9PXV2RH82PXU@Ne02PW]@Ne00PP?G00R8M51dD7A@M0;G00<0emL07mL001cG
00<0emL05=L301CG00S?c/o>clk?cQ[G01j]RJd2[@:]RG]eN`:]MG]eN`2]e`81[E1kD7]@Ne03e`03
0=OG01kG000Le`030=OG017G0`0Ge`06b<o8clS?0lhIe`0NPXV20X82PXU@Ne02PW]@Ne00PWA@0XQd
D7A@M51d0mL201oG000De`@01=L00`3Ge`0?e`@06=L02/o>clk?c/o>clhHe`0N[HV]0Zf9[HUkMG/2
[GEkMG/00e1k0Je@Ne1kD7]@1=L00`3Ge`04e`805mL001cG00<0emL03=L301_G00O?b<o8clS?00?>
00??c]L05]L07X:9PP:2R@:9D7]@0X9kD7]@00:9D0:8M51dD7A@M0GG00<0emL00]L0103Ge`0Fe`00
6]L300_G0`0Ne`0;c/o>clk?c/o>clh00/lGe`0:RJd2[HT2RG]eN`8201QeNgEk00>9N`6]D7]@Ne1k
D=N9[HV]R@03e`040=OG01KG000Le`030=OG00OG100Oe`07clS?b<o8c`03cP04clk?cQKG00Z90@:2
R@:9D7]@0P804HU@Ne000XU@0XQdD7A@M51d00;G00F2RH:90003e`040=OG01KG000Te`808mL02lk?
c/o>clk?c/o>00;?00?EcmL05=L02XT2RJf90XUkMG/20P0ARG]eN`03RG/1[E1kD7]@Ne000mL01HV]
RML000;G00@0emL05]L0027G0`0Ue`06clS?b<o80/h01/o>clk?cP;?5=L02XT1R@:90XU@Ne020P03
RE1k00800P805E02R7A@M51dD7A@Ne1kPXT0e`3G0002e`030=OG01CG000Ne`@09mL02Lk?c/o>clk?
cP04c`04eLoEca?G00Z9[HT2R@:9NgEk0P83000>NgD00W/1[E1kD7]@Ne04N`05[HWGe`000]L201OG
000Ge`801=L202WG00O8clS?b<o800;>00K?c/o>clh3caCG00B2R@:90P800e1k0002000GRE1kD7/0
0U02R7A@M51dD7A@Ne1kPXT00]L201[G000Fe`040=OG00?G0P0Ye`0:clk?c/o>clk?cPC?00GEcmG?
eP0Ce`05[HT2R@800`0057]e0XUkMG]e0`1k0Je@Ne1kD7]@17/00jf9e`03e`030=OG01OG000Fe`04
0=OG00?G00<0e`00:=L01lS?b<o8clP00/h01/o>clk?cPC?4mL00h:90P0200050X9kD7/00P80151k
D7/20P0A00:8M51dD7A@M51kD7/2RH800mL00`3Ge`0Ge`005]L0103Ge`03e`040=OG02OG00[?c/o>
clk?c/o>0/l02=G?eLoEcmK?4]L30007R@82[GEkM@020P0@NgEkM@<2N`2]D7]@Ne1kD0Ak00<]RJd0
0mL201SG000Fe`040=OG00;G0P03e`030=OG02CG00K8clS?b<l3cP04clk?cPK?00?@ZmL03ML30003
PP4200<200B2Ne1k0P80151kD7/30P0@08QdD7A@M51dD7]@N`:9PPCG00<0emL05]L001KG00@0emL0
0]L00`3Ge`02e`03b03G00;G00AeD7G81=L017E@MLP3e`03b7GG013G00[?c/o>clk?c/o>0/l02]G?
eLoFcmK?e/l:e`<01=L02@420Zd2[GEkM@020P0@NgEkM@<20`80D7]@Ne1kD0Ek00>9[ML01=L00`3G
e`0Ee`005mL200?G0P03e`0KbJC9Y<U@M538Y<RTb51dD<RTb:C8D<RSb:>U00_G00O?b<o8clS?00?>
00C?c/o>1Ll01J_@Zm2[00KG0`07e`090@82PP:2Ne1k008200A@Ne1k10803hP0D7A@M51dD7]@Ne29
PP05e`801ML200CG00<0emL00]L300?G000Le`800mL08<S?b<o8ME1eb<o8clQeD7G8clS?b7G7b<O8
W/S7b<O91]L02Lk?c/o>clk?cP04c`0<eLoEcmK?e/o@cm3?0]L300[G00@10P:]0P800gEkM@020P0@
NgEkMG]@N`6]07]@Ne1kD0Ek00<2[ML01ML00`3Ge`02e`040=OG00_G0@01e`7G0004e`801=L00`3G
e`02e`@00]L300CG00<0emL00]L08LVTbJC9D7A@b:C8Y<Q@M538Y<RTb538XlRSYIg7WLNNb005e`07
clS?b<o8c`03cP04clk?cPC?00K@Zm2[d:/300_G00>2N`400P801X820W]@N`8201M@M51dD7A@0XQd
07A@M51dD7]@Ne0WPP06e`800mL0103Ge`0;e`400ML1e`000mL0103Ge`08e`030=OG00KG00D0emOG
0003e`0SMLS?b<o8ME1eb<o8clQeD7G8clS?b7G7b<O9W/S7b:C9b<h01=L02Lk?c/o>clk?cP02c`0:
eLoEc]G?e/oFc`<000??d=L02=L02H9kPW^20Jd2[@020P03MG]e00<200m@Ne1kD7/1[E1k07]@Ne00
1G/00`:]R@07e`040=OG00;G00<0emL01]L300?G0003e`040=OG00WG00<0emL01ML00`3Ge`0200?G
025@bJC9Y7A@M538Y<RTb51dD<RTb:AdD<RSb9jUW/NMYIh00/P4e`0=clS?b<o8clk?c/o>c`03cP;?
0`001Z_@Zm2Ud0GG00R2Nh9kPW^2N`:200L2PP82Ne1k00@201I@M51dD0:8M51d07A@M51kD7]@9h:9
1mL20005e`3Ge`002=L00`3Ge`03e`000mL0103Ge`0:e`040=OGe`<00mL00`3Ge`02e`0TMLS?b<m@
ME1eb<o8ce1eD7G8clS?D7E@b<O9W/W7b:C9b<k70mL02Lk?c/o>clk?cP04c`03eLkE00800ll05M3?
d:_@Zm2UPW^2Nh9kPW^2Nh9k[@040P03MG]e00@200ikD7]@N`6]D7]@051kD0Ek00<2[HT01mL20005
e`3Ge`002=L00`3Ge`03e`000mL0103Ge`0;e`040=OG00GG0P03e`0QD<VTbJAdD7A@b:C8Y7A@M538
Y<RTM51dXlRNYIk7WZFN00?80]L01lS?b<o8clP00/h01Lo9clk?00<01Ll02J_@YM2U[:F/Y@04N`08
PW^2Nh9kPP440P0MNe1kD7A@M51dD7A@0XQdD7A@051dD7]@Ne1k0XT02ML0103G0009e`@00]L000?G
00@0emL02=L0103Ge`02e`030=OG00?G02T0emOGD7G8clS?D7E@MLS?b<m@ME1eb<o8ce1eD<RNbIk9
alVTbLS>a`02e`08clk?c/o>clh3c`<000GEc]G?e@03c`0Ed:_@Zm2Ud:FVNh9kPW^2Nh9kPW^200@2
01G8NgAkM7]@Ne1kD7/1[E1kD7]@05001W/00bf9e`08e`030=OG013G0004e`802]L200?G1002e`04
0=OGe`9@0239Y<U@M51dD<RTb:AdD7A@b:C8Y7A@M:>UWZFNYIjUWP?80]L02<S?b<o8clS>0`001/o>
clk?cPG?00J[cjG@YJ`3Y@Ak00R2Nh9kPW^2N`D201a@M51dD7A@M51dD0:8M51dD7@0M51kD7]@N`:9
2]L00`3Ge`0?e`006mL0:@3GemM@MLS?b7E@ME1eb<o8ce1eD7G8clQeD7E@b9k9W/U@bJC9b<k800;G
00G?c/o>c`0300G?00K>eLoEcmD3c`0Ed<o@Zm2Ud:FVNh9kPW^2Nh9kPW^200D201AkM7]dNe1kD7]@
N`6]D7]@Ne1k00Ik00<]RML02]L00`3Ge`0>e`002ML200CG00<0emL00]L300CG00@0emOG0U008<VT
bE1dD7A@b:C8D7A@M538Y<Q@M51dWZFNYIidWZFN0lP2e`03b<l0008000O?b<jUclW?00?>00??c/l0
1<l01Z_?YJbU[0>U17/00h9kPP05N`D201e@M51dD7A@M51dD0:8M51dD7A@M01kD7]@N`8WPP09e`80
4=L000SG00@0emL02mL00`3Ge`0200?G02A@MLS?b7E@ME1eb<o8ME1eD7G8clQeD7E@M9k9W/U@bJC9
b<h2b0<000C?c/o>1ll07/kEcmG?eLo@cm3?d:G@YJJUYW^2Nh9kPW^2NgakO08201VNWlQkM7]dNe1k
D7]@N`6]D7]@Ne1kD7/000Ak00<]0Zd02mL00`3Ge`0=e`002=L0103Ge`0;e`030=OG00800]L3D00Q
bJC9D7A@M538Y<Q@M51dD<RTb51dD7A@YIjUWWBNYIk800<000g?b<o8clS?b<nUclW?00?>1Ll02:_?
YLnUcjF/0jD<N`<201mjb51dD7A@M51dD7A@0XQdD7A@M51kD01@Ne1k0RN200_G00<0emL00mL400KG
0008e`040=OG00SG0`03e`0U0=OGegE@MLS?D7E@ME1eb<o8ME1eD7G8clQeD7E@M9k9W/U@b@03000;
c/S8elo>clk?c]001/l01<kEcmD3c`0Gd<o@cm2Ud:FVYJIkYW^VNh9kPW]lNg`010804IikM7]dNe1k
D7]@N`6]D7]@00Ik00<0Ng/00W/00`:]e`0;e`030=OG00CG00<0emL01ML000SG00@0emL02=L00`3G
e`03e`040=OGe`9@01fTbJAdD7A@M538Y<Q@M51dD<RTM51dD7A@YIjUD0020003YIk800;800ijemO?
b<o8RJ_?bLo>c`?>1Ll02:_?YLnUcjG90jD<N`81022NNYi@M51dD7A@M51dD0:8NeMkDG]ANe1kD01@
Ne0WPPcG0P05e`030=OG00GG0008e`040=OG00SG00<0emL00mL0803GemMeD<o8ce1eD7E@MLS?D7E@
ME1eb<m@ME1eD7BN0`002539Y<W8c/RO0mL00lo>[@07c`05eLkEcmD00ll0:=3?d<o@YM2UYZFVYJIk
YW^2Nh9kO7]lN`:LWiikM7]dNe1kD7^9[HT;N`0607]kN`8]3ML00`3Ge`03e`030=OG00GG0009e`80
2ML400;G00<0emL00e005jC9Y7A@M51dD<RTM51dD7A@b:AdD7A@00<000NNYE1dWZFN00?800=jemL0
0]L02HV[d:G?bLo>c`03cP??00Z[cj_?YLnUcjG90ZD00g^UN`0<N`0@XWZND7A@M51dD7A@M8R9D@9G
00ikDG]ANe1kD7/0Ne0W0PkG00<0emL00]L00`3Ge`05e`006ML200;G01M@ME3?b7E@ME1eD7G8ce1e
D7E@MLS?D003000DD7BNbIieD<VTbLS>WYoG[HV]RM07c`0beLkEcmG?d<o@cm2Ud:G@YJJUYZFVNjIk
PW^2NgakO7]lNinNNgAkM7]@Ne1kD7]GNe4;N`0507/2;HT03ML20004e`0000OG0002e`801=L00`3G
e`03e`030=OG00;G0`03e`040=OGe`=@016TbE1dD7A@M538Y7A@M51dD0030003D7A@009@00RUWZE@
M9jUWP;800nNN/Q@RHS@ZlnUclW?c/l00lh03MG>cj_?YLnUcjG?YLT00ZD00g^UN`0=N`0PIHmUSfEd
D7A@Ne5kDG]AEe5GDG]ANe1kD7]@N`0W0XT>e`050=OGe`001mL00005e`3Ge`002ML00`3Ge`05e`03
0=OG00800]L04E1eD<o8ME1eD7E@MLS?D7E@00<001[8ce1eD7E@M9k9D7E@bJC9b<jNWlQkM=3?d0K?
02W>eLoEcmK?d<o@cm2Ud:G@YJJUYZFVNjIkPW^2NgakO7]lNgakSfF?I@03N`09Eg]GNeMkDG]A00Yk
00@00Rf91<L:e`802]L00005e`3Ge`002]L00`3Ge`04e`040=OG00?G0e002jC9D7A@M51dD<Q@00<0
00Q@M538D7A@M0=@01NUWWA@M9jUW/QjWW[8D7E@d:_?YLo9c`03cP03eLkE00;?00j[cjG?YLnUbJG9
NjEkY@ik019GNeMkEg]ANe5kDG]ANe5GDEL3D@0;Ne1kD7]@Ne000RL01<L00j?Ge`03e`@000?G0=L0
2ML00005e`3Ge`002]L0103GemL300?G00l0emMeD7E@clQeD7E@ME000`007e1eD7E@MLQeD7E@M51d
W/U@ME39Y<W8WijOb7]dNg@01ll09/k@cmG?e/o@cm3?d:G@YM2Ud:FVYJIkYW^2Nh9kPW^2NgakO7]l
1W/02eMkEg]GNeMkDG]A00Yk00<00/L01LL01=L00005e`030=OG00SG00001ML0emL000_G00@0emL0
1=L200;G15001JAdD7A@00<000i@b51dD7A@M538D7A@M0=@01NUWWA@M9jUW/QjWW[8agE@MJ??YLo9
c`03cP0?eLk?Zln[cjG?YLnUbJG900:U00=kYG/02g/055MkEg]GNeMkDG]ANe5kDG]ANe5G0e402g]@
Ne1kD7]@N`0W00C700JSaj?7XlL5e`030=OG00SG00001ML0emL000SG00@0emL00]L00`3Ge`03e`0:
0=OGME1eD<m@M@8002M@ME1eb7E@ME1eD7G8ME1eD7A@M9k9D7E@bJC9WYnNWlS>M7]dc/P01Ll09ZcE
cmK?d<o@cm2[d:_@YM2Ud:FVYJIkYW^VNh9kPW^2NgakO5Ml1W/03EMkEg]GNeMkDG]AEe4027/00bd0
a`03a`03NlO700?71ML00`3Ge`08e`000]L200WG1002e`@000?G00000]L4D0<001=dD7A@M538D7A@
M51dD<Q@M51d00=@01^UWWA@M9jUWU1jWW[8agE@MJ?8Xlo9cj_@c]D00/l02Z_?YLnUcjG?YLT4Y@03
NjEk009k00>1Ng/01W/05UMkEg]ANeMkDG]ANe5kDG]ANe5GDEL2D@0;D7]@Ne1kD7/29`000lL01U37
XlNSa`KG00<0emL01mL001SG0P000mM@M@03001Ice1eD7E@ME1eD7E@ME1eD7E@ME1eD7A@M9ieD7E@
bJC9BInNWlS>M7]dNlS>WZf9d<oEcmK?d<o@cm2[d:_@YM2Ud:FVYJIkYW^VNh9kPW^2NgakO5MlEg`0
1W/035MkEg]GNe5kDEMAE`Mk00<]0P000lL00g_7a`03a`KG00<0emL01mL0017G1003e`030=L00080
15004gA@M51dD7A@M51dD7A@M51dD7@01E009jE@M51dWZE9D7ZNN/S7b51eD<RSRHS@ZmG>e/o@ZlnU
cjG?YLnUb@04Y@06NjEkYG^127/05UMkEg]ANe5GDG]ANe5kDG]ANe5GDEL3D@0;DU1kD7]@N`8W0P00
0/L01e37XlNSae001ML00`3Ge`07e`004mL00`3Ge`02e`80067GD7E@ME1eD7E@ME1eD7E@ME1eD7E@
ME1eD7E@M51dWWE@ME39Y519WijOb<k8NgAkRJf9d:c@cmK?e/o@Zm3?d:_@YM2Ud:G@YJJUYZFVNjIk
PW^2Nh9kO7]lNgaGO55l00Ak00iGNeMkEg]ANe5GDEL]F0Ek00O8M7_70<Mk00G700=kemL00mL00`3G
e`07e`004mL00`3Ge`03e`030=M@00E@01=dD7A@M51dD7A@M51dD7A@M51d00E@02NUD7A@M9jUBE19
WW[8alQ@ME38N]2[d<kFcmJ[d:_@YLnUcjG?YLT01:D027^UNjEkPG^11W/025MkEg]ANe5G0e402g]A
Ne5kDG]AEe5G00AA00D]DYjTWP02a`0<Ne37a`1@Nj?7XlM@1ML00`3Ge`07e`004mL00`3Ge`04e`80
0]L01GE@ME1e00CG00A@ME1e0]L2N`1=D7E@ME3?YLnUM9ieD7E@bDU@BE2NWlS>b7]dNlROW]2/[MGF
cm3?d:_@Zm2[d:G@YM2Ud:FVYJJUYW^VNh9kPW^2NgakO7]lEgaAO5400g/05UMkEg]GNe5kDG]AEe5H
;ERNbLO8M7/2a`030<Me00C700=kemL00mL00`3Ge`07e`004mL00`3Ge`06e`030=OG00kG00MkD7]@
Ne1k00BU02Q@Ne1kD7BND4U@BIijb<O80GE@b7ZONXVae/o@Zm2Ud:G@YLnUcjFV1ZD01W^UNh5kP@Ik
00QGNeMkDG]AE`9A00`]Ne5kDG]ANe5GDEL4D@05;E8]DYh00/L00g]@a`02a`0807^Saj?7D7/4e`03
0=OG00OG000Ae`<02ML00`3Ge`0=e`Mk00C?YLnU1G/2c`1FNjEkD9jOb<hTBGAkWZf9[HWFcmK?d:_@
Zm2[d:G@YM2Ud:G@YJJUYZFVNjIkPW^2Nh9kPUMlEgaGO55lDEMANeMkEg]GNe5kDG]AEe79Y7^NbIk8
M7/4a`030<O700;70W/4e`030=OG00OG000Ce`030=OG00SG00<0emL03=L01g]@Ne1kD7/01:D01U1k
D7]@c`:U021kYE2NN/PTB2A8D7AjRHSFcmJ[d:_@YM2Ud:G?YLnUYP>U01NVYJEkYG^1Nh5kPW^2Ngak
O5MlEg]AE`02D@0F;E5ANe5kDG]AEe5GDG]@NijTD7^NY0;700=@NlL00/L01`1@aj?7Xg/01ML00`3G
e`06e`007mL00`3Ge`0;e`Ik00FUcjG?Y@05N`;?00IkYG]kDG/4D@1=;DU@Wij?[;>/d:c@Zm2[d:_@
YM2Ud:G@YJJUYZFVYJIkYW^VNh9kPW^2EgaGO55lDGaAEe5GF7]GNeMkNYmjWgAkM<VTNgC9W/S7Ng@0
0lL00gD0a`03a`03NmOG00?G00<0emL01]L0023G0P0;e`07Ne1kD7]@c`04Y@06D7]@Ne3?0ZD087^U
D7]@DBaA9bdWSfF?[:fV[:J/Zm2Ud:G@YM2UYZFV0jD0;jJUYW^UNh9kPW^2Nh9kO7]lEgaGF2eGDEL]
DBeH;EQ@Ne1kNW]jNe1kWZA@NijT00;700=@NlL00/L01g]@0:?7Xg/01ML00`3Ge`06e`008]L00`3G
e`08e`Ik0/l00jG?Y@04N`??00IkYG]kDG/4D@0g;E4dF:bc[=2/d:c@Zm2[d:_@Zm2Ud:G@YJJUYZFV
YJJ1YW^VNh9kPW^2NgaGO55HDGaAEe5GD@03F00CM7]jWgZOM7]dbJAkM<VNb<MkM003a`04MG_700;7
0W/4e`030=OG00KG000Se`030=OG00OG00MkD7]@NjG?00BU00I@Ne1kYLl2Y@1FNjE@Ne1A;54W;BMH
;ERV[:J/Zm2[d:G@YM2Ud:FVYJJUYZFVYJIkYW^VNh9kPW^2NgakO5MlEeP]F2eG;E4]DBeH;G]@M7Yk
NW]@Ne2TD7]@Y9k7D7/3a`08Ne370<NSNe04e`030=OG00KG000Te`030=OG00KG1G/01]3?cjG?Y@Ak
0ll01W^UNg]AN`AA04h]DCAHPZf/d:c@[=2/d:_@Zm2/d:G@YJbUYZFVYJJ1YX6VNjIkPW^2Nh9kO5Ml
DEQAF2eGDEMAWgAkM7]@WgZOM7]dNjAkM7^NbLMkM7/2a`06MG]ea`370W/4e`030=OG00KG000Ue`03
0=OG00GG00MkD7]@cjG?00BU00I@Ne1kYLl2Y@1GNjE@Ne1A;54W;BNVPZJ2YZ_@Zm2[d:_@YM2U[:F/
YJJUYZFVYJJ1YW^VNh9kPW^2NgakO5MlEeP]F2eH9DUdNWAkD7]@M51kNW]@Ne2TD7]@Y9k7D7]@00;7
00QkD7^Sa`1kD0CG00<0emL01]L002KG0P05e`Ak00O?d<o?YLnU00=k1<l01W^UNg]AN`9A01J/[H:3
PZf2[Jb][=2/d:c@[=2[d:c@0Z`0>:F/YJbU[:J/PJJ1YW^VNjIkYW^2O89HPU5HDEP]F7ZONYmdNgAk
D7AjWgAkM7^TNgAkM<W7NgAk0lL01G]ealL000=k0mL00`3Ge`06e`00:=L00`3Ge`02e`07Ne1kD<nU
c`04Y@06D7]@cjG?0ZD01W^UD7]@D@>/18800jJ/[002[006Zm2[d:c@0Z`01:F/YJ`2YP0gYJJUYX6V
PJIkYW^2Nh9kPW^2Nh9kO5Ql=5P]F2eHM7YdNe1kD7A@M7YkD7]@Ne1kD7^Nae1kD003a`08D7^Saj<0
D7/4e`030=OG00GG000Ye`040=OGe`=k00?@cm000/l00jG?Y@03N`C?03ikYG]kDG^/[Jb][8>2Pjb]
[:f/[Jc@[=J/dJc@[=2V[:F/YJbV[:J/PJJ1YX:VPZIkYW^2O89lPUR2=3E8K09901QjWgAkM7]@M52O
M7]dNgAkM7]dbIikM7/3a`03NgEk00;700=k07/01=L00`3Ge`05e`00:]L02P3Geg]@NjG?YLl4Y@06
D7^UcjG?0ZD01W^UD7E@M@B/00a@M51@BJf/[Jb][=06[00MYZbV[:F/YZb1YX6VNjJ2YW^2Nh9kPW^2
Nh9HO5P00c@074Q9BDUdNe1kb<o8NjAkD7]@Ne1kD7]@Y51kD7/2a`08D7]@aj?7D004e`030=OG00GG
000[e`800W/01<o@cm02c`06YLm@Ne1k1<l057YkM7]dNgAkM7]@Ne1dBGA9[Jb]0k<07]6/dJcAYZbV
[:J/YZbV[:J/PZJ2YX:VPZIkYW^VO0:200F/PXV/d006c`:U00S>clk?NlnUc`;G00]dNgAkM7^NNgAk
M002a`03NgEk00?700=k0=L00mL00`3Ge`05e`00;ML01`3GejG?YLl00]L08E1eD7E@ME1kM7]@ME1e
D7E@ME1dD7A9D4U@B;>//jb?R@03[00WR:fV[:J/YZbV[8:/PZb2YX:VNh9kPW^2NjJ2YX:9[=2UclS?
b<o900:U00S?b<o8NjC9b0OG00I@Y51kD7/2a`09D7]@aj?7D7/000?G00<0emL01ML002kG00<0emL0
1=L06E1kD7]@Ne1kBG]jNgAkM7]dNgAkD7]@M4T015400eN?S`03S`03[Jb]00:/00FV[Jb]YP02[00B
[JJ]YZf2YX:VPZJ2[H:]PZb20Z`00mJ/d006c`:U00S>clk?NlnUc`SG00FNNgAkM002a`03NgEk00?7
0g/0103Ge`07e`00;mL00`3Ge`03e`07ME1eD7E@M@02B@0^M7]@ME1eD7E@ME1dD7]@NbaA;54]DBd:
>fDk[HR]YZbV[:J]R:f8[H:/PZJ2YPF201ZVPZJ2YZb][<nUclS?b<o9cjG?b<o8NjC9b0gG0/L02U1k
D7^Sae1kD002e`030=OG00GG000`e`030=OG00;G00I@Ne1kD7/2D00;BG]jNgAkM7]dNg@01W/4D@0?
Ee5H;C@kGhV]RJf/[Jbc00:]01R/[Jb?IHmURH>9PZf2[H:]PZf/[Jb][=07c`09YLk?c/nUcjG?00gG
0/L017]eNgD2a`=k00CG0=L01mL0037G0P02e`06ME1eD7E@14T05G]@ME1eD89ANe5kDG]@NbaA;54]
D@03;@0G=3YO>XV2RHR]R:f8JfA[I6]USfF9PXT00h801JEjYLN]00B/016UclS?bLo9cjG?b<o8cjC9
b00>e`0?ae1kD7^Sae1kD7_G0=L000KG000ce`070=M@Ne1kD004e`04D7YkM09k00<2PW/01g/4D@05
Ee5H;EP00S@00c]O>`04R@0<SfGGYM2UclW?bLo90]L039icWijUW/k8[Jb][0S?00BUc/o>0ll00jG?
e`0Be`;717/2e`801]L003CG00<0ME002mL06e5k0H9ANe5kDG]@NbaA;54]YX63GX=N5cYO>P02I@0=
Jjbc[:JUclS?b<o8c`03e`0LM7>NNZG7b<O8ag]jclS?bLo9cjG?b<o8cjC9b1?G00JSae1kD7/2e`80
1]L003GG00<0emL02]L2N`030X9k00Mk15401ZbV[:J3PP?G0129[H:9PXV2d:G?YLo9clW?1ML2WP0:
YIk>b<k8cWZONPK?00BUc/o>0ll00jG?e`0Je`801]L003KG00<0emL02ML0555k0H9ANe5kDG]@NbaA
;:J1YX6V1ML01HV2RH:300:200UkYZG?b<o8clP01]L06YijYLO8alS7NgYkY<o9clW?YLo8cj_?Y<W8
5mL400SG000ge`802ML2N`030X9k00Mk0e42[003YZbV00GG0129[HT3PJJ1YZG?YLo9clW?1mL02jFN
c/S>b9mjWg[900K?00S>clk@cm2Uca?G100<e`00>ML00`3Ge`06e`0>DG/1PU5kDG]ANe1k;542[003
PJJ100KG0129PP820g^2NjJUclS?b<o81mL02gZUalS7b4UkNW]j00KG00S?b<n[cj_9b0oG100@e`00
>]L00`3Ge`05e`9k00<2PW/01g/01U6/d:c@YPOG00>90`800P<02jJ1YZG?YLo9clW?00WG00[>b<k8
M7ZONYo81ML02<k?c]3?d:G?3=L301CG000ke`030=OG00CG00aAN`62DG]ANe5kD7/5[0SG01290P82
0g^2NjbUclS?b<o82]L02LS7b4UdNW]jb007e`06cj_?ZlW82=L401OG000le`030=OG00?G0W/00`:2
N`04N`08e`4VNgB]R@09e`0?0`83;JJ1d:c?YLo9clW?00_G00S>b7A@WgZOb0SG00G@cm3>c`04e`@0
6mL003gG0P03e`03DG/100OG00N89U1eD8T000WG0`800bek[003[006clS?b<o84=L00g]jb00<e`03
b00000807mL003oG00<0emL00W/20PGG00L1[BIkM7/000[G00l30P<]d:c@[=39clW?bLl04=L00gZO
b00:e`<08mL0043G00L0ee5k0@8100CG00L1R8U@RHP000[G0`800bd3;@04e`05b<o8clP04]L00lSG
e`04e`@09]L0047G00<0Ng/01mL01hV]RG]de`002]L00`<20`08e`04bLo9caGG100Ze`00@]L200OG
00>9R=L00mL00`3Ge`08e`D21mL00lS?b00Be`<0;]L004CG00<0emL01=L00hV]e`03e`030=OG00SG
00<30Z802]L00lW?e`0=e`@0<ML004GG00<0emL00mL00hWGe`03e`030=OG00SG0`8:e`03RJCG00WG
100ee`00A]L01P3GemN]R@GG00<0emL02=L010<29`88e`03[LW?00KG100ie`00AmL00`3Ge`07e`03
0=OG00SG0`800`<2e`06e`03Y<nT00?G0`0me`00B=L00`29[@06e`030=OG00SG00<30]L02mL4043G
001:e`030=OG00CG00<0emL02=L40PKG1014e`00BmL00`3Ge`03e`030=OG00SG00<3emL00mL404SG
001<e`030=OG00;G00<0emL02=L20P04e`0004cG001=e`050=OGe`002ML404oG001>e`8000?G0=L0
1=L405?G001@e`8000?G00000P1Ge`00DML205_G002^e`00[]L00:kG002^e`00[]L00:kG002^e`00
\
\>"],
  ImageRangeCache->{{{0, 173.875}, {140.875, 0}} -> {-0.16023, -0.0447392, \
0.00663002, 0.00663002}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{940, 758},
WindowMargins->{{76, Automatic}, {Automatic, 47}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 107, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[1837, 56, 824, 23, 412, "Input"],
Cell[2664, 81, 166, 2, 52, "Output"],
Cell[2833, 85, 130, 3, 31, "Output"],
Cell[2966, 90, 130, 3, 31, "Output"],
Cell[3099, 95, 9862, 174, 290, 854, 57, "GraphicsData", "PostScript", \
"Graphics"],
Cell[12964, 271, 130, 3, 31, "Output"]
}, Open  ]],
Cell[13109, 277, 397, 13, 212, "Input"],
Cell[13509, 292, 47, 1, 32, "Input"],

Cell[CellGroupData[{
Cell[13581, 297, 383, 13, 212, "Input"],
Cell[13967, 312, 126, 2, 31, "Output"],
Cell[14096, 316, 233, 4, 31, "Output"]
}, Open  ]],
Cell[14344, 323, 222, 7, 112, "Input"],
Cell[14569, 332, 235, 5, 87, "Input"],

Cell[CellGroupData[{
Cell[14829, 341, 62, 1, 32, "Input"],
Cell[14894, 344, 190, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15121, 352, 47, 1, 32, "Input"],
Cell[15171, 355, 37, 1, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15245, 361, 452, 12, 212, "Input"],
Cell[15700, 375, 212476, 5839, 150, 198041, 5656, "GraphicsData", \
"PostScript", "Graphics"],
Cell[228179, 6216, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228353, 6224, 203, 5, 78, "Input"],
Cell[228559, 6231, 31009, 836, 290, 6782, 531, "GraphicsData", "PostScript", \
"Graphics"],
Cell[259571, 7069, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259745, 7077, 93, 1, 32, "Input"],
Cell[259841, 7080, 16751, 403, 183, 3501, 234, "GraphicsData", "PostScript", \
"Graphics"],
Cell[276595, 7485, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[276762, 7493, 91, 1, 32, "Input"],
Cell[276856, 7496, 23119, 489, 218, 3595, 242, "GraphicsData", "PostScript", \
"Graphics"],
Cell[299978, 7987, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[300145, 7995, 81, 2, 32, "Input"],
Cell[300229, 7999, 24139, 934, 143, 9873, 753, "GraphicsData", "PostScript", \
"Graphics"],
Cell[324371, 8935, 135, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[324543, 8943, 421, 11, 192, "Input"],
Cell[324967, 8956, 50786, 1352, 150, 33587, 1134, "GraphicsData", \
"PostScript", "Graphics"],
Cell[375756, 10310, 137, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

