(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1455904,      36874]*)
(*NotebookOutlinePosition[   1456535,      36896]*)
(*  CellTagsIndexPosition[   1456491,      36892]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(\( (*\ 
      c51 : \ Laplace\ equation\ with\ outer\ inhomogeneous\ boundary\ values\
\ on\ square\ and\ inner\ homogeneous\ boundary\ values\ on\ circle\ *) \)\(\n\
\)\(\(Clear[x, y, r, fi];\)\n
    x[1] = 4. ; y[1] = 0. ; x[2] = 4. ; y[2] = 1. ;\n
    x[3] = 4. ; y[3] = 1.5; x[4] = 4. ; y[4] = 2. ;\n
    x[5] = 1. ; y[5] = 2. ; x[6] = 2. ; y[6] = 2. ;\n
    x[7] = 3. ; \ y[7] = 2. ;\)\)\)], "Input"],

Cell["\<\
Table[r[i]=Sqrt[x[i]^2+y[i]^2],{i,1,7}];
Table[fi[i]=ArcTan[y[i]/x[i]],{i,1,7}];
Clear[a,q,l,t,u,v,w,p,M];
Table[a[i]=Log[r[i]],{i,1,7}];
Table[q[k]=(r[1]^(k-1)-r[1]^(-k+1))*Cos[(k-1)*fi[1]],{k,2,7}];
Table[l[k]=(r[2]^(k-1)-r[2]^(-k+1))*Cos[(k-1)*fi[2]],{k,2,7}];
Table[t[k]=(r[3]^(k-1)-r[3]^(-k+1))*Cos[(k-1)*fi[3]],{k,2,7}];
Table[u[k]=(r[4]^(k-1)-r[4]^(-k+1))*Cos[(k-1)*fi[4]],{k,2,7}];
Table[v[k]=(r[5]^(k-1)-r[5]^(-k+1))*Cos[(k-1)*fi[5]],{k,2,7}];
Table[w[k]=(r[6]^(k-1)-r[6]^(-k+1))*Cos[(k-1)*fi[6]],{k,2,7}];
Table[p[k]=(r[7]^(k-1)-r[7]^(-k+1))*Cos[(k-1)*fi[7]],{k,2,7}];Off[Set::partw];\
Off[Set::noval];
M=Table[M[[i,k]]=i*k,{i,1,7},{k,1,7}];
Table[M[[i,1]]=a[i],{i,1,7}];
Table[M[[1,k]]=u[k],{k,2,7}];
Table[M[[2,k]]=v[k],{k,2,7}];
Table[M[[3,k]]=w[k],{k,2,7}];
Table[M[[4,k]]=p[k],{k,2,7}];
Table[M[[5,k]]=q[k],{k,2,7}];
Table[M[[6,k]]=l[k],{k,2,7}];
Table[M[[7,k]]=t[k],{k,2,7}];\
\>", "Input"],

Cell[CellGroupData[{

Cell["MatrixForm[M]", "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.3862943611198906`", "3.8`", "11.970000000000004`", 
              "15.998000000000014`", \(-111.99930000000002`\), \(-1215.99962`\
\), \(-7487.999883000004`\)},
            {"1.416606672028108`", 
              "0.8000000000000003`", \(-2.88`\), \(-10.912000000000003`\), \
\(-6.988800000000012`\), "40.986880000000006`", "116.99251200000009`"},
            {"1.45208254001425`", "1.7500000000000004`", 
              "4.822046771642704`*^-16", \(-15.968750000000002`\), \
\(-63.98437500000003`\), \(-127.99609375000011`\), \(-9.405251539127484`*^-14\
\)},
            {"1.4978661367769956`", "2.769230769230769`", 
              "4.9704142011834325`", \(-8.995903504779243`\), \
\(-118.99583347921985`\), \(-596.9983921054259`\), \(-2034.9995783964098`\)},
            {"0.8047189562170503`", "3.75`", "15.9375`", "63.984375`", 
              "255.99609375`", "1023.9990234375`", "4095.999755859375`"},
            {"1.039720770839918`", "3.764705882352941`", 
              "14.948096885813149`", "51.98941583553837`", 
              "160.99807234108786`", "403.99971546430385`", 
              "494.9999794925495`"},
            {"1.2824746787307684`", "3.7808219178082183`", 
              "13.70871645712141`", "36.99391286241987`", 
              "45.06209377765681`", \(-314.749844528283`\), \
\(-3340.3905345892554`\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Det[M]", "Input",
  AspectRatioFixed->False],

Cell[BoxData[
    \(1.344904330763376`*^7\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["b={0, Cos[Pi/8.],Cos[Pi/4.],Cos[3.*Pi/8.],0,0, 0}", "Input",
  AspectRatioFixed->False],

Cell[BoxData[
    \({0, 0.9238795325112867`, 0.7071067811865476`, 0.38268343236508984`, 0, 
      0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinearSolve[M,b]", "Input",
  AspectRatioFixed->False],

Cell[BoxData[
    \({0.0018039276292623205`, 0.6666772479008716`, \(-0.2793400109294013`\), 
      0.04108891616270895`, \(-0.0034217811241986154`\), 
      0.00019531651605005518`, \(-6.34729171699557`*^-7\)}\)], "Output"]
}, Open  ]],

Cell["\<\
r[x_,y_]:=Sqrt[x^2+y^2]
f[x_,y_]:=ArcTan[y/x]
C1=0.00180393;
C2=0.666677;
C3=-0.27934;
C4=0.0410889;
C5=-0.00342178;
C6=0.000195317;
C7=-6.34729*10^(-7);\
\>", "Input",
  AspectRatioFixed->False],

Cell["\<\
g[x_,y_]:=C1*Log[r[x,y]]+
C2*(r[x,y]^1-r[x,y]^-1)*Cos[1*f[x,y]]+
C3*(r[x,y]^2-r[x,y]^-2)*Cos[2*f[x,y]]+
C4*(r[x,y]^3-r[x,y]^-3)*Cos[3*f[x,y]]+
C5*(r[x,y]^4-r[x,y]^-4)*Cos[4*f[x,y]]+
C6*(r[x,y]^5-r[x,y]^-5)*Cos[5*f[x,y]]+
C7*(r[x,y]^6-r[x,y]^-6)*Cos[6*f[x,y]]/;x^2+y^2>=1.\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Off[Plot3D::plnc];Off[Plot3D::gval];
PD3=Plot3D[g[x,y](*,Hue[0.3*g[x,y]]}*),{x,-4.0000001,4.0000001},{y,-2.000001,\
2.000001},
PlotPoints->80, PlotRange->{0,1.5},ClipFill->None,Mesh->False,
AspectRatio->1.]


\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.04977 -0.0837822 1.2942 [
[.02757 .3035 -12 -8.70276 ]
[.02757 .3035 0 .29724 ]
[.17646 .23126 -11.7989 -9 ]
[.17646 .23126 .20112 0 ]
[.3345 .15462 -5.5867 -9 ]
[.3345 .15462 .4133 0 ]
[.50253 .07317 -5.27396 -9 ]
[.50253 .07317 .72604 0 ]
[.68156 -0.01354 -4.96123 -9 ]
[.68156 -0.01354 1.03877 0 ]
[.70096 -0.0059 0 -6.26206 ]
[.70096 -0.0059 12 2.73794 ]
[.78313 .14923 0 -6.13858 ]
[.78313 .14923 12 2.86142 ]
[.8565 .28773 0 -6.03127 ]
[.8565 .28773 6 2.96873 ]
[.9224 .41214 0 -5.93715 ]
[.9224 .41214 6 3.06285 ]
[.98191 .52452 0 -5.85393 ]
[.98191 .52452 6 3.14607 ]
[.02494 .32044 -6 -2.73794 ]
[.02494 .32044 0 6.26206 ]
[.0131 .41196 -18 -2.80073 ]
[.0131 .41196 0 6.19927 ]
[.00067 .50802 -6 -2.86695 ]
[.00067 .50802 0 6.13305 ]
[-0.0124 .60894 -18 -2.93688 ]
[-0.0124 .60894 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .31454 m
.68874 0 L
s
.03716 .31454 m
.04196 .32006 L
s
[(-4)] .02757 .3035 1 .93395 Mshowa
.18558 .24289 m
.19014 .24871 L
s
[(-2)] .17646 .23126 .96648 1 Mshowa
.34306 .16687 m
.34735 .173 L
s
[(0)] .3345 .15462 .86223 1 Mshowa
.51046 .08606 m
.51442 .09251 L
s
[(2)] .50253 .07317 .75799 1 Mshowa
.68874 0 m
.69233 .00677 L
s
[(4)] .68156 -0.01354 .65374 1 Mshowa
.125 Mabswid
.07346 .29702 m
.0763 .30038 L
s
.11029 .27924 m
.1131 .28264 L
s
.14766 .2612 m
.15043 .26465 L
s
.22407 .22431 m
.22677 .22785 L
s
.26314 .20545 m
.2658 .20903 L
s
.3028 .18631 m
.30541 .18994 L
s
.38395 .14713 m
.38647 .15086 L
s
.42547 .12709 m
.42794 .13086 L
s
.46763 .10674 m
.47006 .11056 L
s
.55397 .06506 m
.55629 .06897 L
s
.59817 .04372 m
.60044 .04768 L
s
.64309 .02204 m
.6453 .02605 L
s
.25 Mabswid
.68874 0 m
.96935 .52918 L
s
.68874 0 m
.68263 .00295 L
s
[(-2)] .70096 -0.0059 -1 .39157 Mshowa
.7708 .15476 m
.76464 .15753 L
s
[(-1)] .78313 .14923 -1 .36413 Mshowa
.84407 .29294 m
.83786 .29555 L
s
[(0)] .8565 .28773 -1 .34028 Mshowa
.9099 .41707 m
.90365 .41953 L
s
[(1)] .9224 .41214 -1 .31937 Mshowa
.96935 .52918 m
.96306 .53151 L
s
[(2)] .98191 .52452 -1 .30087 Mshowa
.125 Mabswid
.70593 .03242 m
.70226 .03417 L
s
.72272 .06408 m
.71904 .06581 L
s
.73912 .09501 m
.73543 .09671 L
s
.75514 .12523 m
.75145 .12691 L
s
.78611 .18363 m
.78241 .18527 L
s
.80108 .21187 m
.79737 .21349 L
s
.81573 .23948 m
.81201 .24108 L
s
.83006 .2665 m
.82633 .26808 L
s
.8578 .31882 m
.85407 .32036 L
s
.87123 .34415 m
.8675 .34568 L
s
.88439 .36896 m
.88065 .37047 L
s
.89727 .39326 m
.89353 .39475 L
s
.92227 .44039 m
.91851 .44185 L
s
.93439 .46325 m
.93063 .4647 L
s
.94627 .48566 m
.94251 .48709 L
s
.95792 .50763 m
.95416 .50905 L
s
.25 Mabswid
.03716 .31454 m
0 .60363 L
s
.03716 .31454 m
.04327 .31159 L
s
[(0)] .02494 .32044 1 -0.39157 Mshowa
.02537 .40625 m
.03151 .40339 L
s
[(0.5)] .0131 .41196 1 -0.37762 Mshowa
.013 .5025 m
.01917 .49974 L
s
[(1)] .00067 .50802 1 -0.3629 Mshowa
0 .60363 m
.0062 .60098 L
s
[(1.5)] -0.0124 .60894 1 -0.34736 Mshowa
.125 Mabswid
.03485 .33254 m
.03852 .33078 L
s
.03251 .3507 m
.03618 .34895 L
s
.03016 .36904 m
.03383 .3673 L
s
.02778 .38755 m
.03145 .38583 L
s
.02295 .42512 m
.02663 .42342 L
s
.0205 .44418 m
.02419 .44249 L
s
.01802 .46343 m
.02172 .46175 L
s
.01552 .48287 m
.01922 .4812 L
s
.01045 .52232 m
.01416 .52068 L
s
.00788 .54234 m
.01159 .54071 L
s
.00528 .56257 m
.00899 .56095 L
s
.00265 .583 m
.00637 .58139 L
s
.25 Mabswid
.03716 .31454 m
0 .60363 L
s
0 .60363 m
.39787 1 L
s
.39787 1 m
.40529 .73841 L
s
.40529 .73841 m
.03716 .31454 L
s
.68874 0 m
.96935 .52918 L
s
.96935 .52918 m
1 .80566 L
s
1 .80566 m
.70298 .30259 L
s
.70298 .30259 m
.68874 0 L
s
.03716 .31454 m
0 .60363 L
s
0 .60363 m
.70298 .30259 L
s
.70298 .30259 m
.68874 0 L
s
.68874 0 m
.03716 .31454 L
s
.40529 .73841 m
.96935 .52918 L
s
.96935 .52918 m
1 .80566 L
s
1 .80566 m
.39787 1 L
s
.39787 1 m
.40529 .73841 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.003 .414 .856 r
.40144 .734 .40529 .73844 .41158 .74259 .40774 .738 Mtetra
.028 .422 .864 r
.40774 .738 .41158 .74259 .41791 .74675 .41407 .742 Mtetra
.054 .431 .871 r
.41407 .742 .41791 .74675 .42428 .7509 .42045 .74599 Mtetra
.08 .44 .877 r
.42045 .74599 .42428 .7509 .43068 .75504 .42686 .74997 Mtetra
.106 .449 .883 r
.42686 .74997 .43068 .75504 .43712 .75916 .4333 .75393 Mtetra
.133 .458 .887 r
.4333 .75393 .43712 .75916 .44359 .76325 .43978 .75785 Mtetra
.159 .466 .89 r
.43978 .75785 .44359 .76325 .4501 .76729 .4463 .76172 Mtetra
.186 .474 .892 r
.4463 .76172 .4501 .76729 .45665 .77128 .45285 .76554 Mtetra
.211 .482 .894 r
.45285 .76554 .45665 .77128 .46324 .77521 .45944 .76929 Mtetra
.237 .49 .894 r
.45944 .76929 .46324 .77521 .46986 .77907 .46607 .77297 Mtetra
.262 .497 .893 r
.46607 .77297 .46986 .77907 .47652 .78284 .47274 .77656 Mtetra
.287 .504 .892 r
.47274 .77656 .47652 .78284 .48322 .78652 .47944 .78005 Mtetra
.311 .51 .889 r
.47944 .78005 .48322 .78652 .48995 .7901 .48617 .78344 Mtetra
.334 .516 .886 r
.48617 .78344 .48995 .7901 .49672 .79357 .49295 .7867 Mtetra
.356 .521 .882 r
.49295 .7867 .49672 .79357 .50353 .79691 .49976 .78983 Mtetra
.378 .526 .878 r
.49976 .78983 .50353 .79691 .51037 .80012 .50661 .79282 Mtetra
.398 .53 .873 r
.50661 .79282 .51037 .80012 .51725 .80318 .51349 .79566 Mtetra
.418 .534 .867 r
.51349 .79566 .51725 .80318 .52416 .80609 .5204 .79833 Mtetra
.437 .537 .861 r
.5204 .79833 .52416 .80609 .53111 .80883 .52735 .80082 Mtetra
.454 .54 .855 r
.52735 .80082 .53111 .80883 .5381 .81139 .53434 .80313 Mtetra
.471 .542 .848 r
.53434 .80313 .5381 .81139 .54511 .81376 .54135 .80524 Mtetra
.487 .544 .841 r
.54135 .80524 .54511 .81376 .55216 .81593 .5484 .80714 Mtetra
.502 .546 .834 r
.5484 .80714 .55216 .81593 .55924 .8179 .55548 .80882 Mtetra
.515 .547 .827 r
.55548 .80882 .55924 .8179 .56635 .81965 .56258 .81028 Mtetra
.528 .548 .819 r
.56258 .81028 .56635 .81965 .57349 .82118 .56972 .8115 Mtetra
.54 .548 .812 r
.56972 .8115 .57349 .82118 .58065 .82247 .57688 .81247 Mtetra
.551 .549 .805 r
.57688 .81247 .58065 .82247 .58785 .82353 .58408 .8132 Mtetra
.561 .549 .798 r
.58408 .8132 .58785 .82353 .59507 .82434 .59129 .81368 Mtetra
.57 .548 .791 r
.59129 .81368 .59507 .82434 .60232 .8249 .59853 .81389 Mtetra
.579 .548 .784 r
.59853 .81389 .60232 .8249 .60959 .82521 .60579 .81385 Mtetra
.587 .547 .777 r
.60579 .81385 .60959 .82521 .61688 .82526 .61308 .81355 Mtetra
.594 .546 .771 r
.61308 .81355 .61688 .82526 .62419 .82505 .62038 .81297 Mtetra
.6 .545 .765 r
.62038 .81297 .62419 .82505 .63153 .82457 .62771 .81213 Mtetra
.606 .545 .759 r
.62771 .81213 .63153 .82457 .63888 .8238 .63505 .81102 Mtetra
.612 .544 .754 r
.63505 .81102 .63888 .8238 .64625 .82274 .64241 .80961 Mtetra
.618 .544 .749 r
.64241 .80961 .64625 .82274 .65364 .82136 .64978 .80789 Mtetra
.624 .544 .744 r
.64978 .80789 .65364 .82136 .66103 .81963 .65717 .80583 Mtetra
.63 .544 .739 r
.65717 .80583 .66103 .81963 .66844 .81751 .66456 .80338 Mtetra
.637 .546 .734 r
.66456 .80338 .66844 .81751 .67585 .81493 .67196 .8005 Mtetra
.63 .539 .733 r
.67196 .8005 .67585 .81493 .68328 .81241 .67939 .79796 Mtetra
.624 .536 .734 r
.67939 .79796 .68328 .81241 .69074 .80993 .68685 .79575 Mtetra
.633 .543 .735 r
.68685 .79575 .69074 .80993 .69819 .80701 .69431 .79311 Mtetra
.64 .55 .737 r
.69431 .79311 .69819 .80701 .70565 .80369 .70178 .79008 Mtetra
.647 .557 .739 r
.70178 .79008 .70565 .80369 .71311 .80001 .70925 .78671 Mtetra
.654 .564 .741 r
.70925 .78671 .71311 .80001 .72057 .796 .71673 .78302 Mtetra
.66 .571 .743 r
.71673 .78302 .72057 .796 .72803 .7917 .72421 .77903 Mtetra
.666 .578 .746 r
.72421 .77903 .72803 .7917 .73549 .7871 .73169 .77476 Mtetra
.673 .585 .748 r
.73169 .77476 .73549 .7871 .74296 .78222 .73917 .77021 Mtetra
.679 .592 .751 r
.73917 .77021 .74296 .78222 .75041 .77707 .74664 .76539 Mtetra
.686 .6 .754 r
.74664 .76539 .75041 .77707 .75787 .77165 .75412 .76029 Mtetra
.693 .607 .756 r
.75412 .76029 .75787 .77165 .76532 .76597 .76159 .75492 Mtetra
.699 .615 .759 r
.76159 .75492 .76532 .76597 .77276 .76002 .76906 .74928 Mtetra
.706 .623 .761 r
.76906 .74928 .77276 .76002 .7802 .75381 .77652 .74337 Mtetra
.713 .63 .764 r
.77652 .74337 .7802 .75381 .78763 .74735 .78398 .7372 Mtetra
.72 .638 .766 r
.78398 .7372 .78763 .74735 .79505 .74064 .79142 .73078 Mtetra
.727 .646 .768 r
.79142 .73078 .79505 .74064 .80246 .73369 .79886 .7241 Mtetra
.733 .653 .77 r
.79886 .7241 .80246 .73369 .80985 .7265 .80628 .71717 Mtetra
.74 .661 .772 r
.80628 .71717 .80985 .7265 .81724 .71909 .8137 .71001 Mtetra
.747 .668 .774 r
.8137 .71001 .81724 .71909 .82461 .71146 .8211 .70262 Mtetra
.753 .675 .775 r
.8211 .70262 .82461 .71146 .83198 .70362 .82849 .69502 Mtetra
.759 .682 .777 r
.82849 .69502 .83198 .70362 .83932 .69559 .83587 .6872 Mtetra
.765 .689 .779 r
.83587 .6872 .83932 .69559 .84666 .68737 .84323 .6792 Mtetra
.771 .696 .78 r
.84323 .6792 .84666 .68737 .85398 .67897 .85058 .671 Mtetra
.777 .703 .782 r
.85058 .671 .85398 .67897 .86129 .67041 .85792 .66264 Mtetra
.782 .709 .783 r
.85792 .66264 .86129 .67041 .86858 .66169 .86525 .65411 Mtetra
.787 .716 .785 r
.86525 .65411 .86858 .66169 .87586 .65283 .87256 .64543 Mtetra
.792 .722 .786 r
.87256 .64543 .87586 .65283 .88313 .64383 .87985 .6366 Mtetra
.797 .728 .787 r
.87985 .6366 .88313 .64383 .89038 .63471 .88714 .62765 Mtetra
.802 .734 .789 r
.88714 .62765 .89038 .63471 .89762 .62547 .89441 .61859 Mtetra
.806 .74 .79 r
.89441 .61859 .89762 .62547 .90484 .61614 .90166 .60941 Mtetra
.811 .746 .792 r
.90166 .60941 .90484 .61614 .91205 .60671 .90891 .60014 Mtetra
.815 .752 .793 r
.90891 .60014 .91205 .60671 .91925 .5972 .91614 .59078 Mtetra
.819 .758 .795 r
.91614 .59078 .91925 .5972 .92644 .58762 .92336 .58135 Mtetra
.823 .763 .796 r
.92336 .58135 .92644 .58762 .93362 .57798 .93057 .57186 Mtetra
.826 .769 .798 r
.93057 .57186 .93362 .57798 .94078 .56829 .93777 .56231 Mtetra
.83 .775 .8 r
.93777 .56231 .94078 .56829 .94794 .55856 .94496 .55272 Mtetra
.833 .781 .802 r
.94496 .55272 .94794 .55856 .95508 .54879 .95214 .5431 Mtetra
.837 .787 .804 r
.95214 .5431 .95508 .54879 .96222 .53901 .95931 .53345 Mtetra
.84 .793 .806 r
.95931 .53345 .96222 .53901 .96935 .52922 .96648 .5238 Mtetra
.028 .43 .867 r
.39757 .72954 .40144 .734 .40774 .738 .40388 .73338 Mtetra
.052 .438 .874 r
.40388 .73338 .40774 .738 .41407 .742 .41022 .73723 Mtetra
.077 .446 .88 r
.41022 .73723 .41407 .742 .42045 .74599 .4166 .74107 Mtetra
.102 .454 .885 r
.4166 .74107 .42045 .74599 .42686 .74997 .42302 .74489 Mtetra
.127 .462 .889 r
.42302 .74489 .42686 .74997 .4333 .75393 .42947 .74868 Mtetra
.153 .471 .893 r
.42947 .74868 .4333 .75393 .43978 .75785 .43595 .75244 Mtetra
.178 .478 .896 r
.43595 .75244 .43978 .75785 .4463 .76172 .44248 .75615 Mtetra
.204 .486 .897 r
.44248 .75615 .4463 .76172 .45285 .76554 .44904 .7598 Mtetra
.229 .494 .898 r
.44904 .7598 .45285 .76554 .45944 .76929 .45563 .76338 Mtetra
.254 .501 .898 r
.45563 .76338 .45944 .76929 .46607 .77297 .46227 .76688 Mtetra
.278 .507 .897 r
.46227 .76688 .46607 .77297 .47274 .77656 .46894 .77029 Mtetra
.302 .514 .895 r
.46894 .77029 .47274 .77656 .47944 .78005 .47564 .77359 Mtetra
.326 .519 .892 r
.47564 .77359 .47944 .78005 .48617 .78344 .48238 .77678 Mtetra
.348 .525 .889 r
.48238 .77678 .48617 .78344 .49295 .7867 .48916 .77984 Mtetra
.37 .53 .884 r
.48916 .77984 .49295 .7867 .49976 .78983 .49598 .78277 Mtetra
.391 .534 .88 r
.49598 .78277 .49976 .78983 .50661 .79282 .50283 .78554 Mtetra
.411 .538 .874 r
.50283 .78554 .50661 .79282 .51349 .79566 .50971 .78816 Mtetra
.431 .542 .868 r
.50971 .78816 .51349 .79566 .5204 .79833 .51663 .79059 Mtetra
.449 .545 .862 r
.51663 .79059 .5204 .79833 .52735 .80082 .52358 .79285 Mtetra
.466 .548 .856 r
.52358 .79285 .52735 .80082 .53434 .80313 .53056 .7949 Mtetra
.483 .55 .849 r
.53056 .7949 .53434 .80313 .54135 .80524 .53758 .79675 Mtetra
.498 .552 .841 r
.53758 .79675 .54135 .80524 .5484 .80714 .54463 .79838 Mtetra
.513 .553 .834 r
.54463 .79838 .5484 .80714 .55548 .80882 .55171 .79978 Mtetra
.526 .554 .827 r
.55171 .79978 .55548 .80882 .56258 .81028 .55881 .80094 Mtetra
.539 .555 .819 r
.55881 .80094 .56258 .81028 .56972 .8115 .56595 .80186 Mtetra
.55 .555 .812 r
.56595 .80186 .56972 .8115 .57688 .81247 .57311 .80252 Mtetra
.561 .555 .805 r
.57311 .80252 .57688 .81247 .58408 .8132 .5803 .80292 Mtetra
.571 .555 .797 r
.5803 .80292 .58408 .8132 .59129 .81368 .58751 .80306 Mtetra
.58 .554 .79 r
.58751 .80306 .59129 .81368 .59853 .81389 .59474 .80293 Mtetra
.588 .554 .783 r
.59474 .80293 .59853 .81389 .60579 .81385 .602 .80254 Mtetra
.595 .553 .777 r
.602 .80254 .60579 .81385 .61308 .81355 .60928 .80188 Mtetra
.602 .552 .771 r
.60928 .80188 .61308 .81355 .62038 .81297 .61657 .80095 Mtetra
.608 .551 .765 r
.61657 .80095 .62038 .81297 .62771 .81213 .62389 .79976 Mtetra
.614 .55 .759 r
.62389 .79976 .62771 .81213 .63505 .81102 .63122 .79829 Mtetra
.619 .549 .753 r
.63122 .79829 .63505 .81102 .64241 .80961 .63857 .79653 Mtetra
.624 .548 .748 r
.63857 .79653 .64241 .80961 .64978 .80789 .64593 .79448 Mtetra
.63 .548 .744 r
.64593 .79448 .64978 .80789 .65717 .80583 .6533 .79211 Mtetra
.636 .548 .739 r
.6533 .79211 .65717 .80583 .66456 .80338 .66068 .78936 Mtetra
.642 .549 .734 r
.66068 .78936 .66456 .80338 .67196 .8005 .66807 .7862 Mtetra
.631 .54 .734 r
.66807 .7862 .67196 .8005 .67939 .79796 .67549 .78363 Mtetra
.62 .534 .736 r
.67549 .78363 .67939 .79796 .68685 .79575 .68296 .78167 Mtetra
.628 .541 .737 r
.68296 .78167 .68685 .79575 .69431 .79311 .69043 .7793 Mtetra
.635 .548 .739 r
.69043 .7793 .69431 .79311 .70178 .79008 .69791 .77655 Mtetra
.642 .555 .741 r
.69791 .77655 .70178 .79008 .70925 .78671 .7054 .77347 Mtetra
.648 .561 .743 r
.7054 .77347 .70925 .78671 .71673 .78302 .71289 .77009 Mtetra
.655 .568 .746 r
.71289 .77009 .71673 .78302 .72421 .77903 .72038 .76642 Mtetra
.661 .575 .748 r
.72038 .76642 .72421 .77903 .73169 .77476 .72788 .76247 Mtetra
.667 .583 .751 r
.72788 .76247 .73169 .77476 .73917 .77021 .73537 .75825 Mtetra
.674 .59 .754 r
.73537 .75825 .73917 .77021 .74664 .76539 .74287 .75375 Mtetra
.68 .598 .756 r
.74287 .75375 .74664 .76539 .75412 .76029 .75037 .74897 Mtetra
.687 .605 .759 r
.75037 .74897 .75412 .76029 .76159 .75492 .75787 .74392 Mtetra
.694 .613 .761 r
.75787 .74392 .76159 .75492 .76906 .74928 .76536 .73859 Mtetra
.701 .621 .764 r
.76536 .73859 .76906 .74928 .77652 .74337 .77284 .73298 Mtetra
.708 .629 .766 r
.77284 .73298 .77652 .74337 .78398 .7372 .78032 .7271 Mtetra
.716 .637 .769 r
.78032 .7271 .78398 .7372 .79142 .73078 .78779 .72095 Mtetra
.723 .645 .771 r
.78779 .72095 .79142 .73078 .79886 .7241 .79526 .71454 Mtetra
.729 .653 .773 r
.79526 .71454 .79886 .7241 .80628 .71717 .80271 .70787 Mtetra
.736 .66 .775 r
.80271 .70787 .80628 .71717 .8137 .71001 .81015 .70096 Mtetra
.743 .668 .777 r
.81015 .70096 .8137 .71001 .8211 .70262 .81758 .69381 Mtetra
.749 .675 .778 r
.81758 .69381 .8211 .70262 .82849 .69502 .825 .68643 Mtetra
.756 .682 .78 r
.825 .68643 .82849 .69502 .83587 .6872 .83241 .67884 Mtetra
.762 .689 .782 r
.83241 .67884 .83587 .6872 .84323 .6792 .8398 .67104 Mtetra
.768 .696 .783 r
.8398 .67104 .84323 .6792 .85058 .671 .84718 .66305 Mtetra
.774 .703 .784 r
.84718 .66305 .85058 .671 .85792 .66264 .85455 .65488 Mtetra
.779 .709 .786 r
.85455 .65488 .85792 .66264 .86525 .65411 .8619 .64653 Mtetra
.785 .716 .787 r
.8619 .64653 .86525 .65411 .87256 .64543 .86924 .63803 Mtetra
.79 .722 .789 r
.86924 .63803 .87256 .64543 .87985 .6366 .87657 .62938 Mtetra
.795 .728 .79 r
.87657 .62938 .87985 .6366 .88714 .62765 .88388 .6206 Mtetra
.799 .734 .791 r
.88388 .6206 .88714 .62765 .89441 .61859 .89118 .6117 Mtetra
.804 .74 .793 r
.89118 .6117 .89441 .61859 .90166 .60941 .89847 .60268 Mtetra
.808 .746 .794 r
.89847 .60268 .90166 .60941 .90891 .60014 .90575 .59356 Mtetra
.813 .752 .796 r
.90575 .59356 .90891 .60014 .91614 .59078 .91301 .58435 Mtetra
.817 .758 .797 r
.91301 .58435 .91614 .59078 .92336 .58135 .92027 .57507 Mtetra
.82 .763 .799 r
.92027 .57507 .92336 .58135 .93057 .57186 .92751 .56572 Mtetra
.824 .769 .801 r
.92751 .56572 .93057 .57186 .93777 .56231 .93474 .55631 Mtetra
.828 .775 .802 r
.93474 .55631 .93777 .56231 .94496 .55272 .94197 .54686 Mtetra
.831 .781 .804 r
.94197 .54686 .94496 .55272 .95214 .5431 .94918 .53738 Mtetra
.834 .786 .806 r
.94918 .53738 .95214 .5431 .95931 .53345 .95639 .52787 Mtetra
.837 .792 .809 r
.95639 .52787 .95931 .53345 .96648 .5238 .96359 .51835 Mtetra
.052 .446 .877 r
.39368 .72507 .39757 .72954 .40388 .73338 .4 .72876 Mtetra
.075 .453 .883 r
.4 .72876 .40388 .73338 .41022 .73723 .40635 .73245 Mtetra
.099 .46 .888 r
.40635 .73245 .41022 .73723 .4166 .74107 .41274 .73613 Mtetra
.123 .468 .892 r
.41274 .73613 .4166 .74107 .42302 .74489 .41916 .7398 Mtetra
.147 .475 .896 r
.41916 .7398 .42302 .74489 .42947 .74868 .42562 .74344 Mtetra
.172 .483 .899 r
.42562 .74344 .42947 .74868 .43595 .75244 .43211 .74703 Mtetra
.197 .49 .901 r
.43211 .74703 .43595 .75244 .44248 .75615 .43864 .75058 Mtetra
.221 .497 .902 r
.43864 .75058 .44248 .75615 .44904 .7598 .44521 .75406 Mtetra
.246 .504 .902 r
.44521 .75406 .44904 .7598 .45563 .76338 .45181 .75747 Mtetra
.27 .511 .901 r
.45181 .75747 .45563 .76338 .46227 .76688 .45845 .7608 Mtetra
.294 .517 .9 r
.45845 .7608 .46227 .76688 .46894 .77029 .46512 .76402 Mtetra
.317 .523 .897 r
.46512 .76402 .46894 .77029 .47564 .77359 .47183 .76714 Mtetra
.34 .529 .894 r
.47183 .76714 .47564 .77359 .48238 .77678 .47858 .77014 Mtetra
.362 .534 .891 r
.47858 .77014 .48238 .77678 .48916 .77984 .48536 .773 Mtetra
.384 .538 .886 r
.48536 .773 .48916 .77984 .49598 .78277 .49218 .77572 Mtetra
.404 .543 .881 r
.49218 .77572 .49598 .78277 .50283 .78554 .49903 .77828 Mtetra
.424 .547 .876 r
.49903 .77828 .50283 .78554 .50971 .78816 .50592 .78067 Mtetra
.443 .55 .869 r
.50592 .78067 .50971 .78816 .51663 .79059 .51284 .78288 Mtetra
.461 .553 .863 r
.51284 .78288 .51663 .79059 .52358 .79285 .5198 .7849 Mtetra
.478 .555 .856 r
.5198 .7849 .52358 .79285 .53056 .7949 .52678 .7867 Mtetra
.494 .557 .849 r
.52678 .7867 .53056 .7949 .53758 .79675 .5338 .78829 Mtetra
.51 .559 .842 r
.5338 .78829 .53758 .79675 .54463 .79838 .54085 .78965 Mtetra
.524 .56 .834 r
.54085 .78965 .54463 .79838 .55171 .79978 .54793 .79077 Mtetra
.537 .561 .827 r
.54793 .79077 .55171 .79978 .55881 .80094 .55503 .79164 Mtetra
.549 .561 .819 r
.55503 .79164 .55881 .80094 .56595 .80186 .56217 .79226 Mtetra
.561 .562 .812 r
.56217 .79226 .56595 .80186 .57311 .80252 .56932 .7926 Mtetra
.571 .562 .804 r
.56932 .7926 .57311 .80252 .5803 .80292 .57651 .79268 Mtetra
.581 .561 .797 r
.57651 .79268 .5803 .80292 .58751 .80306 .58372 .79249 Mtetra
.589 .56 .79 r
.58372 .79249 .58751 .80306 .59474 .80293 .59095 .79202 Mtetra
.597 .559 .783 r
.59095 .79202 .59474 .80293 .602 .80254 .5982 .79128 Mtetra
.604 .558 .776 r
.5982 .79128 .602 .80254 .60928 .80188 .60547 .79026 Mtetra
.61 .557 .77 r
.60547 .79026 .60928 .80188 .61657 .80095 .61276 .78898 Mtetra
.616 .556 .764 r
.61276 .78898 .61657 .80095 .62389 .79976 .62006 .78743 Mtetra
.621 .554 .758 r
.62006 .78743 .62389 .79976 .63122 .79829 .62739 .78561 Mtetra
.626 .553 .753 r
.62739 .78561 .63122 .79829 .63857 .79653 .63473 .78352 Mtetra
.631 .552 .748 r
.63473 .78352 .63857 .79653 .64593 .79448 .64208 .78115 Mtetra
.636 .552 .743 r
.64208 .78115 .64593 .79448 .6533 .79211 .64944 .77847 Mtetra
.641 .552 .739 r
.64944 .77847 .6533 .79211 .66068 .78936 .65681 .77544 Mtetra
.647 .553 .735 r
.65681 .77544 .66068 .78936 .66807 .7862 .66418 .772 Mtetra
.631 .542 .735 r
.66418 .772 .66807 .7862 .67549 .78363 .67161 .76942 Mtetra
.615 .533 .738 r
.67161 .76942 .67549 .78363 .68296 .78167 .67908 .76769 Mtetra
.623 .54 .739 r
.67908 .76769 .68296 .78167 .69043 .7793 .68656 .76556 Mtetra
.63 .546 .741 r
.68656 .76556 .69043 .7793 .69791 .77655 .69404 .76308 Mtetra
.637 .553 .743 r
.69404 .76308 .69791 .77655 .7054 .77347 .70154 .76029 Mtetra
.643 .559 .745 r
.70154 .76029 .7054 .77347 .71289 .77009 .70904 .75721 Mtetra
.649 .566 .748 r
.70904 .75721 .71289 .77009 .72038 .76642 .71655 .75386 Mtetra
.655 .573 .751 r
.71655 .75386 .72038 .76642 .72788 .76247 .72406 .75023 Mtetra
.661 .58 .753 r
.72406 .75023 .72788 .76247 .73537 .75825 .73158 .74633 Mtetra
.668 .588 .756 r
.73158 .74633 .73537 .75825 .74287 .75375 .7391 .74216 Mtetra
.675 .596 .759 r
.7391 .74216 .74287 .75375 .75037 .74897 .74662 .7377 Mtetra
.682 .604 .762 r
.74662 .7377 .75037 .74897 .75787 .74392 .75413 .73296 Mtetra
.689 .612 .764 r
.75413 .73296 .75787 .74392 .76536 .73859 .76165 .72794 Mtetra
.696 .62 .767 r
.76165 .72794 .76536 .73859 .77284 .73298 .76916 .72263 Mtetra
.704 .628 .769 r
.76916 .72263 .77284 .73298 .78032 .7271 .77666 .71703 Mtetra
.711 .636 .772 r
.77666 .71703 .78032 .7271 .78779 .72095 .78416 .71116 Mtetra
.718 .644 .774 r
.78416 .71116 .78779 .72095 .79526 .71454 .79165 .70502 Mtetra
.725 .652 .776 r
.79165 .70502 .79526 .71454 .80271 .70787 .79913 .6986 Mtetra
.732 .66 .778 r
.79913 .6986 .80271 .70787 .81015 .70096 .8066 .69194 Mtetra
.739 .667 .78 r
.8066 .69194 .81015 .70096 .81758 .69381 .81405 .68502 Mtetra
.746 .675 .781 r
.81405 .68502 .81758 .69381 .825 .68643 .8215 .67787 Mtetra
.753 .682 .783 r
.8215 .67787 .825 .68643 .83241 .67884 .82893 .67049 Mtetra
.759 .689 .784 r
.82893 .67049 .83241 .67884 .8398 .67104 .83636 .6629 Mtetra
.765 .696 .786 r
.83636 .6629 .8398 .67104 .84718 .66305 .84377 .65511 Mtetra
.771 .703 .787 r
.84377 .65511 .84718 .66305 .85455 .65488 .85116 .64713 Mtetra
.776 .709 .789 r
.85116 .64713 .85455 .65488 .8619 .64653 .85855 .63897 Mtetra
.782 .716 .79 r
.85855 .63897 .8619 .64653 .86924 .63803 .86592 .63065 Mtetra
.787 .722 .791 r
.86592 .63065 .86924 .63803 .87657 .62938 .87328 .62217 Mtetra
.792 .728 .793 r
.87328 .62217 .87657 .62938 .88388 .6206 .88062 .61355 Mtetra
.797 .734 .794 r
.88062 .61355 .88388 .6206 .89118 .6117 .88795 .60481 Mtetra
.802 .74 .795 r
.88795 .60481 .89118 .6117 .89847 .60268 .89527 .59595 Mtetra
.806 .746 .797 r
.89527 .59595 .89847 .60268 .90575 .59356 .90258 .58698 Mtetra
.81 .752 .798 r
.90258 .58698 .90575 .59356 .91301 .58435 .90988 .57792 Mtetra
.814 .758 .8 r
.90988 .57792 .91301 .58435 .92027 .57507 .91716 .56878 Mtetra
.818 .763 .801 r
.91716 .56878 .92027 .57507 .92751 .56572 .92444 .55957 Mtetra
.822 .769 .803 r
.92444 .55957 .92751 .56572 .93474 .55631 .9317 .5503 Mtetra
.825 .775 .805 r
.9317 .5503 .93474 .55631 .94197 .54686 .93896 .54099 Mtetra
.828 .78 .807 r
.93896 .54099 .94197 .54686 .94918 .53738 .94621 .53164 Mtetra
.832 .786 .809 r
.94621 .53164 .94918 .53738 .95639 .52787 .95346 .52227 Mtetra
.835 .792 .811 r
.95346 .52227 .95639 .52787 .96359 .51835 .96069 .51288 Mtetra
.076 .461 .886 r
.38978 .72058 .39368 .72507 .4 .72876 .3961 .72411 Mtetra
.097 .468 .891 r
.3961 .72411 .4 .72876 .40635 .73245 .40246 .72765 Mtetra
.12 .474 .895 r
.40246 .72765 .40635 .73245 .41274 .73613 .40886 .73119 Mtetra
.143 .481 .899 r
.40886 .73119 .41274 .73613 .41916 .7398 .41529 .7347 Mtetra
.167 .488 .902 r
.41529 .7347 .41916 .7398 .42562 .74344 .42175 .73818 Mtetra
.19 .495 .904 r
.42175 .73818 .42562 .74344 .43211 .74703 .42825 .74162 Mtetra
.214 .501 .905 r
.42825 .74162 .43211 .74703 .43864 .75058 .43479 .745 Mtetra
.238 .508 .906 r
.43479 .745 .43864 .75058 .44521 .75406 .44136 .74832 Mtetra
.262 .515 .905 r
.44136 .74832 .44521 .75406 .45181 .75747 .44797 .75156 Mtetra
.286 .521 .904 r
.44797 .75156 .45181 .75747 .45845 .7608 .45461 .75471 Mtetra
.309 .527 .903 r
.45461 .75471 .45845 .7608 .46512 .76402 .46129 .75776 Mtetra
.332 .532 .9 r
.46129 .75776 .46512 .76402 .47183 .76714 .46801 .7607 Mtetra
.354 .538 .897 r
.46801 .7607 .47183 .76714 .47858 .77014 .47476 .76351 Mtetra
.376 .542 .892 r
.47476 .76351 .47858 .77014 .48536 .773 .48155 .76618 Mtetra
.397 .547 .888 r
.48155 .76618 .48536 .773 .49218 .77572 .48837 .76869 Mtetra
.417 .551 .882 r
.48837 .76869 .49218 .77572 .49903 .77828 .49523 .77104 Mtetra
.436 .554 .877 r
.49523 .77104 .49903 .77828 .50592 .78067 .50212 .77322 Mtetra
.455 .558 .87 r
.50212 .77322 .50592 .78067 .51284 .78288 .50904 .7752 Mtetra
.473 .56 .864 r
.50904 .7752 .51284 .78288 .5198 .7849 .516 .77698 Mtetra
.49 .563 .857 r
.516 .77698 .5198 .7849 .52678 .7867 .52299 .77854 Mtetra
.505 .564 .85 r
.52299 .77854 .52678 .7867 .5338 .78829 .53001 .77987 Mtetra
.52 .566 .842 r
.53001 .77987 .5338 .78829 .54085 .78965 .53706 .78096 Mtetra
.534 .567 .834 r
.53706 .78096 .54085 .78965 .54793 .79077 .54414 .78181 Mtetra
.547 .568 .827 r
.54414 .78181 .54793 .79077 .55503 .79164 .55124 .78239 Mtetra
.559 .568 .819 r
.55124 .78239 .55503 .79164 .56217 .79226 .55838 .7827 Mtetra
.571 .568 .811 r
.55838 .7827 .56217 .79226 .56932 .7926 .56553 .78273 Mtetra
.581 .568 .804 r
.56553 .78273 .56932 .7926 .57651 .79268 .57272 .78249 Mtetra
.59 .567 .797 r
.57272 .78249 .57651 .79268 .58372 .79249 .57992 .78196 Mtetra
.598 .566 .789 r
.57992 .78196 .58372 .79249 .59095 .79202 .58715 .78115 Mtetra
.606 .565 .782 r
.58715 .78115 .59095 .79202 .5982 .79128 .59439 .78006 Mtetra
.612 .564 .776 r
.59439 .78006 .5982 .79128 .60547 .79026 .60166 .77869 Mtetra
.618 .562 .769 r
.60166 .77869 .60547 .79026 .61276 .78898 .60894 .77705 Mtetra
.623 .561 .763 r
.60894 .77705 .61276 .78898 .62006 .78743 .61624 .77515 Mtetra
.628 .559 .758 r
.61624 .77515 .62006 .78743 .62739 .78561 .62355 .77299 Mtetra
.632 .558 .752 r
.62355 .77299 .62739 .78561 .63473 .78352 .63088 .77057 Mtetra
.637 .557 .748 r
.63088 .77057 .63473 .78352 .64208 .78115 .63822 .76788 Mtetra
.641 .556 .743 r
.63822 .76788 .64208 .78115 .64944 .77847 .64557 .76491 Mtetra
.646 .556 .739 r
.64557 .76491 .64944 .77847 .65681 .77544 .65293 .7616 Mtetra
.651 .556 .735 r
.65293 .7616 .65681 .77544 .66418 .772 .6603 .75792 Mtetra
.631 .543 .736 r
.6603 .75792 .66418 .772 .67161 .76942 .66772 .75532 Mtetra
.611 .531 .74 r
.66772 .75532 .67161 .76942 .67908 .76769 .67519 .7538 Mtetra
.618 .538 .741 r
.67519 .7538 .67908 .76769 .68656 .76556 .68268 .75191 Mtetra
.625 .544 .743 r
.68268 .75191 .68656 .76556 .69404 .76308 .69018 .74968 Mtetra
.631 .55 .745 r
.69018 .74968 .69404 .76308 .70154 .76029 .69768 .74717 Mtetra
.637 .557 .747 r
.69768 .74717 .70154 .76029 .70904 .75721 .7052 .74439 Mtetra
.643 .563 .75 r
.7052 .74439 .70904 .75721 .71655 .75386 .71272 .74135 Mtetra
.649 .571 .753 r
.71272 .74135 .71655 .75386 .72406 .75023 .72025 .73804 Mtetra
.655 .578 .756 r
.72025 .73804 .72406 .75023 .73158 .74633 .72778 .73447 Mtetra
.662 .586 .759 r
.72778 .73447 .73158 .74633 .7391 .74216 .73532 .73061 Mtetra
.669 .593 .762 r
.73532 .73061 .7391 .74216 .74662 .7377 .74286 .72648 Mtetra
.676 .602 .764 r
.74286 .72648 .74662 .7377 .75413 .73296 .7504 .72205 Mtetra
.684 .61 .767 r
.7504 .72205 .75413 .73296 .76165 .72794 .75793 .71733 Mtetra
.691 .618 .77 r
.75793 .71733 .76165 .72794 .76916 .72263 .76547 .71232 Mtetra
.699 .627 .772 r
.76547 .71232 .76916 .72263 .77666 .71703 .773 .70701 Mtetra
.706 .635 .775 r
.773 .70701 .77666 .71703 .78416 .71116 .78052 .70141 Mtetra
.714 .643 .777 r
.78052 .70141 .78416 .71116 .79165 .70502 .78803 .69553 Mtetra
.721 .651 .779 r
.78803 .69553 .79165 .70502 .79913 .6986 .79554 .68937 Mtetra
.729 .659 .781 r
.79554 .68937 .79913 .6986 .8066 .69194 .80303 .68295 Mtetra
.736 .667 .783 r
.80303 .68295 .8066 .69194 .81405 .68502 .81052 .67627 Mtetra
.743 .674 .784 r
.81052 .67627 .81405 .68502 .8215 .67787 .81799 .66934 Mtetra
.749 .682 .786 r
.81799 .66934 .8215 .67787 .82893 .67049 .82546 .66218 Mtetra
.756 .689 .787 r
.82546 .66218 .82893 .67049 .83636 .6629 .83291 .65479 Mtetra
.762 .696 .789 r
.83291 .65479 .83636 .6629 .84377 .65511 .84034 .64719 Mtetra
.768 .703 .79 r
.84034 .64719 .84377 .65511 .85116 .64713 .84777 .6394 Mtetra
.774 .709 .791 r
.84777 .6394 .85116 .64713 .85855 .63897 .85518 .63142 Mtetra
.779 .716 .793 r
.85518 .63142 .85855 .63897 .86592 .63065 .86258 .62327 Mtetra
.785 .722 .794 r
.86258 .62327 .86592 .63065 .87328 .62217 .86997 .61496 Mtetra
.79 .728 .795 r
.86997 .61496 .87328 .62217 .88062 .61355 .87735 .60651 Mtetra
.795 .734 .796 r
.87735 .60651 .88062 .61355 .88795 .60481 .88471 .59792 Mtetra
.799 .74 .798 r
.88471 .59792 .88795 .60481 .89527 .59595 .89206 .58921 Mtetra
.804 .746 .799 r
.89206 .58921 .89527 .59595 .90258 .58698 .8994 .58039 Mtetra
.808 .752 .801 r
.8994 .58039 .90258 .58698 .90988 .57792 .90673 .57148 Mtetra
.812 .758 .802 r
.90673 .57148 .90988 .57792 .91716 .56878 .91405 .56248 Mtetra
.816 .763 .804 r
.91405 .56248 .91716 .56878 .92444 .55957 .92135 .55341 Mtetra
.819 .769 .805 r
.92135 .55341 .92444 .55957 .9317 .5503 .92865 .54427 Mtetra
.823 .775 .807 r
.92865 .54427 .9317 .5503 .93896 .54099 .93594 .5351 Mtetra
.826 .78 .809 r
.93594 .5351 .93896 .54099 .94621 .53164 .94323 .52588 Mtetra
.829 .786 .811 r
.94323 .52588 .94621 .53164 .95346 .52227 .95051 .51664 Mtetra
.832 .792 .813 r
.95051 .51664 .95346 .52227 .96069 .51288 .95778 .50739 Mtetra
.098 .476 .894 r
.38585 .71606 .38978 .72058 .3961 .72411 .39219 .71945 Mtetra
.119 .481 .898 r
.39219 .71945 .3961 .72411 .40246 .72765 .39856 .72284 Mtetra
.141 .487 .902 r
.39856 .72284 .40246 .72765 .40886 .73119 .40496 .72623 Mtetra
.163 .493 .905 r
.40496 .72623 .40886 .73119 .41529 .7347 .4114 .72959 Mtetra
.185 .499 .907 r
.4114 .72959 .41529 .7347 .42175 .73818 .41787 .73292 Mtetra
.208 .506 .909 r
.41787 .73292 .42175 .73818 .42825 .74162 .42438 .7362 Mtetra
.231 .512 .909 r
.42438 .7362 .42825 .74162 .43479 .745 .43092 .73943 Mtetra
.255 .518 .909 r
.43092 .73943 .43479 .745 .44136 .74832 .4375 .74258 Mtetra
.278 .524 .909 r
.4375 .74258 .44136 .74832 .44797 .75156 .44411 .74566 Mtetra
.301 .53 .907 r
.44411 .74566 .44797 .75156 .45461 .75471 .45076 .74864 Mtetra
.323 .536 .905 r
.45076 .74864 .45461 .75471 .46129 .75776 .45745 .75151 Mtetra
.346 .541 .902 r
.45745 .75151 .46129 .75776 .46801 .7607 .46417 .75427 Mtetra
.368 .546 .898 r
.46417 .75427 .46801 .7607 .47476 .76351 .47093 .75689 Mtetra
.389 .551 .894 r
.47093 .75689 .47476 .76351 .48155 .76618 .47772 .75937 Mtetra
.409 .555 .889 r
.47772 .75937 .48155 .76618 .48837 .76869 .48455 .76168 Mtetra
.429 .559 .884 r
.48455 .76168 .48837 .76869 .49523 .77104 .49141 .76383 Mtetra
.448 .562 .878 r
.49141 .76383 .49523 .77104 .50212 .77322 .4983 .76579 Mtetra
.467 .565 .871 r
.4983 .76579 .50212 .77322 .50904 .7752 .50523 .76754 Mtetra
.484 .568 .864 r
.50523 .76754 .50904 .7752 .516 .77698 .51219 .76909 Mtetra
.501 .57 .857 r
.51219 .76909 .516 .77698 .52299 .77854 .51918 .77041 Mtetra
.516 .571 .85 r
.51918 .77041 .52299 .77854 .53001 .77987 .52621 .77149 Mtetra
.531 .573 .842 r
.52621 .77149 .53001 .77987 .53706 .78096 .53326 .77231 Mtetra
.545 .574 .835 r
.53326 .77231 .53706 .78096 .54414 .78181 .54034 .77288 Mtetra
.557 .574 .827 r
.54034 .77288 .54414 .78181 .55124 .78239 .54744 .77317 Mtetra
.569 .574 .819 r
.54744 .77317 .55124 .78239 .55838 .7827 .55458 .77319 Mtetra
.58 .574 .811 r
.55458 .77319 .55838 .7827 .56553 .78273 .56173 .77291 Mtetra
.59 .574 .804 r
.56173 .77291 .56553 .78273 .57272 .78249 .56891 .77235 Mtetra
.599 .573 .796 r
.56891 .77235 .57272 .78249 .57992 .78196 .57612 .77149 Mtetra
.607 .572 .789 r
.57612 .77149 .57992 .78196 .58715 .78115 .58334 .77033 Mtetra
.614 .571 .782 r
.58334 .77033 .58715 .78115 .59439 .78006 .59058 .76889 Mtetra
.621 .569 .775 r
.59058 .76889 .59439 .78006 .60166 .77869 .59784 .76717 Mtetra
.626 .567 .769 r
.59784 .76717 .60166 .77869 .60894 .77705 .60511 .76518 Mtetra
.631 .565 .763 r
.60511 .76518 .60894 .77705 .61624 .77515 .61241 .76292 Mtetra
.635 .564 .757 r
.61241 .76292 .61624 .77515 .62355 .77299 .61971 .76042 Mtetra
.639 .562 .752 r
.61971 .76042 .62355 .77299 .63088 .77057 .62703 .75767 Mtetra
.642 .56 .747 r
.62703 .75767 .63088 .77057 .63822 .76788 .63437 .75467 Mtetra
.646 .559 .743 r
.63437 .75467 .63822 .76788 .64557 .76491 .64171 .75141 Mtetra
.65 .559 .739 r
.64171 .75141 .64557 .76491 .65293 .7616 .64906 .74785 Mtetra
.655 .559 .735 r
.64906 .74785 .65293 .7616 .6603 .75792 .65642 .74394 Mtetra
.632 .544 .738 r
.65642 .74394 .6603 .75792 .66772 .75532 .66383 .74132 Mtetra
.607 .53 .742 r
.66383 .74132 .66772 .75532 .67519 .7538 .67131 .73999 Mtetra
.614 .536 .743 r
.67131 .73999 .67519 .7538 .68268 .75191 .6788 .73832 Mtetra
.62 .542 .745 r
.6788 .73832 .68268 .75191 .69018 .74968 .68631 .73634 Mtetra
.626 .548 .747 r
.68631 .73634 .69018 .74968 .69768 .74717 .69382 .73411 Mtetra
.631 .554 .75 r
.69382 .73411 .69768 .74717 .7052 .74439 .70135 .73162 Mtetra
.637 .561 .752 r
.70135 .73162 .7052 .74439 .71272 .74135 .70888 .72889 Mtetra
.643 .568 .755 r
.70888 .72889 .71272 .74135 .72025 .73804 .71643 .7259 Mtetra
.649 .575 .758 r
.71643 .7259 .72025 .73804 .72778 .73447 .72398 .72265 Mtetra
.656 .583 .761 r
.72398 .72265 .72778 .73447 .73532 .73061 .73154 .71912 Mtetra
.663 .591 .764 r
.73154 .71912 .73532 .73061 .74286 .72648 .7391 .7153 Mtetra
.67 .6 .767 r
.7391 .7153 .74286 .72648 .7504 .72205 .74666 .71119 Mtetra
.678 .608 .77 r
.74666 .71119 .7504 .72205 .75793 .71733 .75422 .70678 Mtetra
.686 .617 .773 r
.75422 .70678 .75793 .71733 .76547 .71232 .76177 .70206 Mtetra
.694 .625 .775 r
.76177 .70206 .76547 .71232 .773 .70701 .76933 .69703 Mtetra
.702 .634 .778 r
.76933 .69703 .773 .70701 .78052 .70141 .77687 .69171 Mtetra
.709 .642 .78 r
.77687 .69171 .78052 .70141 .78803 .69553 .78441 .68609 Mtetra
.717 .65 .782 r
.78441 .68609 .78803 .69553 .79554 .68937 .79194 .68018 Mtetra
.724 .658 .784 r
.79194 .68018 .79554 .68937 .80303 .68295 .79946 .674 Mtetra
.732 .666 .786 r
.79946 .674 .80303 .68295 .81052 .67627 .80698 .66754 Mtetra
.739 .674 .787 r
.80698 .66754 .81052 .67627 .81799 .66934 .81448 .66084 Mtetra
.746 .681 .789 r
.81448 .66084 .81799 .66934 .82546 .66218 .82197 .65388 Mtetra
.753 .689 .79 r
.82197 .65388 .82546 .66218 .83291 .65479 .82945 .6467 Mtetra
.759 .696 .792 r
.82945 .6467 .83291 .65479 .84034 .64719 .83691 .6393 Mtetra
.765 .703 .793 r
.83691 .6393 .84034 .64719 .84777 .6394 .84437 .63169 Mtetra
.771 .709 .794 r
.84437 .63169 .84777 .6394 .85518 .63142 .85181 .62389 Mtetra
.777 .716 .795 r
.85181 .62389 .85518 .63142 .86258 .62327 .85924 .61591 Mtetra
.782 .722 .797 r
.85924 .61591 .86258 .62327 .86997 .61496 .86666 .60776 Mtetra
.787 .728 .798 r
.86666 .60776 .86997 .61496 .87735 .60651 .87406 .59947 Mtetra
.792 .734 .799 r
.87406 .59947 .87735 .60651 .88471 .59792 .88146 .59103 Mtetra
.797 .74 .8 r
.88146 .59103 .88471 .59792 .89206 .58921 .88884 .58247 Mtetra
.801 .746 .802 r
.88884 .58247 .89206 .58921 .8994 .58039 .89621 .5738 Mtetra
.805 .752 .803 r
.89621 .5738 .8994 .58039 .90673 .57148 .90357 .56503 Mtetra
.81 .758 .804 r
.90357 .56503 .90673 .57148 .91405 .56248 .91092 .55617 Mtetra
.813 .763 .806 r
.91092 .55617 .91405 .56248 .92135 .55341 .91826 .54723 Mtetra
.817 .769 .808 r
.91826 .54723 .92135 .55341 .92865 .54427 .92559 .53823 Mtetra
.82 .774 .809 r
.92559 .53823 .92865 .54427 .93594 .5351 .93291 .52919 Mtetra
.824 .78 .811 r
.93291 .52919 .93594 .5351 .94323 .52588 .94023 .5201 Mtetra
.827 .786 .813 r
.94023 .5201 .94323 .52588 .95051 .51664 .94754 .51099 Mtetra
.829 .791 .816 r
.94754 .51099 .95051 .51664 .95778 .50739 .95485 .50187 Mtetra
.12 .49 .902 r
.38192 .71153 .38585 .71606 .39219 .71945 .38826 .71477 Mtetra
.14 .494 .905 r
.38826 .71477 .39219 .71945 .39856 .72284 .39463 .71802 Mtetra
.16 .5 .908 r
.39463 .71802 .39856 .72284 .40496 .72623 .40105 .72126 Mtetra
.182 .505 .91 r
.40105 .72126 .40496 .72623 .4114 .72959 .40749 .72447 Mtetra
.203 .511 .912 r
.40749 .72447 .4114 .72959 .41787 .73292 .41397 .72765 Mtetra
.225 .517 .913 r
.41397 .72765 .41787 .73292 .42438 .7362 .42048 .73078 Mtetra
.248 .522 .913 r
.42048 .73078 .42438 .7362 .43092 .73943 .42703 .73385 Mtetra
.27 .528 .913 r
.42703 .73385 .43092 .73943 .4375 .74258 .43362 .73684 Mtetra
.293 .534 .912 r
.43362 .73684 .4375 .74258 .44411 .74566 .44024 .73976 Mtetra
.315 .539 .91 r
.44024 .73976 .44411 .74566 .45076 .74864 .4469 .74257 Mtetra
.337 .545 .907 r
.4469 .74257 .45076 .74864 .45745 .75151 .45359 .74527 Mtetra
.359 .55 .904 r
.45359 .74527 .45745 .75151 .46417 .75427 .46032 .74785 Mtetra
.38 .554 .9 r
.46032 .74785 .46417 .75427 .47093 .75689 .46708 .75029 Mtetra
.401 .559 .896 r
.46708 .75029 .47093 .75689 .47772 .75937 .47388 .75258 Mtetra
.421 .563 .89 r
.47388 .75258 .47772 .75937 .48455 .76168 .48071 .7547 Mtetra
.441 .566 .885 r
.48071 .7547 .48455 .76168 .49141 .76383 .48758 .75664 Mtetra
.46 .57 .879 r
.48758 .75664 .49141 .76383 .4983 .76579 .49448 .75838 Mtetra
.478 .572 .872 r
.49448 .75838 .4983 .76579 .50523 .76754 .50141 .75992 Mtetra
.495 .575 .865 r
.50141 .75992 .50523 .76754 .51219 .76909 .50837 .76123 Mtetra
.511 .577 .858 r
.50837 .76123 .51219 .76909 .51918 .77041 .51537 .76231 Mtetra
.527 .578 .85 r
.51537 .76231 .51918 .77041 .52621 .77149 .52239 .76314 Mtetra
.541 .579 .842 r
.52239 .76314 .52621 .77149 .53326 .77231 .52945 .76371 Mtetra
.555 .58 .835 r
.52945 .76371 .53326 .77231 .54034 .77288 .53653 .764 Mtetra
.567 .581 .827 r
.53653 .764 .54034 .77288 .54744 .77317 .54364 .76401 Mtetra
.579 .581 .819 r
.54364 .76401 .54744 .77317 .55458 .77319 .55077 .76372 Mtetra
.59 .581 .811 r
.55077 .76372 .55458 .77319 .56173 .77291 .55793 .76314 Mtetra
.599 .58 .803 r
.55793 .76314 .56173 .77291 .56891 .77235 .5651 .76225 Mtetra
.608 .579 .795 r
.5651 .76225 .56891 .77235 .57612 .77149 .5723 .76106 Mtetra
.616 .578 .788 r
.5723 .76106 .57612 .77149 .58334 .77033 .57952 .75957 Mtetra
.623 .576 .781 r
.57952 .75957 .58334 .77033 .59058 .76889 .58676 .75777 Mtetra
.629 .574 .774 r
.58676 .75777 .59058 .76889 .59784 .76717 .59402 .7557 Mtetra
.634 .572 .768 r
.59402 .7557 .59784 .76717 .60511 .76518 .60129 .75335 Mtetra
.638 .57 .762 r
.60129 .75335 .60511 .76518 .61241 .76292 .60857 .75074 Mtetra
.642 .568 .756 r
.60857 .75074 .61241 .76292 .61971 .76042 .61587 .74789 Mtetra
.645 .566 .751 r
.61587 .74789 .61971 .76042 .62703 .75767 .62318 .74482 Mtetra
.648 .564 .747 r
.62318 .74482 .62703 .75767 .63437 .75467 .63051 .74152 Mtetra
.651 .563 .742 r
.63051 .74152 .63437 .75467 .64171 .75141 .63784 .73798 Mtetra
.654 .562 .738 r
.63784 .73798 .64171 .75141 .64906 .74785 .64519 .73418 Mtetra
.659 .562 .735 r
.64519 .73418 .64906 .74785 .65642 .74394 .65254 .73006 Mtetra
.632 .545 .739 r
.65254 .73006 .65642 .74394 .66383 .74132 .65995 .72742 Mtetra
.603 .529 .744 r
.65995 .72742 .66383 .74132 .67131 .73999 .66743 .72626 Mtetra
.61 .535 .745 r
.66743 .72626 .67131 .73999 .6788 .73832 .67493 .72479 Mtetra
.615 .54 .747 r
.67493 .72479 .6788 .73832 .68631 .73634 .68244 .72306 Mtetra
.62 .546 .749 r
.68244 .72306 .68631 .73634 .69382 .73411 .68996 .72109 Mtetra
.625 .552 .752 r
.68996 .72109 .69382 .73411 .70135 .73162 .6975 .71889 Mtetra
.631 .558 .754 r
.6975 .71889 .70135 .73162 .70888 .72889 .70505 .71647 Mtetra
.636 .565 .758 r
.70505 .71647 .70888 .72889 .71643 .7259 .71261 .7138 Mtetra
.643 .573 .761 r
.71261 .7138 .71643 .7259 .72398 .72265 .72018 .71088 Mtetra
.649 .581 .764 r
.72018 .71088 .72398 .72265 .73154 .71912 .72775 .70767 Mtetra
.657 .589 .767 r
.72775 .70767 .73154 .71912 .7391 .7153 .73533 .70418 Mtetra
.664 .597 .77 r
.73533 .70418 .7391 .7153 .74666 .71119 .74291 .70038 Mtetra
.672 .606 .773 r
.74291 .70038 .74666 .71119 .75422 .70678 .75049 .69627 Mtetra
.68 .615 .776 r
.75049 .69627 .75422 .70678 .76177 .70206 .75807 .69184 Mtetra
.688 .624 .779 r
.75807 .69184 .76177 .70206 .76933 .69703 .76565 .6871 Mtetra
.697 .633 .781 r
.76565 .6871 .76933 .69703 .77687 .69171 .77322 .68205 Mtetra
.705 .641 .783 r
.77322 .68205 .77687 .69171 .78441 .68609 .78078 .67669 Mtetra
.713 .65 .785 r
.78078 .67669 .78441 .68609 .79194 .68018 .78834 .67103 Mtetra
.72 .658 .787 r
.78834 .67103 .79194 .68018 .79946 .674 .79589 .66508 Mtetra
.728 .666 .789 r
.79589 .66508 .79946 .674 .80698 .66754 .80343 .65886 Mtetra
.735 .674 .79 r
.80343 .65886 .80698 .66754 .81448 .66084 .81096 .65236 Mtetra
.742 .681 .792 r
.81096 .65236 .81448 .66084 .82197 .65388 .81847 .64562 Mtetra
.749 .689 .793 r
.81847 .64562 .82197 .65388 .82945 .6467 .82598 .63863 Mtetra
.756 .696 .794 r
.82598 .63863 .82945 .6467 .83691 .6393 .83347 .63142 Mtetra
.762 .703 .796 r
.83347 .63142 .83691 .6393 .84437 .63169 .84096 .62399 Mtetra
.768 .709 .797 r
.84096 .62399 .84437 .63169 .85181 .62389 .84843 .61637 Mtetra
.774 .716 .798 r
.84843 .61637 .85181 .62389 .85924 .61591 .85589 .60856 Mtetra
.779 .722 .799 r
.85589 .60856 .85924 .61591 .86666 .60776 .86333 .60057 Mtetra
.785 .728 .8 r
.86333 .60057 .86666 .60776 .87406 .59947 .87077 .59243 Mtetra
.79 .735 .802 r
.87077 .59243 .87406 .59947 .88146 .59103 .87819 .58415 Mtetra
.794 .74 .803 r
.87819 .58415 .88146 .59103 .88884 .58247 .8856 .57574 Mtetra
.799 .746 .804 r
.8856 .57574 .88884 .58247 .89621 .5738 .893 .56721 Mtetra
.803 .752 .805 r
.893 .56721 .89621 .5738 .90357 .56503 .90039 .55857 Mtetra
.807 .758 .807 r
.90039 .55857 .90357 .56503 .91092 .55617 .90778 .54985 Mtetra
.811 .763 .808 r
.90778 .54985 .91092 .55617 .91826 .54723 .91515 .54104 Mtetra
.815 .769 .81 r
.91515 .54104 .91826 .54723 .92559 .53823 .92251 .53218 Mtetra
.818 .774 .812 r
.92251 .53218 .92559 .53823 .93291 .52919 .92987 .52326 Mtetra
.821 .78 .814 r
.92987 .52326 .93291 .52919 .94023 .5201 .93722 .5143 Mtetra
.824 .785 .816 r
.93722 .5143 .94023 .5201 .94754 .51099 .94457 .50532 Mtetra
.827 .791 .818 r
.94457 .50532 .94754 .51099 .95485 .50187 .95191 .49632 Mtetra
.142 .503 .909 r
.37796 .70698 .38192 .71153 .38826 .71477 .38431 .71008 Mtetra
.16 .507 .911 r
.38431 .71008 .38826 .71477 .39463 .71802 .3907 .71318 Mtetra
.18 .511 .914 r
.3907 .71318 .39463 .71802 .40105 .72126 .39711 .71627 Mtetra
.2 .516 .915 r
.39711 .71627 .40105 .72126 .40749 .72447 .40357 .71934 Mtetra
.221 .521 .916 r
.40357 .71934 .40749 .72447 .41397 .72765 .41005 .72237 Mtetra
.242 .527 .917 r
.41005 .72237 .41397 .72765 .42048 .73078 .41658 .72535 Mtetra
.264 .532 .917 r
.41658 .72535 .42048 .73078 .42703 .73385 .42313 .72827 Mtetra
.285 .538 .916 r
.42313 .72827 .42703 .73385 .43362 .73684 .42973 .73111 Mtetra
.307 .543 .914 r
.42973 .73111 .43362 .73684 .44024 .73976 .43635 .73386 Mtetra
.329 .548 .912 r
.43635 .73386 .44024 .73976 .4469 .74257 .44302 .73651 Mtetra
.351 .553 .909 r
.44302 .73651 .4469 .74257 .45359 .74527 .44971 .73904 Mtetra
.372 .558 .906 r
.44971 .73904 .45359 .74527 .46032 .74785 .45645 .74145 Mtetra
.393 .562 .902 r
.45645 .74145 .46032 .74785 .46708 .75029 .46322 .7437 Mtetra
.413 .566 .897 r
.46322 .7437 .46708 .75029 .47388 .75258 .47002 .7458 Mtetra
.433 .57 .892 r
.47002 .7458 .47388 .75258 .48071 .7547 .47686 .74773 Mtetra
.452 .574 .886 r
.47686 .74773 .48071 .7547 .48758 .75664 .48373 .74947 Mtetra
.471 .577 .879 r
.48373 .74947 .48758 .75664 .49448 .75838 .49063 .751 Mtetra
.488 .579 .873 r
.49063 .751 .49448 .75838 .50141 .75992 .49757 .75232 Mtetra
.505 .582 .866 r
.49757 .75232 .50141 .75992 .50837 .76123 .50454 .75341 Mtetra
.521 .583 .858 r
.50454 .75341 .50837 .76123 .51537 .76231 .51154 .75425 Mtetra
.537 .585 .85 r
.51154 .75425 .51537 .76231 .52239 .76314 .51857 .75483 Mtetra
.551 .586 .843 r
.51857 .75483 .52239 .76314 .52945 .76371 .52562 .75514 Mtetra
.564 .587 .835 r
.52562 .75514 .52945 .76371 .53653 .764 .53271 .75517 Mtetra
.577 .587 .826 r
.53271 .75517 .53653 .764 .54364 .76401 .53982 .75489 Mtetra
.588 .587 .818 r
.53982 .75489 .54364 .76401 .55077 .76372 .54695 .75431 Mtetra
.599 .587 .81 r
.54695 .75431 .55077 .76372 .55793 .76314 .55411 .75342 Mtetra
.608 .586 .803 r
.55411 .75342 .55793 .76314 .5651 .76225 .56129 .75221 Mtetra
.617 .585 .795 r
.56129 .75221 .5651 .76225 .5723 .76106 .56849 .75069 Mtetra
.625 .583 .787 r
.56849 .75069 .5723 .76106 .57952 .75957 .5757 .74885 Mtetra
.631 .582 .78 r
.5757 .74885 .57952 .75957 .58676 .75777 .58294 .74671 Mtetra
.637 .58 .773 r
.58294 .74671 .58676 .75777 .59402 .7557 .59019 .74427 Mtetra
.642 .577 .767 r
.59019 .74427 .59402 .7557 .60129 .75335 .59745 .74156 Mtetra
.646 .575 .761 r
.59745 .74156 .60129 .75335 .60857 .75074 .60473 .7386 Mtetra
.649 .572 .755 r
.60473 .7386 .60857 .75074 .61587 .74789 .61203 .73541 Mtetra
.651 .57 .75 r
.61203 .73541 .61587 .74789 .62318 .74482 .61933 .732 Mtetra
.653 .568 .746 r
.61933 .732 .62318 .74482 .63051 .74152 .62665 .7284 Mtetra
.656 .566 .742 r
.62665 .7284 .63051 .74152 .63784 .73798 .63398 .7246 Mtetra
.658 .565 .738 r
.63398 .7246 .63784 .73798 .64519 .73418 .64131 .72057 Mtetra
.662 .565 .735 r
.64131 .72057 .64519 .73418 .65254 .73006 .64866 .71627 Mtetra
.632 .546 .74 r
.64866 .71627 .65254 .73006 .65995 .72742 .65607 .71361 Mtetra
.599 .528 .745 r
.65607 .71361 .65995 .72742 .66743 .72626 .66355 .7126 Mtetra
.605 .533 .747 r
.66355 .7126 .66743 .72626 .67493 .72479 .67105 .71132 Mtetra
.61 .538 .748 r
.67105 .71132 .67493 .72479 .68244 .72306 .67857 .70981 Mtetra
.615 .543 .751 r
.67857 .70981 .68244 .72306 .68996 .72109 .6861 .70811 Mtetra
.619 .549 .753 r
.6861 .70811 .68996 .72109 .6975 .71889 .69365 .70621 Mtetra
.624 .555 .757 r
.69365 .70621 .6975 .71889 .70505 .71647 .70121 .7041 Mtetra
.63 .562 .76 r
.70121 .7041 .70505 .71647 .71261 .7138 .70879 .70175 Mtetra
.636 .57 .763 r
.70879 .70175 .71261 .7138 .72018 .71088 .71637 .69915 Mtetra
.643 .578 .767 r
.71637 .69915 .72018 .71088 .72775 .70767 .72396 .69628 Mtetra
.65 .586 .77 r
.72396 .69628 .72775 .70767 .73533 .70418 .73156 .6931 Mtetra
.658 .595 .773 r
.73156 .6931 .73533 .70418 .74291 .70038 .73917 .68962 Mtetra
.666 .604 .776 r
.73917 .68962 .74291 .70038 .75049 .69627 .74677 .68581 Mtetra
.674 .613 .779 r
.74677 .68581 .75049 .69627 .75807 .69184 .75437 .68168 Mtetra
.683 .622 .782 r
.75437 .68168 .75807 .69184 .76565 .6871 .76197 .67722 Mtetra
.691 .631 .784 r
.76197 .67722 .76565 .6871 .77322 .68205 .76956 .67244 Mtetra
.7 .64 .786 r
.76956 .67244 .77322 .68205 .78078 .67669 .77715 .66733 Mtetra
.708 .649 .788 r
.77715 .66733 .78078 .67669 .78834 .67103 .78473 .66192 Mtetra
.716 .657 .79 r
.78473 .66192 .78834 .67103 .79589 .66508 .79231 .65621 Mtetra
.724 .666 .792 r
.79231 .65621 .79589 .66508 .80343 .65886 .79987 .65021 Mtetra
.732 .673 .793 r
.79987 .65021 .80343 .65886 .81096 .65236 .80743 .64393 Mtetra
.739 .681 .795 r
.80743 .64393 .81096 .65236 .81847 .64562 .81497 .63738 Mtetra
.746 .689 .796 r
.81497 .63738 .81847 .64562 .82598 .63863 .8225 .63059 Mtetra
.753 .696 .797 r
.8225 .63059 .82598 .63863 .83347 .63142 .83003 .62356 Mtetra
.759 .703 .799 r
.83003 .62356 .83347 .63142 .84096 .62399 .83754 .61632 Mtetra
.765 .71 .8 r
.83754 .61632 .84096 .62399 .84843 .61637 .84504 .60886 Mtetra
.771 .716 .801 r
.84504 .60886 .84843 .61637 .85589 .60856 .85252 .60122 Mtetra
.777 .722 .802 r
.85252 .60122 .85589 .60856 .86333 .60057 .86 .59339 Mtetra
.782 .729 .803 r
.86 .59339 .86333 .60057 .87077 .59243 .86746 .58541 Mtetra
.787 .735 .804 r
.86746 .58541 .87077 .59243 .87819 .58415 .87491 .57727 Mtetra
.792 .741 .805 r
.87491 .57727 .87819 .58415 .8856 .57574 .88236 .569 Mtetra
.797 .746 .806 r
.88236 .569 .8856 .57574 .893 .56721 .88979 .56061 Mtetra
.801 .752 .808 r
.88979 .56061 .893 .56721 .90039 .55857 .89721 .55211 Mtetra
.805 .758 .809 r
.89721 .55211 .90039 .55857 .90778 .54985 .90462 .54352 Mtetra
.809 .763 .811 r
.90462 .54352 .90778 .54985 .91515 .54104 .91203 .53484 Mtetra
.812 .769 .812 r
.91203 .53484 .91515 .54104 .92251 .53218 .91942 .5261 Mtetra
.816 .774 .814 r
.91942 .5261 .92251 .53218 .92987 .52326 .92681 .51731 Mtetra
.819 .779 .816 r
.92681 .51731 .92987 .52326 .93722 .5143 .9342 .50848 Mtetra
.821 .785 .818 r
.9342 .50848 .93722 .5143 .94457 .50532 .94157 .49962 Mtetra
.824 .79 .82 r
.94157 .49962 .94457 .50532 .95191 .49632 .94895 .49075 Mtetra
.162 .515 .915 r
.37398 .70241 .37796 .70698 .38431 .71008 .38034 .70537 Mtetra
.18 .519 .917 r
.38034 .70537 .38431 .71008 .3907 .71318 .38674 .70833 Mtetra
.198 .522 .918 r
.38674 .70833 .3907 .71318 .39711 .71627 .39316 .71128 Mtetra
.217 .527 .92 r
.39316 .71128 .39711 .71627 .40357 .71934 .39963 .7142 Mtetra
.237 .532 .92 r
.39963 .7142 .40357 .71934 .41005 .72237 .40612 .71709 Mtetra
.258 .536 .92 r
.40612 .71709 .41005 .72237 .41658 .72535 .41265 .71992 Mtetra
.279 .541 .92 r
.41265 .71992 .41658 .72535 .42313 .72827 .41921 .72269 Mtetra
.3 .547 .919 r
.41921 .72269 .42313 .72827 .42973 .73111 .42581 .72538 Mtetra
.321 .552 .917 r
.42581 .72538 .42973 .73111 .43635 .73386 .43245 .72797 Mtetra
.342 .556 .914 r
.43245 .72797 .43635 .73386 .44302 .73651 .43912 .73046 Mtetra
.363 .561 .911 r
.43912 .73046 .44302 .73651 .44971 .73904 .44582 .73282 Mtetra
.384 .566 .908 r
.44582 .73282 .44971 .73904 .45645 .74145 .45256 .73506 Mtetra
.405 .57 .903 r
.45256 .73506 .45645 .74145 .46322 .7437 .45934 .73714 Mtetra
.425 .574 .898 r
.45934 .73714 .46322 .7437 .47002 .7458 .46615 .73905 Mtetra
.444 .578 .893 r
.46615 .73905 .47002 .7458 .47686 .74773 .47299 .74079 Mtetra
.463 .581 .887 r
.47299 .74079 .47686 .74773 .48373 .74947 .47987 .74233 Mtetra
.481 .584 .88 r
.47987 .74233 .48373 .74947 .49063 .751 .48678 .74366 Mtetra
.499 .586 .873 r
.48678 .74366 .49063 .751 .49757 .75232 .49372 .74476 Mtetra
.516 .588 .866 r
.49372 .74476 .49757 .75232 .50454 .75341 .50069 .74563 Mtetra
.531 .59 .858 r
.50069 .74563 .50454 .75341 .51154 .75425 .5077 .74624 Mtetra
.546 .591 .851 r
.5077 .74624 .51154 .75425 .51857 .75483 .51473 .74657 Mtetra
.56 .592 .843 r
.51473 .74657 .51857 .75483 .52562 .75514 .52179 .74663 Mtetra
.574 .593 .834 r
.52179 .74663 .52562 .75514 .53271 .75517 .52888 .74638 Mtetra
.586 .593 .826 r
.52888 .74638 .53271 .75517 .53982 .75489 .53599 .74583 Mtetra
.597 .593 .818 r
.53599 .74583 .53982 .75489 .54695 .75431 .54312 .74495 Mtetra
.608 .593 .81 r
.54312 .74495 .54695 .75431 .55411 .75342 .55028 .74376 Mtetra
.617 .592 .802 r
.55028 .74376 .55411 .75342 .56129 .75221 .55746 .74223 Mtetra
.626 .59 .794 r
.55746 .74223 .56129 .75221 .56849 .75069 .56466 .74037 Mtetra
.633 .589 .787 r
.56466 .74037 .56849 .75069 .5757 .74885 .57188 .73819 Mtetra
.64 .587 .779 r
.57188 .73819 .5757 .74885 .58294 .74671 .57911 .73569 Mtetra
.645 .585 .772 r
.57911 .73569 .58294 .74671 .59019 .74427 .58636 .73289 Mtetra
.649 .582 .766 r
.58636 .73289 .59019 .74427 .59745 .74156 .59362 .72982 Mtetra
.653 .579 .76 r
.59362 .72982 .59745 .74156 .60473 .7386 .60089 .7265 Mtetra
.655 .577 .754 r
.60089 .7265 .60473 .7386 .61203 .73541 .60818 .72296 Mtetra
.657 .574 .749 r
.60818 .72296 .61203 .73541 .61933 .732 .61548 .71923 Mtetra
.659 .571 .745 r
.61548 .71923 .61933 .732 .62665 .7284 .62279 .71533 Mtetra
.66 .569 .741 r
.62279 .71533 .62665 .7284 .63398 .7246 .63011 .71127 Mtetra
.662 .567 .738 r
.63011 .71127 .63398 .7246 .64131 .72057 .63744 .70703 Mtetra
.665 .567 .735 r
.63744 .70703 .64131 .72057 .64866 .71627 .64478 .70256 Mtetra
.632 .547 .741 r
.64478 .70256 .64866 .71627 .65607 .71361 .65218 .69988 Mtetra
.596 .527 .747 r
.65218 .69988 .65607 .71361 .66355 .7126 .65967 .699 Mtetra
.601 .531 .748 r
.65967 .699 .66355 .7126 .67105 .71132 .66717 .69789 Mtetra
.605 .536 .75 r
.66717 .69789 .67105 .71132 .67857 .70981 .67469 .69661 Mtetra
.609 .54 .752 r
.67469 .69661 .67857 .70981 .6861 .70811 .68223 .69517 Mtetra
.613 .546 .755 r
.68223 .69517 .6861 .70811 .69365 .70621 .68979 .69356 Mtetra
.617 .552 .759 r
.68979 .69356 .69365 .70621 .70121 .7041 .69737 .69176 Mtetra
.622 .559 .762 r
.69737 .69176 .70121 .7041 .70879 .70175 .70496 .68974 Mtetra
.628 .567 .766 r
.70496 .68974 .70879 .70175 .71637 .69915 .71256 .68748 Mtetra
.635 .575 .769 r
.71256 .68748 .71637 .69915 .72396 .69628 .72017 .68493 Mtetra
.643 .584 .773 r
.72017 .68493 .72396 .69628 .73156 .6931 .72779 .68208 Mtetra
.651 .593 .776 r
.72779 .68208 .73156 .6931 .73917 .68962 .73541 .67892 Mtetra
.66 .602 .779 r
.73541 .67892 .73917 .68962 .74677 .68581 .74304 .67541 Mtetra
.668 .612 .782 r
.74304 .67541 .74677 .68581 .75437 .68168 .75066 .67157 Mtetra
.677 .621 .785 r
.75066 .67157 .75437 .68168 .76197 .67722 .75828 .66739 Mtetra
.686 .63 .788 r
.75828 .66739 .76197 .67722 .76956 .67244 .7659 .66288 Mtetra
.695 .639 .79 r
.7659 .66288 .76956 .67244 .77715 .66733 .77351 .65803 Mtetra
.704 .648 .792 r
.77351 .65803 .77715 .66733 .78473 .66192 .78112 .65286 Mtetra
.712 .657 .793 r
.78112 .65286 .78473 .66192 .79231 .65621 .78872 .64738 Mtetra
.72 .665 .795 r
.78872 .64738 .79231 .65621 .79987 .65021 .79631 .64159 Mtetra
.728 .673 .797 r
.79631 .64159 .79987 .65021 .80743 .64393 .80389 .63552 Mtetra
.736 .681 .798 r
.80389 .63552 .80743 .64393 .81497 .63738 .81146 .62918 Mtetra
.743 .689 .799 r
.81146 .62918 .81497 .63738 .8225 .63059 .81902 .62258 Mtetra
.75 .696 .8 r
.81902 .62258 .8225 .63059 .83003 .62356 .82657 .61574 Mtetra
.756 .703 .801 r
.82657 .61574 .83003 .62356 .83754 .61632 .83411 .60866 Mtetra
.763 .71 .802 r
.83411 .60866 .83754 .61632 .84504 .60886 .84163 .60138 Mtetra
.769 .716 .804 r
.84163 .60138 .84504 .60886 .85252 .60122 .84915 .59389 Mtetra
.774 .723 .805 r
.84915 .59389 .85252 .60122 .86 .59339 .85665 .58622 Mtetra
.78 .729 .806 r
.85665 .58622 .86 .59339 .86746 .58541 .86415 .57839 Mtetra
.785 .735 .807 r
.86415 .57839 .86746 .58541 .87491 .57727 .87163 .57039 Mtetra
.79 .741 .808 r
.87163 .57039 .87491 .57727 .88236 .569 .8791 .56226 Mtetra
.794 .747 .809 r
.8791 .56226 .88236 .569 .88979 .56061 .88656 .55401 Mtetra
.798 .752 .81 r
.88656 .55401 .88979 .56061 .89721 .55211 .89401 .54564 Mtetra
.803 .758 .812 r
.89401 .54564 .89721 .55211 .90462 .54352 .90146 .53718 Mtetra
.806 .763 .813 r
.90146 .53718 .90462 .54352 .91203 .53484 .90889 .52863 Mtetra
.81 .768 .815 r
.90889 .52863 .91203 .53484 .91942 .5261 .91632 .52002 Mtetra
.813 .774 .816 r
.91632 .52002 .91942 .5261 .92681 .51731 .92374 .51135 Mtetra
.816 .779 .818 r
.92374 .51135 .92681 .51731 .9342 .50848 .93116 .50264 Mtetra
.819 .785 .82 r
.93116 .50264 .9342 .50848 .94157 .49962 .93857 .4939 Mtetra
.822 .79 .822 r
.93857 .4939 .94157 .49962 .94895 .49075 .94598 .48514 Mtetra
.182 .527 .921 r
.36999 .69781 .37398 .70241 .38034 .70537 .37636 .70064 Mtetra
.198 .53 .922 r
.37636 .70064 .38034 .70537 .38674 .70833 .38276 .70346 Mtetra
.216 .533 .923 r
.38276 .70346 .38674 .70833 .39316 .71128 .3892 .70628 Mtetra
.234 .537 .923 r
.3892 .70628 .39316 .71128 .39963 .7142 .39567 .70906 Mtetra
.253 .541 .924 r
.39567 .70906 .39963 .7142 .40612 .71709 .40217 .7118 Mtetra
.273 .546 .923 r
.40217 .7118 .40612 .71709 .41265 .71992 .40871 .71449 Mtetra
.293 .55 .922 r
.40871 .71449 .41265 .71992 .41921 .72269 .41528 .71711 Mtetra
.314 .555 .921 r
.41528 .71711 .41921 .72269 .42581 .72538 .42189 .71964 Mtetra
.334 .56 .919 r
.42189 .71964 .42581 .72538 .43245 .72797 .42853 .72209 Mtetra
.355 .564 .916 r
.42853 .72209 .43245 .72797 .43912 .73046 .43521 .72441 Mtetra
.376 .569 .913 r
.43521 .72441 .43912 .73046 .44582 .73282 .44192 .72662 Mtetra
.396 .573 .909 r
.44192 .72662 .44582 .73282 .45256 .73506 .44867 .72868 Mtetra
.416 .577 .904 r
.44867 .72868 .45256 .73506 .45934 .73714 .45545 .73059 Mtetra
.436 .581 .899 r
.45545 .73059 .45934 .73714 .46615 .73905 .46226 .73232 Mtetra
.455 .585 .894 r
.46226 .73232 .46615 .73905 .47299 .74079 .46911 .73387 Mtetra
.474 .588 .887 r
.46911 .73387 .47299 .74079 .47987 .74233 .47599 .73522 Mtetra
.492 .59 .881 r
.47599 .73522 .47987 .74233 .48678 .74366 .48291 .73635 Mtetra
.509 .593 .874 r
.48291 .73635 .48678 .74366 .49372 .74476 .48986 .73724 Mtetra
.525 .595 .866 r
.48986 .73724 .49372 .74476 .50069 .74563 .49684 .73788 Mtetra
.541 .597 .859 r
.49684 .73788 .50069 .74563 .5077 .74624 .50384 .73826 Mtetra
.556 .598 .851 r
.50384 .73826 .5077 .74624 .51473 .74657 .51088 .73836 Mtetra
.57 .599 .843 r
.51088 .73836 .51473 .74657 .52179 .74663 .51794 .73816 Mtetra
.583 .599 .834 r
.51794 .73816 .52179 .74663 .52888 .74638 .52503 .73765 Mtetra
.595 .599 .826 r
.52503 .73765 .52888 .74638 .53599 .74583 .53215 .73682 Mtetra
.606 .599 .818 r
.53215 .73682 .53599 .74583 .54312 .74495 .53929 .73565 Mtetra
.617 .598 .81 r
.53929 .73565 .54312 .74495 .55028 .74376 .54645 .73415 Mtetra
.626 .597 .801 r
.54645 .73415 .55028 .74376 .55746 .74223 .55363 .7323 Mtetra
.634 .596 .794 r
.55363 .7323 .55746 .74223 .56466 .74037 .56083 .73011 Mtetra
.642 .594 .786 r
.56083 .73011 .56466 .74037 .57188 .73819 .56804 .72758 Mtetra
.648 .592 .778 r
.56804 .72758 .57188 .73819 .57911 .73569 .57527 .72472 Mtetra
.653 .59 .771 r
.57527 .72472 .57911 .73569 .58636 .73289 .58252 .72156 Mtetra
.657 .587 .765 r
.58252 .72156 .58636 .73289 .59362 .72982 .58977 .71812 Mtetra
.66 .584 .759 r
.58977 .71812 .59362 .72982 .60089 .7265 .59704 .71443 Mtetra
.662 .581 .753 r
.59704 .71443 .60089 .7265 .60818 .72296 .60433 .71054 Mtetra
.663 .577 .748 r
.60433 .71054 .60818 .72296 .61548 .71923 .61162 .70647 Mtetra
.664 .574 .744 r
.61162 .70647 .61548 .71923 .62279 .71533 .61892 .70227 Mtetra
.664 .572 .741 r
.61892 .70227 .62279 .71533 .63011 .71127 .62624 .69796 Mtetra
.665 .57 .738 r
.62624 .69796 .63011 .71127 .63744 .70703 .63356 .69352 Mtetra
.667 .569 .735 r
.63356 .69352 .63744 .70703 .64478 .70256 .6409 .68891 Mtetra
.633 .548 .741 r
.6409 .68891 .64478 .70256 .65218 .69988 .6483 .68622 Mtetra
.594 .526 .748 r
.6483 .68622 .65218 .69988 .65967 .699 .65578 .68544 Mtetra
.597 .53 .749 r
.65578 .68544 .65967 .699 .66717 .69789 .66329 .68449 Mtetra
.6 .533 .751 r
.66329 .68449 .66717 .69789 .67469 .69661 .67082 .68343 Mtetra
.603 .537 .754 r
.67082 .68343 .67469 .69661 .68223 .69517 .67837 .68225 Mtetra
.606 .542 .757 r
.67837 .68225 .68223 .69517 .68979 .69356 .68594 .68094 Mtetra
.61 .548 .761 r
.68594 .68094 .68979 .69356 .69737 .69176 .69352 .67946 Mtetra
.615 .555 .764 r
.69352 .67946 .69737 .69176 .70496 .68974 .70113 .67778 Mtetra
.621 .563 .768 r
.70113 .67778 .70496 .68974 .71256 .68748 .70875 .67585 Mtetra
.628 .572 .772 r
.70875 .67585 .71256 .68748 .72017 .68493 .71638 .67364 Mtetra
.636 .581 .776 r
.71638 .67364 .72017 .68493 .72779 .68208 .72401 .67112 Mtetra
.644 .59 .779 r
.72401 .67112 .72779 .68208 .73541 .67892 .73166 .66827 Mtetra
.653 .6 .783 r
.73166 .66827 .73541 .67892 .74304 .67541 .7393 .66507 Mtetra
.662 .61 .786 r
.7393 .66507 .74304 .67541 .75066 .67157 .74695 .66152 Mtetra
.672 .62 .788 r
.74695 .66152 .75066 .67157 .75828 .66739 .75459 .65762 Mtetra
.681 .629 .791 r
.75459 .65762 .75828 .66739 .7659 .66288 .76223 .65337 Mtetra
.69 .639 .793 r
.76223 .65337 .7659 .66288 .77351 .65803 .76987 .64877 Mtetra
.699 .648 .795 r
.76987 .64877 .77351 .65803 .78112 .65286 .7775 .64384 Mtetra
.708 .656 .797 r
.7775 .64384 .78112 .65286 .78872 .64738 .78512 .63859 Mtetra
.716 .665 .798 r
.78512 .63859 .78872 .64738 .79631 .64159 .79274 .63302 Mtetra
.724 .673 .8 r
.79274 .63302 .79631 .64159 .80389 .63552 .80034 .62716 Mtetra
.732 .681 .801 r
.80034 .62716 .80389 .63552 .81146 .62918 .80794 .62101 Mtetra
.739 .689 .802 r
.80794 .62101 .81146 .62918 .81902 .62258 .81553 .6146 Mtetra
.747 .696 .803 r
.81553 .6146 .81902 .62258 .82657 .61574 .8231 .60793 Mtetra
.753 .703 .804 r
.8231 .60793 .82657 .61574 .83411 .60866 .83067 .60103 Mtetra
.76 .71 .805 r
.83067 .60103 .83411 .60866 .84163 .60138 .83822 .59391 Mtetra
.766 .717 .806 r
.83822 .59391 .84163 .60138 .84915 .59389 .84577 .58658 Mtetra
.772 .723 .807 r
.84577 .58658 .84915 .59389 .85665 .58622 .8533 .57907 Mtetra
.777 .729 .808 r
.8533 .57907 .85665 .58622 .86415 .57839 .86082 .57137 Mtetra
.782 .735 .809 r
.86082 .57137 .86415 .57839 .87163 .57039 .86833 .56352 Mtetra
.787 .741 .81 r
.86833 .56352 .87163 .57039 .8791 .56226 .87583 .55553 Mtetra
.792 .747 .811 r
.87583 .55553 .8791 .56226 .88656 .55401 .88332 .54741 Mtetra
.796 .752 .813 r
.88332 .54741 .88656 .55401 .89401 .54564 .8908 .53917 Mtetra
.8 .758 .814 r
.8908 .53917 .89401 .54564 .90146 .53718 .89828 .53083 Mtetra
.804 .763 .815 r
.89828 .53083 .90146 .53718 .90889 .52863 .90574 .52241 Mtetra
.807 .768 .817 r
.90574 .52241 .90889 .52863 .91632 .52002 .9132 .51392 Mtetra
.811 .774 .818 r
.9132 .51392 .91632 .52002 .92374 .51135 .92066 .50537 Mtetra
.814 .779 .82 r
.92066 .50537 .92374 .51135 .93116 .50264 .9281 .49677 Mtetra
.817 .784 .822 r
.9281 .49677 .93116 .50264 .93857 .4939 .93555 .48815 Mtetra
.819 .789 .825 r
.93555 .48815 .93857 .4939 .94598 .48514 .94299 .47952 Mtetra
.2 .538 .926 r
.36598 .6932 .36999 .69781 .37636 .70064 .37236 .69589 Mtetra
.216 .54 .926 r
.37236 .69589 .37636 .70064 .38276 .70346 .37877 .69858 Mtetra
.233 .543 .927 r
.37877 .69858 .38276 .70346 .3892 .70628 .38521 .70126 Mtetra
.25 .547 .927 r
.38521 .70126 .3892 .70628 .39567 .70906 .39169 .70391 Mtetra
.268 .55 .927 r
.39169 .70391 .39567 .70906 .40217 .7118 .3982 .70651 Mtetra
.287 .555 .926 r
.3982 .70651 .40217 .7118 .40871 .71449 .40475 .70905 Mtetra
.307 .559 .925 r
.40475 .70905 .40871 .71449 .41528 .71711 .41133 .71153 Mtetra
.327 .563 .923 r
.41133 .71153 .41528 .71711 .42189 .71964 .41794 .71392 Mtetra
.347 .568 .921 r
.41794 .71392 .42189 .71964 .42853 .72209 .42459 .71621 Mtetra
.367 .572 .918 r
.42459 .71621 .42853 .72209 .43521 .72441 .43128 .71838 Mtetra
.387 .576 .914 r
.43128 .71838 .43521 .72441 .44192 .72662 .438 .72042 Mtetra
.407 .581 .91 r
.438 .72042 .44192 .72662 .44867 .72868 .44475 .72232 Mtetra
.427 .584 .906 r
.44475 .72232 .44867 .72868 .45545 .73059 .45154 .72406 Mtetra
.446 .588 .9 r
.45154 .72406 .45545 .73059 .46226 .73232 .45836 .72562 Mtetra
.465 .591 .895 r
.45836 .72562 .46226 .73232 .46911 .73387 .46522 .72698 Mtetra
.484 .594 .888 r
.46522 .72698 .46911 .73387 .47599 .73522 .47211 .72814 Mtetra
.501 .597 .881 r
.47211 .72814 .47599 .73522 .48291 .73635 .47903 .72907 Mtetra
.518 .599 .874 r
.47903 .72907 .48291 .73635 .48986 .73724 .48598 .72976 Mtetra
.535 .601 .867 r
.48598 .72976 .48986 .73724 .49684 .73788 .49296 .73018 Mtetra
.55 .603 .859 r
.49296 .73018 .49684 .73788 .50384 .73826 .49998 .73033 Mtetra
.565 .604 .851 r
.49998 .73033 .50384 .73826 .51088 .73836 .50702 .73019 Mtetra
.579 .605 .843 r
.50702 .73019 .51088 .73836 .51794 .73816 .51409 .72974 Mtetra
.592 .605 .834 r
.51409 .72974 .51794 .73816 .52503 .73765 .52118 .72897 Mtetra
.604 .605 .826 r
.52118 .72897 .52503 .73765 .53215 .73682 .5283 .72786 Mtetra
.615 .605 .817 r
.5283 .72786 .53215 .73682 .53929 .73565 .53544 .72641 Mtetra
.625 .604 .809 r
.53544 .72641 .53929 .73565 .54645 .73415 .5426 .7246 Mtetra
.634 .603 .801 r
.5426 .7246 .54645 .73415 .55363 .7323 .54979 .72244 Mtetra
.643 .602 .793 r
.54979 .72244 .55363 .7323 .56083 .73011 .55699 .71991 Mtetra
.65 .6 .785 r
.55699 .71991 .56083 .73011 .56804 .72758 .5642 .71703 Mtetra
.656 .598 .777 r
.5642 .71703 .56804 .72758 .57527 .72472 .57143 .71381 Mtetra
.661 .595 .77 r
.57143 .71381 .57527 .72472 .58252 .72156 .57867 .71028 Mtetra
.665 .592 .764 r
.57867 .71028 .58252 .72156 .58977 .71812 .58593 .70646 Mtetra
.667 .589 .758 r
.58593 .70646 .58977 .71812 .59704 .71443 .59319 .7024 Mtetra
.669 .585 .752 r
.59319 .7024 .59704 .71443 .60433 .71054 .60047 .69814 Mtetra
.669 .581 .747 r
.60047 .69814 .60433 .71054 .61162 .70647 .60776 .69374 Mtetra
.669 .577 .743 r
.60776 .69374 .61162 .70647 .61892 .70227 .61505 .68924 Mtetra
.669 .574 .74 r
.61505 .68924 .61892 .70227 .62624 .69796 .62236 .68467 Mtetra
.668 .571 .737 r
.62236 .68467 .62624 .69796 .63356 .69352 .62968 .68005 Mtetra
.669 .57 .735 r
.62968 .68005 .63356 .69352 .6409 .68891 .63702 .67532 Mtetra
.633 .549 .742 r
.63702 .67532 .6409 .68891 .6483 .68622 .64442 .6726 Mtetra
.591 .525 .749 r
.64442 .6726 .6483 .68622 .65578 .68544 .6519 .6719 Mtetra
.593 .528 .75 r
.6519 .6719 .65578 .68544 .66329 .68449 .65941 .67111 Mtetra
.595 .53 .752 r
.65941 .67111 .66329 .68449 .67082 .68343 .66694 .67026 Mtetra
.596 .534 .755 r
.66694 .67026 .67082 .68343 .67837 .68225 .67449 .66934 Mtetra
.598 .538 .759 r
.67449 .66934 .67837 .68225 .68594 .68094 .68207 .66834 Mtetra
.602 .544 .763 r
.68207 .66834 .68594 .68094 .69352 .67946 .68968 .66719 Mtetra
.606 .551 .767 r
.68968 .66719 .69352 .67946 .70113 .67778 .6973 .66585 Mtetra
.612 .559 .771 r
.6973 .66585 .70113 .67778 .70875 .67585 .70493 .66427 Mtetra
.62 .568 .775 r
.70493 .66427 .70875 .67585 .71638 .67364 .71258 .6624 Mtetra
.628 .578 .779 r
.71258 .6624 .71638 .67364 .72401 .67112 .72023 .66021 Mtetra
.637 .588 .783 r
.72023 .66021 .72401 .67112 .73166 .66827 .72789 .65768 Mtetra
.646 .598 .786 r
.72789 .65768 .73166 .66827 .7393 .66507 .73556 .65479 Mtetra
.656 .608 .789 r
.73556 .65479 .7393 .66507 .74695 .66152 .74323 .65153 Mtetra
.665 .618 .792 r
.74323 .65153 .74695 .66152 .75459 .65762 .75089 .64791 Mtetra
.675 .628 .794 r
.75089 .64791 .75459 .65762 .76223 .65337 .75856 .64392 Mtetra
.685 .638 .797 r
.75856 .64392 .76223 .65337 .76987 .64877 .76622 .63957 Mtetra
.694 .647 .799 r
.76622 .63957 .76987 .64877 .7775 .64384 .77387 .63488 Mtetra
.703 .656 .8 r
.77387 .63488 .7775 .64384 .78512 .63859 .78152 .62985 Mtetra
.712 .665 .802 r
.78152 .62985 .78512 .63859 .79274 .63302 .78916 .62449 Mtetra
.72 .673 .803 r
.78916 .62449 .79274 .63302 .80034 .62716 .79679 .61883 Mtetra
.729 .681 .804 r
.79679 .61883 .80034 .62716 .80794 .62101 .80441 .61288 Mtetra
.736 .689 .805 r
.80441 .61288 .80794 .62101 .81553 .6146 .81203 .60665 Mtetra
.744 .696 .806 r
.81203 .60665 .81553 .6146 .8231 .60793 .81963 .60016 Mtetra
.75 .703 .807 r
.81963 .60016 .8231 .60793 .83067 .60103 .82722 .59343 Mtetra
.757 .71 .808 r
.82722 .59343 .83067 .60103 .83822 .59391 .8348 .58646 Mtetra
.763 .717 .809 r
.8348 .58646 .83822 .59391 .84577 .58658 .84237 .57929 Mtetra
.769 .723 .81 r
.84237 .57929 .84577 .58658 .8533 .57907 .84993 .57192 Mtetra
.775 .729 .811 r
.84993 .57192 .8533 .57907 .86082 .57137 .85748 .56437 Mtetra
.78 .735 .812 r
.85748 .56437 .86082 .57137 .86833 .56352 .86502 .55666 Mtetra
.785 .741 .813 r
.86502 .55666 .86833 .56352 .87583 .55553 .87255 .5488 Mtetra
.79 .747 .814 r
.87255 .5488 .87583 .55553 .88332 .54741 .88007 .5408 Mtetra
.794 .752 .815 r
.88007 .5408 .88332 .54741 .8908 .53917 .88758 .53269 Mtetra
.798 .758 .816 r
.88758 .53269 .8908 .53917 .89828 .53083 .89509 .52448 Mtetra
.802 .763 .818 r
.89509 .52448 .89828 .53083 .90574 .52241 .90258 .51618 Mtetra
.805 .768 .819 r
.90258 .51618 .90574 .52241 .9132 .51392 .91007 .5078 Mtetra
.808 .774 .821 r
.91007 .5078 .9132 .51392 .92066 .50537 .91756 .49937 Mtetra
.811 .779 .822 r
.91756 .49937 .92066 .50537 .9281 .49677 .92504 .49089 Mtetra
.814 .784 .824 r
.92504 .49089 .9281 .49677 .93555 .48815 .93251 .48238 Mtetra
.816 .789 .827 r
.93251 .48238 .93555 .48815 .94299 .47952 .93999 .47386 Mtetra
.218 .548 .93 r
.36195 .68857 .36598 .6932 .37236 .69589 .36834 .69113 Mtetra
.233 .55 .93 r
.36834 .69113 .37236 .69589 .37877 .69858 .37476 .69369 Mtetra
.249 .553 .93 r
.37476 .69369 .37877 .69858 .38521 .70126 .38121 .69623 Mtetra
.265 .556 .93 r
.38121 .69623 .38521 .70126 .39169 .70391 .3877 .69874 Mtetra
.283 .559 .93 r
.3877 .69874 .39169 .70391 .3982 .70651 .39422 .70121 Mtetra
.301 .563 .929 r
.39422 .70121 .3982 .70651 .40475 .70905 .40077 .70362 Mtetra
.32 .567 .927 r
.40077 .70362 .40475 .70905 .41133 .71153 .40736 .70595 Mtetra
.34 .571 .925 r
.40736 .70595 .41133 .71153 .41794 .71392 .41398 .7082 Mtetra
.359 .575 .923 r
.41398 .7082 .41794 .71392 .42459 .71621 .42064 .71034 Mtetra
.379 .579 .92 r
.42064 .71034 .42459 .71621 .43128 .71838 .42733 .71236 Mtetra
.399 .584 .916 r
.42733 .71236 .43128 .71838 .438 .72042 .43406 .71425 Mtetra
.418 .588 .912 r
.43406 .71425 .438 .72042 .44475 .72232 .44082 .71598 Mtetra
.438 .591 .907 r
.44082 .71598 .44475 .72232 .45154 .72406 .44761 .71755 Mtetra
.457 .595 .901 r
.44761 .71755 .45154 .72406 .45836 .72562 .45444 .71894 Mtetra
.475 .598 .895 r
.45444 .71894 .45836 .72562 .46522 .72698 .46131 .72012 Mtetra
.493 .601 .889 r
.46131 .72012 .46522 .72698 .47211 .72814 .4682 .72109 Mtetra
.511 .603 .882 r
.4682 .72109 .47211 .72814 .47903 .72907 .47513 .72183 Mtetra
.528 .606 .875 r
.47513 .72183 .47903 .72907 .48598 .72976 .48209 .72231 Mtetra
.544 .607 .867 r
.48209 .72231 .48598 .72976 .49296 .73018 .48908 .72252 Mtetra
.559 .609 .859 r
.48908 .72252 .49296 .73018 .49998 .73033 .4961 .72245 Mtetra
.574 .61 .851 r
.4961 .72245 .49998 .73033 .50702 .73019 .50314 .72207 Mtetra
.587 .611 .843 r
.50314 .72207 .50702 .73019 .51409 .72974 .51022 .72138 Mtetra
.6 .611 .834 r
.51022 .72138 .51409 .72974 .52118 .72897 .51732 .72035 Mtetra
.612 .611 .826 r
.51732 .72035 .52118 .72897 .5283 .72786 .52444 .71897 Mtetra
.623 .611 .817 r
.52444 .71897 .5283 .72786 .53544 .72641 .53159 .71723 Mtetra
.634 .61 .809 r
.53159 .71723 .53544 .72641 .5426 .7246 .53875 .71512 Mtetra
.643 .609 .8 r
.53875 .71512 .5426 .7246 .54979 .72244 .54594 .71263 Mtetra
.651 .607 .792 r
.54594 .71263 .54979 .72244 .55699 .71991 .55314 .70977 Mtetra
.658 .605 .784 r
.55314 .70977 .55699 .71991 .5642 .71703 .56035 .70654 Mtetra
.664 .603 .776 r
.56035 .70654 .5642 .71703 .57143 .71381 .56758 .70296 Mtetra
.669 .6 .769 r
.56758 .70296 .57143 .71381 .57867 .71028 .57482 .69905 Mtetra
.672 .597 .762 r
.57482 .69905 .57867 .71028 .58593 .70646 .58207 .69484 Mtetra
.675 .593 .756 r
.58207 .69484 .58593 .70646 .59319 .7024 .58934 .69039 Mtetra
.676 .589 .751 r
.58934 .69039 .59319 .7024 .60047 .69814 .59661 .68576 Mtetra
.675 .585 .746 r
.59661 .68576 .60047 .69814 .60776 .69374 .60389 .68101 Mtetra
.674 .58 .742 r
.60389 .68101 .60776 .69374 .61505 .68924 .61118 .6762 Mtetra
.673 .576 .739 r
.61118 .6762 .61505 .68924 .62236 .68467 .61849 .67139 Mtetra
.671 .573 .736 r
.61849 .67139 .62236 .68467 .62968 .68005 .6258 .66658 Mtetra
.67 .571 .735 r
.6258 .66658 .62968 .68005 .63702 .67532 .63313 .66176 Mtetra
.633 .55 .743 r
.63313 .66176 .63702 .67532 .64442 .6726 .64053 .65903 Mtetra
.589 .525 .75 r
.64053 .65903 .64442 .6726 .6519 .6719 .64801 .65838 Mtetra
.59 .526 .751 r
.64801 .65838 .6519 .6719 .65941 .67111 .65552 .65773 Mtetra
.589 .528 .753 r
.65552 .65773 .65941 .67111 .66694 .67026 .66306 .65709 Mtetra
.589 .53 .756 r
.66306 .65709 .66694 .67026 .67449 .66934 .67062 .65645 Mtetra
.59 .534 .76 r
.67062 .65645 .67449 .66934 .68207 .66834 .67821 .65576 Mtetra
.593 .54 .764 r
.67821 .65576 .68207 .66834 .68968 .66719 .68582 .65495 Mtetra
.598 .547 .769 r
.68582 .65495 .68968 .66719 .6973 .66585 .69346 .65397 Mtetra
.604 .555 .773 r
.69346 .65397 .6973 .66585 .70493 .66427 .70111 .65274 Mtetra
.611 .565 .778 r
.70111 .65274 .70493 .66427 .71258 .6624 .70877 .65122 Mtetra
.62 .575 .782 r
.70877 .65122 .71258 .6624 .72023 .66021 .71645 .64937 Mtetra
.629 .585 .786 r
.71645 .64937 .72023 .66021 .72789 .65768 .72413 .64716 Mtetra
.639 .596 .79 r
.72413 .64716 .72789 .65768 .73556 .65479 .73182 .64457 Mtetra
.649 .606 .793 r
.73182 .64457 .73556 .65479 .74323 .65153 .7395 .64161 Mtetra
.659 .617 .796 r
.7395 .64161 .74323 .65153 .75089 .64791 .74719 .63826 Mtetra
.669 .627 .798 r
.74719 .63826 .75089 .64791 .75856 .64392 .75488 .63453 Mtetra
.68 .637 .8 r
.75488 .63453 .75856 .64392 .76622 .63957 .76256 .63043 Mtetra
.689 .647 .802 r
.76256 .63043 .76622 .63957 .77387 .63488 .77024 .62597 Mtetra
.699 .656 .804 r
.77024 .62597 .77387 .63488 .78152 .62985 .77791 .62116 Mtetra
.708 .665 .805 r
.77791 .62116 .78152 .62985 .78916 .62449 .78557 .61601 Mtetra
.717 .673 .806 r
.78557 .61601 .78916 .62449 .79679 .61883 .79323 .61055 Mtetra
.725 .681 .808 r
.79323 .61055 .79679 .61883 .80441 .61288 .80088 .60479 Mtetra
.733 .689 .809 r
.80088 .60479 .80441 .61288 .81203 .60665 .80852 .59874 Mtetra
.74 .697 .809 r
.80852 .59874 .81203 .60665 .81963 .60016 .81614 .59242 Mtetra
.748 .704 .81 r
.81614 .59242 .81963 .60016 .82722 .59343 .82376 .58585 Mtetra
.754 .711 .811 r
.82376 .58585 .82722 .59343 .8348 .58646 .83137 .57904 Mtetra
.761 .717 .812 r
.83137 .57904 .8348 .58646 .84237 .57929 .83897 .57202 Mtetra
.767 .724 .813 r
.83897 .57202 .84237 .57929 .84993 .57192 .84656 .56479 Mtetra
.772 .73 .813 r
.84656 .56479 .84993 .57192 .85748 .56437 .85413 .55738 Mtetra
.778 .736 .814 r
.85413 .55738 .85748 .56437 .86502 .55666 .8617 .5498 Mtetra
.783 .742 .815 r
.8617 .5498 .86502 .55666 .87255 .5488 .86926 .54207 Mtetra
.787 .747 .816 r
.86926 .54207 .87255 .5488 .88007 .5408 .87681 .5342 Mtetra
.792 .753 .817 r
.87681 .5342 .88007 .5408 .88758 .53269 .88435 .52621 Mtetra
.796 .758 .818 r
.88435 .52621 .88758 .53269 .89509 .52448 .89188 .51812 Mtetra
.799 .763 .82 r
.89188 .51812 .89509 .52448 .90258 .51618 .89941 .50993 Mtetra
.803 .768 .821 r
.89941 .50993 .90258 .51618 .91007 .5078 .90693 .50167 Mtetra
.806 .773 .823 r
.90693 .50167 .91007 .5078 .91756 .49937 .91444 .49335 Mtetra
.809 .778 .825 r
.91444 .49335 .91756 .49937 .92504 .49089 .92196 .48498 Mtetra
.812 .783 .827 r
.92196 .48498 .92504 .49089 .93251 .48238 .92946 .47659 Mtetra
.814 .788 .829 r
.92946 .47659 .93251 .48238 .93999 .47386 .93697 .46817 Mtetra
.236 .558 .934 r
.3579 .68391 .36195 .68857 .36834 .69113 .3643 .68635 Mtetra
.249 .559 .934 r
.3643 .68635 .36834 .69113 .37476 .69369 .37073 .68878 Mtetra
.264 .561 .934 r
.37073 .68878 .37476 .69369 .38121 .69623 .37719 .69119 Mtetra
.28 .564 .933 r
.37719 .69119 .38121 .69623 .3877 .69874 .38369 .69357 Mtetra
.297 .567 .932 r
.38369 .69357 .3877 .69874 .39422 .70121 .39021 .69591 Mtetra
.315 .571 .931 r
.39021 .69591 .39422 .70121 .40077 .70362 .39678 .69818 Mtetra
.333 .575 .929 r
.39678 .69818 .40077 .70362 .40736 .70595 .40337 .70037 Mtetra
.352 .578 .927 r
.40337 .70037 .40736 .70595 .41398 .7082 .41 .70248 Mtetra
.371 .582 .924 r
.41 .70248 .41398 .7082 .42064 .71034 .41667 .70448 Mtetra
.39 .586 .921 r
.41667 .70448 .42064 .71034 .42733 .71236 .42337 .70635 Mtetra
.409 .59 .917 r
.42337 .70635 .42733 .71236 .43406 .71425 .4301 .70808 Mtetra
.429 .594 .913 r
.4301 .70808 .43406 .71425 .44082 .71598 .43687 .70966 Mtetra
.448 .598 .908 r
.43687 .70966 .44082 .71598 .44761 .71755 .44367 .71107 Mtetra
.466 .601 .902 r
.44367 .71107 .44761 .71755 .45444 .71894 .45051 .71228 Mtetra
.485 .604 .896 r
.45051 .71228 .45444 .71894 .46131 .72012 .45738 .71329 Mtetra
.503 .607 .89 r
.45738 .71329 .46131 .72012 .4682 .72109 .46428 .71408 Mtetra
.52 .61 .883 r
.46428 .71408 .4682 .72109 .47513 .72183 .47122 .71462 Mtetra
.537 .612 .875 r
.47122 .71462 .47513 .72183 .48209 .72231 .47818 .71491 Mtetra
.553 .614 .867 r
.47818 .71491 .48209 .72231 .48908 .72252 .48518 .71491 Mtetra
.568 .615 .859 r
.48518 .71491 .48908 .72252 .4961 .72245 .49221 .71462 Mtetra
.582 .616 .851 r
.49221 .71462 .4961 .72245 .50314 .72207 .49926 .71401 Mtetra
.596 .617 .843 r
.49926 .71401 .50314 .72207 .51022 .72138 .50634 .71307 Mtetra
.609 .617 .834 r
.50634 .71307 .51022 .72138 .51732 .72035 .51344 .71179 Mtetra
.621 .617 .825 r
.51344 .71179 .51732 .72035 .52444 .71897 .52057 .71014 Mtetra
.632 .616 .817 r
.52057 .71014 .52444 .71897 .53159 .71723 .52772 .70811 Mtetra
.642 .616 .808 r
.52772 .70811 .53159 .71723 .53875 .71512 .53489 .7057 Mtetra
.651 .614 .8 r
.53489 .7057 .53875 .71512 .54594 .71263 .54208 .7029 Mtetra
.659 .613 .791 r
.54208 .7029 .54594 .71263 .55314 .70977 .54928 .6997 Mtetra
.666 .611 .783 r
.54928 .6997 .55314 .70977 .56035 .70654 .5565 .69612 Mtetra
.672 .608 .775 r
.5565 .69612 .56035 .70654 .56758 .70296 .56373 .69217 Mtetra
.677 .605 .768 r
.56373 .69217 .56758 .70296 .57482 .69905 .57097 .68787 Mtetra
.68 .601 .761 r
.57097 .68787 .57482 .69905 .58207 .69484 .57822 .68327 Mtetra
.682 .597 .755 r
.57822 .68327 .58207 .69484 .58934 .69039 .58547 .67842 Mtetra
.682 .593 .749 r
.58547 .67842 .58934 .69039 .59661 .68576 .59274 .67339 Mtetra
.682 .588 .744 r
.59274 .67339 .59661 .68576 .60389 .68101 .60002 .66828 Mtetra
.679 .583 .741 r
.60002 .66828 .60389 .68101 .61118 .6762 .60731 .66315 Mtetra
.677 .578 .738 r
.60731 .66315 .61118 .6762 .61849 .67139 .61461 .65808 Mtetra
.674 .574 .736 r
.61461 .65808 .61849 .67139 .6258 .66658 .62192 .65311 Mtetra
.671 .572 .734 r
.62192 .65311 .6258 .66658 .63313 .66176 .62925 .64822 Mtetra
.633 .55 .743 r
.62925 .64822 .63313 .66176 .64053 .65903 .63664 .64546 Mtetra
.588 .524 .751 r
.63664 .64546 .64053 .65903 .64801 .65838 .64412 .64485 Mtetra
.586 .524 .752 r
.64412 .64485 .64801 .65838 .65552 .65773 .65163 .64433 Mtetra
.584 .524 .754 r
.65163 .64433 .65552 .65773 .66306 .65709 .65917 .64391 Mtetra
.582 .526 .757 r
.65917 .64391 .66306 .65709 .67062 .65645 .66674 .64355 Mtetra
.582 .53 .762 r
.66674 .64355 .67062 .65645 .67821 .65576 .67434 .64319 Mtetra
.584 .535 .766 r
.67434 .64319 .67821 .65576 .68582 .65495 .68197 .64274 Mtetra
.588 .542 .771 r
.68197 .64274 .68582 .65495 .69346 .65397 .68962 .64212 Mtetra
.594 .551 .776 r
.68962 .64212 .69346 .65397 .70111 .65274 .69728 .64126 Mtetra
.602 .561 .781 r
.69728 .64126 .70111 .65274 .70877 .65122 .70496 .6401 Mtetra
.611 .571 .785 r
.70496 .6401 .70877 .65122 .71645 .64937 .71266 .63859 Mtetra
.621 .582 .789 r
.71266 .63859 .71645 .64937 .72413 .64716 .72036 .6367 Mtetra
.631 .593 .793 r
.72036 .6367 .72413 .64716 .73182 .64457 .72806 .63442 Mtetra
.642 .604 .796 r
.72806 .63442 .73182 .64457 .7395 .64161 .73577 .63175 Mtetra
.653 .615 .799 r
.73577 .63175 .7395 .64161 .74719 .63826 .74348 .62867 Mtetra
.663 .626 .802 r
.74348 .62867 .74719 .63826 .75488 .63453 .75119 .6252 Mtetra
.674 .636 .804 r
.75119 .6252 .75488 .63453 .76256 .63043 .7589 .62134 Mtetra
.684 .646 .806 r
.7589 .62134 .76256 .63043 .77024 .62597 .7666 .61711 Mtetra
.694 .656 .807 r
.7666 .61711 .77024 .62597 .77791 .62116 .77429 .61252 Mtetra
.704 .665 .809 r
.77429 .61252 .77791 .62116 .78557 .61601 .78198 .60758 Mtetra
.713 .673 .81 r
.78198 .60758 .78557 .61601 .79323 .61055 .78966 .60231 Mtetra
.721 .682 .811 r
.78966 .60231 .79323 .61055 .80088 .60479 .79733 .59673 Mtetra
.73 .689 .812 r
.79733 .59673 .80088 .60479 .80852 .59874 .805 .59086 Mtetra
.737 .697 .813 r
.805 .59086 .80852 .59874 .81614 .59242 .81265 .5847 Mtetra
.745 .704 .813 r
.81265 .5847 .81614 .59242 .82376 .58585 .82029 .57829 Mtetra
.752 .711 .814 r
.82029 .57829 .82376 .58585 .83137 .57904 .82793 .57164 Mtetra
.758 .718 .815 r
.82793 .57164 .83137 .57904 .83897 .57202 .83555 .56476 Mtetra
.764 .724 .815 r
.83555 .56476 .83897 .57202 .84656 .56479 .84317 .55767 Mtetra
.77 .73 .816 r
.84317 .55767 .84656 .56479 .85413 .55738 .85077 .5504 Mtetra
.775 .736 .817 r
.85077 .5504 .85413 .55738 .8617 .5498 .85837 .54295 Mtetra
.78 .742 .818 r
.85837 .54295 .8617 .5498 .86926 .54207 .86596 .53534 Mtetra
.785 .747 .819 r
.86596 .53534 .86926 .54207 .87681 .5342 .87353 .5276 Mtetra
.789 .753 .82 r
.87353 .5276 .87681 .5342 .88435 .52621 .8811 .51973 Mtetra
.793 .758 .821 r
.8811 .51973 .88435 .52621 .89188 .51812 .88867 .51175 Mtetra
.797 .763 .822 r
.88867 .51175 .89188 .51812 .89941 .50993 .89622 .50368 Mtetra
.801 .768 .823 r
.89622 .50368 .89941 .50993 .90693 .50167 .90377 .49553 Mtetra
.804 .773 .825 r
.90377 .49553 .90693 .50167 .91444 .49335 .91132 .48732 Mtetra
.807 .778 .827 r
.91132 .48732 .91444 .49335 .92196 .48498 .91886 .47906 Mtetra
.809 .783 .829 r
.91886 .47906 .92196 .48498 .92946 .47659 .9264 .47077 Mtetra
.811 .788 .831 r
.9264 .47077 .92946 .47659 .93697 .46817 .93394 .46246 Mtetra
.252 .567 .938 r
.35384 .67924 .3579 .68391 .3643 .68635 .36024 .68155 Mtetra
.265 .568 .937 r
.36024 .68155 .3643 .68635 .37073 .68878 .36668 .68385 Mtetra
.279 .57 .936 r
.36668 .68385 .37073 .68878 .37719 .69119 .37315 .68614 Mtetra
.294 .572 .935 r
.37315 .68614 .37719 .69119 .38369 .69357 .37966 .68839 Mtetra
.31 .575 .934 r
.37966 .68839 .38369 .69357 .39021 .69591 .38619 .6906 Mtetra
.327 .578 .933 r
.38619 .6906 .39021 .69591 .39678 .69818 .39276 .69274 Mtetra
.345 .582 .931 r
.39276 .69274 .39678 .69818 .40337 .70037 .39937 .6948 Mtetra
.363 .586 .928 r
.39937 .6948 .40337 .70037 .41 .70248 .40601 .69677 Mtetra
.382 .589 .926 r
.40601 .69677 .41 .70248 .41667 .70448 .41268 .69862 Mtetra
.401 .593 .922 r
.41268 .69862 .41667 .70448 .42337 .70635 .41939 .70035 Mtetra
.42 .597 .918 r
.41939 .70035 .42337 .70635 .4301 .70808 .42613 .70194 Mtetra
.438 .601 .914 r
.42613 .70194 .4301 .70808 .43687 .70966 .43291 .70336 Mtetra
.457 .604 .909 r
.43291 .70336 .43687 .70966 .44367 .71107 .43972 .70461 Mtetra
.476 .607 .903 r
.43972 .70461 .44367 .71107 .45051 .71228 .44656 .70566 Mtetra
.494 .611 .897 r
.44656 .70566 .45051 .71228 .45738 .71329 .45344 .7065 Mtetra
.511 .613 .89 r
.45344 .7065 .45738 .71329 .46428 .71408 .46035 .7071 Mtetra
.529 .616 .883 r
.46035 .7071 .46428 .71408 .47122 .71462 .46729 .70746 Mtetra
.545 .618 .876 r
.46729 .70746 .47122 .71462 .47818 .71491 .47426 .70755 Mtetra
.561 .619 .868 r
.47426 .70755 .47818 .71491 .48518 .71491 .48127 .70734 Mtetra
.576 .621 .86 r
.48127 .70734 .48518 .71491 .49221 .71462 .4883 .70684 Mtetra
.591 .622 .851 r
.4883 .70684 .49221 .71462 .49926 .71401 .49536 .706 Mtetra
.604 .622 .843 r
.49536 .706 .49926 .71401 .50634 .71307 .50244 .70483 Mtetra
.617 .623 .834 r
.50244 .70483 .50634 .71307 .51344 .71179 .50955 .70329 Mtetra
.629 .623 .825 r
.50955 .70329 .51344 .71179 .52057 .71014 .51669 .70138 Mtetra
.64 .622 .816 r
.51669 .70138 .52057 .71014 .52772 .70811 .52384 .69907 Mtetra
.65 .621 .808 r
.52384 .69907 .52772 .70811 .53489 .7057 .53102 .69636 Mtetra
.659 .62 .799 r
.53102 .69636 .53489 .7057 .54208 .7029 .53821 .69324 Mtetra
.667 .618 .79 r
.53821 .69324 .54208 .7029 .54928 .6997 .54541 .68971 Mtetra
.674 .616 .782 r
.54541 .68971 .54928 .6997 .5565 .69612 .55263 .68577 Mtetra
.68 .613 .774 r
.55263 .68577 .5565 .69612 .56373 .69217 .55986 .68143 Mtetra
.685 .61 .767 r
.55986 .68143 .56373 .69217 .57097 .68787 .5671 .67674 Mtetra
.688 .606 .759 r
.5671 .67674 .57097 .68787 .57822 .68327 .57435 .67173 Mtetra
.689 .602 .753 r
.57435 .67173 .57822 .68327 .58547 .67842 .58161 .66646 Mtetra
.689 .597 .747 r
.58161 .66646 .58547 .67842 .59274 .67339 .58887 .66103 Mtetra
.688 .592 .743 r
.58887 .66103 .59274 .67339 .60002 .66828 .59614 .65553 Mtetra
.685 .586 .739 r
.59614 .65553 .60002 .66828 .60731 .66315 .60343 .65007 Mtetra
.681 .58 .736 r
.60343 .65007 .60731 .66315 .61461 .65808 .61072 .64474 Mtetra
.676 .575 .735 r
.61072 .64474 .61461 .65808 .62192 .65311 .61803 .6396 Mtetra
.672 .572 .734 r
.61803 .6396 .62192 .65311 .62925 .64822 .62536 .63466 Mtetra
.633 .55 .743 r
.62536 .63466 .62925 .64822 .63664 .64546 .63275 .63189 Mtetra
.587 .524 .751 r
.63275 .63189 .63664 .64546 .64412 .64485 .64023 .63129 Mtetra
.583 .522 .752 r
.64023 .63129 .64412 .64485 .65163 .64433 .64774 .63089 Mtetra
.578 .521 .754 r
.64774 .63089 .65163 .64433 .65917 .64391 .65528 .6307 Mtetra
.574 .521 .758 r
.65528 .6307 .65917 .64391 .66674 .64355 .66286 .63064 Mtetra
.573 .524 .763 r
.66286 .63064 .66674 .64355 .67434 .64319 .67047 .63063 Mtetra
.574 .53 .768 r
.67047 .63063 .67434 .64319 .68197 .64274 .67811 .63056 Mtetra
.578 .537 .773 r
.67811 .63056 .68197 .64274 .68962 .64212 .68577 .63032 Mtetra
.584 .546 .779 r
.68577 .63032 .68962 .64212 .69728 .64126 .69345 .62983 Mtetra
.592 .557 .784 r
.69345 .62983 .69728 .64126 .70496 .6401 .70115 .62903 Mtetra
.601 .568 .788 r
.70115 .62903 .70496 .6401 .71266 .63859 .70886 .62787 Mtetra
.612 .579 .793 r
.70886 .62787 .71266 .63859 .72036 .6367 .71658 .62631 Mtetra
.623 .591 .797 r
.71658 .62631 .72036 .6367 .72806 .63442 .72431 .62435 Mtetra
.634 .602 .8 r
.72431 .62435 .72806 .63442 .73577 .63175 .73204 .62196 Mtetra
.646 .614 .803 r
.73204 .62196 .73577 .63175 .74348 .62867 .73977 .61916 Mtetra
.657 .625 .806 r
.73977 .61916 .74348 .62867 .75119 .6252 .7475 .61594 Mtetra
.668 .635 .808 r
.7475 .61594 .75119 .6252 .7589 .62134 .75523 .61232 Mtetra
.679 .646 .809 r
.75523 .61232 .7589 .62134 .7666 .61711 .76295 .60832 Mtetra
.69 .655 .811 r
.76295 .60832 .7666 .61711 .77429 .61252 .77067 .60393 Mtetra
.699 .665 .812 r
.77067 .60393 .77429 .61252 .78198 .60758 .77838 .5992 Mtetra
.709 .673 .813 r
.77838 .5992 .78198 .60758 .78966 .60231 .78608 .59412 Mtetra
.718 .682 .814 r
.78608 .59412 .78966 .60231 .79733 .59673 .79378 .58872 Mtetra
.726 .69 .815 r
.79378 .58872 .79733 .59673 .805 .59086 .80147 .58301 Mtetra
.734 .697 .816 r
.80147 .58301 .805 .59086 .81265 .5847 .80915 .57702 Mtetra
.742 .705 .816 r
.80915 .57702 .81265 .5847 .82029 .57829 .81682 .57077 Mtetra
.749 .712 .817 r
.81682 .57077 .82029 .57829 .82793 .57164 .82448 .56426 Mtetra
.755 .718 .818 r
.82448 .56426 .82793 .57164 .83555 .56476 .83213 .55753 Mtetra
.762 .725 .818 r
.83213 .55753 .83555 .56476 .84317 .55767 .83977 .55058 Mtetra
.767 .731 .819 r
.83977 .55058 .84317 .55767 .85077 .5504 .8474 .54343 Mtetra
.773 .737 .819 r
.8474 .54343 .85077 .5504 .85837 .54295 .85503 .53611 Mtetra
.778 .742 .82 r
.85503 .53611 .85837 .54295 .86596 .53534 .86264 .52862 Mtetra
.783 .748 .821 r
.86264 .52862 .86596 .53534 .87353 .5276 .87025 .521 Mtetra
.787 .753 .822 r
.87025 .521 .87353 .5276 .8811 .51973 .87784 .51324 Mtetra
.791 .758 .823 r
.87784 .51324 .8811 .51973 .88867 .51175 .88544 .50537 Mtetra
.795 .763 .824 r
.88544 .50537 .88867 .51175 .89622 .50368 .89302 .49741 Mtetra
.798 .768 .825 r
.89302 .49741 .89622 .50368 .90377 .49553 .9006 .48937 Mtetra
.801 .773 .827 r
.9006 .48937 .90377 .49553 .91132 .48732 .90818 .48126 Mtetra
.804 .778 .829 r
.90818 .48126 .91132 .48732 .91886 .47906 .91575 .47311 Mtetra
.807 .783 .831 r
.91575 .47311 .91886 .47906 .9264 .47077 .92332 .46492 Mtetra
.809 .788 .833 r
.92332 .46492 .9264 .47077 .93394 .46246 .93089 .45672 Mtetra
.268 .576 .941 r
.34975 .67454 .35384 .67924 .36024 .68155 .35617 .67673 Mtetra
.279 .576 .94 r
.35617 .67673 .36024 .68155 .36668 .68385 .36262 .67891 Mtetra
.293 .578 .939 r
.36262 .67891 .36668 .68385 .37315 .68614 .3691 .68108 Mtetra
.307 .58 .938 r
.3691 .68108 .37315 .68614 .37966 .68839 .37561 .68321 Mtetra
.323 .582 .936 r
.37561 .68321 .37966 .68839 .38619 .6906 .38215 .68528 Mtetra
.339 .585 .935 r
.38215 .68528 .38619 .6906 .39276 .69274 .38873 .6873 Mtetra
.356 .589 .932 r
.38873 .6873 .39276 .69274 .39937 .6948 .39535 .68923 Mtetra
.374 .592 .93 r
.39535 .68923 .39937 .6948 .40601 .69677 .40199 .69106 Mtetra
.392 .596 .927 r
.40199 .69106 .40601 .69677 .41268 .69862 .40867 .69278 Mtetra
.411 .6 .923 r
.40867 .69278 .41268 .69862 .41939 .70035 .41539 .69437 Mtetra
.429 .603 .919 r
.41539 .69437 .41939 .70035 .42613 .70194 .42214 .69581 Mtetra
.448 .607 .915 r
.42214 .69581 .42613 .70194 .43291 .70336 .42893 .69708 Mtetra
.466 .61 .909 r
.42893 .69708 .43291 .70336 .43972 .70461 .43574 .69817 Mtetra
.485 .614 .904 r
.43574 .69817 .43972 .70461 .44656 .70566 .4426 .69906 Mtetra
.502 .616 .898 r
.4426 .69906 .44656 .70566 .45344 .7065 .44948 .69973 Mtetra
.52 .619 .891 r
.44948 .69973 .45344 .7065 .46035 .7071 .4564 .70016 Mtetra
.537 .622 .884 r
.4564 .70016 .46035 .7071 .46729 .70746 .46335 .70034 Mtetra
.553 .624 .876 r
.46335 .70034 .46729 .70746 .47426 .70755 .47033 .70023 Mtetra
.569 .625 .868 r
.47033 .70023 .47426 .70755 .48127 .70734 .47734 .69983 Mtetra
.584 .627 .86 r
.47734 .69983 .48127 .70734 .4883 .70684 .48438 .69911 Mtetra
.598 .628 .851 r
.48438 .69911 .4883 .70684 .49536 .706 .49144 .69806 Mtetra
.612 .628 .843 r
.49144 .69806 .49536 .706 .50244 .70483 .49854 .69665 Mtetra
.625 .628 .834 r
.49854 .69665 .50244 .70483 .50955 .70329 .50565 .69486 Mtetra
.637 .628 .825 r
.50565 .69486 .50955 .70329 .51669 .70138 .51279 .69268 Mtetra
.648 .628 .816 r
.51279 .69268 .51669 .70138 .52384 .69907 .51995 .6901 Mtetra
.658 .627 .807 r
.51995 .6901 .52384 .69907 .53102 .69636 .52713 .68709 Mtetra
.667 .625 .798 r
.52713 .68709 .53102 .69636 .53821 .69324 .53433 .68365 Mtetra
.675 .624 .79 r
.53433 .68365 .53821 .69324 .54541 .68971 .54154 .67978 Mtetra
.682 .621 .781 r
.54154 .67978 .54541 .68971 .55263 .68577 .54876 .67548 Mtetra
.688 .619 .773 r
.54876 .67548 .55263 .68577 .55986 .68143 .55599 .67077 Mtetra
.693 .615 .765 r
.55599 .67077 .55986 .68143 .5671 .67674 .56323 .66567 Mtetra
.696 .611 .758 r
.56323 .66567 .5671 .67674 .57435 .67173 .57048 .66023 Mtetra
.697 .607 .751 r
.57048 .66023 .57435 .67173 .58161 .66646 .57774 .65453 Mtetra
.697 .601 .746 r
.57774 .65453 .58161 .66646 .58887 .66103 .585 .64867 Mtetra
.694 .595 .741 r
.585 .64867 .58887 .66103 .59614 .65553 .59227 .64276 Mtetra
.69 .589 .737 r
.59227 .64276 .59614 .65553 .60343 .65007 .59954 .63694 Mtetra
.685 .582 .735 r
.59954 .63694 .60343 .65007 .61072 .64474 .60683 .63133 Mtetra
.678 .576 .733 r
.60683 .63133 .61072 .64474 .61803 .6396 .61414 .62603 Mtetra
.672 .571 .733 r
.61414 .62603 .61803 .6396 .62536 .63466 .62147 .62106 Mtetra
.633 .55 .743 r
.62147 .62106 .62536 .63466 .63275 .63189 .62886 .61827 Mtetra
.587 .523 .75 r
.62886 .61827 .63275 .63189 .64023 .63129 .63633 .61766 Mtetra
.579 .519 .752 r
.63633 .61766 .64023 .63129 .64774 .63089 .64384 .61739 Mtetra
.572 .516 .755 r
.64384 .61739 .64774 .63089 .65528 .6307 .65139 .61743 Mtetra
.566 .516 .759 r
.65139 .61743 .65528 .6307 .66286 .63064 .65897 .6177 Mtetra
.563 .518 .764 r
.65897 .6177 .66286 .63064 .67047 .63063 .66659 .61807 Mtetra
.563 .524 .769 r
.66659 .61807 .67047 .63063 .67811 .63056 .67424 .61839 Mtetra
.566 .531 .775 r
.67424 .61839 .67811 .63056 .68577 .63032 .68192 .61856 Mtetra
.572 .541 .781 r
.68192 .61856 .68577 .63032 .69345 .62983 .68962 .61846 Mtetra
.581 .552 .787 r
.68962 .61846 .69345 .62983 .70115 .62903 .69734 .61804 Mtetra
.591 .564 .792 r
.69734 .61804 .70115 .62903 .70886 .62787 .70507 .61723 Mtetra
.602 .576 .796 r
.70507 .61723 .70886 .62787 .71658 .62631 .7128 .616 Mtetra
.614 .588 .8 r
.7128 .616 .71658 .62631 .72431 .62435 .72055 .61435 Mtetra
.627 .6 .804 r
.72055 .61435 .72431 .62435 .73204 .62196 .7283 .61225 Mtetra
.639 .612 .807 r
.7283 .61225 .73204 .62196 .73977 .61916 .73605 .60971 Mtetra
.651 .624 .809 r
.73605 .60971 .73977 .61916 .7475 .61594 .7438 .60675 Mtetra
.663 .635 .812 r
.7438 .60675 .7475 .61594 .75523 .61232 .75155 .60337 Mtetra
.674 .645 .813 r
.75155 .60337 .75523 .61232 .76295 .60832 .7593 .59958 Mtetra
.685 .655 .815 r
.7593 .59958 .76295 .60832 .77067 .60393 .76704 .59541 Mtetra
.695 .665 .816 r
.76704 .59541 .77067 .60393 .77838 .5992 .77477 .59087 Mtetra
.705 .674 .817 r
.77477 .59087 .77838 .5992 .78608 .59412 .7825 .58597 Mtetra
.714 .682 .818 r
.7825 .58597 .78608 .59412 .79378 .58872 .79022 .58075 Mtetra
.723 .69 .818 r
.79022 .58075 .79378 .58872 .80147 .58301 .79793 .57521 Mtetra
.731 .698 .819 r
.79793 .57521 .80147 .58301 .80915 .57702 .80564 .56938 Mtetra
.739 .705 .819 r
.80564 .56938 .80915 .57702 .81682 .57077 .81333 .56327 Mtetra
.746 .712 .82 r
.81333 .56327 .81682 .57077 .82448 .56426 .82102 .55691 Mtetra
.753 .719 .82 r
.82102 .55691 .82448 .56426 .83213 .55753 .82869 .55031 Mtetra
.759 .725 .821 r
.82869 .55031 .83213 .55753 .83977 .55058 .83636 .54349 Mtetra
.765 .731 .821 r
.83636 .54349 .83977 .55058 .8474 .54343 .84402 .53648 Mtetra
.771 .737 .822 r
.84402 .53648 .8474 .54343 .85503 .53611 .85167 .52928 Mtetra
.776 .743 .823 r
.85167 .52928 .85503 .53611 .86264 .52862 .85931 .52191 Mtetra
.781 .748 .823 r
.85931 .52191 .86264 .52862 .87025 .521 .86695 .5144 Mtetra
.785 .753 .824 r
.86695 .5144 .87025 .521 .87784 .51324 .87457 .50675 Mtetra
.789 .758 .825 r
.87457 .50675 .87784 .51324 .88544 .50537 .88219 .49899 Mtetra
.793 .763 .826 r
.88219 .49899 .88544 .50537 .89302 .49741 .88981 .49113 Mtetra
.796 .768 .828 r
.88981 .49113 .89302 .49741 .9006 .48937 .89742 .4832 Mtetra
.799 .773 .829 r
.89742 .4832 .9006 .48937 .90818 .48126 .90502 .47519 Mtetra
.802 .778 .831 r
.90502 .47519 .90818 .48126 .91575 .47311 .91262 .46714 Mtetra
.804 .782 .832 r
.91262 .46714 .91575 .47311 .92332 .46492 .92023 .45905 Mtetra
.807 .787 .835 r
.92023 .45905 .92332 .46492 .93089 .45672 .92783 .45095 Mtetra
.282 .584 .943 r
.34565 .66982 .34975 .67454 .35617 .67673 .35207 .6719 Mtetra
.293 .584 .942 r
.35207 .6719 .35617 .67673 .36262 .67891 .35853 .67396 Mtetra
.306 .585 .941 r
.35853 .67396 .36262 .67891 .3691 .68108 .36502 .676 Mtetra
.32 .587 .94 r
.36502 .676 .3691 .68108 .37561 .68321 .37154 .67801 Mtetra
.335 .589 .938 r
.37154 .67801 .37561 .68321 .38215 .68528 .3781 .67997 Mtetra
.351 .592 .936 r
.3781 .67997 .38215 .68528 .38873 .6873 .38468 .68186 Mtetra
.367 .595 .934 r
.38468 .68186 .38873 .6873 .39535 .68923 .39131 .68366 Mtetra
.385 .599 .931 r
.39131 .68366 .39535 .68923 .40199 .69106 .39796 .68536 Mtetra
.402 .602 .928 r
.39796 .68536 .40199 .69106 .40867 .69278 .40465 .68695 Mtetra
.42 .606 .924 r
.40465 .68695 .40867 .69278 .41539 .69437 .41138 .6884 Mtetra
.439 .609 .92 r
.41138 .6884 .41539 .69437 .42214 .69581 .41813 .68969 Mtetra
.457 .613 .916 r
.41813 .68969 .42214 .69581 .42893 .69708 .42493 .69082 Mtetra
.475 .616 .91 r
.42493 .69082 .42893 .69708 .43574 .69817 .43175 .69176 Mtetra
.493 .619 .904 r
.43175 .69176 .43574 .69817 .4426 .69906 .43861 .69249 Mtetra
.511 .622 .898 r
.43861 .69249 .4426 .69906 .44948 .69973 .44551 .693 Mtetra
.528 .625 .891 r
.44551 .693 .44948 .69973 .4564 .70016 .45243 .69326 Mtetra
.545 .627 .884 r
.45243 .69326 .4564 .70016 .46335 .70034 .45939 .69326 Mtetra
.561 .629 .877 r
.45939 .69326 .46335 .70034 .47033 .70023 .46638 .69296 Mtetra
.577 .631 .869 r
.46638 .69296 .47033 .70023 .47734 .69983 .4734 .69237 Mtetra
.592 .632 .86 r
.4734 .69237 .47734 .69983 .48438 .69911 .48044 .69144 Mtetra
.606 .633 .852 r
.48044 .69144 .48438 .69911 .49144 .69806 .48752 .69017 Mtetra
.62 .634 .843 r
.48752 .69017 .49144 .69806 .49854 .69665 .49462 .68853 Mtetra
.632 .634 .834 r
.49462 .68853 .49854 .69665 .50565 .69486 .50174 .6865 Mtetra
.644 .634 .825 r
.50174 .6865 .50565 .69486 .51279 .69268 .50889 .68407 Mtetra
.655 .633 .816 r
.50889 .68407 .51279 .69268 .51995 .6901 .51605 .68121 Mtetra
.666 .632 .807 r
.51605 .68121 .51995 .6901 .52713 .68709 .52324 .6779 Mtetra
.675 .631 .798 r
.52324 .6779 .52713 .68709 .53433 .68365 .53044 .67415 Mtetra
.683 .629 .789 r
.53044 .67415 .53433 .68365 .54154 .67978 .53765 .66994 Mtetra
.69 .627 .78 r
.53765 .66994 .54154 .67978 .54876 .67548 .54488 .66528 Mtetra
.696 .624 .772 r
.54488 .66528 .54876 .67548 .55599 .67077 .55211 .66017 Mtetra
.701 .62 .764 r
.55211 .66017 .55599 .67077 .56323 .66567 .55936 .65466 Mtetra
.704 .616 .756 r
.55936 .65466 .56323 .66567 .57048 .66023 .56661 .64878 Mtetra
.705 .611 .749 r
.56661 .64878 .57048 .66023 .57774 .65453 .57386 .64263 Mtetra
.704 .605 .743 r
.57386 .64263 .57774 .65453 .585 .64867 .58112 .6363 Mtetra
.701 .599 .739 r
.58112 .6363 .585 .64867 .59227 .64276 .58838 .62995 Mtetra
.696 .591 .735 r
.58838 .62995 .59227 .64276 .59954 .63694 .59566 .62374 Mtetra
.689 .584 .733 r
.59566 .62374 .59954 .63694 .60683 .63133 .60294 .61783 Mtetra
.68 .576 .732 r
.60294 .61783 .60683 .63133 .61414 .62603 .61024 .61236 Mtetra
.671 .57 .733 r
.61024 .61236 .61414 .62603 .62147 .62106 .61757 .60739 Mtetra
.633 .549 .742 r
.61757 .60739 .62147 .62106 .62886 .61827 .62496 .60458 Mtetra
.587 .523 .75 r
.62496 .60458 .62886 .61827 .63633 .61766 .63243 .60394 Mtetra
.576 .516 .751 r
.63243 .60394 .63633 .61766 .64384 .61739 .63993 .6038 Mtetra
.565 .511 .754 r
.63993 .6038 .64384 .61739 .65139 .61743 .64748 .6041 Mtetra
.556 .51 .759 r
.64748 .6041 .65139 .61743 .65897 .6177 .65508 .60472 Mtetra
.551 .512 .765 r
.65508 .60472 .65897 .6177 .66659 .61807 .66271 .6055 Mtetra
.55 .517 .771 r
.66271 .6055 .66659 .61807 .67424 .61839 .67037 .60625 Mtetra
.554 .525 .777 r
.67037 .60625 .67424 .61839 .68192 .61856 .67807 .60684 Mtetra
.56 .535 .784 r
.67807 .60684 .68192 .61856 .68962 .61846 .68578 .60716 Mtetra
.569 .547 .79 r
.68578 .60716 .68962 .61846 .69734 .61804 .69351 .60712 Mtetra
.58 .559 .795 r
.69351 .60712 .69734 .61804 .70507 .61723 .70126 .60667 Mtetra
.593 .572 .8 r
.70126 .60667 .70507 .61723 .7128 .616 .70902 .60578 Mtetra
.605 .585 .804 r
.70902 .60578 .7128 .616 .72055 .61435 .71678 .60443 Mtetra
.619 .598 .808 r
.71678 .60443 .72055 .61435 .7283 .61225 .72455 .60262 Mtetra
.632 .611 .811 r
.72455 .60262 .7283 .61225 .73605 .60971 .73232 .60035 Mtetra
.644 .623 .813 r
.73232 .60035 .73605 .60971 .7438 .60675 .7401 .59763 Mtetra
.657 .634 .816 r
.7401 .59763 .7438 .60675 .75155 .60337 .74787 .59448 Mtetra
.669 .645 .817 r
.74787 .59448 .75155 .60337 .7593 .59958 .75563 .59091 Mtetra
.68 .655 .819 r
.75563 .59091 .7593 .59958 .76704 .59541 .7634 .58694 Mtetra
.691 .665 .82 r
.7634 .58694 .76704 .59541 .77477 .59087 .77115 .58259 Mtetra
.701 .674 .821 r
.77115 .58259 .77477 .59087 .7825 .58597 .77891 .57788 Mtetra
.711 .683 .821 r
.77891 .57788 .7825 .58597 .79022 .58075 .78665 .57283 Mtetra
.72 .691 .822 r
.78665 .57283 .79022 .58075 .79793 .57521 .79439 .56745 Mtetra
.728 .698 .822 r
.79439 .56745 .79793 .57521 .80564 .56938 .80212 .56177 Mtetra
.736 .706 .823 r
.80212 .56177 .80564 .56938 .81333 .56327 .80984 .55581 Mtetra
.743 .713 .823 r
.80984 .55581 .81333 .56327 .82102 .55691 .81755 .54959 Mtetra
.75 .719 .823 r
.81755 .54959 .82102 .55691 .82869 .55031 .82525 .54312 Mtetra
.757 .726 .824 r
.82525 .54312 .82869 .55031 .83636 .54349 .83294 .53643 Mtetra
.763 .732 .824 r
.83294 .53643 .83636 .54349 .84402 .53648 .84063 .52954 Mtetra
.768 .738 .825 r
.84063 .52954 .84402 .53648 .85167 .52928 .8483 .52245 Mtetra
.774 .743 .825 r
.8483 .52245 .85167 .52928 .85931 .52191 .85597 .5152 Mtetra
.778 .748 .826 r
.85597 .5152 .85931 .52191 .86695 .5144 .86363 .5078 Mtetra
.783 .754 .827 r
.86363 .5078 .86695 .5144 .87457 .50675 .87129 .50026 Mtetra
.787 .759 .827 r
.87129 .50026 .87457 .50675 .88219 .49899 .87894 .4926 Mtetra
.791 .764 .828 r
.87894 .4926 .88219 .49899 .88981 .49113 .88658 .48485 Mtetra
.794 .768 .83 r
.88658 .48485 .88981 .49113 .89742 .4832 .89422 .47701 Mtetra
.797 .773 .831 r
.89422 .47701 .89742 .4832 .90502 .47519 .90185 .4691 Mtetra
.8 .778 .833 r
.90185 .4691 .90502 .47519 .91262 .46714 .90948 .46115 Mtetra
.802 .782 .834 r
.90948 .46115 .91262 .46714 .92023 .45905 .91712 .45316 Mtetra
.804 .787 .836 r
.91712 .45316 .92023 .45905 .92783 .45095 .92475 .44515 Mtetra
.296 .591 .945 r
.34153 .66509 .34565 .66982 .35207 .6719 .34796 .66704 Mtetra
.307 .591 .944 r
.34796 .66704 .35207 .6719 .35853 .67396 .35443 .66899 Mtetra
.319 .592 .943 r
.35443 .66899 .35853 .67396 .36502 .676 .36093 .67092 Mtetra
.332 .594 .941 r
.36093 .67092 .36502 .676 .37154 .67801 .36746 .67281 Mtetra
.346 .596 .94 r
.36746 .67281 .37154 .67801 .3781 .67997 .37402 .67465 Mtetra
.361 .599 .937 r
.37402 .67465 .3781 .67997 .38468 .68186 .38062 .67641 Mtetra
.378 .602 .935 r
.38062 .67641 .38468 .68186 .39131 .68366 .38725 .67809 Mtetra
.394 .605 .932 r
.38725 .67809 .39131 .68366 .39796 .68536 .39391 .67967 Mtetra
.412 .608 .929 r
.39391 .67967 .39796 .68536 .40465 .68695 .40061 .68112 Mtetra
.429 .612 .925 r
.40061 .68112 .40465 .68695 .41138 .6884 .40734 .68244 Mtetra
.447 .615 .921 r
.40734 .68244 .41138 .6884 .41813 .68969 .41411 .6836 Mtetra
.465 .619 .916 r
.41411 .6836 .41813 .68969 .42493 .69082 .42091 .68459 Mtetra
.483 .622 .911 r
.42091 .68459 .42493 .69082 .43175 .69176 .42775 .68538 Mtetra
.501 .625 .905 r
.42775 .68538 .43175 .69176 .43861 .69249 .43462 .68596 Mtetra
.519 .628 .899 r
.43462 .68596 .43861 .69249 .44551 .693 .44152 .6863 Mtetra
.536 .631 .892 r
.44152 .6863 .44551 .693 .45243 .69326 .44845 .6864 Mtetra
.553 .633 .885 r
.44845 .6864 .45243 .69326 .45939 .69326 .45542 .68622 Mtetra
.569 .635 .877 r
.45542 .68622 .45939 .69326 .46638 .69296 .46241 .68575 Mtetra
.584 .636 .869 r
.46241 .68575 .46638 .69296 .4734 .69237 .46944 .68496 Mtetra
.599 .638 .86 r
.46944 .68496 .4734 .69237 .48044 .69144 .47649 .68383 Mtetra
.614 .639 .852 r
.47649 .68383 .48044 .69144 .48752 .69017 .48358 .68235 Mtetra
.627 .639 .843 r
.48358 .68235 .48752 .69017 .49462 .68853 .49068 .68048 Mtetra
.64 .639 .834 r
.49068 .68048 .49462 .68853 .50174 .6865 .49782 .67822 Mtetra
.652 .639 .825 r
.49782 .67822 .50174 .6865 .50889 .68407 .50497 .67553 Mtetra
.663 .639 .815 r
.50497 .67553 .50889 .68407 .51605 .68121 .51214 .67239 Mtetra
.673 .638 .806 r
.51214 .67239 .51605 .68121 .52324 .6779 .51933 .6688 Mtetra
.683 .636 .797 r
.51933 .6688 .52324 .6779 .53044 .67415 .52654 .66474 Mtetra
.691 .634 .788 r
.52654 .66474 .53044 .67415 .53765 .66994 .53376 .66019 Mtetra
.698 .632 .779 r
.53376 .66019 .53765 .66994 .54488 .66528 .54099 .65516 Mtetra
.704 .629 .77 r
.54099 .65516 .54488 .66528 .55211 .66017 .54823 .64966 Mtetra
.709 .625 .762 r
.54823 .64966 .55211 .66017 .55936 .65466 .55547 .64371 Mtetra
.712 .621 .754 r
.55547 .64371 .55936 .65466 .56661 .64878 .56272 .63738 Mtetra
.713 .616 .747 r
.56272 .63738 .56661 .64878 .57386 .64263 .56998 .63074 Mtetra
.712 .61 .741 r
.56998 .63074 .57386 .64263 .58112 .6363 .57723 .62392 Mtetra
.708 .602 .736 r
.57723 .62392 .58112 .6363 .58838 .62995 .58449 .61709 Mtetra
.702 .594 .732 r
.58449 .61709 .58838 .62995 .59566 .62374 .59176 .61045 Mtetra
.693 .585 .73 r
.59176 .61045 .59566 .62374 .60294 .61783 .59904 .60421 Mtetra
.682 .576 .73 r
.59904 .60421 .60294 .61783 .61024 .61236 .60634 .59856 Mtetra
.67 .568 .731 r
.60634 .59856 .61024 .61236 .61757 .60739 .61367 .5936 Mtetra
.632 .547 .741 r
.61367 .5936 .61757 .60739 .62496 .60458 .62105 .59077 Mtetra
.588 .522 .748 r
.62105 .59077 .62496 .60458 .63243 .60394 .62852 .59007 Mtetra
.572 .512 .75 r
.62852 .59007 .63243 .60394 .63993 .6038 .63602 .59008 Mtetra
.557 .505 .754 r
.63602 .59008 .63993 .6038 .64748 .6041 .64358 .59068 Mtetra
.545 .502 .759 r
.64358 .59068 .64748 .6041 .65508 .60472 .65118 .5917 Mtetra
.538 .504 .765 r
.65118 .5917 .65508 .60472 .66271 .6055 .65882 .59292 Mtetra
.537 .509 .772 r
.65882 .59292 .66271 .6055 .67037 .60625 .6665 .59413 Mtetra
.54 .517 .78 r
.6665 .59413 .67037 .60625 .67807 .60684 .67421 .59517 Mtetra
.547 .528 .786 r
.67421 .59517 .67807 .60684 .68578 .60716 .68194 .59591 Mtetra
.557 .541 .793 r
.68194 .59591 .68578 .60716 .69351 .60712 .68969 .59627 Mtetra
.569 .555 .799 r
.68969 .59627 .69351 .60712 .70126 .60667 .69745 .59619 Mtetra
.582 .569 .804 r
.69745 .59619 .70126 .60667 .70902 .60578 .70523 .59563 Mtetra
.596 .583 .808 r
.70523 .59563 .70902 .60578 .71678 .60443 .71301 .5946 Mtetra
.61 .596 .812 r
.71301 .5946 .71678 .60443 .72455 .60262 .7208 .59307 Mtetra
.624 .609 .815 r
.7208 .59307 .72455 .60262 .73232 .60035 .72859 .59106 Mtetra
.638 .622 .818 r
.72859 .59106 .73232 .60035 .7401 .59763 .73639 .58859 Mtetra
.651 .633 .82 r
.73639 .58859 .7401 .59763 .74787 .59448 .74418 .58567 Mtetra
.663 .645 .821 r
.74418 .58567 .74787 .59448 .75563 .59091 .75197 .58231 Mtetra
.675 .655 .822 r
.75197 .58231 .75563 .59091 .7634 .58694 .75975 .57854 Mtetra
.686 .665 .823 r
.75975 .57854 .7634 .58694 .77115 .58259 .76753 .57438 Mtetra
.697 .674 .824 r
.76753 .57438 .77115 .58259 .77891 .57788 .7753 .56984 Mtetra
.707 .683 .825 r
.7753 .56984 .77891 .57788 .78665 .57283 .78307 .56495 Mtetra
.716 .691 .825 r
.78307 .56495 .78665 .57283 .79439 .56745 .79083 .55973 Mtetra
.725 .699 .825 r
.79083 .55973 .79439 .56745 .80212 .56177 .79859 .5542 Mtetra
.733 .707 .826 r
.79859 .5542 .80212 .56177 .80984 .55581 .80633 .54838 Mtetra
.741 .713 .826 r
.80633 .54838 .80984 .55581 .81755 .54959 .81407 .54229 Mtetra
.748 .72 .826 r
.81407 .54229 .81755 .54959 .82525 .54312 .82179 .53595 Mtetra
.754 .726 .826 r
.82179 .53595 .82525 .54312 .83294 .53643 .82951 .52939 Mtetra
.761 .732 .827 r
.82951 .52939 .83294 .53643 .84063 .52954 .83722 .52261 Mtetra
.766 .738 .827 r
.83722 .52261 .84063 .52954 .8483 .52245 .84493 .51564 Mtetra
.771 .744 .828 r
.84493 .51564 .8483 .52245 .85597 .5152 .85262 .5085 Mtetra
.776 .749 .828 r
.85262 .5085 .85597 .5152 .86363 .5078 .86031 .5012 Mtetra
.781 .754 .829 r
.86031 .5012 .86363 .5078 .87129 .50026 .86799 .49376 Mtetra
.785 .759 .83 r
.86799 .49376 .87129 .50026 .87894 .4926 .87567 .48621 Mtetra
.789 .764 .831 r
.87567 .48621 .87894 .4926 .88658 .48485 .88334 .47855 Mtetra
.792 .768 .832 r
.88334 .47855 .88658 .48485 .89422 .47701 .891 .47081 Mtetra
.795 .773 .833 r
.891 .47081 .89422 .47701 .90185 .4691 .89867 .463 Mtetra
.798 .777 .834 r
.89867 .463 .90185 .4691 .90948 .46115 .90633 .45513 Mtetra
.8 .782 .836 r
.90633 .45513 .90948 .46115 .91712 .45316 .91399 .44723 Mtetra
.802 .786 .838 r
.91399 .44723 .91712 .45316 .92475 .44515 .92165 .43932 Mtetra
.309 .598 .947 r
.33738 .66032 .34153 .66509 .34796 .66704 .34383 .66217 Mtetra
.319 .598 .946 r
.34383 .66217 .34796 .66704 .35443 .66899 .35031 .66401 Mtetra
.331 .599 .944 r
.35031 .66401 .35443 .66899 .36093 .67092 .35681 .66582 Mtetra
.343 .6 .943 r
.35681 .66582 .36093 .67092 .36746 .67281 .36335 .6676 Mtetra
.357 .602 .941 r
.36335 .6676 .36746 .67281 .37402 .67465 .36993 .66932 Mtetra
.372 .605 .939 r
.36993 .66932 .37402 .67465 .38062 .67641 .37653 .67097 Mtetra
.387 .608 .936 r
.37653 .67097 .38062 .67641 .38725 .67809 .38317 .67253 Mtetra
.404 .611 .933 r
.38317 .67253 .38725 .67809 .39391 .67967 .38984 .67398 Mtetra
.421 .614 .93 r
.38984 .67398 .39391 .67967 .40061 .68112 .39655 .67531 Mtetra
.438 .617 .926 r
.39655 .67531 .40061 .68112 .40734 .68244 .40329 .6765 Mtetra
.456 .621 .922 r
.40329 .6765 .40734 .68244 .41411 .6836 .41007 .67753 Mtetra
.473 .624 .917 r
.41007 .67753 .41411 .6836 .42091 .68459 .41688 .67837 Mtetra
.491 .627 .912 r
.41688 .67837 .42091 .68459 .42775 .68538 .42372 .67902 Mtetra
.509 .631 .906 r
.42372 .67902 .42775 .68538 .43462 .68596 .4306 .67946 Mtetra
.526 .633 .899 r
.4306 .67946 .43462 .68596 .44152 .6863 .43751 .67965 Mtetra
.543 .636 .893 r
.43751 .67965 .44152 .6863 .44845 .6864 .44445 .67958 Mtetra
.56 .638 .885 r
.44445 .67958 .44845 .6864 .45542 .68622 .45143 .67923 Mtetra
.576 .64 .877 r
.45143 .67923 .45542 .68622 .46241 .68575 .45843 .67858 Mtetra
.592 .642 .869 r
.45843 .67858 .46241 .68575 .46944 .68496 .46547 .67761 Mtetra
.606 .643 .861 r
.46547 .67761 .46944 .68496 .47649 .68383 .47253 .67629 Mtetra
.621 .644 .852 r
.47253 .67629 .47649 .68383 .48358 .68235 .47962 .67459 Mtetra
.634 .645 .843 r
.47962 .67459 .48358 .68235 .49068 .68048 .48674 .67251 Mtetra
.647 .645 .834 r
.48674 .67251 .49068 .68048 .49782 .67822 .49388 .67001 Mtetra
.659 .645 .825 r
.49388 .67001 .49782 .67822 .50497 .67553 .50104 .66707 Mtetra
.67 .644 .815 r
.50104 .66707 .50497 .67553 .51214 .67239 .50822 .66367 Mtetra
.681 .643 .806 r
.50822 .66367 .51214 .67239 .51933 .6688 .51542 .65979 Mtetra
.69 .642 .796 r
.51542 .65979 .51933 .6688 .52654 .66474 .52263 .65541 Mtetra
.699 .64 .787 r
.52263 .65541 .52654 .66474 .53376 .66019 .52986 .65053 Mtetra
.706 .637 .778 r
.52986 .65053 .53376 .66019 .54099 .65516 .53709 .64513 Mtetra
.712 .634 .769 r
.53709 .64513 .54099 .65516 .54823 .64966 .54434 .63923 Mtetra
.717 .631 .76 r
.54434 .63923 .54823 .64966 .55547 .64371 .55158 .63285 Mtetra
.72 .626 .752 r
.55158 .63285 .55547 .64371 .56272 .63738 .55884 .62604 Mtetra
.721 .621 .745 r
.55884 .62604 .56272 .63738 .56998 .63074 .56609 .61889 Mtetra
.72 .614 .739 r
.56609 .61889 .56998 .63074 .57723 .62392 .57334 .61153 Mtetra
.716 .606 .733 r
.57334 .61153 .57723 .62392 .58449 .61709 .5806 .60417 Mtetra
.708 .597 .73 r
.5806 .60417 .58449 .61709 .59176 .61045 .58786 .59704 Mtetra
.698 .587 .728 r
.58786 .59704 .59176 .61045 .59904 .60421 .59514 .59042 Mtetra
.684 .576 .728 r
.59514 .59042 .59904 .60421 .60634 .59856 .60244 .58457 Mtetra
.668 .566 .73 r
.60244 .58457 .60634 .59856 .61367 .5936 .60976 .57963 Mtetra
.632 .545 .739 r
.60976 .57963 .61367 .5936 .62105 .59077 .61714 .57678 Mtetra
.588 .521 .746 r
.61714 .57678 .62105 .59077 .62852 .59007 .6246 .57602 Mtetra
.567 .508 .748 r
.6246 .57602 .62852 .59007 .63602 .59008 .63211 .5762 Mtetra
.548 .498 .753 r
.63211 .5762 .63602 .59008 .64358 .59068 .63967 .57714 Mtetra
.533 .494 .759 r
.63967 .57714 .64358 .59068 .65118 .5917 .64728 .57861 Mtetra
.524 .494 .766 r
.64728 .57861 .65118 .5917 .65882 .59292 .65493 .58032 Mtetra
.521 .5 .774 r
.65493 .58032 .65882 .59292 .6665 .59413 .66262 .58204 Mtetra
.524 .509 .782 r
.66262 .58204 .6665 .59413 .67421 .59517 .67034 .58356 Mtetra
.532 .521 .789 r
.67034 .58356 .67421 .59517 .68194 .59591 .67809 .58475 Mtetra
.543 .535 .796 r
.67809 .58475 .68194 .59591 .68969 .59627 .68586 .58551 Mtetra
.556 .55 .803 r
.68586 .58551 .68969 .59627 .69745 .59619 .69364 .5858 Mtetra
.571 .565 .808 r
.69364 .5858 .69745 .59619 .70523 .59563 .70144 .58559 Mtetra
.586 .58 .813 r
.70144 .58559 .70523 .59563 .71301 .5946 .70924 .58486 Mtetra
.601 .594 .816 r
.70924 .58486 .71301 .5946 .7208 .59307 .71705 .58361 Mtetra
.616 .608 .819 r
.71705 .58361 .7208 .59307 .72859 .59106 .72486 .58187 Mtetra
.631 .621 .822 r
.72486 .58187 .72859 .59106 .73639 .58859 .73267 .57963 Mtetra
.645 .633 .824 r
.73267 .57963 .73639 .58859 .74418 .58567 .74048 .57693 Mtetra
.658 .644 .825 r
.74048 .57693 .74418 .58567 .75197 .58231 .74829 .57378 Mtetra
.67 .655 .826 r
.74829 .57378 .75197 .58231 .75975 .57854 .7561 .5702 Mtetra
.682 .665 .827 r
.7561 .5702 .75975 .57854 .76753 .57438 .7639 .56622 Mtetra
.693 .675 .828 r
.7639 .56622 .76753 .57438 .7753 .56984 .77169 .56185 Mtetra
.703 .684 .828 r
.77169 .56185 .7753 .56984 .78307 .56495 .77949 .55712 Mtetra
.713 .692 .829 r
.77949 .55712 .78307 .56495 .79083 .55973 .78727 .55206 Mtetra
.722 .7 .829 r
.78727 .55206 .79083 .55973 .79859 .5542 .79504 .54667 Mtetra
.73 .707 .829 r
.79504 .54667 .79859 .5542 .80633 .54838 .80281 .54099 Mtetra
.738 .714 .829 r
.80281 .54099 .80633 .54838 .81407 .54229 .81057 .53503 Mtetra
.745 .721 .829 r
.81057 .53503 .81407 .54229 .82179 .53595 .81833 .52881 Mtetra
.752 .727 .829 r
.81833 .52881 .82179 .53595 .82951 .52939 .82607 .52236 Mtetra
.758 .733 .829 r
.82607 .52236 .82951 .52939 .83722 .52261 .83381 .5157 Mtetra
.764 .739 .83 r
.83381 .5157 .83722 .52261 .84493 .51564 .84154 .50884 Mtetra
.769 .744 .83 r
.84154 .50884 .84493 .51564 .85262 .5085 .84926 .5018 Mtetra
.774 .749 .83 r
.84926 .5018 .85262 .5085 .86031 .5012 .85697 .4946 Mtetra
.779 .754 .831 r
.85697 .4946 .86031 .5012 .86799 .49376 .86468 .48727 Mtetra
.783 .759 .832 r
.86468 .48727 .86799 .49376 .87567 .48621 .87238 .47981 Mtetra
.786 .764 .833 r
.87238 .47981 .87567 .48621 .88334 .47855 .88008 .47224 Mtetra
.79 .768 .834 r
.88008 .47224 .88334 .47855 .891 .47081 .88778 .46459 Mtetra
.793 .773 .835 r
.88778 .46459 .891 .47081 .89867 .463 .89547 .45687 Mtetra
.795 .777 .836 r
.89547 .45687 .89867 .463 .90633 .45513 .90316 .4491 Mtetra
.798 .781 .838 r
.90316 .4491 .90633 .45513 .91399 .44723 .91085 .44129 Mtetra
.8 .786 .84 r
.91085 .44129 .91399 .44723 .92165 .43932 .91854 .43346 Mtetra
.322 .605 .949 r
.33322 .65554 .33738 .66032 .34383 .66217 .33968 .65728 Mtetra
.331 .604 .947 r
.33968 .65728 .34383 .66217 .35031 .66401 .34616 .65901 Mtetra
.342 .605 .946 r
.34616 .65901 .35031 .66401 .35681 .66582 .35268 .66072 Mtetra
.354 .606 .944 r
.35268 .66072 .35681 .66582 .36335 .6676 .35923 .66238 Mtetra
.367 .608 .942 r
.35923 .66238 .36335 .6676 .36993 .66932 .36581 .66399 Mtetra
.381 .61 .94 r
.36581 .66399 .36993 .66932 .37653 .67097 .37243 .66553 Mtetra
.397 .613 .937 r
.37243 .66553 .37653 .67097 .38317 .67253 .37907 .66697 Mtetra
.413 .616 .934 r
.37907 .66697 .38317 .67253 .38984 .67398 .38576 .66831 Mtetra
.429 .619 .931 r
.38576 .66831 .38984 .67398 .39655 .67531 .39247 .66951 Mtetra
.446 .623 .927 r
.39247 .66951 .39655 .67531 .40329 .6765 .39922 .67058 Mtetra
.463 .626 .923 r
.39922 .67058 .40329 .6765 .41007 .67753 .40601 .67147 Mtetra
.481 .63 .918 r
.40601 .67147 .41007 .67753 .41688 .67837 .41283 .67219 Mtetra
.499 .633 .913 r
.41283 .67219 .41688 .67837 .42372 .67902 .41968 .6727 Mtetra
.516 .636 .907 r
.41968 .6727 .42372 .67902 .4306 .67946 .42657 .67299 Mtetra
.533 .639 .9 r
.42657 .67299 .4306 .67946 .43751 .67965 .43349 .67303 Mtetra
.55 .641 .893 r
.43349 .67303 .43751 .67965 .44445 .67958 .44044 .67281 Mtetra
.567 .644 .886 r
.44044 .67281 .44445 .67958 .45143 .67923 .44742 .67229 Mtetra
.583 .646 .878 r
.44742 .67229 .45143 .67923 .45843 .67858 .45444 .67147 Mtetra
.598 .647 .87 r
.45444 .67147 .45843 .67858 .46547 .67761 .46148 .67032 Mtetra
.613 .649 .861 r
.46148 .67032 .46547 .67761 .47253 .67629 .46855 .6688 Mtetra
.628 .65 .852 r
.46855 .6688 .47253 .67629 .47962 .67459 .47565 .66691 Mtetra
.641 .65 .843 r
.47565 .66691 .47962 .67459 .48674 .67251 .48277 .66461 Mtetra
.654 .65 .834 r
.48277 .66461 .48674 .67251 .49388 .67001 .48992 .66188 Mtetra
.666 .65 .825 r
.48992 .66188 .49388 .67001 .50104 .66707 .49709 .6587 Mtetra
.677 .65 .815 r
.49709 .6587 .50104 .66707 .50822 .66367 .50428 .65504 Mtetra
.688 .649 .805 r
.50428 .65504 .50822 .66367 .51542 .65979 .51149 .65087 Mtetra
.698 .647 .796 r
.51149 .65087 .51542 .65979 .52263 .65541 .51871 .64619 Mtetra
.706 .645 .786 r
.51871 .64619 .52263 .65541 .52986 .65053 .52594 .64097 Mtetra
.714 .643 .777 r
.52594 .64097 .52986 .65053 .53709 .64513 .53318 .63521 Mtetra
.72 .64 .768 r
.53318 .63521 .53709 .64513 .54434 .63923 .54043 .6289 Mtetra
.725 .636 .759 r
.54043 .6289 .54434 .63923 .55158 .63285 .54769 .62206 Mtetra
.728 .631 .75 r
.54769 .62206 .55158 .63285 .55884 .62604 .55494 .61475 Mtetra
.73 .626 .742 r
.55494 .61475 .55884 .62604 .56609 .61889 .56219 .60706 Mtetra
.728 .619 .736 r
.56219 .60706 .56609 .61889 .57334 .61153 .56945 .59913 Mtetra
.724 .61 .73 r
.56945 .59913 .57334 .61153 .5806 .60417 .5767 .59118 Mtetra
.716 .6 .726 r
.5767 .59118 .5806 .60417 .58786 .59704 .58396 .5835 Mtetra
.703 .588 .724 r
.58396 .5835 .58786 .59704 .59514 .59042 .59123 .57643 Mtetra
.686 .575 .725 r
.59123 .57643 .59514 .59042 .60244 .58457 .59852 .57033 Mtetra
.667 .562 .728 r
.59852 .57033 .60244 .58457 .60976 .57963 .60585 .56542 Mtetra
.631 .543 .736 r
.60585 .56542 .60976 .57963 .61714 .57678 .61323 .56255 Mtetra
.589 .519 .743 r
.61323 .56255 .61714 .57678 .6246 .57602 .62067 .56173 Mtetra
.562 .502 .746 r
.62067 .56173 .6246 .57602 .63211 .5762 .62818 .56211 Mtetra
.537 .49 .751 r
.62818 .56211 .63211 .5762 .63967 .57714 .63575 .56346 Mtetra
.518 .484 .758 r
.63575 .56346 .63967 .57714 .64728 .57861 .64337 .56545 Mtetra
.507 .484 .766 r
.64337 .56545 .64728 .57861 .65493 .58032 .65103 .56771 Mtetra
.503 .489 .775 r
.65103 .56771 .65493 .58032 .66262 .58204 .65874 .56997 Mtetra
.506 .5 .783 r
.65874 .56997 .66262 .58204 .67034 .58356 .66648 .57201 Mtetra
.515 .513 .792 r
.66648 .57201 .67034 .58356 .67809 .58475 .67424 .57366 Mtetra
.528 .528 .8 r
.67424 .57366 .67809 .58475 .68586 .58551 .68203 .57485 Mtetra
.543 .545 .806 r
.68203 .57485 .68586 .58551 .69364 .5858 .68983 .57552 Mtetra
.559 .561 .812 r
.68983 .57552 .69364 .5858 .70144 .58559 .69764 .57564 Mtetra
.575 .577 .817 r
.69764 .57564 .70144 .58559 .70924 .58486 .70546 .57522 Mtetra
.592 .592 .821 r
.70546 .57522 .70924 .58486 .71705 .58361 .71328 .57425 Mtetra
.608 .606 .824 r
.71328 .57425 .71705 .58361 .72486 .58187 .72111 .57276 Mtetra
.623 .62 .826 r
.72111 .57276 .72486 .58187 .73267 .57963 .72895 .57076 Mtetra
.638 .632 .828 r
.72895 .57076 .73267 .57963 .74048 .57693 .73678 .56828 Mtetra
.652 .644 .83 r
.73678 .56828 .74048 .57693 .74829 .57378 .74461 .56533 Mtetra
.665 .655 .831 r
.74461 .56533 .74829 .57378 .7561 .5702 .75243 .56194 Mtetra
.677 .666 .831 r
.75243 .56194 .7561 .5702 .7639 .56622 .76026 .55813 Mtetra
.689 .675 .832 r
.76026 .55813 .7639 .56622 .77169 .56185 .76808 .55393 Mtetra
.7 .684 .832 r
.76808 .55393 .77169 .56185 .77949 .55712 .77589 .54935 Mtetra
.71 .693 .832 r
.77589 .54935 .77949 .55712 .78727 .55206 .7837 .54443 Mtetra
.719 .701 .832 r
.7837 .54443 .78727 .55206 .79504 .54667 .7915 .53918 Mtetra
.727 .708 .832 r
.7915 .53918 .79504 .54667 .80281 .54099 .79929 .53363 Mtetra
.735 .715 .832 r
.79929 .53363 .80281 .54099 .81057 .53503 .80707 .52779 Mtetra
.743 .722 .832 r
.80707 .52779 .81057 .53503 .81833 .52881 .81485 .5217 Mtetra
.75 .728 .832 r
.81485 .5217 .81833 .52881 .82607 .52236 .82262 .51536 Mtetra
.756 .734 .832 r
.82262 .51536 .82607 .52236 .83381 .5157 .83038 .5088 Mtetra
.762 .739 .832 r
.83038 .5088 .83381 .5157 .84154 .50884 .83813 .50205 Mtetra
.767 .745 .832 r
.83813 .50205 .84154 .50884 .84926 .5018 .84588 .49511 Mtetra
.772 .75 .833 r
.84588 .49511 .84926 .5018 .85697 .4946 .85362 .48801 Mtetra
.777 .755 .833 r
.85362 .48801 .85697 .4946 .86468 .48727 .86136 .48077 Mtetra
.781 .76 .834 r
.86136 .48077 .86468 .48727 .87238 .47981 .86909 .4734 Mtetra
.785 .764 .835 r
.86909 .4734 .87238 .47981 .88008 .47224 .87681 .46593 Mtetra
.788 .769 .836 r
.87681 .46593 .88008 .47224 .88778 .46459 .88454 .45836 Mtetra
.791 .773 .837 r
.88454 .45836 .88778 .46459 .89547 .45687 .89226 .45073 Mtetra
.793 .777 .838 r
.89226 .45073 .89547 .45687 .90316 .4491 .89998 .44304 Mtetra
.796 .781 .84 r
.89998 .44304 .90316 .4491 .91085 .44129 .9077 .43531 Mtetra
.797 .785 .841 r
.9077 .43531 .91085 .44129 .91854 .43346 .91542 .42757 Mtetra
.334 .611 .95 r
.32904 .65073 .33322 .65554 .33968 .65728 .33551 .65237 Mtetra
.342 .61 .949 r
.33551 .65237 .33968 .65728 .34616 .65901 .342 .654 Mtetra
.352 .611 .947 r
.342 .654 .34616 .65901 .35268 .66072 .34853 .6556 Mtetra
.364 .612 .945 r
.34853 .6556 .35268 .66072 .35923 .66238 .35509 .65716 Mtetra
.377 .614 .943 r
.35509 .65716 .35923 .66238 .36581 .66399 .36168 .65866 Mtetra
.39 .616 .941 r
.36168 .65866 .36581 .66399 .37243 .66553 .3683 .66009 Mtetra
.405 .618 .938 r
.3683 .66009 .37243 .66553 .37907 .66697 .37496 .66142 Mtetra
.421 .621 .935 r
.37496 .66142 .37907 .66697 .38576 .66831 .38165 .66264 Mtetra
.437 .625 .932 r
.38165 .66264 .38576 .66831 .39247 .66951 .38838 .66373 Mtetra
.454 .628 .928 r
.38838 .66373 .39247 .66951 .39922 .67058 .39514 .66467 Mtetra
.471 .631 .924 r
.39514 .66467 .39922 .67058 .40601 .67147 .40193 .66544 Mtetra
.488 .635 .919 r
.40193 .66544 .40601 .67147 .41283 .67219 .40876 .66603 Mtetra
.506 .638 .913 r
.40876 .66603 .41283 .67219 .41968 .6727 .41562 .66641 Mtetra
.523 .641 .907 r
.41562 .66641 .41968 .6727 .42657 .67299 .42252 .66655 Mtetra
.54 .644 .901 r
.42252 .66655 .42657 .67299 .43349 .67303 .42945 .66645 Mtetra
.557 .646 .894 r
.42945 .66645 .43349 .67303 .44044 .67281 .43641 .66608 Mtetra
.573 .649 .886 r
.43641 .66608 .44044 .67281 .44742 .67229 .4434 .66541 Mtetra
.59 .651 .879 r
.4434 .66541 .44742 .67229 .45444 .67147 .45042 .66442 Mtetra
.605 .652 .87 r
.45042 .66442 .45444 .67147 .46148 .67032 .45747 .66309 Mtetra
.62 .654 .862 r
.45747 .66309 .46148 .67032 .46855 .6688 .46456 .66139 Mtetra
.634 .655 .853 r
.46456 .66139 .46855 .6688 .47565 .66691 .47166 .6593 Mtetra
.648 .655 .844 r
.47166 .6593 .47565 .66691 .48277 .66461 .4788 .65679 Mtetra
.661 .656 .834 r
.4788 .65679 .48277 .66461 .48992 .66188 .48596 .65384 Mtetra
.673 .656 .825 r
.48596 .65384 .48992 .66188 .49709 .6587 .49313 .65042 Mtetra
.684 .655 .815 r
.49313 .65042 .49709 .6587 .50428 .65504 .50033 .6465 Mtetra
.695 .654 .805 r
.50033 .6465 .50428 .65504 .51149 .65087 .50755 .64206 Mtetra
.705 .653 .795 r
.50755 .64206 .51149 .65087 .51871 .64619 .51478 .63707 Mtetra
.714 .651 .786 r
.51478 .63707 .51871 .64619 .52594 .64097 .52202 .63152 Mtetra
.721 .648 .776 r
.52202 .63152 .52594 .64097 .53318 .63521 .52927 .62539 Mtetra
.728 .645 .766 r
.52927 .62539 .53318 .63521 .54043 .6289 .53652 .61867 Mtetra
.733 .642 .757 r
.53652 .61867 .54043 .6289 .54769 .62206 .54378 .61137 Mtetra
.737 .637 .748 r
.54378 .61137 .54769 .62206 .55494 .61475 .55104 .60355 Mtetra
.738 .631 .74 r
.55104 .60355 .55494 .61475 .56219 .60706 .55829 .59528 Mtetra
.737 .624 .733 r
.55829 .59528 .56219 .60706 .56945 .59913 .56555 .58672 Mtetra
.732 .615 .727 r
.56555 .58672 .56945 .59913 .5767 .59118 .5728 .5781 Mtetra
.723 .604 .723 r
.5728 .5781 .5767 .59118 .58396 .5835 .58005 .56979 Mtetra
.709 .59 .721 r
.58005 .56979 .58396 .5835 .59123 .57643 .58731 .5622 Mtetra
.689 .575 .721 r
.58731 .5622 .59123 .57643 .59852 .57033 .5946 .55578 Mtetra
.664 .558 .725 r
.5946 .55578 .59852 .57033 .60585 .56542 .60192 .5509 Mtetra
.63 .539 .733 r
.60192 .5509 .60585 .56542 .61323 .56255 .6093 .54801 Mtetra
.59 .516 .739 r
.6093 .54801 .61323 .56255 .62067 .56173 .61674 .54712 Mtetra
.555 .495 .743 r
.61674 .54712 .62067 .56173 .62818 .56211 .62425 .54778 Mtetra
.524 .479 .749 r
.62425 .54778 .62818 .56211 .63575 .56346 .63182 .54962 Mtetra
.5 .471 .756 r
.63182 .54962 .63575 .56346 .64337 .56545 .63945 .5522 Mtetra
.487 .471 .766 r
.63945 .5522 .64337 .56545 .65103 .56771 .64713 .5551 Mtetra
.482 .477 .775 r
.64713 .5551 .65103 .56771 .65874 .56997 .65485 .55795 Mtetra
.487 .489 .785 r
.65485 .55795 .65874 .56997 .66648 .57201 .66261 .56053 Mtetra
.497 .504 .795 r
.66261 .56053 .66648 .57201 .67424 .57366 .67039 .56268 Mtetra
.511 .521 .803 r
.67039 .56268 .67424 .57366 .68203 .57485 .67819 .56429 Mtetra
.528 .539 .81 r
.67819 .56429 .68203 .57485 .68983 .57552 .68601 .56534 Mtetra
.546 .557 .816 r
.68601 .56534 .68983 .57552 .69764 .57564 .69383 .5658 Mtetra
.564 .574 .821 r
.69383 .5658 .69764 .57564 .70546 .57522 .70167 .56568 Mtetra
.582 .59 .825 r
.70167 .56568 .70546 .57522 .71328 .57425 .70952 .56499 Mtetra
.6 .605 .828 r
.70952 .56499 .71328 .57425 .72111 .57276 .71737 .56375 Mtetra
.616 .619 .831 r
.71737 .56375 .72111 .57276 .72895 .57076 .72522 .56198 Mtetra
.632 .632 .833 r
.72522 .56198 .72895 .57076 .73678 .56828 .73307 .55971 Mtetra
.646 .644 .834 r
.73307 .55971 .73678 .56828 .74461 .56533 .74092 .55695 Mtetra
.66 .656 .835 r
.74092 .55695 .74461 .56533 .75243 .56194 .74877 .55374 Mtetra
.673 .666 .835 r
.74877 .55374 .75243 .56194 .76026 .55813 .75661 .5501 Mtetra
.685 .676 .836 r
.75661 .5501 .76026 .55813 .76808 .55393 .76445 .54606 Mtetra
.696 .685 .836 r
.76445 .54606 .76808 .55393 .77589 .54935 .77228 .54163 Mtetra
.706 .694 .836 r
.77228 .54163 .77589 .54935 .7837 .54443 .78011 .53685 Mtetra
.716 .702 .835 r
.78011 .53685 .7837 .54443 .7915 .53918 .78794 .53173 Mtetra
.725 .709 .835 r
.78794 .53173 .7915 .53918 .79929 .53363 .79575 .52631 Mtetra
.733 .716 .835 r
.79575 .52631 .79929 .53363 .80707 .52779 .80356 .52059 Mtetra
.741 .723 .835 r
.80356 .52059 .80707 .52779 .81485 .5217 .81136 .51461 Mtetra
.748 .729 .835 r
.81136 .51461 .81485 .5217 .82262 .51536 .81915 .50838 Mtetra
.754 .735 .835 r
.81915 .50838 .82262 .51536 .83038 .5088 .82694 .50193 Mtetra
.76 .74 .835 r
.82694 .50193 .83038 .5088 .83813 .50205 .83472 .49527 Mtetra
.765 .745 .835 r
.83472 .49527 .83813 .50205 .84588 .49511 .84249 .48843 Mtetra
.77 .75 .835 r
.84249 .48843 .84588 .49511 .85362 .48801 .85026 .48142 Mtetra
.775 .755 .835 r
.85026 .48142 .85362 .48801 .86136 .48077 .85802 .47427 Mtetra
.779 .76 .836 r
.85802 .47427 .86136 .48077 .86909 .4734 .86578 .46699 Mtetra
.783 .764 .837 r
.86578 .46699 .86909 .4734 .87681 .46593 .87353 .4596 Mtetra
.786 .769 .837 r
.87353 .4596 .87681 .46593 .88454 .45836 .88128 .45212 Mtetra
.789 .773 .839 r
.88128 .45212 .88454 .45836 .89226 .45073 .88903 .44457 Mtetra
.791 .777 .84 r
.88903 .44457 .89226 .45073 .89998 .44304 .89678 .43696 Mtetra
.793 .781 .841 r
.89678 .43696 .89998 .44304 .9077 .43531 .90452 .42931 Mtetra
.795 .785 .843 r
.90452 .42931 .9077 .43531 .91542 .42757 .91228 .42165 Mtetra
.345 .616 .951 r
.32484 .64591 .32904 .65073 .33551 .65237 .33132 .64744 Mtetra
.353 .616 .95 r
.33132 .64744 .33551 .65237 .342 .654 .33782 .64897 Mtetra
.362 .616 .948 r
.33782 .64897 .342 .654 .34853 .6556 .34436 .65047 Mtetra
.373 .617 .946 r
.34436 .65047 .34853 .6556 .35509 .65716 .35093 .65193 Mtetra
.386 .619 .944 r
.35093 .65193 .35509 .65716 .36168 .65866 .35753 .65333 Mtetra
.399 .621 .942 r
.35753 .65333 .36168 .65866 .3683 .66009 .36416 .65465 Mtetra
.413 .624 .939 r
.36416 .65465 .3683 .66009 .37496 .66142 .37083 .65587 Mtetra
.429 .626 .936 r
.37083 .65587 .37496 .66142 .38165 .66264 .37753 .65698 Mtetra
.445 .63 .933 r
.37753 .65698 .38165 .66264 .38838 .66373 .38426 .65796 Mtetra
.461 .633 .929 r
.38426 .65796 .38838 .66373 .39514 .66467 .39103 .65878 Mtetra
.478 .636 .924 r
.39103 .65878 .39514 .66467 .40193 .66544 .39783 .65943 Mtetra
.495 .64 .919 r
.39783 .65943 .40193 .66544 .40876 .66603 .40467 .65989 Mtetra
.512 .643 .914 r
.40467 .65989 .40876 .66603 .41562 .66641 .41154 .66014 Mtetra
.529 .646 .908 r
.41154 .66014 .41562 .66641 .42252 .66655 .41845 .66016 Mtetra
.547 .649 .902 r
.41845 .66016 .42252 .66655 .42945 .66645 .42539 .65991 Mtetra
.563 .651 .895 r
.42539 .65991 .42945 .66645 .43641 .66608 .43236 .65939 Mtetra
.58 .654 .887 r
.43236 .65939 .43641 .66608 .4434 .66541 .43936 .65857 Mtetra
.596 .656 .879 r
.43936 .65857 .4434 .66541 .45042 .66442 .44639 .65742 Mtetra
.611 .658 .871 r
.44639 .65742 .45042 .66442 .45747 .66309 .45345 .65592 Mtetra
.626 .659 .862 r
.45345 .65592 .45747 .66309 .46456 .66139 .46054 .65404 Mtetra
.641 .66 .853 r
.46054 .65404 .46456 .66139 .47166 .6593 .46766 .65176 Mtetra
.654 .661 .844 r
.46766 .65176 .47166 .6593 .4788 .65679 .47481 .64905 Mtetra
.667 .661 .834 r
.47481 .64905 .4788 .65679 .48596 .65384 .48197 .64588 Mtetra
.68 .661 .825 r
.48197 .64588 .48596 .65384 .49313 .65042 .48916 .64223 Mtetra
.691 .66 .815 r
.48916 .64223 .49313 .65042 .50033 .6465 .49637 .63806 Mtetra
.702 .659 .805 r
.49637 .63806 .50033 .6465 .50755 .64206 .50359 .63335 Mtetra
.712 .658 .795 r
.50359 .63335 .50755 .64206 .51478 .63707 .51083 .62807 Mtetra
.721 .656 .785 r
.51083 .62807 .51478 .63707 .52202 .63152 .51808 .62219 Mtetra
.729 .654 .775 r
.51808 .62219 .52202 .63152 .52927 .62539 .52534 .61569 Mtetra
.736 .651 .765 r
.52534 .61569 .52927 .62539 .53652 .61867 .5326 .60856 Mtetra
.742 .647 .755 r
.5326 .60856 .53652 .61867 .54378 .61137 .53987 .6008 Mtetra
.746 .642 .746 r
.53987 .6008 .54378 .61137 .55104 .60355 .54713 .59243 Mtetra
.747 .636 .737 r
.54713 .59243 .55104 .60355 .55829 .59528 .55439 .58355 Mtetra
.746 .629 .729 r
.55439 .58355 .55829 .59528 .56555 .58672 .56164 .5743 Mtetra
.742 .619 .723 r
.56164 .5743 .56555 .58672 .5728 .5781 .56889 .56495 Mtetra
.732 .607 .718 r
.56889 .56495 .5728 .5781 .58005 .56979 .57614 .55589 Mtetra
.716 .592 .716 r
.57614 .55589 .58005 .56979 .58731 .5622 .58339 .54765 Mtetra
.508 .466 .746 r
.62031 .53314 .62425 .54778 .63182 .54962 .62788 .53558 Mtetra
.479 .456 .754 r
.62788 .53558 .63182 .54962 .63945 .5522 .63553 .53887 Mtetra
.463 .456 .765 r
.63553 .53887 .63945 .5522 .64713 .5551 .64322 .54248 Mtetra
.459 .463 .776 r
.64322 .54248 .64713 .5551 .65485 .55795 .65096 .54599 Mtetra
.464 .477 .787 r
.65096 .54599 .65485 .55795 .66261 .56053 .65873 .54915 Mtetra
.476 .494 .797 r
.65873 .54915 .66261 .56053 .67039 .56268 .66653 .5518 Mtetra
.493 .513 .807 r
.66653 .5518 .67039 .56268 .67819 .56429 .67435 .55386 Mtetra
.512 .533 .814 r
.67435 .55386 .67819 .56429 .68601 .56534 .68218 .55529 Mtetra
.532 .552 .821 r
.68218 .55529 .68601 .56534 .69383 .5658 .69003 .55608 Mtetra
.553 .57 .826 r
.69003 .55608 .69383 .5658 .70167 .56568 .69788 .55626 Mtetra
.572 .587 .83 r
.69788 .55626 .70167 .56568 .70952 .56499 .70574 .55584 Mtetra
.591 .603 .833 r
.70574 .55584 .70952 .56499 .71737 .56375 .71361 .55484 Mtetra
.609 .618 .835 r
.71361 .55484 .71737 .56375 .72522 .56198 .72148 .55329 Mtetra
.625 .632 .837 r
.72148 .55329 .72522 .56198 .73307 .55971 .72935 .55122 Mtetra
.641 .644 .838 r
.72935 .55122 .73307 .55971 .74092 .55695 .73722 .54865 Mtetra
.655 .656 .839 r
.73722 .54865 .74092 .55695 .74877 .55374 .74509 .54562 Mtetra
.668 .667 .839 r
.74509 .54562 .74877 .55374 .75661 .5501 .75295 .54214 Mtetra
.681 .677 .839 r
.75295 .54214 .75661 .5501 .76445 .54606 .76081 .53825 Mtetra
.692 .686 .839 r
.76081 .53825 .76445 .54606 .77228 .54163 .76867 .53397 Mtetra
.703 .695 .839 r
.76867 .53397 .77228 .54163 .78011 .53685 .77652 .52932 Mtetra
.713 .703 .839 r
.77652 .52932 .78011 .53685 .78794 .53173 .78437 .52433 Mtetra
.722 .71 .838 r
.78437 .52433 .78794 .53173 .79575 .52631 .7922 .51902 Mtetra
.73 .717 .838 r
.7922 .51902 .79575 .52631 .80356 .52059 .80004 .51342 Mtetra
.738 .724 .838 r
.80004 .51342 .80356 .52059 .81136 .51461 .80786 .50755 Mtetra
.745 .73 .837 r
.80786 .50755 .81136 .51461 .81915 .50838 .81568 .50142 Mtetra
.752 .736 .837 r
.81568 .50142 .81915 .50838 .82694 .50193 .82349 .49507 Mtetra
.758 .741 .837 r
.82349 .49507 .82694 .50193 .83472 .49527 .83129 .48851 Mtetra
.763 .746 .837 r
.83129 .48851 .83472 .49527 .84249 .48843 .83909 .48176 Mtetra
.768 .751 .837 r
.83909 .48176 .84249 .48843 .85026 .48142 .84688 .47484 Mtetra
.773 .756 .837 r
.84688 .47484 .85026 .48142 .85802 .47427 .85467 .46777 Mtetra
.777 .76 .838 r
.85467 .46777 .85802 .47427 .86578 .46699 .86245 .46057 Mtetra
.781 .765 .838 r
.86245 .46057 .86578 .46699 .87353 .4596 .87023 .45327 Mtetra
.784 .769 .839 r
.87023 .45327 .87353 .4596 .88128 .45212 .87801 .44586 Mtetra
.787 .773 .84 r
.87801 .44586 .88128 .45212 .88903 .44457 .88579 .43839 Mtetra
.789 .777 .841 r
.88579 .43839 .88903 .44457 .89678 .43696 .89356 .43086 Mtetra
.791 .781 .843 r
.89356 .43086 .89678 .43696 .90452 .42931 .90134 .42329 Mtetra
.793 .784 .845 r
.90134 .42329 .90452 .42931 .91228 .42165 .90912 .4157 Mtetra
.355 .621 .952 r
.32063 .64106 .32484 .64591 .33132 .64744 .32711 .6425 Mtetra
.363 .621 .951 r
.32711 .6425 .33132 .64744 .33782 .64897 .33362 .64393 Mtetra
.372 .621 .949 r
.33362 .64393 .33782 .64897 .34436 .65047 .34017 .64533 Mtetra
.382 .622 .947 r
.34017 .64533 .34436 .65047 .35093 .65193 .34675 .64669 Mtetra
.394 .624 .945 r
.34675 .64669 .35093 .65193 .35753 .65333 .35336 .64799 Mtetra
.407 .626 .942 r
.35336 .64799 .35753 .65333 .36416 .65465 .36 .64921 Mtetra
.421 .628 .94 r
.36 .64921 .36416 .65465 .37083 .65587 .36667 .65033 Mtetra
.436 .631 .937 r
.36667 .65033 .37083 .65587 .37753 .65698 .37338 .65133 Mtetra
.452 .634 .933 r
.37338 .65133 .37753 .65698 .38426 .65796 .38013 .6522 Mtetra
.468 .638 .929 r
.38013 .6522 .38426 .65796 .39103 .65878 .38691 .65291 Mtetra
.485 .641 .925 r
.38691 .65291 .39103 .65878 .39783 .65943 .39372 .65345 Mtetra
.501 .644 .92 r
.39372 .65345 .39783 .65943 .40467 .65989 .40057 .65379 Mtetra
.519 .648 .915 r
.40057 .65379 .40467 .65989 .41154 .66014 .40745 .65391 Mtetra
.536 .651 .909 r
.40745 .65391 .41154 .66014 .41845 .66016 .41436 .6538 Mtetra
.553 .654 .902 r
.41436 .6538 .41845 .66016 .42539 .65991 .42131 .65342 Mtetra
.569 .656 .895 r
.42131 .65342 .42539 .65991 .43236 .65939 .42829 .65276 Mtetra
.586 .659 .888 r
.42829 .65276 .43236 .65939 .43936 .65857 .4353 .65179 Mtetra
.602 .661 .88 r
.4353 .65179 .43936 .65857 .44639 .65742 .44234 .65048 Mtetra
.617 .663 .872 r
.44234 .65048 .44639 .65742 .45345 .65592 .44942 .64882 Mtetra
.632 .664 .863 r
.44942 .64882 .45345 .65592 .46054 .65404 .45652 .64677 Mtetra
.647 .665 .854 r
.45652 .64677 .46054 .65404 .46766 .65176 .46365 .6443 Mtetra
.661 .666 .844 r
.46365 .6443 .46766 .65176 .47481 .64905 .4708 .6414 Mtetra
.674 .666 .835 r
.4708 .6414 .47481 .64905 .48197 .64588 .47798 .63802 Mtetra
.686 .666 .825 r
.47798 .63802 .48197 .64588 .48916 .64223 .48517 .63415 Mtetra
.698 .666 .815 r
.48517 .63415 .48916 .64223 .49637 .63806 .49239 .62974 Mtetra
.709 .665 .805 r
.49239 .62974 .49637 .63806 .50359 .63335 .49963 .62476 Mtetra
.719 .664 .795 r
.49963 .62476 .50359 .63335 .51083 .62807 .50688 .61919 Mtetra
.728 .662 .784 r
.50688 .61919 .51083 .62807 .51808 .62219 .51414 .61299 Mtetra
.736 .659 .774 r
.51414 .61299 .51808 .62219 .52534 .61569 .5214 .60613 Mtetra
.744 .657 .764 r
.5214 .60613 .52534 .61569 .5326 .60856 .52867 .59858 Mtetra
.75 .653 .754 r
.52867 .59858 .5326 .60856 .53987 .6008 .53595 .59034 Mtetra
.754 .648 .744 r
.53595 .59034 .53987 .6008 .54713 .59243 .54322 .58143 Mtetra
.757 .642 .734 r
.54322 .58143 .54713 .59243 .55439 .58355 .55048 .5719 Mtetra
.756 .634 .726 r
.55048 .5719 .55439 .58355 .56164 .5743 .55773 .5619 Mtetra
.752 .624 .719 r
.55773 .5619 .56164 .5743 .56889 .56495 .56498 .55171 Mtetra
.742 .612 .713 r
.56498 .55171 .56889 .56495 .57614 .55589 .57222 .54178 Mtetra
.454 .438 .752 r
.62394 .52134 .62788 .53558 .63553 .53887 .6316 .52546 Mtetra
.435 .438 .763 r
.6316 .52546 .63553 .53887 .64322 .54248 .63931 .52987 Mtetra
.431 .447 .776 r
.63931 .52987 .64322 .54248 .65096 .54599 .64707 .5341 Mtetra
.438 .463 .788 r
.64707 .5341 .65096 .54599 .65873 .54915 .65485 .53788 Mtetra
.453 .483 .8 r
.65485 .53788 .65873 .54915 .66653 .5518 .66267 .54105 Mtetra
.473 .505 .81 r
.66267 .54105 .66653 .5518 .67435 .55386 .6705 .54355 Mtetra
.495 .527 .819 r
.6705 .54355 .67435 .55386 .68218 .55529 .67835 .54536 Mtetra
.518 .547 .825 r
.67835 .54536 .68218 .55529 .69003 .55608 .68621 .54649 Mtetra
.54 .567 .831 r
.68621 .54649 .69003 .55608 .69788 .55626 .69408 .54696 Mtetra
.562 .585 .835 r
.69408 .54696 .69788 .55626 .70574 .55584 .70196 .5468 Mtetra
.582 .602 .838 r
.70196 .5468 .70574 .55584 .71361 .55484 .70985 .54604 Mtetra
.601 .618 .84 r
.70985 .54604 .71361 .55484 .72148 .55329 .71774 .5447 Mtetra
.618 .632 .842 r
.71774 .5447 .72148 .55329 .72935 .55122 .72562 .54283 Mtetra
.635 .645 .843 r
.72562 .54283 .72935 .55122 .73722 .54865 .73351 .54044 Mtetra
.65 .657 .843 r
.73351 .54044 .73722 .54865 .74509 .54562 .7414 .53758 Mtetra
.664 .668 .843 r
.7414 .53758 .74509 .54562 .75295 .54214 .74929 .53426 Mtetra
.677 .678 .843 r
.74929 .53426 .75295 .54214 .76081 .53825 .75717 .53051 Mtetra
.689 .687 .843 r
.75717 .53051 .76081 .53825 .76867 .53397 .76505 .52636 Mtetra
.7 .696 .843 r
.76505 .52636 .76867 .53397 .77652 .52932 .77292 .52184 Mtetra
.71 .704 .842 r
.77292 .52184 .77652 .52932 .78437 .52433 .78079 .51698 Mtetra
.719 .711 .842 r
.78079 .51698 .78437 .52433 .7922 .51902 .78865 .51178 Mtetra
.728 .718 .841 r
.78865 .51178 .7922 .51902 .80004 .51342 .7965 .50629 Mtetra
.736 .725 .841 r
.7965 .50629 .80004 .51342 .80786 .50755 .80435 .50052 Mtetra
.743 .731 .84 r
.80435 .50052 .80786 .50755 .81568 .50142 .81219 .49449 Mtetra
.75 .736 .84 r
.81219 .49449 .81568 .50142 .82349 .49507 .82003 .48823 Mtetra
.756 .742 .84 r
.82003 .48823 .82349 .49507 .83129 .48851 .82785 .48176 Mtetra
.762 .747 .839 r
.82785 .48176 .83129 .48851 .83909 .48176 .83568 .47509 Mtetra
.767 .752 .839 r
.83568 .47509 .83909 .48176 .84688 .47484 .84349 .46826 Mtetra
.771 .756 .84 r
.84349 .46826 .84688 .47484 .85467 .46777 .85131 .46127 Mtetra
.775 .761 .84 r
.85131 .46127 .85467 .46777 .86245 .46057 .85912 .45415 Mtetra
.779 .765 .84 r
.85912 .45415 .86245 .46057 .87023 .45327 .86692 .44692 Mtetra
.782 .769 .841 r
.86692 .44692 .87023 .45327 .87801 .44586 .87473 .43959 Mtetra
.785 .773 .842 r
.87473 .43959 .87801 .44586 .88579 .43839 .88253 .43219 Mtetra
.787 .777 .843 r
.88253 .43219 .88579 .43839 .89356 .43086 .89033 .42473 Mtetra
.789 .78 .844 r
.89033 .42473 .89356 .43086 .90134 .42329 .89813 .41723 Mtetra
.791 .784 .846 r
.89813 .41723 .90134 .42329 .90912 .4157 .90594 .40971 Mtetra
.365 .626 .953 r
.31639 .63618 .32063 .64106 .32711 .6425 .32288 .63753 Mtetra
.372 .626 .951 r
.32288 .63753 .32711 .6425 .33362 .64393 .32941 .63887 Mtetra
.38 .626 .949 r
.32941 .63887 .33362 .64393 .34017 .64533 .33596 .64018 Mtetra
.39 .627 .948 r
.33596 .64018 .34017 .64533 .34675 .64669 .34255 .64145 Mtetra
.402 .628 .945 r
.34255 .64145 .34675 .64669 .35336 .64799 .34917 .64265 Mtetra
.414 .63 .943 r
.34917 .64265 .35336 .64799 .36 .64921 .35582 .64377 Mtetra
.428 .633 .94 r
.35582 .64377 .36 .64921 .36667 .65033 .3625 .64479 Mtetra
.443 .636 .937 r
.3625 .64479 .36667 .65033 .37338 .65133 .36922 .64569 Mtetra
.458 .639 .934 r
.36922 .64569 .37338 .65133 .38013 .6522 .37597 .64646 Mtetra
.474 .642 .93 r
.37597 .64646 .38013 .6522 .38691 .65291 .38276 .64706 Mtetra
.491 .646 .926 r
.38276 .64706 .38691 .65291 .39372 .65345 .38958 .64749 Mtetra
.508 .649 .921 r
.38958 .64749 .39372 .65345 .40057 .65379 .39644 .64771 Mtetra
.524 .652 .916 r
.39644 .64771 .40057 .65379 .40745 .65391 .40333 .64772 Mtetra
.541 .655 .91 r
.40333 .64772 .40745 .65391 .41436 .6538 .41025 .64748 Mtetra
.558 .658 .903 r
.41025 .64748 .41436 .6538 .42131 .65342 .41721 .64697 Mtetra
.575 .661 .896 r
.41721 .64697 .42131 .65342 .42829 .65276 .4242 .64617 Mtetra
.592 .664 .889 r
.4242 .64617 .42829 .65276 .4353 .65179 .43122 .64506 Mtetra
.608 .666 .881 r
.43122 .64506 .4353 .65179 .44234 .65048 .43828 .64361 Mtetra
.623 .668 .872 r
.43828 .64361 .44234 .65048 .44942 .64882 .44536 .64178 Mtetra
.638 .669 .863 r
.44536 .64178 .44942 .64882 .45652 .64677 .45247 .63957 Mtetra
.653 .67 .854 r
.45247 .63957 .45652 .64677 .46365 .6443 .45961 .63693 Mtetra
.666 .671 .845 r
.45961 .63693 .46365 .6443 .4708 .6414 .46678 .63383 Mtetra
.68 .671 .835 r
.46678 .63383 .4708 .6414 .47798 .63802 .47396 .63026 Mtetra
.692 .671 .825 r
.47396 .63026 .47798 .63802 .48517 .63415 .48117 .62616 Mtetra
.704 .671 .815 r
.48117 .62616 .48517 .63415 .49239 .62974 .4884 .62152 Mtetra
.715 .67 .805 r
.4884 .62152 .49239 .62974 .49963 .62476 .49565 .61629 Mtetra
.725 .669 .794 r
.49565 .61629 .49963 .62476 .50688 .61919 .50291 .61043 Mtetra
.735 .667 .784 r
.50291 .61043 .50688 .61919 .51414 .61299 .51018 .60392 Mtetra
.744 .665 .773 r
.51018 .60392 .51414 .61299 .5214 .60613 .51745 .5967 Mtetra
.751 .662 .763 r
.51745 .5967 .5214 .60613 .52867 .59858 .52474 .58875 Mtetra
.758 .659 .752 r
.52474 .58875 .52867 .59858 .53595 .59034 .53202 .58004 Mtetra
.763 .654 .741 r
.53202 .58004 .53595 .59034 .54322 .58143 .53929 .57056 Mtetra
.766 .648 .731 r
.53929 .57056 .54322 .58143 .55048 .5719 .54656 .56035 Mtetra
.766 .64 .722 r
.54656 .56035 .55048 .5719 .55773 .5619 .55382 .54954 Mtetra
.398 .428 .775 r
.6354 .5173 .63931 .52987 .64707 .5341 .64317 .52232 Mtetra
.408 .447 .789 r
.64317 .52232 .64707 .5341 .65485 .53788 .65097 .52674 Mtetra
.428 .471 .802 r
.65097 .52674 .65485 .53788 .66267 .54105 .6588 .53045 Mtetra
.451 .496 .814 r
.6588 .53045 .66267 .54105 .6705 .54355 .66665 .53339 Mtetra
.477 .52 .823 r
.66665 .53339 .6705 .54355 .67835 .54536 .67452 .53558 Mtetra
.503 .543 .83 r
.67452 .53558 .67835 .54536 .68621 .54649 .68239 .53704 Mtetra
.527 .564 .836 r
.68239 .53704 .68621 .54649 .69408 .54696 .69028 .53779 Mtetra
.551 .583 .84 r
.69028 .53779 .69408 .54696 .70196 .5468 .69818 .53788 Mtetra
.573 .601 .843 r
.69818 .53788 .70196 .5468 .70985 .54604 .70608 .53735 Mtetra
.593 .617 .845 r
.70608 .53735 .70985 .54604 .71774 .5447 .71399 .53622 Mtetra
.612 .632 .847 r
.71399 .53622 .71774 .5447 .72562 .54283 .72189 .53453 Mtetra
.629 .645 .847 r
.72189 .53453 .72562 .54283 .73351 .54044 .7298 .53232 Mtetra
.645 .657 .848 r
.7298 .53232 .73351 .54044 .7414 .53758 .73771 .52961 Mtetra
.66 .669 .848 r
.73771 .52961 .7414 .53758 .74929 .53426 .74561 .52644 Mtetra
.673 .679 .847 r
.74561 .52644 .74929 .53426 .75717 .53051 .75351 .52283 Mtetra
.685 .688 .847 r
.75351 .52283 .75717 .53051 .76505 .52636 .76141 .51882 Mtetra
.697 .697 .846 r
.76141 .51882 .76505 .52636 .77292 .52184 .76931 .51442 Mtetra
.707 .705 .846 r
.76931 .51442 .77292 .52184 .78079 .51698 .7772 .50967 Mtetra
.717 .713 .845 r
.7772 .50967 .78079 .51698 .78865 .51178 .78508 .50458 Mtetra
.726 .719 .844 r
.78508 .50458 .78865 .51178 .7965 .50629 .79296 .49919 Mtetra
.734 .726 .844 r
.79296 .49919 .7965 .50629 .80435 .50052 .80083 .49352 Mtetra
.741 .732 .843 r
.80083 .49352 .80435 .50052 .81219 .49449 .80869 .48758 Mtetra
.748 .737 .842 r
.80869 .48758 .81219 .49449 .82003 .48823 .81655 .48141 Mtetra
.754 .743 .842 r
.81655 .48141 .82003 .48823 .82785 .48176 .8244 .47502 Mtetra
.76 .748 .842 r
.8244 .47502 .82785 .48176 .83568 .47509 .83225 .46844 Mtetra
.765 .752 .842 r
.83225 .46844 .83568 .47509 .84349 .46826 .84009 .46168 Mtetra
.769 .757 .842 r
.84009 .46168 .84349 .46826 .85131 .46127 .84793 .45477 Mtetra
.774 .761 .842 r
.84793 .45477 .85131 .46127 .85912 .45415 .85576 .44773 Mtetra
.777 .765 .842 r
.85576 .44773 .85912 .45415 .86692 .44692 .8636 .44057 Mtetra
.78 .769 .843 r
.8636 .44057 .86692 .44692 .87473 .43959 .87143 .43331 Mtetra
.783 .773 .844 r
.87143 .43331 .87473 .43959 .88253 .43219 .87925 .42598 Mtetra
.786 .777 .845 r
.87925 .42598 .88253 .43219 .89033 .42473 .88708 .41859 Mtetra
.788 .78 .846 r
.88708 .41859 .89033 .42473 .89813 .41723 .89492 .41115 Mtetra
.789 .784 .847 r
.89492 .41115 .89813 .41723 .90594 .40971 .90275 .4037 Mtetra
.374 .631 .954 r
.31213 .63128 .31639 .63618 .32288 .63753 .31863 .63255 Mtetra
.38 .63 .952 r
.31863 .63255 .32288 .63753 .32941 .63887 .32517 .6338 Mtetra
.388 .63 .95 r
.32517 .6338 .32941 .63887 .33596 .64018 .33173 .63502 Mtetra
.398 .631 .948 r
.33173 .63502 .33596 .64018 .34255 .64145 .33833 .6362 Mtetra
.409 .632 .946 r
.33833 .6362 .34255 .64145 .34917 .64265 .34495 .63731 Mtetra
.421 .635 .944 r
.34495 .63731 .34917 .64265 .35582 .64377 .35162 .63833 Mtetra
.435 .637 .941 r
.35162 .63833 .35582 .64377 .3625 .64479 .35831 .63926 Mtetra
.449 .64 .938 r
.35831 .63926 .3625 .64479 .36922 .64569 .36504 .64006 Mtetra
.464 .643 .935 r
.36504 .64006 .36922 .64569 .37597 .64646 .3718 .64073 Mtetra
.48 .647 .931 r
.3718 .64073 .37597 .64646 .38276 .64706 .3786 .64123 Mtetra
.496 .65 .927 r
.3786 .64123 .38276 .64706 .38958 .64749 .38543 .64155 Mtetra
.513 .653 .922 r
.38543 .64155 .38958 .64749 .39644 .64771 .3923 .64167 Mtetra
.53 .657 .916 r
.3923 .64167 .39644 .64771 .40333 .64772 .3992 .64156 Mtetra
.547 .66 .91 r
.3992 .64156 .40333 .64772 .41025 .64748 .40613 .6412 Mtetra
.564 .663 .904 r
.40613 .6412 .41025 .64748 .41721 .64697 .4131 .64057 Mtetra
.58 .666 .897 r
.4131 .64057 .41721 .64697 .4242 .64617 .4201 .63964 Mtetra
.597 .668 .889 r
.4201 .63964 .4242 .64617 .43122 .64506 .42713 .63839 Mtetra
.613 .671 .881 r
.42713 .63839 .43122 .64506 .43828 .64361 .43419 .63679 Mtetra
.629 .673 .873 r
.43419 .63679 .43828 .64361 .44536 .64178 .44129 .63482 Mtetra
.644 .674 .864 r
.44129 .63482 .44536 .64178 .45247 .63957 .44841 .63244 Mtetra
.658 .675 .855 r
.44841 .63244 .45247 .63957 .45961 .63693 .45556 .62963 Mtetra
.672 .676 .845 r
.45556 .62963 .45961 .63693 .46678 .63383 .46274 .62636 Mtetra
.685 .677 .836 r
.46274 .62636 .46678 .63383 .47396 .63026 .46993 .62259 Mtetra
.698 .677 .826 r
.46993 .62259 .47396 .63026 .48117 .62616 .47716 .61829 Mtetra
.71 .676 .815 r
.47716 .61829 .48117 .62616 .4884 .62152 .4844 .61342 Mtetra
.721 .676 .805 r
.4844 .61342 .4884 .62152 .49565 .61629 .49165 .60794 Mtetra
.732 .674 .794 r
.49165 .60794 .49565 .61629 .50291 .61043 .49892 .60182 Mtetra
.742 .673 .783 r
.49892 .60182 .50291 .61043 .51018 .60392 .50621 .595 Mtetra
.751 .671 .773 r
.50621 .595 .51018 .60392 .51745 .5967 .51349 .58744 Mtetra
.759 .668 .762 r
.51349 .58744 .51745 .5967 .52474 .58875 .52079 .57909 Mtetra
.766 .665 .75 r
.52079 .57909 .52474 .58875 .53202 .58004 .52808 .56991 Mtetra
.772 .66 .739 r
.52808 .56991 .53202 .58004 .53929 .57056 .53536 .55985 Mtetra
.776 .654 .728 r
.53536 .55985 .53929 .57056 .54656 .56035 .54264 .54894 Mtetra
.777 .647 .718 r
.54264 .54894 .54656 .56035 .55382 .54954 .5499 .53725 Mtetra
.359 .405 .773 r
.63148 .50481 .6354 .5173 .64317 .52232 .63927 .51067 Mtetra
.374 .429 .79 r
.63927 .51067 .64317 .52232 .65097 .52674 .64709 .51577 Mtetra
.399 .457 .805 r
.64709 .51577 .65097 .52674 .6588 .53045 .65493 .52002 Mtetra
.428 .486 .817 r
.65493 .52002 .6588 .53045 .66665 .53339 .6628 .5234 Mtetra
.457 .513 .827 r
.6628 .5234 .66665 .53339 .67452 .53558 .67068 .52596 Mtetra
.486 .538 .835 r
.67068 .52596 .67452 .53558 .68239 .53704 .67857 .52773 Mtetra
.514 .561 .841 r
.67857 .52773 .68239 .53704 .69028 .53779 .68648 .52876 Mtetra
.539 .581 .845 r
.68648 .52876 .69028 .53779 .69818 .53788 .69439 .52909 Mtetra
.563 .6 .848 r
.69439 .52909 .69818 .53788 .70608 .53735 .70231 .52877 Mtetra
.585 .617 .85 r
.70231 .52877 .70608 .53735 .71399 .53622 .71023 .52784 Mtetra
.605 .632 .851 r
.71023 .52784 .71399 .53622 .72189 .53453 .71815 .52633 Mtetra
.623 .646 .852 r
.71815 .52633 .72189 .53453 .7298 .53232 .72608 .52428 Mtetra
.64 .658 .852 r
.72608 .52428 .7298 .53232 .73771 .52961 .734 .52173 Mtetra
.655 .67 .852 r
.734 .52173 .73771 .52961 .74561 .52644 .74193 .5187 Mtetra
.669 .68 .851 r
.74193 .5187 .74561 .52644 .75351 .52283 .74985 .51522 Mtetra
.682 .69 .851 r
.74985 .51522 .75351 .52283 .76141 .51882 .75777 .51133 Mtetra
.694 .698 .85 r
.75777 .51133 .76141 .51882 .76931 .51442 .76568 .50705 Mtetra
.705 .706 .849 r
.76568 .50705 .76931 .51442 .7772 .50967 .77359 .50241 Mtetra
.714 .714 .848 r
.77359 .50241 .7772 .50967 .78508 .50458 .7815 .49742 Mtetra
.723 .721 .847 r
.7815 .49742 .78508 .50458 .79296 .49919 .7894 .49213 Mtetra
.732 .727 .846 r
.7894 .49213 .79296 .49919 .80083 .49352 .79729 .48655 Mtetra
.739 .733 .846 r
.79729 .48655 .80083 .49352 .80869 .48758 .80518 .4807 Mtetra
.746 .739 .845 r
.80518 .4807 .80869 .48758 .81655 .48141 .81306 .47461 Mtetra
.752 .744 .844 r
.81306 .47461 .81655 .48141 .8244 .47502 .82094 .46831 Mtetra
.758 .749 .844 r
.82094 .46831 .8244 .47502 .83225 .46844 .82881 .4618 Mtetra
.763 .753 .844 r
.82881 .4618 .83225 .46844 .84009 .46168 .83668 .45512 Mtetra
.768 .758 .844 r
.83668 .45512 .84009 .46168 .84793 .45477 .84454 .44828 Mtetra
.772 .762 .844 r
.84454 .44828 .84793 .45477 .85576 .44773 .8524 .4413 Mtetra
.776 .766 .844 r
.8524 .4413 .85576 .44773 .8636 .44057 .86026 .43421 Mtetra
.779 .769 .844 r
.86026 .43421 .8636 .44057 .87143 .43331 .86811 .42701 Mtetra
.782 .773 .845 r
.86811 .42701 .87143 .43331 .87925 .42598 .87597 .41975 Mtetra
.784 .777 .846 r
.87597 .41975 .87925 .42598 .88708 .41859 .88382 .41242 Mtetra
.786 .78 .847 r
.88382 .41242 .88708 .41859 .89492 .41115 .89168 .40505 Mtetra
.787 .783 .849 r
.89168 .40505 .89492 .41115 .90275 .4037 .89954 .39766 Mtetra
.382 .635 .954 r
.30785 .62636 .31213 .63128 .31863 .63255 .31436 .62754 Mtetra
.388 .634 .952 r
.31436 .62754 .31863 .63255 .32517 .6338 .32091 .62871 Mtetra
.396 .634 .951 r
.32091 .62871 .32517 .6338 .33173 .63502 .32748 .62985 Mtetra
.405 .635 .949 r
.32748 .62985 .33173 .63502 .33833 .6362 .33409 .63094 Mtetra
.416 .636 .947 r
.33409 .63094 .33833 .6362 .34495 .63731 .34072 .63196 Mtetra
.428 .639 .944 r
.34072 .63196 .34495 .63731 .35162 .63833 .34739 .6329 Mtetra
.441 .641 .942 r
.34739 .6329 .35162 .63833 .35831 .63926 .3541 .63374 Mtetra
.455 .644 .939 r
.3541 .63374 .35831 .63926 .36504 .64006 .36084 .63445 Mtetra
.47 .647 .935 r
.36084 .63445 .36504 .64006 .3718 .64073 .36761 .63502 Mtetra
.486 .651 .932 r
.36761 .63502 .3718 .64073 .3786 .64123 .37441 .63542 Mtetra
.502 .654 .927 r
.37441 .63542 .3786 .64123 .38543 .64155 .38126 .63564 Mtetra
.518 .658 .923 r
.38126 .63564 .38543 .64155 .3923 .64167 .38813 .63565 Mtetra
.535 .661 .917 r
.38813 .63565 .3923 .64167 .3992 .64156 .39504 .63543 Mtetra
.552 .664 .911 r
.39504 .63543 .3992 .64156 .40613 .6412 .40199 .63496 Mtetra
.569 .668 .905 r
.40199 .63496 .40613 .6412 .4131 .64057 .40896 .63421 Mtetra
.586 .671 .898 r
.40896 .63421 .4131 .64057 .4201 .63964 .41597 .63316 Mtetra
.602 .673 .89 r
.41597 .63316 .4201 .63964 .42713 .63839 .42302 .63178 Mtetra
.618 .675 .882 r
.42302 .63178 .42713 .63839 .43419 .63679 .43009 .63005 Mtetra
.634 .677 .874 r
.43009 .63005 .43419 .63679 .44129 .63482 .4372 .62793 Mtetra
.649 .679 .865 r
.4372 .62793 .44129 .63482 .44841 .63244 .44433 .6254 Mtetra
.664 .68 .856 r
.44433 .6254 .44841 .63244 .45556 .62963 .45149 .62243 Mtetra
.678 .681 .846 r
.45149 .62243 .45556 .62963 .46274 .62636 .45868 .61898 Mtetra
.691 .682 .836 r
.45868 .61898 .46274 .62636 .46993 .62259 .46589 .61502 Mtetra
.704 .682 .826 r
.46589 .61502 .46993 .62259 .47716 .61829 .47312 .61052 Mtetra
.716 .682 .816 r
.47312 .61052 .47716 .61829 .4844 .61342 .48037 .60544 Mtetra
.727 .681 .805 r
.48037 .60544 .4844 .61342 .49165 .60794 .48764 .59973 Mtetra
.738 .68 .794 r
.48764 .59973 .49165 .60794 .49892 .60182 .49493 .59334 Mtetra
.748 .679 .783 r
.49493 .59334 .49892 .60182 .50621 .595 .50222 .58623 Mtetra
.758 .677 .772 r
.50222 .58623 .50621 .595 .51349 .58744 .50952 .57835 Mtetra
.766 .674 .761 r
.50952 .57835 .51349 .58744 .52079 .57909 .51682 .56961 Mtetra
.774 .671 .749 r
.51682 .56961 .52079 .57909 .52808 .56991 .52413 .55996 Mtetra
.781 .667 .737 r
.52413 .55996 .52808 .56991 .53536 .55985 .53142 .54934 Mtetra
.786 .661 .725 r
.53142 .54934 .53536 .55985 .54264 .54894 .53871 .5377 Mtetra
.335 .409 .79 r
.63536 .4992 .63927 .51067 .64709 .51577 .6432 .50499 Mtetra
.367 .443 .807 r
.6432 .50499 .64709 .51577 .65493 .52002 .65106 .50978 Mtetra
.402 .475 .821 r
.65106 .50978 .65493 .52002 .6628 .5234 .65894 .5136 Mtetra
.436 .506 .832 r
.65894 .5136 .6628 .5234 .67068 .52596 .66684 .51651 Mtetra
.469 .533 .84 r
.66684 .51651 .67068 .52596 .67857 .52773 .67474 .51858 Mtetra
.5 .558 .846 r
.67474 .51858 .67857 .52773 .68648 .52876 .68266 .51987 Mtetra
.528 .579 .851 r
.68266 .51987 .68648 .52876 .69439 .52909 .69059 .52043 Mtetra
.553 .599 .854 r
.69059 .52043 .69439 .52909 .70231 .52877 .69852 .52032 Mtetra
.577 .617 .855 r
.69852 .52032 .70231 .52877 .71023 .52784 .70646 .51957 Mtetra
.598 .632 .856 r
.70646 .51957 .71023 .52784 .71815 .52633 .7144 .51823 Mtetra
.617 .647 .857 r
.7144 .51823 .71815 .52633 .72608 .52428 .72235 .51634 Mtetra
.635 .659 .857 r
.72235 .51634 .72608 .52428 .734 .52173 .73029 .51393 Mtetra
.651 .671 .856 r
.73029 .51393 .734 .52173 .74193 .5187 .73824 .51104 Mtetra
.665 .682 .856 r
.73824 .51104 .74193 .5187 .74985 .51522 .74618 .50769 Mtetra
.679 .691 .855 r
.74618 .50769 .74985 .51522 .75777 .51133 .75412 .50391 Mtetra
.691 .7 .854 r
.75412 .50391 .75777 .51133 .76568 .50705 .76205 .49974 Mtetra
.702 .708 .853 r
.76205 .49974 .76568 .50705 .77359 .50241 .76998 .49519 Mtetra
.712 .715 .851 r
.76998 .49519 .77359 .50241 .7815 .49742 .77791 .49031 Mtetra
.721 .722 .85 r
.77791 .49031 .7815 .49742 .7894 .49213 .78583 .48511 Mtetra
.73 .728 .849 r
.78583 .48511 .7894 .49213 .79729 .48655 .79375 .47961 Mtetra
.737 .734 .848 r
.79375 .47961 .79729 .48655 .80518 .4807 .80166 .47385 Mtetra
.744 .74 .847 r
.80166 .47385 .80518 .4807 .81306 .47461 .80956 .46784 Mtetra
.751 .745 .847 r
.80956 .46784 .81306 .47461 .82094 .46831 .81746 .4616 Mtetra
.756 .75 .846 r
.81746 .4616 .82094 .46831 .82881 .4618 .82536 .45517 Mtetra
.762 .754 .846 r
.82536 .45517 .82881 .4618 .83668 .45512 .83325 .44855 Mtetra
.766 .758 .846 r
.83325 .44855 .83668 .45512 .84454 .44828 .84113 .44178 Mtetra
.77 .762 .846 r
.84113 .44178 .84454 .44828 .8524 .4413 .84902 .43487 Mtetra
.774 .766 .846 r
.84902 .43487 .8524 .4413 .86026 .43421 .8569 .42783 Mtetra
.777 .77 .846 r
.8569 .42783 .86026 .43421 .86811 .42701 .86478 .4207 Mtetra
.78 .773 .847 r
.86478 .4207 .86811 .42701 .87597 .41975 .87266 .41349 Mtetra
.782 .776 .848 r
.87266 .41349 .87597 .41975 .88382 .41242 .88054 .40622 Mtetra
.784 .78 .849 r
.88054 .40622 .88382 .41242 .89168 .40505 .88843 .39891 Mtetra
.786 .783 .85 r
.88843 .39891 .89168 .40505 .89954 .39766 .89632 .39158 Mtetra
.39 .638 .955 r
.30355 .62142 .30785 .62636 .31436 .62754 .31008 .62252 Mtetra
.396 .638 .953 r
.31008 .62252 .31436 .62754 .32091 .62871 .31663 .62361 Mtetra
.403 .638 .951 r
.31663 .62361 .32091 .62871 .32748 .62985 .32321 .62466 Mtetra
.412 .639 .949 r
.32321 .62466 .32748 .62985 .33409 .63094 .32983 .62567 Mtetra
.422 .64 .947 r
.32983 .62567 .33409 .63094 .34072 .63196 .33647 .62661 Mtetra
.434 .642 .945 r
.33647 .62661 .34072 .63196 .34739 .6329 .34315 .62747 Mtetra
.447 .645 .942 r
.34315 .62747 .34739 .6329 .3541 .63374 .34987 .62822 Mtetra
.461 .648 .939 r
.34987 .62822 .3541 .63374 .36084 .63445 .35661 .62884 Mtetra
.475 .651 .936 r
.35661 .62884 .36084 .63445 .36761 .63502 .36339 .62932 Mtetra
.491 .655 .932 r
.36339 .62932 .36761 .63502 .37441 .63542 .37021 .62963 Mtetra
.507 .658 .928 r
.37021 .62963 .37441 .63542 .38126 .63564 .37706 .62975 Mtetra
.523 .662 .923 r
.37706 .62975 .38126 .63564 .38813 .63565 .38395 .62966 Mtetra
.54 .665 .918 r
.38395 .62966 .38813 .63565 .39504 .63543 .39087 .62934 Mtetra
.557 .669 .912 r
.39087 .62934 .39504 .63543 .40199 .63496 .39782 .62876 Mtetra
.574 .672 .906 r
.39782 .62876 .40199 .63496 .40896 .63421 .40481 .6279 Mtetra
.59 .675 .899 r
.40481 .6279 .40896 .63421 .41597 .63316 .41183 .62673 Mtetra
.607 .678 .891 r
.41183 .62673 .41597 .63316 .42302 .63178 .41889 .62523 Mtetra
.623 .68 .883 r
.41889 .62523 .42302 .63178 .43009 .63005 .42597 .62337 Mtetra
.639 .682 .875 r
.42597 .62337 .43009 .63005 .4372 .62793 .43309 .62111 Mtetra
.654 .684 .866 r
.43309 .62111 .4372 .62793 .44433 .6254 .44023 .61844 Mtetra
.669 .685 .857 r
.44023 .61844 .44433 .6254 .45149 .62243 .4474 .61531 Mtetra
.683 .686 .847 r
.4474 .61531 .45149 .62243 .45868 .61898 .4546 .6117 Mtetra
.696 .687 .837 r
.4546 .6117 .45868 .61898 .46589 .61502 .46183 .60757 Mtetra
.709 .687 .827 r
.46183 .60757 .46589 .61502 .47312 .61052 .46907 .60288 Mtetra
.722 .687 .816 r
.46907 .60288 .47312 .61052 .48037 .60544 .47634 .59758 Mtetra
.733 .686 .805 r
.47634 .59758 .48037 .60544 .48764 .59973 .48362 .59165 Mtetra
.744 .685 .795 r
.48362 .59165 .48764 .59973 .49493 .59334 .49091 .58502 Mtetra
.755 .684 .783 r
.49091 .58502 .49493 .59334 .50222 .58623 .49822 .57764 Mtetra
.764 .682 .772 r
.49822 .57764 .50222 .58623 .50952 .57835 .50553 .56943 Mtetra
.774 .68 .76 r
.50553 .56943 .50952 .57835 .51682 .56961 .51285 .56033 Mtetra
.782 .677 .748 r
.51285 .56033 .51682 .56961 .52413 .55996 .52017 .55024 Mtetra
.79 .673 .736 r
.52017 .55024 .52413 .55996 .53142 .54934 .52747 .53906 Mtetra
.331 .426 .809 r
.63931 .49445 .6432 .50499 .65106 .50978 .64719 .49976 Mtetra
.374 .464 .825 r
.64719 .49976 .65106 .50978 .65894 .5136 .65508 .504 Mtetra
.414 .498 .837 r
.65508 .504 .65894 .5136 .66684 .51651 .66299 .50724 Mtetra
.452 .528 .845 r
.66299 .50724 .66684 .51651 .67474 .51858 .67091 .5096 Mtetra
.485 .555 .852 r
.67091 .5096 .67474 .51858 .68266 .51987 .67884 .51113 Mtetra
.516 .578 .856 r
.67884 .51113 .68266 .51987 .69059 .52043 .68678 .51191 Mtetra
.543 .598 .859 r
.68678 .51191 .69059 .52043 .69852 .52032 .69473 .51199 Mtetra
.568 .617 .861 r
.69473 .51199 .69852 .52032 .70646 .51957 .70269 .51142 Mtetra
.591 .633 .862 r
.70269 .51142 .70646 .51957 .7144 .51823 .71065 .51024 Mtetra
.611 .647 .862 r
.71065 .51024 .7144 .51823 .72235 .51634 .71861 .5085 Mtetra
.63 .661 .861 r
.71861 .5085 .72235 .51634 .73029 .51393 .72657 .50623 Mtetra
.646 .672 .861 r
.72657 .50623 .73029 .51393 .73824 .51104 .73453 .50346 Mtetra
.662 .683 .86 r
.73453 .50346 .73824 .51104 .74618 .50769 .74249 .50022 Mtetra
.675 .693 .859 r
.74249 .50022 .74618 .50769 .75412 .50391 .75045 .49655 Mtetra
.688 .702 .857 r
.75045 .49655 .75412 .50391 .76205 .49974 .75841 .49248 Mtetra
.699 .71 .856 r
.75841 .49248 .76205 .49974 .76998 .49519 .76636 .48804 Mtetra
.71 .717 .855 r
.76636 .48804 .76998 .49519 .77791 .49031 .77431 .48324 Mtetra
.719 .724 .853 r
.77431 .48324 .77791 .49031 .78583 .48511 .78225 .47812 Mtetra
.728 .73 .852 r
.78225 .47812 .78583 .48511 .79375 .47961 .79019 .47271 Mtetra
.736 .736 .851 r
.79019 .47271 .79375 .47961 .80166 .47385 .79812 .46702 Mtetra
.743 .741 .85 r
.79812 .46702 .80166 .47385 .80956 .46784 .80605 .46108 Mtetra
.749 .746 .849 r
.80605 .46108 .80956 .46784 .81746 .4616 .81397 .45491 Mtetra
.755 .751 .848 r
.81397 .45491 .81746 .4616 .82536 .45517 .82189 .44855 Mtetra
.76 .755 .848 r
.82189 .44855 .82536 .45517 .83325 .44855 .8298 .44199 Mtetra
.765 .759 .848 r
.8298 .44199 .83325 .44855 .84113 .44178 .83772 .43528 Mtetra
.769 .763 .847 r
.83772 .43528 .84113 .44178 .84902 .43487 .84562 .42843 Mtetra
.773 .767 .847 r
.84562 .42843 .84902 .43487 .8569 .42783 .85353 .42145 Mtetra
.776 .77 .848 r
.85353 .42145 .8569 .42783 .86478 .4207 .86144 .41438 Mtetra
.778 .773 .848 r
.86144 .41438 .86478 .4207 .87266 .41349 .86934 .40723 Mtetra
.781 .776 .849 r
.86934 .40723 .87266 .41349 .88054 .40622 .87725 .40001 Mtetra
.782 .78 .85 r
.87725 .40001 .88054 .40622 .88843 .39891 .88516 .39275 Mtetra
.784 .782 .851 r
.88516 .39275 .88843 .39891 .89632 .39158 .89308 .38547 Mtetra
.397 .642 .955 r
.29923 .61645 .30355 .62142 .31008 .62252 .30577 .61748 Mtetra
.402 .641 .953 r
.30577 .61748 .31008 .62252 .31663 .62361 .31233 .61849 Mtetra
.409 .641 .951 r
.31233 .61849 .31663 .62361 .32321 .62466 .31892 .61947 Mtetra
.418 .642 .95 r
.31892 .61947 .32321 .62466 .32983 .62567 .32554 .6204 Mtetra
.428 .644 .948 r
.32554 .6204 .32983 .62567 .33647 .62661 .3322 .62127 Mtetra
.439 .646 .945 r
.3322 .62127 .33647 .62661 .34315 .62747 .33889 .62204 Mtetra
.452 .649 .943 r
.33889 .62204 .34315 .62747 .34987 .62822 .34561 .62271 Mtetra
.466 .652 .94 r
.34561 .62271 .34987 .62822 .35661 .62884 .35237 .62325 Mtetra
.48 .655 .937 r
.35237 .62325 .35661 .62884 .36339 .62932 .35916 .62364 Mtetra
.495 .658 .933 r
.35916 .62364 .36339 .62932 .37021 .62963 .36599 .62386 Mtetra
.511 .662 .929 r
.36599 .62386 .37021 .62963 .37706 .62975 .37285 .62389 Mtetra
.528 .666 .924 r
.37285 .62389 .37706 .62975 .38395 .62966 .37974 .62371 Mtetra
.544 .669 .919 r
.37974 .62371 .38395 .62966 .39087 .62934 .38667 .62329 Mtetra
.561 .673 .913 r
.38667 .62329 .39087 .62934 .39782 .62876 .39364 .62261 Mtetra
.578 .676 .907 r
.39364 .62261 .39782 .62876 .40481 .6279 .40064 .62164 Mtetra
.595 .679 .9 r
.40064 .62164 .40481 .6279 .41183 .62673 .40767 .62036 Mtetra
.611 .682 .892 r
.40767 .62036 .41183 .62673 .41889 .62523 .41473 .61874 Mtetra
.627 .685 .884 r
.41473 .61874 .41889 .62523 .42597 .62337 .42183 .61675 Mtetra
.643 .687 .876 r
.42183 .61675 .42597 .62337 .43309 .62111 .42896 .61437 Mtetra
.659 .689 .867 r
.42896 .61437 .43309 .62111 .44023 .61844 .43611 .61156 Mtetra
.673 .69 .858 r
.43611 .61156 .44023 .61844 .4474 .61531 .4433 .60828 Mtetra
.688 .691 .848 r
.4433 .60828 .4474 .61531 .4546 .6117 .45051 .60452 Mtetra
.701 .692 .838 r
.45051 .60452 .4546 .6117 .46183 .60757 .45775 .60022 Mtetra
.714 .692 .828 r
.45775 .60022 .46183 .60757 .46907 .60288 .465 .59535 Mtetra
.727 .692 .817 r
.465 .59535 .46907 .60288 .47634 .59758 .47228 .58986 Mtetra
.739 .692 .806 r
.47228 .58986 .47634 .59758 .48362 .59165 .47958 .58372 Mtetra
.75 .691 .795 r
.47958 .58372 .48362 .59165 .49091 .58502 .48689 .57685 Mtetra
.761 .69 .784 r
.48689 .57685 .49091 .58502 .49822 .57764 .49421 .56921 Mtetra
.771 .688 .772 r
.49421 .56921 .49822 .57764 .50553 .56943 .50154 .56072 Mtetra
.781 .686 .76 r
.50154 .56072 .50553 .56943 .51285 .56033 .50887 .55128 Mtetra
.79 .684 .747 r
.50887 .55128 .51285 .56033 .52017 .55024 .51619 .54077 Mtetra
.798 .68 .734 r
.51619 .54077 .52017 .55024 .52747 .53906 .52352 .52907 Mtetra
.292 .409 .81 r
.63542 .48419 .63931 .49445 .64719 .49976 .64331 .49 Mtetra
.344 .453 .828 r
.64331 .49 .64719 .49976 .65508 .504 .65122 .49462 Mtetra
.391 .491 .841 r
.65122 .49462 .65508 .504 .66299 .50724 .65914 .49817 Mtetra
.433 .524 .851 r
.65914 .49817 .66299 .50724 .67091 .5096 .66707 .50079 Mtetra
.471 .552 .857 r
.66707 .50079 .67091 .5096 .67884 .51113 .67502 .50255 Mtetra
.504 .576 .862 r
.67502 .50255 .67884 .51113 .68678 .51191 .68297 .50353 Mtetra
.533 .598 .864 r
.68297 .50353 .68678 .51191 .69473 .51199 .69094 .50379 Mtetra
.56 .617 .866 r
.69094 .50379 .69473 .51199 .70269 .51142 .69891 .50339 Mtetra
.584 .634 .867 r
.69891 .50339 .70269 .51142 .71065 .51024 .70688 .50236 Mtetra
.605 .649 .867 r
.70688 .50236 .71065 .51024 .71861 .5085 .71486 .50075 Mtetra
.625 .662 .866 r
.71486 .50075 .71861 .5085 .72657 .50623 .72284 .49861 Mtetra
.642 .674 .865 r
.72284 .49861 .72657 .50623 .73453 .50346 .73082 .49595 Mtetra
.658 .685 .864 r
.73082 .49595 .73453 .50346 .74249 .50022 .7388 .49283 Mtetra
.672 .694 .863 r
.7388 .49283 .74249 .50022 .75045 .49655 .74678 .48926 Mtetra
.685 .703 .861 r
.74678 .48926 .75045 .49655 .75841 .49248 .75475 .48529 Mtetra
.697 .711 .859 r
.75475 .48529 .75841 .49248 .76636 .48804 .76273 .48093 Mtetra
.708 .719 .858 r
.76273 .48093 .76636 .48804 .77431 .48324 .77069 .47622 Mtetra
.717 .725 .856 r
.77069 .47622 .77431 .48324 .78225 .47812 .77866 .47118 Mtetra
.726 .731 .855 r
.77866 .47118 .78225 .47812 .79019 .47271 .78662 .46584 Mtetra
.734 .737 .854 r
.78662 .46584 .79019 .47271 .79812 .46702 .79457 .46022 Mtetra
.741 .742 .852 r
.79457 .46022 .79812 .46702 .80605 .46108 .80252 .45435 Mtetra
.748 .747 .851 r
.80252 .45435 .80605 .46108 .81397 .45491 .81047 .44824 Mtetra
.754 .752 .851 r
.81047 .44824 .81397 .45491 .82189 .44855 .81841 .44194 Mtetra
.759 .756 .85 r
.81841 .44194 .82189 .44855 .8298 .44199 .82635 .43544 Mtetra
.763 .76 .849 r
.82635 .43544 .8298 .44199 .83772 .43528 .83428 .42879 Mtetra
.768 .764 .849 r
.83428 .42879 .83772 .43528 .84562 .42843 .84222 .42199 Mtetra
.771 .767 .849 r
.84222 .42199 .84562 .42843 .85353 .42145 .85015 .41507 Mtetra
.774 .77 .849 r
.85015 .41507 .85353 .42145 .86144 .41438 .85808 .40804 Mtetra
.777 .774 .85 r
.85808 .40804 .86144 .41438 .86934 .40723 .86601 .40094 Mtetra
.779 .777 .85 r
.86601 .40094 .86934 .40723 .87725 .40001 .87394 .39377 Mtetra
.781 .779 .851 r
.87394 .39377 .87725 .40001 .88516 .39275 .88188 .38656 Mtetra
.782 .782 .852 r
.88188 .38656 .88516 .39275 .89308 .38547 .88982 .37933 Mtetra
.404 .645 .955 r
.2949 .61146 .29923 .61645 .30577 .61748 .30144 .61242 Mtetra
.409 .644 .953 r
.30144 .61242 .30577 .61748 .31233 .61849 .30801 .61336 Mtetra
.415 .644 .952 r
.30801 .61336 .31233 .61849 .31892 .61947 .31461 .61427 Mtetra
.424 .645 .95 r
.31461 .61427 .31892 .61947 .32554 .6204 .32124 .61513 Mtetra
.433 .647 .948 r
.32124 .61513 .32554 .6204 .3322 .62127 .32791 .61591 Mtetra
.444 .649 .946 r
.32791 .61591 .3322 .62127 .33889 .62204 .33461 .61661 Mtetra
.457 .652 .944 r
.33461 .61661 .33889 .62204 .34561 .62271 .34134 .61721 Mtetra
.47 .655 .941 r
.34134 .61721 .34561 .62271 .35237 .62325 .3481 .61767 Mtetra
.485 .658 .938 r
.3481 .61767 .35237 .62325 .35916 .62364 .35491 .61798 Mtetra
.5 .662 .934 r
.35491 .61798 .35916 .62364 .36599 .62386 .36174 .61812 Mtetra
.516 .666 .93 r
.36174 .61812 .36599 .62386 .37285 .62389 .36861 .61806 Mtetra
.532 .67 .925 r
.36861 .61806 .37285 .62389 .37974 .62371 .37552 .61779 Mtetra
.548 .673 .92 r
.37552 .61779 .37974 .62371 .38667 .62329 .38246 .61728 Mtetra
.565 .677 .914 r
.38246 .61728 .38667 .62329 .39364 .62261 .38943 .6165 Mtetra
.582 .68 .908 r
.38943 .6165 .39364 .62261 .40064 .62164 .39644 .61543 Mtetra
.599 .684 .901 r
.39644 .61543 .40064 .62164 .40767 .62036 .40349 .61404 Mtetra
.615 .687 .894 r
.40349 .61404 .40767 .62036 .41473 .61874 .41056 .61231 Mtetra
.632 .689 .886 r
.41056 .61231 .41473 .61874 .42183 .61675 .41767 .61021 Mtetra
.648 .692 .877 r
.41767 .61021 .42183 .61675 .42896 .61437 .42481 .6077 Mtetra
.663 .694 .868 r
.42481 .6077 .42896 .61437 .43611 .61156 .43198 .60476 Mtetra
.678 .695 .859 r
.43198 .60476 .43611 .61156 .4433 .60828 .43918 .60135 Mtetra
.692 .696 .849 r
.43918 .60135 .4433 .60828 .45051 .60452 .4464 .59744 Mtetra
.706 .697 .839 r
.4464 .59744 .45051 .60452 .45775 .60022 .45365 .59298 Mtetra
.719 .698 .828 r
.45365 .59298 .45775 .60022 .465 .59535 .46092 .58794 Mtetra
.732 .698 .818 r
.46092 .58794 .465 .59535 .47228 .58986 .46821 .58227 Mtetra
.744 .697 .807 r
.46821 .58227 .47228 .58986 .47958 .58372 .47552 .57593 Mtetra
.756 .697 .795 r
.47552 .57593 .47958 .58372 .48689 .57685 .48284 .56886 Mtetra
.767 .696 .784 r
.48284 .56886 .48689 .57685 .49421 .56921 .49018 .56098 Mtetra
.777 .694 .772 r
.49018 .56098 .49421 .56921 .50154 .56072 .49752 .55221 Mtetra
.787 .692 .76 r
.49752 .55221 .50154 .56072 .50887 .55128 .50487 .54246 Mtetra
.797 .69 .747 r
.50487 .54246 .50887 .55128 .51619 .54077 .51221 .53158 Mtetra
.312 .441 .831 r
.63943 .48051 .64331 .49 .65122 .49462 .64735 .48548 Mtetra
.367 .484 .846 r
.64735 .48548 .65122 .49462 .65914 .49817 .65528 .48932 Mtetra
.414 .519 .856 r
.65528 .48932 .65914 .49817 .66707 .50079 .66323 .49217 Mtetra
.455 .549 .863 r
.66323 .49217 .66707 .50079 .67502 .50255 .67118 .49414 Mtetra
.491 .575 .867 r
.67118 .49414 .67502 .50255 .68297 .50353 .67915 .4953 Mtetra
.523 .598 .87 r
.67915 .4953 .68297 .50353 .69094 .50379 .68713 .49573 Mtetra
.552 .617 .872 r
.68713 .49573 .69094 .50379 .69891 .50339 .69512 .49548 Mtetra
.577 .635 .872 r
.69512 .49548 .69891 .50339 .70688 .50236 .70311 .49459 Mtetra
.599 .65 .872 r
.70311 .49459 .70688 .50236 .71486 .50075 .7111 .49311 Mtetra
.62 .664 .871 r
.7111 .49311 .71486 .50075 .72284 .49861 .7191 .49108 Mtetra
.638 .676 .87 r
.7191 .49108 .72284 .49861 .73082 .49595 .7271 .48854 Mtetra
.654 .687 .868 r
.7271 .48854 .73082 .49595 .7388 .49283 .7351 .48551 Mtetra
.669 .696 .866 r
.7351 .48551 .7388 .49283 .74678 .48926 .7431 .48204 Mtetra
.683 .705 .865 r
.7431 .48204 .74678 .48926 .75475 .48529 .75109 .47815 Mtetra
.695 .713 .863 r
.75109 .47815 .75475 .48529 .76273 .48093 .75908 .47388 Mtetra
.706 .72 .861 r
.75908 .47388 .76273 .48093 .77069 .47622 .76707 .46924 Mtetra
.715 .727 .859 r
.76707 .46924 .77069 .47622 .77866 .47118 .77505 .46427 Mtetra
.724 .733 .858 r
.77505 .46427 .77866 .47118 .78662 .46584 .78304 .459 Mtetra
.732 .739 .856 r
.78304 .459 .78662 .46584 .79457 .46022 .79101 .45345 Mtetra
.74 .744 .855 r
.79101 .45345 .79457 .46022 .80252 .45435 .79898 .44764 Mtetra
.746 .748 .854 r
.79898 .44764 .80252 .45435 .81047 .44824 .80695 .44159 Mtetra
.752 .753 .853 r
.80695 .44159 .81047 .44824 .81841 .44194 .81492 .43534 Mtetra
.757 .757 .852 r
.81492 .43534 .81841 .44194 .82635 .43544 .82288 .4289 Mtetra
.762 .761 .851 r
.82288 .4289 .82635 .43544 .83428 .42879 .83083 .42229 Mtetra
.766 .764 .851 r
.83083 .42229 .83428 .42879 .84222 .42199 .83879 .41554 Mtetra
.77 .768 .851 r
.83879 .41554 .84222 .42199 .85015 .41507 .84675 .40867 Mtetra
.773 .771 .851 r
.84675 .40867 .85015 .41507 .85808 .40804 .8547 .40169 Mtetra
.776 .774 .851 r
.8547 .40169 .85808 .40804 .86601 .40094 .86266 .39463 Mtetra
.778 .777 .852 r
.86266 .39463 .86601 .40094 .87394 .39377 .87061 .38751 Mtetra
.78 .779 .852 r
.87061 .38751 .87394 .39377 .88188 .38656 .87857 .38034 Mtetra
.781 .782 .853 r
.87857 .38034 .88188 .38656 .88982 .37933 .88654 .37315 Mtetra
.41 .648 .955 r
.29054 .60645 .2949 .61146 .30144 .61242 .29709 .60734 Mtetra
.414 .647 .954 r
.29709 .60734 .30144 .61242 .30801 .61336 .30367 .60821 Mtetra
.421 .647 .952 r
.30367 .60821 .30801 .61336 .31461 .61427 .31028 .60905 Mtetra
.429 .648 .95 r
.31028 .60905 .31461 .61427 .32124 .61513 .31692 .60984 Mtetra
.438 .65 .948 r
.31692 .60984 .32124 .61513 .32791 .61591 .32359 .61056 Mtetra
.449 .652 .946 r
.32359 .61056 .32791 .61591 .33461 .61661 .3303 .61119 Mtetra
.461 .655 .944 r
.3303 .61119 .33461 .61661 .34134 .61721 .33704 .61171 Mtetra
.474 .658 .941 r
.33704 .61171 .34134 .61721 .3481 .61767 .34382 .6121 Mtetra
.489 .662 .938 r
.34382 .6121 .3481 .61767 .35491 .61798 .35063 .61233 Mtetra
.504 .665 .935 r
.35063 .61233 .35491 .61798 .36174 .61812 .35747 .61239 Mtetra
.519 .669 .931 r
.35747 .61239 .36174 .61812 .36861 .61806 .36436 .61226 Mtetra
.536 .673 .926 r
.36436 .61226 .36861 .61806 .37552 .61779 .37127 .6119 Mtetra
.552 .677 .921 r
.37127 .6119 .37552 .61779 .38246 .61728 .37822 .6113 Mtetra
.569 .681 .916 r
.37822 .6113 .38246 .61728 .38943 .6165 .38521 .61043 Mtetra
.586 .685 .909 r
.38521 .61043 .38943 .6165 .39644 .61543 .39223 .60927 Mtetra
.603 .688 .902 r
.39223 .60927 .39644 .61543 .40349 .61404 .39928 .60779 Mtetra
.619 .691 .895 r
.39928 .60779 .40349 .61404 .41056 .61231 .40637 .60595 Mtetra
.636 .694 .887 r
.40637 .60595 .41056 .61231 .41767 .61021 .41349 .60374 Mtetra
.652 .696 .878 r
.41349 .60374 .41767 .61021 .42481 .6077 .42064 .60112 Mtetra
.667 .698 .869 r
.42064 .60112 .42481 .6077 .43198 .60476 .42782 .59805 Mtetra
.682 .7 .86 r
.42782 .59805 .43198 .60476 .43918 .60135 .43503 .59451 Mtetra
.697 .701 .85 r
.43503 .59451 .43918 .60135 .4464 .59744 .44227 .59046 Mtetra
.711 .702 .84 r
.44227 .59046 .4464 .59744 .45365 .59298 .44953 .58586 Mtetra
.724 .703 .83 r
.44953 .58586 .45365 .59298 .46092 .58794 .45682 .58066 Mtetra
.737 .703 .819 r
.45682 .58066 .46092 .58794 .46821 .58227 .46412 .57483 Mtetra
.749 .703 .808 r
.46412 .57483 .46821 .58227 .47552 .57593 .47145 .5683 Mtetra
.761 .702 .796 r
.47145 .5683 .47552 .57593 .48284 .56886 .47878 .56103 Mtetra
.772 .701 .785 r
.47878 .56103 .48284 .56886 .49018 .56098 .48613 .55293 Mtetra
.783 .7 .773 r
.48613 .55293 .49018 .56098 .49752 .55221 .49349 .54393 Mtetra
.793 .699 .76 r
.49349 .54393 .49752 .55221 .50487 .54246 .50085 .5339 Mtetra
.804 .697 .747 r
.50085 .5339 .50487 .54246 .51221 .53158 .50821 .52269 Mtetra
.279 .43 .834 r
.63555 .47133 .63943 .48051 .64735 .48548 .64347 .47659 Mtetra
.342 .477 .85 r
.64347 .47659 .64735 .48548 .65528 .48932 .65142 .48068 Mtetra
.395 .515 .861 r
.65142 .48068 .65528 .48932 .66323 .49217 .65937 .48374 Mtetra
.44 .547 .869 r
.65937 .48374 .66323 .49217 .67118 .49414 .66735 .48589 Mtetra
.479 .574 .873 r
.66735 .48589 .67118 .49414 .67915 .4953 .67533 .48723 Mtetra
.513 .598 .876 r
.67533 .48723 .67915 .4953 .68713 .49573 .68332 .48781 Mtetra
.543 .618 .877 r
.68332 .48781 .68713 .49573 .69512 .49548 .69132 .48769 Mtetra
.57 .636 .877 r
.69132 .48769 .69512 .49548 .70311 .49459 .69933 .48693 Mtetra
.594 .652 .877 r
.69933 .48693 .70311 .49459 .7111 .49311 .70734 .48557 Mtetra
.615 .665 .876 r
.70734 .48557 .7111 .49311 .7191 .49108 .71535 .48365 Mtetra
.634 .678 .874 r
.71535 .48365 .7191 .49108 .7271 .48854 .72337 .48121 Mtetra
.651 .689 .872 r
.72337 .48121 .7271 .48854 .7351 .48551 .73138 .47828 Mtetra
.666 .698 .87 r
.73138 .47828 .7351 .48551 .7431 .48204 .7394 .47489 Mtetra
.68 .707 .868 r
.7394 .47489 .7431 .48204 .75109 .47815 .74741 .47108 Mtetra
.692 .715 .866 r
.74741 .47108 .75109 .47815 .75908 .47388 .75542 .46688 Mtetra
.704 .722 .864 r
.75542 .46688 .75908 .47388 .76707 .46924 .76343 .46231 Mtetra
.714 .729 .862 r
.76343 .46231 .76707 .46924 .77505 .46427 .77144 .45741 Mtetra
.723 .735 .861 r
.77144 .45741 .77505 .46427 .78304 .459 .77944 .4522 Mtetra
.731 .74 .859 r
.77944 .4522 .78304 .459 .79101 .45345 .78744 .4467 Mtetra
.738 .745 .857 r
.78744 .4467 .79101 .45345 .79898 .44764 .79543 .44095 Mtetra
.745 .75 .856 r
.79543 .44095 .79898 .44764 .80695 .44159 .80342 .43496 Mtetra
.751 .754 .855 r
.80342 .43496 .80695 .44159 .81492 .43534 .81141 .42875 Mtetra
.756 .758 .854 r
.81141 .42875 .81492 .43534 .82288 .4289 .81939 .42236 Mtetra
.761 .762 .853 r
.81939 .42236 .82288 .4289 .83083 .42229 .82737 .4158 Mtetra
.765 .765 .852 r
.82737 .4158 .83083 .42229 .83879 .41554 .83535 .40909 Mtetra
.769 .768 .852 r
.83535 .40909 .83879 .41554 .84675 .40867 .84333 .40226 Mtetra
.772 .771 .852 r
.84333 .40226 .84675 .40867 .8547 .40169 .85131 .39533 Mtetra
.774 .774 .852 r
.85131 .39533 .8547 .40169 .86266 .39463 .85929 .38831 Mtetra
.777 .777 .853 r
.85929 .38831 .86266 .39463 .87061 .38751 .86727 .38123 Mtetra
.778 .779 .853 r
.86727 .38123 .87061 .38751 .87857 .38034 .87526 .3741 Mtetra
.779 .782 .854 r
.87526 .3741 .87857 .38034 .88654 .37315 .88325 .36695 Mtetra
.415 .65 .955 r
.28616 .60141 .29054 .60645 .29709 .60734 .29272 .60224 Mtetra
.419 .65 .954 r
.29272 .60224 .29709 .60734 .30367 .60821 .29931 .60305 Mtetra
.426 .65 .952 r
.29931 .60305 .30367 .60821 .31028 .60905 .30592 .60383 Mtetra
.433 .651 .951 r
.30592 .60383 .31028 .60905 .31692 .60984 .31258 .60455 Mtetra
.442 .653 .949 r
.31258 .60455 .31692 .60984 .32359 .61056 .31926 .60521 Mtetra
.453 .655 .947 r
.31926 .60521 .32359 .61056 .3303 .61119 .32598 .60577 Mtetra
.465 .658 .945 r
.32598 .60577 .3303 .61119 .33704 .61171 .33273 .60622 Mtetra
.478 .661 .942 r
.33273 .60622 .33704 .61171 .34382 .6121 .33951 .60654 Mtetra
.492 .665 .939 r
.33951 .60654 .34382 .6121 .35063 .61233 .34633 .60671 Mtetra
.507 .669 .936 r
.34633 .60671 .35063 .61233 .35747 .61239 .35319 .60669 Mtetra
.523 .673 .932 r
.35319 .60669 .35747 .61239 .36436 .61226 .36008 .60648 Mtetra
.539 .677 .927 r
.36008 .60648 .36436 .61226 .37127 .6119 .367 .60605 Mtetra
.555 .681 .922 r
.367 .60605 .37127 .6119 .37822 .6113 .37396 .60537 Mtetra
.572 .685 .917 r
.37396 .60537 .37822 .6113 .38521 .61043 .38096 .60442 Mtetra
.589 .688 .911 r
.38096 .60442 .38521 .61043 .39223 .60927 .38799 .60317 Mtetra
.606 .692 .904 r
.38799 .60317 .39223 .60927 .39928 .60779 .39506 .60159 Mtetra
.623 .695 .896 r
.39506 .60159 .39928 .60779 .40637 .60595 .40216 .59966 Mtetra
.639 .698 .888 r
.40216 .59966 .40637 .60595 .41349 .60374 .40929 .59734 Mtetra
.655 .701 .88 r
.40929 .59734 .41349 .60374 .42064 .60112 .41645 .59461 Mtetra
.671 .703 .871 r
.41645 .59461 .42064 .60112 .42782 .59805 .42365 .59144 Mtetra
.686 .705 .861 r
.42365 .59144 .42782 .59805 .43503 .59451 .43087 .58777 Mtetra
.701 .706 .852 r
.43087 .58777 .43503 .59451 .44227 .59046 .43812 .58359 Mtetra
.715 .707 .841 r
.43812 .58359 .44227 .59046 .44953 .58586 .44539 .57885 Mtetra
.729 .708 .831 r
.44539 .57885 .44953 .58586 .45682 .58066 .45269 .57351 Mtetra
.742 .708 .82 r
.45269 .57351 .45682 .58066 .46412 .57483 .46001 .56752 Mtetra
.754 .708 .809 r
.46001 .56752 .46412 .57483 .47145 .5683 .46735 .56083 Mtetra
.766 .708 .797 r
.46735 .56083 .47145 .5683 .47878 .56103 .47471 .55337 Mtetra
.777 .707 .786 r
.47471 .55337 .47878 .56103 .48613 .55293 .48207 .54508 Mtetra
.788 .706 .773 r
.48207 .54508 .48613 .55293 .49349 .54393 .48945 .53587 Mtetra
.799 .705 .761 r
.48945 .53587 .49349 .54393 .50085 .5339 .49682 .5256 Mtetra
.81 .704 .747 r
.49682 .5256 .50085 .5339 .50821 .52269 .5042 .51412 Mtetra
.246 .419 .837 r
.63166 .46248 .63555 .47133 .64347 .47659 .6396 .46798 Mtetra
.317 .47 .855 r
.6396 .46798 .64347 .47659 .65142 .48068 .64755 .47226 Mtetra
.376 .511 .867 r
.64755 .47226 .65142 .48068 .65937 .48374 .65552 .47551 Mtetra
.425 .545 .874 r
.65552 .47551 .65937 .48374 .66735 .48589 .6635 .47782 Mtetra
.467 .574 .879 r
.6635 .47782 .66735 .48589 .67533 .48723 .67149 .47931 Mtetra
.503 .598 .882 r
.67149 .47931 .67533 .48723 .68332 .48781 .6795 .48002 Mtetra
.535 .619 .883 r
.6795 .48002 .68332 .48781 .69132 .48769 .68751 .48004 Mtetra
.563 .637 .883 r
.68751 .48004 .69132 .48769 .69933 .48693 .69554 .47939 Mtetra
.588 .653 .882 r
.69554 .47939 .69933 .48693 .70734 .48557 .70356 .47814 Mtetra
.61 .668 .88 r
.70356 .47814 .70734 .48557 .71535 .48365 .71159 .47632 Mtetra
.63 .68 .879 r
.71159 .47632 .71535 .48365 .72337 .48121 .71963 .47396 Mtetra
.648 .691 .877 r
.71963 .47396 .72337 .48121 .73138 .47828 .72766 .47112 Mtetra
.663 .701 .874 r
.72766 .47112 .73138 .47828 .7394 .47489 .73569 .46781 Mtetra
.678 .71 .872 r
.73569 .46781 .7394 .47489 .74741 .47108 .74373 .46407 Mtetra
.69 .717 .87 r
.74373 .46407 .74741 .47108 .75542 .46688 .75176 .45994 Mtetra
.702 .724 .867 r
.75176 .45994 .75542 .46688 .76343 .46231 .75978 .45544 Mtetra
.712 .731 .865 r
.75978 .45544 .76343 .46231 .77144 .45741 .76781 .45059 Mtetra
.721 .737 .863 r
.76781 .45059 .77144 .45741 .77944 .4522 .77583 .44544 Mtetra
.73 .742 .861 r
.77583 .44544 .77944 .4522 .78744 .4467 .78385 .43999 Mtetra
.737 .747 .86 r
.78385 .43999 .78744 .4467 .79543 .44095 .79187 .43429 Mtetra
.744 .751 .858 r
.79187 .43429 .79543 .44095 .80342 .43496 .79988 .42834 Mtetra
.75 .755 .857 r
.79988 .42834 .80342 .43496 .81141 .42875 .80789 .42218 Mtetra
.755 .759 .856 r
.80789 .42218 .81141 .42875 .81939 .42236 .81589 .41583 Mtetra
.76 .763 .855 r
.81589 .41583 .81939 .42236 .82737 .4158 .8239 .40931 Mtetra
.764 .766 .854 r
.8239 .40931 .82737 .4158 .83535 .40909 .8319 .40264 Mtetra
.768 .769 .854 r
.8319 .40264 .83535 .40909 .84333 .40226 .8399 .39585 Mtetra
.771 .772 .853 r
.8399 .39585 .84333 .40226 .85131 .39533 .8479 .38895 Mtetra
.773 .774 .854 r
.8479 .38895 .85131 .39533 .85929 .38831 .85591 .38197 Mtetra
.775 .777 .854 r
.85591 .38197 .85929 .38831 .86727 .38123 .86391 .37492 Mtetra
.777 .779 .854 r
.86391 .37492 .86727 .38123 .87526 .3741 .87192 .36783 Mtetra
.778 .781 .855 r
.87192 .36783 .87526 .3741 .88325 .36695 .87994 .36071 Mtetra
.42 .652 .955 r
.28176 .59635 .28616 .60141 .29272 .60224 .28832 .59711 Mtetra
.424 .652 .954 r
.28832 .59711 .29272 .60224 .29931 .60305 .29492 .59787 Mtetra
.43 .652 .952 r
.29492 .59787 .29931 .60305 .30592 .60383 .30155 .59859 Mtetra
.437 .654 .951 r
.30155 .59859 .30592 .60383 .31258 .60455 .30821 .59926 Mtetra
.446 .655 .949 r
.30821 .59926 .31258 .60455 .31926 .60521 .3149 .59985 Mtetra
.457 .658 .947 r
.3149 .59985 .31926 .60521 .32598 .60577 .32163 .60036 Mtetra
.468 .661 .945 r
.32163 .60036 .32598 .60577 .33273 .60622 .32839 .60074 Mtetra
.481 .664 .943 r
.32839 .60074 .33273 .60622 .33951 .60654 .33518 .601 Mtetra
.495 .668 .94 r
.33518 .601 .33951 .60654 .34633 .60671 .34201 .6011 Mtetra
.51 .672 .937 r
.34201 .6011 .34633 .60671 .35319 .60669 .34888 .60102 Mtetra
.526 .676 .933 r
.34888 .60102 .35319 .60669 .36008 .60648 .35578 .60074 Mtetra
.542 .68 .928 r
.35578 .60074 .36008 .60648 .367 .60605 .36271 .60023 Mtetra
.558 .684 .924 r
.36271 .60023 .367 .60605 .37396 .60537 .36969 .59948 Mtetra
.575 .688 .918 r
.36969 .59948 .37396 .60537 .38096 .60442 .37669 .59844 Mtetra
.592 .692 .912 r
.37669 .59844 .38096 .60442 .38799 .60317 .38373 .59711 Mtetra
.609 .696 .905 r
.38373 .59711 .38799 .60317 .39506 .60159 .39081 .59545 Mtetra
.626 .699 .898 r
.39081 .59545 .39506 .60159 .40216 .59966 .39792 .59343 Mtetra
.643 .703 .89 r
.39792 .59343 .40216 .59966 .40929 .59734 .40507 .59102 Mtetra
.659 .705 .881 r
.40507 .59102 .40929 .59734 .41645 .59461 .41224 .58819 Mtetra
.675 .708 .872 r
.41224 .58819 .41645 .59461 .42365 .59144 .41945 .58491 Mtetra
.69 .71 .863 r
.41945 .58491 .42365 .59144 .43087 .58777 .42668 .58113 Mtetra
.705 .711 .853 r
.42668 .58113 .43087 .58777 .43812 .58359 .43395 .57683 Mtetra
.719 .712 .843 r
.43395 .57683 .43812 .58359 .44539 .57885 .44124 .57197 Mtetra
.733 .713 .832 r
.44124 .57197 .44539 .57885 .45269 .57351 .44855 .56649 Mtetra
.746 .713 .821 r
.44855 .56649 .45269 .57351 .46001 .56752 .45589 .56036 Mtetra
.759 .714 .81 r
.45589 .56036 .46001 .56752 .46735 .56083 .46324 .55351 Mtetra
.771 .713 .799 r
.46324 .55351 .46735 .56083 .47471 .55337 .47061 .5459 Mtetra
.782 .713 .787 r
.47061 .5459 .47471 .55337 .48207 .54508 .47799 .53744 Mtetra
.794 .712 .775 r
.47799 .53744 .48207 .54508 .48945 .53587 .48538 .52804 Mtetra
.805 .711 .762 r
.48538 .52804 .48945 .53587 .49682 .5256 .49278 .51759 Mtetra
.293 .465 .859 r
.63572 .45964 .6396 .46798 .64755 .47226 .64367 .46409 Mtetra
.356 .508 .872 r
.64367 .46409 .64755 .47226 .65552 .47551 .65165 .46748 Mtetra
.409 .544 .88 r
.65165 .46748 .65552 .47551 .6635 .47782 .65964 .46994 Mtetra
.454 .574 .885 r
.65964 .46994 .6635 .47782 .67149 .47931 .66765 .47155 Mtetra
.493 .599 .887 r
.66765 .47155 .67149 .47931 .6795 .48002 .67567 .47239 Mtetra
.527 .62 .888 r
.67567 .47239 .6795 .48002 .68751 .48004 .6837 .47251 Mtetra
.556 .639 .888 r
.6837 .47251 .68751 .48004 .69554 .47939 .69173 .47197 Mtetra
.582 .656 .887 r
.69173 .47197 .69554 .47939 .70356 .47814 .69978 .47081 Mtetra
.606 .67 .885 r
.69978 .47081 .70356 .47814 .71159 .47632 .70782 .46908 Mtetra
.626 .682 .883 r
.70782 .46908 .71159 .47632 .71963 .47396 .71587 .46681 Mtetra
.644 .693 .881 r
.71587 .46681 .71963 .47396 .72766 .47112 .72392 .46404 Mtetra
.661 .703 .878 r
.72392 .46404 .72766 .47112 .73569 .46781 .73197 .4608 Mtetra
.675 .712 .876 r
.73197 .4608 .73569 .46781 .74373 .46407 .74003 .45713 Mtetra
.688 .72 .873 r
.74003 .45713 .74373 .46407 .75176 .45994 .74808 .45305 Mtetra
.7 .727 .871 r
.74808 .45305 .75176 .45994 .75978 .45544 .75612 .44861 Mtetra
.711 .733 .868 r
.75612 .44861 .75978 .45544 .76781 .45059 .76417 .44382 Mtetra
.72 .739 .866 r
.76417 .44382 .76781 .45059 .77583 .44544 .77221 .43871 Mtetra
.729 .744 .864 r
.77221 .43871 .77583 .44544 .78385 .43999 .78025 .43331 Mtetra
.736 .748 .862 r
.78025 .43331 .78385 .43999 .79187 .43429 .78829 .42765 Mtetra
.743 .753 .86 r
.78829 .42765 .79187 .43429 .79988 .42834 .79632 .42174 Mtetra
.749 .757 .859 r
.79632 .42174 .79988 .42834 .80789 .42218 .80435 .41562 Mtetra
.754 .76 .857 r
.80435 .41562 .80789 .42218 .81589 .41583 .81238 .40931 Mtetra
.759 .764 .856 r
.81238 .40931 .81589 .41583 .8239 .40931 .8204 .40282 Mtetra
.763 .767 .856 r
.8204 .40282 .8239 .40931 .8319 .40264 .82843 .39619 Mtetra
.767 .769 .855 r
.82843 .39619 .8319 .40264 .8399 .39585 .83645 .38943 Mtetra
.77 .772 .855 r
.83645 .38943 .8399 .39585 .8479 .38895 .84448 .38256 Mtetra
.772 .775 .855 r
.84448 .38256 .8479 .38895 .85591 .38197 .85251 .37561 Mtetra
.774 .777 .855 r
.85251 .37561 .85591 .38197 .86391 .37492 .86054 .36859 Mtetra
.776 .779 .855 r
.86054 .36859 .86391 .37492 .87192 .36783 .86857 .36152 Mtetra
.777 .781 .856 r
.86857 .36152 .87192 .36783 .87994 .36071 .87661 .35444 Mtetra
.425 .654 .955 r
.27733 .59126 .28176 .59635 .28832 .59711 .28391 .59197 Mtetra
.428 .654 .954 r
.28391 .59197 .28832 .59711 .29492 .59787 .29052 .59268 Mtetra
.434 .655 .953 r
.29052 .59268 .29492 .59787 .30155 .59859 .29716 .59334 Mtetra
.441 .656 .951 r
.29716 .59334 .30155 .59859 .30821 .59926 .30382 .59396 Mtetra
.45 .658 .95 r
.30382 .59396 .30821 .59926 .3149 .59985 .31053 .5945 Mtetra
.46 .66 .948 r
.31053 .5945 .3149 .59985 .32163 .60036 .31726 .59494 Mtetra
.471 .663 .946 r
.31726 .59494 .32163 .60036 .32839 .60074 .32403 .59527 Mtetra
.484 .667 .944 r
.32403 .59527 .32839 .60074 .33518 .601 .33083 .59547 Mtetra
.498 .671 .941 r
.33083 .59547 .33518 .601 .34201 .6011 .33767 .59551 Mtetra
.513 .675 .938 r
.33767 .59551 .34201 .6011 .34888 .60102 .34455 .59537 Mtetra
.528 .679 .934 r
.34455 .59537 .34888 .60102 .35578 .60074 .35146 .59502 Mtetra
.544 .683 .93 r
.35146 .59502 .35578 .60074 .36271 .60023 .3584 .59445 Mtetra
.561 .688 .925 r
.3584 .59445 .36271 .60023 .36969 .59948 .36538 .59362 Mtetra
.578 .692 .919 r
.36538 .59362 .36969 .59948 .37669 .59844 .3724 .59252 Mtetra
.595 .696 .913 r
.3724 .59252 .37669 .59844 .38373 .59711 .37945 .59111 Mtetra
.612 .7 .907 r
.37945 .59111 .38373 .59711 .39081 .59545 .38654 .58937 Mtetra
.629 .704 .899 r
.38654 .58937 .39081 .59545 .39792 .59343 .39367 .58727 Mtetra
.646 .707 .892 r
.39367 .58727 .39792 .59343 .40507 .59102 .40082 .58477 Mtetra
.662 .71 .883 r
.40082 .58477 .40507 .59102 .41224 .58819 .40801 .58185 Mtetra
.678 .712 .874 r
.40801 .58185 .41224 .58819 .41945 .58491 .41523 .57847 Mtetra
.694 .714 .865 r
.41523 .57847 .41945 .58491 .42668 .58113 .42248 .57459 Mtetra
.709 .716 .855 r
.42248 .57459 .42668 .58113 .43395 .57683 .42976 .57019 Mtetra
.723 .717 .844 r
.42976 .57019 .43395 .57683 .44124 .57197 .43706 .5652 Mtetra
.737 .718 .834 r
.43706 .5652 .44124 .57197 .44855 .56649 .44439 .55961 Mtetra
.75 .719 .823 r
.44439 .55961 .44855 .56649 .45589 .56036 .45174 .55334 Mtetra
.763 .719 .811 r
.45174 .55334 .45589 .56036 .46324 .55351 .45911 .54636 Mtetra
.775 .719 .8 r
.45911 .54636 .46324 .55351 .47061 .5459 .46649 .5386 Mtetra
.787 .719 .788 r
.46649 .5386 .47061 .5459 .47799 .53744 .47389 .52999 Mtetra
.798 .718 .776 r
.47389 .52999 .47799 .53744 .48538 .52804 .4813 .52045 Mtetra
.81 .718 .764 r
.4813 .52045 .48538 .52804 .49278 .51759 .48871 .50985 Mtetra
.269 .46 .863 r
.63183 .45159 .63572 .45964 .64367 .46409 .63979 .45615 Mtetra
.338 .506 .877 r
.63979 .45615 .64367 .46409 .65165 .46748 .64778 .45965 Mtetra
.394 .543 .886 r
.64778 .45965 .65165 .46748 .65964 .46994 .65578 .46223 Mtetra
.442 .574 .891 r
.65578 .46223 .65964 .46994 .66765 .47155 .6638 .46395 Mtetra
.483 .6 .893 r
.6638 .46395 .66765 .47155 .67567 .47239 .67183 .4649 Mtetra
.519 .622 .894 r
.67183 .4649 .67567 .47239 .6837 .47251 .67987 .46512 Mtetra
.55 .641 .894 r
.67987 .46512 .6837 .47251 .69173 .47197 .68792 .46467 Mtetra
.577 .658 .892 r
.68792 .46467 .69173 .47197 .69978 .47081 .69598 .4636 Mtetra
.601 .672 .89 r
.69598 .4636 .69978 .47081 .70782 .46908 .70404 .46194 Mtetra
.622 .685 .888 r
.70404 .46194 .70782 .46908 .71587 .46681 .71211 .45974 Mtetra
.641 .696 .885 r
.71211 .45974 .71587 .46681 .72392 .46404 .72017 .45704 Mtetra
.658 .706 .882 r
.72017 .45704 .72392 .46404 .73197 .4608 .72824 .45386 Mtetra
.673 .714 .879 r
.72824 .45386 .73197 .4608 .74003 .45713 .73631 .45025 Mtetra
.687 .722 .877 r
.73631 .45025 .74003 .45713 .74808 .45305 .74438 .44623 Mtetra
.699 .729 .874 r
.74438 .44623 .74808 .45305 .75612 .44861 .75245 .44183 Mtetra
.709 .735 .871 r
.75245 .44183 .75612 .44861 .76417 .44382 .76051 .43708 Mtetra
.719 .741 .869 r
.76051 .43708 .76417 .44382 .77221 .43871 .76858 .43202 Mtetra
.728 .746 .866 r
.76858 .43202 .77221 .43871 .78025 .43331 .77664 .42666 Mtetra
.735 .75 .864 r
.77664 .42666 .78025 .43331 .78829 .42765 .78469 .42103 Mtetra
.742 .754 .862 r
.78469 .42103 .78829 .42765 .79632 .42174 .79275 .41516 Mtetra
.748 .758 .861 r
.79275 .41516 .79632 .42174 .80435 .41562 .8008 .40908 Mtetra
.754 .761 .859 r
.8008 .40908 .80435 .41562 .81238 .40931 .80885 .40279 Mtetra
.758 .765 .858 r
.80885 .40279 .81238 .40931 .8204 .40282 .8169 .39634 Mtetra
.762 .768 .857 r
.8169 .39634 .8204 .40282 .82843 .39619 .82494 .38973 Mtetra
.766 .77 .856 r
.82494 .38973 .82843 .39619 .83645 .38943 .83299 .383 Mtetra
.769 .773 .856 r
.83299 .383 .83645 .38943 .84448 .38256 .84104 .37616 Mtetra
.771 .775 .856 r
.84104 .37616 .84448 .38256 .85251 .37561 .84909 .36923 Mtetra
.773 .777 .856 r
.84909 .36923 .85251 .37561 .86054 .36859 .85714 .36223 Mtetra
.775 .779 .856 r
.85714 .36223 .86054 .36859 .86857 .36152 .8652 .35519 Mtetra
.776 .781 .857 r
.8652 .35519 .86857 .36152 .87661 .35444 .87326 .34813 Mtetra
.428 .656 .955 r
.27289 .58615 .27733 .59126 .28391 .59197 .27948 .58681 Mtetra
.432 .656 .954 r
.27948 .58681 .28391 .59197 .29052 .59268 .28609 .58747 Mtetra
.437 .657 .953 r
.28609 .58747 .29052 .59268 .29716 .59334 .29274 .58808 Mtetra
.444 .658 .952 r
.29274 .58808 .29716 .59334 .30382 .59396 .29942 .58865 Mtetra
.453 .66 .95 r
.29942 .58865 .30382 .59396 .31053 .5945 .30613 .58914 Mtetra
.463 .663 .948 r
.30613 .58914 .31053 .5945 .31726 .59494 .31287 .58953 Mtetra
.474 .666 .947 r
.31287 .58953 .31726 .59494 .32403 .59527 .31965 .58981 Mtetra
.487 .669 .944 r
.31965 .58981 .32403 .59527 .33083 .59547 .32646 .58995 Mtetra
.5 .673 .942 r
.32646 .58995 .33083 .59547 .33767 .59551 .33331 .58994 Mtetra
.515 .678 .939 r
.33331 .58994 .33767 .59551 .34455 .59537 .34019 .58974 Mtetra
.531 .682 .935 r
.34019 .58974 .34455 .59537 .35146 .59502 .34711 .58933 Mtetra
.547 .687 .931 r
.34711 .58933 .35146 .59502 .3584 .59445 .35407 .5887 Mtetra
.563 .691 .926 r
.35407 .5887 .3584 .59445 .36538 .59362 .36106 .58781 Mtetra
.58 .696 .921 r
.36106 .58781 .36538 .59362 .3724 .59252 .36809 .58664 Mtetra
.597 .7 .915 r
.36809 .58664 .3724 .59252 .37945 .59111 .37515 .58517 Mtetra
.614 .704 .908 r
.37515 .58517 .37945 .59111 .38654 .58937 .38225 .58335 Mtetra
.631 .708 .901 r
.38225 .58335 .38654 .58937 .39367 .58727 .38939 .58118 Mtetra
.648 .711 .893 r
.38939 .58118 .39367 .58727 .40082 .58477 .39655 .5786 Mtetra
.665 .714 .885 r
.39655 .5786 .40082 .58477 .40801 .58185 .40376 .5756 Mtetra
.681 .717 .876 r
.40376 .5756 .40801 .58185 .41523 .57847 .41099 .57213 Mtetra
.697 .719 .867 r
.41099 .57213 .41523 .57847 .42248 .57459 .41825 .56816 Mtetra
.712 .721 .857 r
.41825 .56816 .42248 .57459 .42976 .57019 .42554 .56365 Mtetra
.727 .722 .846 r
.42554 .56365 .42976 .57019 .43706 .5652 .43286 .55856 Mtetra
.741 .723 .835 r
.43286 .55856 .43706 .5652 .44439 .55961 .4402 .55285 Mtetra
.754 .724 .824 r
.4402 .55285 .44439 .55961 .45174 .55334 .44757 .54647 Mtetra
.767 .724 .813 r
.44757 .54647 .45174 .55334 .45911 .54636 .45496 .53937 Mtetra
.779 .725 .802 r
.45496 .53937 .45911 .54636 .46649 .5386 .46236 .53149 Mtetra
.791 .724 .79 r
.46236 .53149 .46649 .5386 .47389 .52999 .46977 .52275 Mtetra
.803 .724 .778 r
.46977 .52275 .47389 .52999 .4813 .52045 .4772 .51309 Mtetra
.814 .724 .766 r
.4772 .51309 .4813 .52045 .48871 .50985 .48463 .50239 Mtetra
.247 .457 .867 r
.62793 .44381 .63183 .45159 .63979 .45615 .6359 .44844 Mtetra
.32 .504 .882 r
.6359 .44844 .63979 .45615 .64778 .45965 .64389 .45204 Mtetra
.38 .542 .891 r
.64389 .45204 .64778 .45965 .65578 .46223 .65191 .4547 Mtetra
.43 .574 .896 r
.65191 .4547 .65578 .46223 .6638 .46395 .65994 .45652 Mtetra
.473 .601 .899 r
.65994 .45652 .6638 .46395 .67183 .4649 .66798 .45755 Mtetra
.511 .624 .9 r
.66798 .45755 .67183 .4649 .67987 .46512 .67603 .45786 Mtetra
.543 .644 .899 r
.67603 .45786 .67987 .46512 .68792 .46467 .6841 .45749 Mtetra
.572 .661 .897 r
.6841 .45749 .68792 .46467 .69598 .4636 .69217 .45649 Mtetra
.597 .675 .895 r
.69217 .45649 .69598 .4636 .70404 .46194 .70025 .45491 Mtetra
.619 .688 .892 r
.70025 .45491 .70404 .46194 .71211 .45974 .70833 .45277 Mtetra
.639 .699 .889 r
.70833 .45277 .71211 .45974 .72017 .45704 .71641 .45012 Mtetra
.656 .709 .886 r
.71641 .45012 .72017 .45704 .72824 .45386 .7245 .447 Mtetra
.671 .717 .883 r
.7245 .447 .72824 .45386 .73631 .45025 .73259 .44344 Mtetra
.685 .725 .88 r
.73259 .44344 .73631 .45025 .74438 .44623 .74068 .43946 Mtetra
.697 .731 .877 r
.74068 .43946 .74438 .44623 .75245 .44183 .74876 .4351 Mtetra
.708 .737 .874 r
.74876 .4351 .75245 .44183 .76051 .43708 .75685 .4304 Mtetra
.718 .743 .871 r
.75685 .4304 .76051 .43708 .76858 .43202 .76493 .42537 Mtetra
.727 .748 .869 r
.76493 .42537 .76858 .43202 .77664 .42666 .77301 .42004 Mtetra
.734 .752 .866 r
.77301 .42004 .77664 .42666 .78469 .42103 .78109 .41445 Mtetra
.741 .756 .864 r
.78109 .41445 .78469 .42103 .79275 .41516 .78916 .40861 Mtetra
.747 .759 .862 r
.78916 .40861 .79275 .41516 .8008 .40908 .79723 .40254 Mtetra
.753 .763 .861 r
.79723 .40254 .8008 .40908 .80885 .40279 .8053 .39629 Mtetra
.758 .766 .859 r
.8053 .39629 .80885 .40279 .8169 .39634 .81337 .38985 Mtetra
.762 .768 .858 r
.81337 .38985 .8169 .39634 .82494 .38973 .82144 .38327 Mtetra
.765 .771 .858 r
.82144 .38327 .82494 .38973 .83299 .383 .82951 .37656 Mtetra
.768 .773 .857 r
.82951 .37656 .83299 .383 .84104 .37616 .83758 .36974 Mtetra
.771 .775 .857 r
.83758 .36974 .84104 .37616 .84909 .36923 .84566 .36283 Mtetra
.773 .777 .857 r
.84566 .36283 .84909 .36923 .85714 .36223 .85373 .35586 Mtetra
.774 .779 .857 r
.85373 .35586 .85714 .36223 .8652 .35519 .86181 .34884 Mtetra
.775 .781 .858 r
.86181 .34884 .8652 .35519 .87326 .34813 .8699 .34179 Mtetra
.432 .658 .955 r
.26843 .58101 .27289 .58615 .27948 .58681 .27502 .58163 Mtetra
.435 .658 .954 r
.27502 .58163 .27948 .58681 .28609 .58747 .28164 .58224 Mtetra
.44 .658 .953 r
.28164 .58224 .28609 .58747 .29274 .58808 .2883 .58282 Mtetra
.447 .66 .952 r
.2883 .58282 .29274 .58808 .29942 .58865 .29498 .58333 Mtetra
.455 .662 .951 r
.29498 .58333 .29942 .58865 .30613 .58914 .3017 .58378 Mtetra
.465 .665 .949 r
.3017 .58378 .30613 .58914 .31287 .58953 .30846 .58413 Mtetra
.476 .668 .947 r
.30846 .58413 .31287 .58953 .31965 .58981 .31524 .58436 Mtetra
.489 .672 .945 r
.31524 .58436 .31965 .58981 .32646 .58995 .32206 .58445 Mtetra
.502 .676 .943 r
.32206 .58445 .32646 .58995 .33331 .58994 .32892 .58439 Mtetra
.517 .68 .94 r
.32892 .58439 .33331 .58994 .34019 .58974 .33581 .58414 Mtetra
.532 .685 .936 r
.33581 .58414 .34019 .58974 .34711 .58933 .34274 .58368 Mtetra
.548 .69 .932 r
.34274 .58368 .34711 .58933 .35407 .5887 .34971 .58299 Mtetra
.565 .694 .928 r
.34971 .58299 .35407 .5887 .36106 .58781 .35671 .58204 Mtetra
.582 .699 .922 r
.35671 .58204 .36106 .58781 .36809 .58664 .36375 .58082 Mtetra
.599 .703 .917 r
.36375 .58082 .36809 .58664 .37515 .58517 .37083 .57928 Mtetra
.616 .708 .91 r
.37083 .57928 .37515 .58517 .38225 .58335 .37794 .5774 Mtetra
.634 .712 .903 r
.37794 .5774 .38225 .58335 .38939 .58118 .38508 .57515 Mtetra
.651 .715 .895 r
.38508 .57515 .38939 .58118 .39655 .5786 .39227 .57251 Mtetra
.667 .719 .887 r
.39227 .57251 .39655 .5786 .40376 .5756 .39948 .56943 Mtetra
.684 .721 .878 r
.39948 .56943 .40376 .5756 .41099 .57213 .40672 .56588 Mtetra
.7 .724 .869 r
.40672 .56588 .41099 .57213 .41825 .56816 .414 .56183 Mtetra
.715 .726 .859 r
.414 .56183 .41825 .56816 .42554 .56365 .42131 .55723 Mtetra
.73 .728 .848 r
.42131 .55723 .42554 .56365 .43286 .55856 .42864 .55205 Mtetra
.744 .729 .837 r
.42864 .55205 .43286 .55856 .4402 .55285 .436 .54624 Mtetra
.758 .73 .826 r
.436 .54624 .4402 .55285 .44757 .54647 .44338 .53976 Mtetra
.771 .73 .815 r
.44338 .53976 .44757 .54647 .45496 .53937 .45078 .53255 Mtetra
.783 .73 .803 r
.45078 .53255 .45496 .53937 .46236 .53149 .4582 .52456 Mtetra
.795 .73 .792 r
.4582 .52456 .46236 .53149 .46977 .52275 .46564 .51572 Mtetra
.807 .73 .78 r
.46564 .51572 .46977 .52275 .4772 .51309 .47308 .50597 Mtetra
.818 .73 .768 r
.47308 .50597 .4772 .51309 .48463 .50239 .48053 .4952 Mtetra
.226 .455 .871 r
.62403 .43631 .62793 .44381 .6359 .44844 .632 .44097 Mtetra
.303 .503 .887 r
.632 .44097 .6359 .44844 .64389 .45204 .64 .44462 Mtetra
.365 .542 .896 r
.64 .44462 .64389 .45204 .65191 .4547 .64802 .44736 Mtetra
.418 .575 .902 r
.64802 .44736 .65191 .4547 .65994 .45652 .65606 .44925 Mtetra
.464 .603 .905 r
.65606 .44925 .65994 .45652 .66798 .45755 .66412 .45036 Mtetra
.503 .626 .905 r
.66412 .45036 .66798 .45755 .67603 .45786 .67219 .45074 Mtetra
.537 .646 .904 r
.67219 .45074 .67603 .45786 .6841 .45749 .68026 .45044 Mtetra
.567 .663 .903 r
.68026 .45044 .6841 .45749 .69217 .45649 .68835 .4495 Mtetra
.593 .678 .9 r
.68835 .4495 .69217 .45649 .70025 .45491 .69644 .44797 Mtetra
.616 .691 .897 r
.69644 .44797 .70025 .45491 .70833 .45277 .70454 .44589 Mtetra
.636 .702 .894 r
.70454 .44589 .70833 .45277 .71641 .45012 .71264 .44329 Mtetra
.654 .712 .89 r
.71264 .44329 .71641 .45012 .7245 .447 .72075 .44021 Mtetra
.67 .72 .887 r
.72075 .44021 .7245 .447 .73259 .44344 .72885 .43669 Mtetra
.684 .727 .883 r
.72885 .43669 .73259 .44344 .74068 .43946 .73696 .43275 Mtetra
.696 .734 .88 r
.73696 .43275 .74068 .43946 .74876 .4351 .74506 .42843 Mtetra
.707 .74 .877 r
.74506 .42843 .74876 .4351 .75685 .4304 .75316 .42375 Mtetra
.717 .745 .874 r
.75316 .42375 .75685 .4304 .76493 .42537 .76127 .41875 Mtetra
.726 .75 .871 r
.76127 .41875 .76493 .42537 .77301 .42004 .76937 .41345 Mtetra
.734 .754 .868 r
.76937 .41345 .77301 .42004 .78109 .41445 .77746 .40788 Mtetra
.741 .758 .866 r
.77746 .40788 .78109 .41445 .78916 .40861 .78556 .40207 Mtetra
.747 .761 .864 r
.78556 .40207 .78916 .40861 .79723 .40254 .79365 .39603 Mtetra
.752 .764 .862 r
.79365 .39603 .79723 .40254 .8053 .39629 .80174 .38979 Mtetra
.757 .767 .861 r
.80174 .38979 .8053 .39629 .81337 .38985 .80984 .38337 Mtetra
.761 .769 .86 r
.80984 .38337 .81337 .38985 .82144 .38327 .81793 .37681 Mtetra
.765 .772 .859 r
.81793 .37681 .82144 .38327 .82951 .37656 .82602 .37011 Mtetra
.768 .774 .858 r
.82602 .37011 .82951 .37656 .83758 .36974 .83411 .36331 Mtetra
.77 .776 .858 r
.83411 .36331 .83758 .36974 .84566 .36283 .84221 .35641 Mtetra
.772 .778 .858 r
.84221 .35641 .84566 .36283 .85373 .35586 .8503 .34945 Mtetra
.773 .779 .858 r
.8503 .34945 .85373 .35586 .86181 .34884 .85841 .34245 Mtetra
.774 .781 .858 r
.85841 .34245 .86181 .34884 .8699 .34179 .86652 .33541 Mtetra
.435 .659 .955 r
.26394 .57585 .26843 .58101 .27502 .58163 .27054 .57643 Mtetra
.438 .659 .954 r
.27054 .57643 .27502 .58163 .28164 .58224 .27718 .577 Mtetra
.442 .66 .953 r
.27718 .577 .28164 .58224 .2883 .58282 .28384 .57754 Mtetra
.449 .661 .952 r
.28384 .57754 .2883 .58282 .29498 .58333 .29053 .57801 Mtetra
.457 .664 .951 r
.29053 .57801 .29498 .58333 .3017 .58378 .29726 .57842 Mtetra
.467 .667 .95 r
.29726 .57842 .3017 .58378 .30846 .58413 .30402 .57873 Mtetra
.478 .67 .948 r
.30402 .57873 .30846 .58413 .31524 .58436 .31081 .57891 Mtetra
.49 .674 .946 r
.31081 .57891 .31524 .58436 .32206 .58445 .31765 .57896 Mtetra
.504 .678 .944 r
.31765 .57896 .32206 .58445 .32892 .58439 .32451 .57885 Mtetra
.518 .683 .941 r
.32451 .57885 .32892 .58439 .33581 .58414 .33141 .57856 Mtetra
.534 .688 .938 r
.33141 .57856 .33581 .58414 .34274 .58368 .33835 .57805 Mtetra
.55 .693 .934 r
.33835 .57805 .34274 .58368 .34971 .58299 .34533 .57732 Mtetra
.567 .697 .929 r
.34533 .57732 .34971 .58299 .35671 .58204 .35234 .57632 Mtetra
.584 .702 .924 r
.35234 .57632 .35671 .58204 .36375 .58082 .35939 .57504 Mtetra
.601 .707 .918 r
.35939 .57504 .36375 .58082 .37083 .57928 .36648 .57345 Mtetra
.618 .711 .912 r
.36648 .57345 .37083 .57928 .37794 .5774 .3736 .57151 Mtetra
.636 .716 .905 r
.3736 .57151 .37794 .5774 .38508 .57515 .38076 .5692 Mtetra
.653 .719 .897 r
.38076 .5692 .38508 .57515 .39227 .57251 .38795 .56649 Mtetra
.67 .723 .889 r
.38795 .56649 .39227 .57251 .39948 .56943 .39518 .56334 Mtetra
.686 .726 .88 r
.39518 .56334 .39948 .56943 .40672 .56588 .40244 .55973 Mtetra
.702 .729 .871 r
.40244 .55973 .40672 .56588 .414 .56183 .40973 .5556 Mtetra
.718 .731 .861 r
.40973 .5556 .414 .56183 .42131 .55723 .41705 .55092 Mtetra
.733 .733 .85 r
.41705 .55092 .42131 .55723 .42864 .55205 .4244 .54566 Mtetra
.748 .734 .84 r
.4244 .54566 .42864 .55205 .436 .54624 .43177 .53977 Mtetra
.761 .735 .828 r
.43177 .53977 .436 .54624 .44338 .53976 .43917 .53319 Mtetra
.774 .736 .817 r
.43917 .53319 .44338 .53976 .45078 .53255 .44659 .52589 Mtetra
.787 .736 .806 r
.44659 .52589 .45078 .53255 .4582 .52456 .45402 .51781 Mtetra
.799 .736 .794 r
.45402 .51781 .4582 .52456 .46564 .51572 .46148 .50889 Mtetra
.81 .736 .782 r
.46148 .50889 .46564 .51572 .47308 .50597 .46894 .49907 Mtetra
.822 .737 .771 r
.46894 .49907 .47308 .50597 .48053 .4952 .47641 .48827 Mtetra
.208 .454 .875 r
.62011 .42907 .62403 .43631 .632 .44097 .62809 .43372 Mtetra
.286 .503 .891 r
.62809 .43372 .632 .44097 .64 .44462 .6361 .43741 Mtetra
.352 .543 .901 r
.6361 .43741 .64 .44462 .64802 .44736 .64413 .4402 Mtetra
.407 .576 .907 r
.64413 .4402 .64802 .44736 .65606 .44925 .65218 .44215 Mtetra
.455 .605 .91 r
.65218 .44215 .65606 .44925 .66412 .45036 .66025 .44332 Mtetra
.496 .629 .911 r
.66025 .44332 .66412 .45036 .67219 .45074 .66833 .44376 Mtetra
.531 .649 .91 r
.66833 .44376 .67219 .45074 .68026 .45044 .67642 .44351 Mtetra
.562 .667 .908 r
.67642 .44351 .68026 .45044 .68835 .4495 .68452 .44263 Mtetra
.589 .682 .905 r
.68452 .44263 .68835 .4495 .69644 .44797 .69263 .44115 Mtetra
.613 .694 .901 r
.69263 .44115 .69644 .44797 .70454 .44589 .70074 .43911 Mtetra
.634 .705 .898 r
.70074 .43911 .70454 .44589 .71264 .44329 .70886 .43655 Mtetra
.652 .715 .894 r
.70886 .43655 .71264 .44329 .72075 .44021 .71698 .4335 Mtetra
.668 .723 .89 r
.71698 .4335 .72075 .44021 .72885 .43669 .7251 .43001 Mtetra
.683 .73 .886 r
.7251 .43001 .72885 .43669 .73696 .43275 .73322 .4261 Mtetra
.695 .737 .883 r
.73322 .4261 .73696 .43275 .74506 .42843 .74135 .42181 Mtetra
.707 .742 .879 r
.74135 .42181 .74506 .42843 .75316 .42375 .74947 .41716 Mtetra
.717 .747 .876 r
.74947 .41716 .75316 .42375 .76127 .41875 .75759 .41218 Mtetra
.725 .752 .873 r
.75759 .41218 .76127 .41875 .76937 .41345 .76571 .4069 Mtetra
.733 .756 .871 r
.76571 .4069 .76937 .41345 .77746 .40788 .77383 .40135 Mtetra
.74 .759 .868 r
.77383 .40135 .77746 .40788 .78556 .40207 .78194 .39555 Mtetra
.746 .763 .866 r
.78194 .39555 .78556 .40207 .79365 .39603 .79006 .38952 Mtetra
.752 .766 .864 r
.79006 .38952 .79365 .39603 .80174 .38979 .79817 .3833 Mtetra
.757 .768 .862 r
.79817 .3833 .80174 .38979 .80984 .38337 .80628 .3769 Mtetra
.761 .771 .861 r
.80628 .3769 .80984 .38337 .81793 .37681 .81439 .37034 Mtetra
.764 .773 .86 r
.81439 .37034 .81793 .37681 .82602 .37011 .82251 .36366 Mtetra
.767 .775 .859 r
.82251 .36366 .82602 .37011 .83411 .36331 .83062 .35686 Mtetra
.769 .776 .859 r
.83062 .35686 .83411 .36331 .84221 .35641 .83874 .34998 Mtetra
.771 .778 .858 r
.83874 .34998 .84221 .35641 .8503 .34945 .84686 .34303 Mtetra
.773 .779 .859 r
.84686 .34303 .8503 .34945 .85841 .34245 .85499 .33603 Mtetra
.773 .781 .859 r
.85499 .33603 .85841 .34245 .86652 .33541 .86312 .32901 Mtetra
.437 .66 .955 r
.25943 .57066 .26394 .57585 .27054 .57643 .26604 .57121 Mtetra
.44 .66 .954 r
.26604 .57121 .27054 .57643 .27718 .577 .27268 .57175 Mtetra
.444 .661 .953 r
.27268 .57175 .27718 .577 .28384 .57754 .27935 .57225 Mtetra
.451 .663 .952 r
.27935 .57225 .28384 .57754 .29053 .57801 .28606 .57269 Mtetra
.459 .665 .951 r
.28606 .57269 .29053 .57801 .29726 .57842 .29279 .57306 Mtetra
.468 .668 .95 r
.29279 .57306 .29726 .57842 .30402 .57873 .29956 .57333 Mtetra
.479 .672 .949 r
.29956 .57333 .30402 .57873 .31081 .57891 .30636 .57348 Mtetra
.491 .676 .947 r
.30636 .57348 .31081 .57891 .31765 .57896 .3132 .57349 Mtetra
.505 .68 .945 r
.3132 .57349 .31765 .57896 .32451 .57885 .32008 .57334 Mtetra
.519 .685 .942 r
.32008 .57334 .32451 .57885 .33141 .57856 .32699 .573 Mtetra
.535 .69 .939 r
.32699 .573 .33141 .57856 .33835 .57805 .33394 .57246 Mtetra
.551 .695 .935 r
.33394 .57246 .33835 .57805 .34533 .57732 .34093 .57168 Mtetra
.568 .7 .931 r
.34093 .57168 .34533 .57732 .35234 .57632 .34795 .57064 Mtetra
.585 .705 .926 r
.34795 .57064 .35234 .57632 .35939 .57504 .35501 .56931 Mtetra
.602 .71 .92 r
.35501 .56931 .35939 .57504 .36648 .57345 .36211 .56767 Mtetra
.62 .715 .914 r
.36211 .56767 .36648 .57345 .3736 .57151 .36924 .56568 Mtetra
.637 .719 .907 r
.36924 .56568 .3736 .57151 .38076 .5692 .37641 .56332 Mtetra
.655 .723 .899 r
.37641 .56332 .38076 .5692 .38795 .56649 .38362 .56056 Mtetra
.672 .727 .891 r
.38362 .56056 .38795 .56649 .39518 .56334 .39086 .55735 Mtetra
.689 .73 .882 r
.39086 .55735 .39518 .56334 .40244 .55973 .39813 .55367 Mtetra
.705 .733 .873 r
.39813 .55367 .40244 .55973 .40973 .5556 .40543 .54948 Mtetra
.721 .736 .863 r
.40543 .54948 .40973 .5556 .41705 .55092 .41277 .54473 Mtetra
.736 .738 .853 r
.41277 .54473 .41705 .55092 .4244 .54566 .42013 .5394 Mtetra
.751 .739 .842 r
.42013 .5394 .4244 .54566 .43177 .53977 .42752 .53343 Mtetra
.764 .74 .831 r
.42752 .53343 .43177 .53977 .43917 .53319 .43493 .52678 Mtetra
.778 .741 .819 r
.43493 .52678 .43917 .53319 .44659 .52589 .44237 .5194 Mtetra
.79 .742 .808 r
.44237 .5194 .44659 .52589 .45402 .51781 .44982 .51124 Mtetra
.802 .742 .796 r
.44982 .51124 .45402 .51781 .46148 .50889 .45729 .50225 Mtetra
.814 .742 .785 r
.45729 .50225 .46148 .50889 .46894 .49907 .46477 .49238 Mtetra
.271 .503 .895 r
.62417 .42669 .62809 .43372 .6361 .43741 .63219 .43039 Mtetra
.338 .544 .906 r
.63219 .43039 .6361 .43741 .64413 .4402 .64023 .43322 Mtetra
.396 .578 .913 r
.64023 .43322 .64413 .4402 .65218 .44215 .64828 .43521 Mtetra
.446 .607 .916 r
.64828 .43521 .65218 .44215 .66025 .44332 .65636 .43643 Mtetra
.488 .632 .916 r
.65636 .43643 .66025 .44332 .66833 .44376 .66445 .43691 Mtetra
.525 .653 .915 r
.66445 .43691 .66833 .44376 .67642 .44351 .67256 .43671 Mtetra
.558 .67 .913 r
.67256 .43671 .67642 .44351 .68452 .44263 .68067 .43587 Mtetra
.586 .685 .91 r
.68067 .43587 .68452 .44263 .69263 .44115 .6888 .43442 Mtetra
.61 .698 .906 r
.6888 .43442 .69263 .44115 .70074 .43911 .69693 .43242 Mtetra
.632 .709 .902 r
.69693 .43242 .70074 .43911 .70886 .43655 .70506 .42989 Mtetra
.65 .718 .898 r
.70506 .42989 .70886 .43655 .71698 .4335 .7132 .42687 Mtetra
.667 .726 .894 r
.7132 .42687 .71698 .4335 .7251 .43001 .72134 .4234 Mtetra
.682 .733 .89 r
.72134 .4234 .7251 .43001 .73322 .4261 .72948 .41952 Mtetra
.695 .74 .886 r
.72948 .41952 .73322 .4261 .74135 .42181 .73762 .41524 Mtetra
.706 .745 .882 r
.73762 .41524 .74135 .42181 .74947 .41716 .74576 .41061 Mtetra
.716 .75 .879 r
.74576 .41061 .74947 .41716 .75759 .41218 .7539 .40564 Mtetra
.725 .754 .875 r
.7539 .40564 .75759 .41218 .76571 .4069 .76204 .40038 Mtetra
.733 .758 .873 r
.76204 .40038 .76571 .4069 .77383 .40135 .77018 .39484 Mtetra
.74 .761 .87 r
.77018 .39484 .77383 .40135 .78194 .39555 .77831 .38905 Mtetra
.746 .764 .868 r
.77831 .38905 .78194 .39555 .79006 .38952 .78645 .38303 Mtetra
.752 .767 .865 r
.78645 .38303 .79006 .38952 .79817 .3833 .79458 .37681 Mtetra
.756 .769 .864 r
.79458 .37681 .79817 .3833 .80628 .3769 .80271 .37042 Mtetra
.76 .772 .862 r
.80271 .37042 .80628 .3769 .81439 .37034 .81085 .36387 Mtetra
.764 .774 .861 r
.81085 .36387 .81439 .37034 .82251 .36366 .81898 .35719 Mtetra
.767 .775 .86 r
.81898 .35719 .82251 .36366 .83062 .35686 .82712 .3504 Mtetra
.769 .777 .859 r
.82712 .3504 .83062 .35686 .83874 .34998 .83526 .34352 Mtetra
.771 .778 .859 r
.83526 .34352 .83874 .34998 .84686 .34303 .8434 .33658 Mtetra
.772 .78 .859 r
.8434 .33658 .84686 .34303 .85499 .33603 .85155 .32958 Mtetra
.773 .781 .859 r
.85155 .32958 .85499 .33603 .86312 .32901 .8597 .32256 Mtetra
.439 .661 .955 r
.25491 .56545 .25943 .57066 .26604 .57121 .26152 .56597 Mtetra
.442 .661 .954 r
.26152 .56597 .26604 .57121 .27268 .57175 .26817 .56647 Mtetra
.446 .662 .954 r
.26817 .56647 .27268 .57175 .27935 .57225 .27485 .56694 Mtetra
.452 .664 .953 r
.27485 .56694 .27935 .57225 .28606 .57269 .28156 .56736 Mtetra
.46 .667 .952 r
.28156 .56736 .28606 .57269 .29279 .57306 .2883 .56769 Mtetra
.469 .67 .951 r
.2883 .56769 .29279 .57306 .29956 .57333 .29508 .56793 Mtetra
.48 .673 .949 r
.29508 .56793 .29956 .57333 .30636 .57348 .30189 .56805 Mtetra
.492 .678 .948 r
.30189 .56805 .30636 .57348 .3132 .57349 .30874 .56803 Mtetra
.506 .682 .946 r
.30874 .56803 .3132 .57349 .32008 .57334 .31562 .56785 Mtetra
.52 .687 .943 r
.31562 .56785 .32008 .57334 .32699 .573 .32254 .56748 Mtetra
.535 .693 .94 r
.32254 .56748 .32699 .573 .33394 .57246 .3295 .5669 Mtetra
.552 .698 .937 r
.3295 .5669 .33394 .57246 .34093 .57168 .3365 .56608 Mtetra
.568 .703 .933 r
.3365 .56608 .34093 .57168 .34795 .57064 .34353 .565 Mtetra
.586 .708 .928 r
.34353 .565 .34795 .57064 .35501 .56931 .3506 .56363 Mtetra
.603 .714 .922 r
.3506 .56363 .35501 .56931 .36211 .56767 .35771 .56195 Mtetra
.621 .719 .916 r
.35771 .56195 .36211 .56767 .36924 .56568 .36486 .55992 Mtetra
.638 .723 .909 r
.36486 .55992 .36924 .56568 .37641 .56332 .37204 .55751 Mtetra
.656 .728 .902 r
.37204 .55751 .37641 .56332 .38362 .56056 .37926 .5547 Mtetra
.673 .731 .894 r
.37926 .5547 .38362 .56056 .39086 .55735 .38651 .55144 Mtetra
.69 .735 .885 r
.38651 .55144 .39086 .55735 .39813 .55367 .39379 .54771 Mtetra
.707 .738 .875 r
.39379 .54771 .39813 .55367 .40543 .54948 .40111 .54346 Mtetra
.723 .741 .866 r
.40111 .54346 .40543 .54948 .41277 .54473 .40846 .53866 Mtetra
.738 .743 .855 r
.40846 .53866 .41277 .54473 .42013 .5394 .41584 .53327 Mtetra
.753 .744 .844 r
.41584 .53327 .42013 .5394 .42752 .53343 .42325 .52723 Mtetra
.767 .746 .833 r
.42325 .52723 .42752 .53343 .43493 .52678 .43068 .52051 Mtetra
.781 .747 .822 r
.43068 .52051 .43493 .52678 .44237 .5194 .43813 .51307 Mtetra
.794 .747 .81 r
.43813 .51307 .44237 .5194 .44982 .51124 .4456 .50484 Mtetra
.806 .748 .799 r
.4456 .50484 .44982 .51124 .45729 .50225 .45309 .4958 Mtetra
.817 .748 .787 r
.45309 .4958 .45729 .50225 .46477 .49238 .46059 .4859 Mtetra
.257 .503 .899 r
.62024 .41987 .62417 .42669 .63219 .43039 .62826 .42357 Mtetra
.326 .545 .911 r
.62826 .42357 .63219 .43039 .64023 .43322 .63631 .42641 Mtetra
.385 .58 .918 r
.63631 .42641 .64023 .43322 .64828 .43521 .64438 .42844 Mtetra
.437 .61 .921 r
.64438 .42844 .64828 .43521 .65636 .43643 .65247 .42969 Mtetra
.482 .635 .922 r
.65247 .42969 .65636 .43643 .66445 .43691 .66057 .43021 Mtetra
.52 .656 .921 r
.66057 .43021 .66445 .43691 .67256 .43671 .66869 .43004 Mtetra
.554 .674 .918 r
.66869 .43004 .67256 .43671 .68067 .43587 .67682 .42922 Mtetra
.583 .689 .915 r
.67682 .42922 .68067 .43587 .6888 .43442 .68495 .4278 Mtetra
.608 .702 .91 r
.68495 .4278 .6888 .43442 .69693 .43242 .6931 .42582 Mtetra
.63 .713 .906 r
.6931 .42582 .69693 .43242 .70506 .42989 .70125 .42331 Mtetra
.649 .722 .902 r
.70125 .42331 .70506 .42989 .7132 .42687 .7094 .42032 Mtetra
.666 .73 .897 r
.7094 .42032 .7132 .42687 .72134 .4234 .71756 .41686 Mtetra
.681 .737 .893 r
.71756 .41686 .72134 .4234 .72948 .41952 .72572 .41299 Mtetra
.694 .743 .889 r
.72572 .41299 .72948 .41952 .73762 .41524 .73388 .40873 Mtetra
.706 .748 .885 r
.73388 .40873 .73762 .41524 .74576 .41061 .74204 .4041 Mtetra
.716 .752 .881 r
.74204 .4041 .74576 .41061 .7539 .40564 .75019 .39915 Mtetra
.725 .756 .878 r
.75019 .39915 .7539 .40564 .76204 .40038 .75835 .39389 Mtetra
.733 .76 .875 r
.75835 .39389 .76204 .40038 .77018 .39484 .76651 .38835 Mtetra
.74 .763 .872 r
.76651 .38835 .77018 .39484 .77831 .38905 .77466 .38257 Mtetra
.746 .766 .869 r
.77466 .38257 .77831 .38905 .78645 .38303 .78282 .37655 Mtetra
.751 .769 .867 r
.78282 .37655 .78645 .38303 .79458 .37681 .79097 .37034 Mtetra
.756 .771 .865 r
.79097 .37034 .79458 .37681 .80271 .37042 .79913 .36395 Mtetra
.76 .773 .863 r
.79913 .36395 .80271 .37042 .81085 .36387 .80728 .3574 Mtetra
.764 .775 .862 r
.80728 .3574 .81085 .36387 .81898 .35719 .81544 .35072 Mtetra
.766 .776 .861 r
.81544 .35072 .81898 .35719 .82712 .3504 .82359 .34393 Mtetra
.769 .778 .86 r
.82359 .34393 .82712 .3504 .83526 .34352 .83175 .33705 Mtetra
.77 .779 .86 r
.83175 .33705 .83526 .34352 .8434 .33658 .83992 .3301 Mtetra
.772 .78 .86 r
.83992 .3301 .8434 .33658 .85155 .32958 .84809 .32311 Mtetra
.772 .781 .86 r
.84809 .32311 .85155 .32958 .8597 .32256 .85626 .31608 Mtetra
.44 .661 .955 r
.25035 .56021 .25491 .56545 .26152 .56597 .25698 .56071 Mtetra
.443 .662 .954 r
.25698 .56071 .26152 .56597 .26817 .56647 .26363 .56119 Mtetra
.447 .663 .954 r
.26363 .56119 .26817 .56647 .27485 .56694 .27032 .56163 Mtetra
.453 .665 .953 r
.27032 .56163 .27485 .56694 .28156 .56736 .27704 .56202 Mtetra
.461 .668 .952 r
.27704 .56202 .28156 .56736 .2883 .56769 .28379 .56233 Mtetra
.47 .671 .951 r
.28379 .56233 .2883 .56769 .29508 .56793 .29057 .56254 Mtetra
.48 .675 .95 r
.29057 .56254 .29508 .56793 .30189 .56805 .29739 .56264 Mtetra
.493 .679 .949 r
.29739 .56264 .30189 .56805 .30874 .56803 .30425 .56259 Mtetra
.506 .684 .947 r
.30425 .56259 .30874 .56803 .31562 .56785 .31114 .56238 Mtetra
.52 .689 .945 r
.31114 .56238 .31562 .56785 .32254 .56748 .31807 .56198 Mtetra
.536 .695 .942 r
.31807 .56198 .32254 .56748 .3295 .5669 .32504 .56136 Mtetra
.552 .7 .938 r
.32504 .56136 .3295 .5669 .3365 .56608 .33205 .56052 Mtetra
.569 .706 .934 r
.33205 .56052 .3365 .56608 .34353 .565 .33909 .55941 Mtetra
.586 .711 .93 r
.33909 .55941 .34353 .565 .3506 .56363 .34617 .558 Mtetra
.604 .717 .924 r
.34617 .558 .3506 .56363 .35771 .56195 .35329 .55629 Mtetra
.621 .722 .918 r
.35329 .55629 .35771 .56195 .36486 .55992 .36045 .55422 Mtetra
.639 .727 .912 r
.36045 .55422 .36486 .55992 .37204 .55751 .36764 .55178 Mtetra
.657 .731 .904 r
.36764 .55178 .37204 .55751 .37926 .5547 .37487 .54892 Mtetra
.675 .736 .896 r
.37487 .54892 .37926 .5547 .38651 .55144 .38213 .54563 Mtetra
.692 .739 .887 r
.38213 .54563 .38651 .55144 .39379 .54771 .38943 .54185 Mtetra
.709 .743 .878 r
.38943 .54185 .39379 .54771 .40111 .54346 .39677 .53756 Mtetra
.725 .746 .868 r
.39677 .53756 .40111 .54346 .40846 .53866 .40413 .53271 Mtetra
.741 .748 .858 r
.40413 .53271 .40846 .53866 .41584 .53327 .41152 .52726 Mtetra
.756 .75 .847 r
.41152 .52726 .41584 .53327 .42325 .52723 .41895 .52117 Mtetra
.77 .751 .836 r
.41895 .52117 .42325 .52723 .43068 .52051 .42639 .5144 Mtetra
.784 .752 .824 r
.42639 .5144 .43068 .52051 .43813 .51307 .43386 .5069 Mtetra
.797 .753 .813 r
.43386 .5069 .43813 .51307 .4456 .50484 .44135 .49863 Mtetra
.809 .753 .801 r
.44135 .49863 .4456 .50484 .45309 .4958 .44886 .48954 Mtetra
.82 .754 .79 r
.44886 .48954 .45309 .4958 .46059 .4859 .45638 .47961 Mtetra
.243 .504 .902 r
.6163 .41324 .62024 .41987 .62826 .42357 .62432 .41693 Mtetra
.313 .546 .915 r
.62432 .41693 .62826 .42357 .63631 .42641 .63238 .41979 Mtetra
.375 .582 .923 r
.63238 .41979 .63631 .42641 .64438 .42844 .64046 .42183 Mtetra
.429 .613 .927 r
.64046 .42183 .64438 .42844 .65247 .42969 .64856 .4231 Mtetra
.475 .639 .927 r
.64856 .4231 .65247 .42969 .66057 .43021 .65667 .42364 Mtetra
.515 .66 .926 r
.65667 .42364 .66057 .43021 .66869 .43004 .6648 .42349 Mtetra
.55 .678 .923 r
.6648 .42349 .66869 .43004 .67682 .42922 .67295 .42269 Mtetra
.58 .693 .919 r
.67295 .42269 .67682 .42922 .68495 .4278 .6811 .42129 Mtetra
.606 .706 .915 r
.6811 .42129 .68495 .4278 .6931 .42582 .68926 .41932 Mtetra
.628 .717 .91 r
.68926 .41932 .6931 .42582 .70125 .42331 .69742 .41683 Mtetra
.648 .726 .905 r
.69742 .41683 .70125 .42331 .7094 .42032 .70559 .41384 Mtetra
.665 .733 .901 r
.70559 .41384 .7094 .42032 .71756 .41686 .71377 .41039 Mtetra
.68 .74 .896 r
.71377 .41039 .71756 .41686 .72572 .41299 .72194 .40653 Mtetra
.694 .746 .891 r
.72194 .40653 .72572 .41299 .73388 .40873 .73012 .40227 Mtetra
.705 .751 .887 r
.73012 .40227 .73388 .40873 .74204 .4041 .7383 .39764 Mtetra
.716 .755 .883 r
.7383 .39764 .74204 .4041 .75019 .39915 .74647 .39269 Mtetra
.725 .759 .88 r
.74647 .39269 .75019 .39915 .75835 .39389 .75465 .38743 Mtetra
.733 .762 .876 r
.75465 .38743 .75835 .39389 .76651 .38835 .76283 .38189 Mtetra
.74 .765 .873 r
.76283 .38189 .76651 .38835 .77466 .38257 .771 .37611 Mtetra
.746 .768 .871 r
.771 .37611 .77466 .38257 .78282 .37655 .77918 .37009 Mtetra
.751 .77 .868 r
.77918 .37009 .78282 .37655 .79097 .37034 .78735 .36387 Mtetra
.756 .772 .866 r
.78735 .36387 .79097 .37034 .79913 .36395 .79552 .35748 Mtetra
.76 .774 .864 r
.79552 .35748 .79913 .36395 .80728 .3574 .8037 .35092 Mtetra
.764 .776 .863 r
.8037 .35092 .80728 .3574 .81544 .35072 .81188 .34424 Mtetra
.766 .777 .862 r
.81188 .34424 .81544 .35072 .82359 .34393 .82005 .33744 Mtetra
.769 .778 .861 r
.82005 .33744 .82359 .34393 .83175 .33705 .82823 .33056 Mtetra
.77 .779 .86 r
.82823 .33056 .83175 .33705 .83992 .3301 .83642 .3236 Mtetra
.771 .78 .86 r
.83642 .3236 .83992 .3301 .84809 .32311 .84461 .3166 Mtetra
.772 .781 .86 r
.84461 .3166 .84809 .32311 .85626 .31608 .85281 .30957 Mtetra
.441 .662 .955 r
.24578 .55495 .25035 .56021 .25698 .56071 .25241 .55542 Mtetra
.444 .662 .954 r
.25241 .55542 .25698 .56071 .26363 .56119 .25908 .55588 Mtetra
.448 .664 .954 r
.25908 .55588 .26363 .56119 .27032 .56163 .26577 .55631 Mtetra
.453 .666 .954 r
.26577 .55631 .27032 .56163 .27704 .56202 .27249 .55667 Mtetra
.461 .669 .953 r
.27249 .55667 .27704 .56202 .28379 .56233 .27925 .55696 Mtetra
.47 .672 .952 r
.27925 .55696 .28379 .56233 .29057 .56254 .28604 .55716 Mtetra
.48 .676 .951 r
.28604 .55716 .29057 .56254 .29739 .56264 .29287 .55723 Mtetra
.492 .681 .95 r
.29287 .55723 .29739 .56264 .30425 .56259 .29974 .55716 Mtetra
.506 .686 .948 r
.29974 .55716 .30425 .56259 .31114 .56238 .30664 .55692 Mtetra
.52 .691 .946 r
.30664 .55692 .31114 .56238 .31807 .56198 .31358 .5565 Mtetra
.535 .697 .943 r
.31358 .5565 .31807 .56198 .32504 .56136 .32055 .55586 Mtetra
.552 .703 .94 r
.32055 .55586 .32504 .56136 .33205 .56052 .32757 .55499 Mtetra
.569 .709 .936 r
.32757 .55499 .33205 .56052 .33909 .55941 .33462 .55386 Mtetra
.586 .714 .932 r
.33462 .55386 .33909 .55941 .34617 .558 .34171 .55243 Mtetra
.604 .72 .927 r
.34171 .55243 .34617 .558 .35329 .55629 .34884 .55068 Mtetra
.622 .725 .921 r
.34884 .55068 .35329 .55629 .36045 .55422 .35601 .54859 Mtetra
.64 .731 .914 r
.35601 .54859 .36045 .55422 .36764 .55178 .36322 .54611 Mtetra
.658 .735 .907 r
.36322 .54611 .36764 .55178 .37487 .54892 .37046 .54323 Mtetra
.676 .74 .899 r
.37046 .54323 .37487 .54892 .38213 .54563 .37774 .5399 Mtetra
.693 .744 .89 r
.37774 .5399 .38213 .54563 .38943 .54185 .38505 .53609 Mtetra
.71 .747 .881 r
.38505 .53609 .38943 .54185 .39677 .53756 .3924 .53176 Mtetra
.727 .75 .871 r
.3924 .53176 .39677 .53756 .40413 .53271 .39977 .52687 Mtetra
.743 .753 .861 r
.39977 .52687 .40413 .53271 .41152 .52726 .40718 .52139 Mtetra
.758 .755 .85 r
.40718 .52139 .41152 .52726 .41895 .52117 .41462 .51526 Mtetra
.773 .757 .839 r
.41462 .51526 .41895 .52117 .42639 .5144 .42209 .50844 Mtetra
.787 .758 .827 r
.42209 .50844 .42639 .5144 .43386 .5069 .42957 .5009 Mtetra
.8 .759 .815 r
.42957 .5009 .43386 .5069 .44135 .49863 .43708 .49259 Mtetra
.812 .759 .804 r
.43708 .49259 .44135 .49863 .44886 .48954 .44461 .48347 Mtetra
.823 .76 .793 r
.44461 .48347 .44886 .48954 .45638 .47961 .45215 .47352 Mtetra
.229 .504 .905 r
.61234 .40679 .6163 .41324 .62432 .41693 .62037 .41048 Mtetra
.301 .547 .919 r
.62037 .41048 .62432 .41693 .63238 .41979 .62843 .41333 Mtetra
.365 .585 .928 r
.62843 .41333 .63238 .41979 .64046 .42183 .63652 .41539 Mtetra
.421 .616 .932 r
.63652 .41539 .64046 .42183 .64856 .4231 .64463 .41667 Mtetra
.469 .643 .933 r
.64463 .41667 .64856 .4231 .65667 .42364 .65276 .41722 Mtetra
.51 .664 .931 r
.65276 .41722 .65667 .42364 .6648 .42349 .66091 .41708 Mtetra
.546 .683 .928 r
.66091 .41708 .6648 .42349 .67295 .42269 .66906 .41628 Mtetra
.577 .698 .924 r
.66906 .41628 .67295 .42269 .6811 .42129 .67723 .41489 Mtetra
.604 .71 .919 r
.67723 .41489 .6811 .42129 .68926 .41932 .6854 .41292 Mtetra
.627 .721 .914 r
.6854 .41292 .68926 .41932 .69742 .41683 .69358 .41043 Mtetra
.647 .73 .909 r
.69358 .41043 .69742 .41683 .70559 .41384 .70177 .40744 Mtetra
.665 .737 .904 r
.70177 .40744 .70559 .41384 .71377 .41039 .70996 .40399 Mtetra
.68 .744 .899 r
.70996 .40399 .71377 .41039 .72194 .40653 .71815 .40012 Mtetra
.694 .749 .894 r
.71815 .40012 .72194 .40653 .73012 .40227 .72635 .39586 Mtetra
.705 .754 .89 r
.72635 .39586 .73012 .40227 .7383 .39764 .73454 .39123 Mtetra
.716 .758 .886 r
.73454 .39123 .7383 .39764 .74647 .39269 .74274 .38627 Mtetra
.725 .762 .882 r
.74274 .38627 .74647 .39269 .75465 .38743 .75093 .38101 Mtetra
.733 .765 .878 r
.75093 .38101 .75465 .38743 .76283 .38189 .75913 .37546 Mtetra
.74 .767 .875 r
.75913 .37546 .76283 .38189 .771 .37611 .76732 .36967 Mtetra
.746 .77 .872 r
.76732 .36967 .771 .37611 .77918 .37009 .77552 .36364 Mtetra
.752 .772 .869 r
.77552 .36364 .77918 .37009 .78735 .36387 .78371 .35741 Mtetra
.756 .774 .867 r
.78371 .35741 .78735 .36387 .79552 .35748 .79191 .35101 Mtetra
.76 .775 .865 r
.79191 .35101 .79552 .35748 .8037 .35092 .8001 .34444 Mtetra
.764 .777 .864 r
.8001 .34444 .8037 .35092 .81188 .34424 .8083 .33775 Mtetra
.766 .778 .862 r
.8083 .33775 .81188 .34424 .82005 .33744 .8165 .33094 Mtetra
.769 .779 .861 r
.8165 .33094 .82005 .33744 .82823 .33056 .8247 .32404 Mtetra
.77 .78 .861 r
.8247 .32404 .82823 .33056 .83642 .3236 .8329 .31708 Mtetra
.771 .78 .86 r
.8329 .31708 .83642 .3236 .84461 .3166 .84112 .31006 Mtetra
.772 .781 .86 r
.84112 .31006 .84461 .3166 .85281 .30957 .84934 .30302 Mtetra
.442 .662 .955 r
.24119 .54966 .24578 .55495 .25241 .55542 .24783 .55012 Mtetra
.444 .663 .955 r
.24783 .55012 .25241 .55542 .25908 .55588 .25449 .55056 Mtetra
.448 .664 .954 r
.25449 .55056 .25908 .55588 .26577 .55631 .26119 .55097 Mtetra
.453 .666 .954 r
.26119 .55097 .26577 .55631 .27249 .55667 .26793 .55132 Mtetra
.461 .669 .953 r
.26793 .55132 .27249 .55667 .27925 .55696 .27469 .5516 Mtetra
.469 .673 .953 r
.27469 .5516 .27925 .55696 .28604 .55716 .28149 .55177 Mtetra
.48 .677 .952 r
.28149 .55177 .28604 .55716 .29287 .55723 .28833 .55183 Mtetra
.492 .682 .951 r
.28833 .55183 .29287 .55723 .29974 .55716 .2952 .55174 Mtetra
.505 .687 .949 r
.2952 .55174 .29974 .55716 .30664 .55692 .30211 .55149 Mtetra
.519 .693 .947 r
.30211 .55149 .30664 .55692 .31358 .5565 .30906 .55105 Mtetra
.535 .699 .945 r
.30906 .55105 .31358 .5565 .32055 .55586 .31604 .5504 Mtetra
.551 .705 .942 r
.31604 .5504 .32055 .55586 .32757 .55499 .32307 .5495 Mtetra
.568 .711 .938 r
.32307 .5495 .32757 .55499 .33462 .55386 .33013 .54835 Mtetra
.586 .717 .934 r
.33013 .54835 .33462 .55386 .34171 .55243 .33723 .5469 Mtetra
.604 .723 .929 r
.33723 .5469 .34171 .55243 .34884 .55068 .34437 .54514 Mtetra
.622 .729 .923 r
.34437 .54514 .34884 .55068 .35601 .54859 .35155 .54302 Mtetra
.64 .734 .917 r
.35155 .54302 .35601 .54859 .36322 .54611 .35877 .54053 Mtetra
.658 .739 .91 r
.35877 .54053 .36322 .54611 .37046 .54323 .36602 .53762 Mtetra
.676 .744 .902 r
.36602 .53762 .37046 .54323 .37774 .5399 .37331 .53426 Mtetra
.694 .748 .893 r
.37331 .53426 .37774 .5399 .38505 .53609 .38064 .53043 Mtetra
.711 .752 .884 r
.38064 .53043 .38505 .53609 .3924 .53176 .388 .52607 Mtetra
.728 .755 .874 r
.388 .52607 .3924 .53176 .39977 .52687 .39539 .52115 Mtetra
.744 .758 .864 r
.39539 .52115 .39977 .52687 .40718 .52139 .40282 .51564 Mtetra
.76 .761 .853 r
.40282 .51564 .40718 .52139 .41462 .51526 .41027 .50948 Mtetra
.775 .762 .842 r
.41027 .50948 .41462 .51526 .42209 .50844 .41775 .50264 Mtetra
.789 .764 .83 r
.41775 .50264 .42209 .50844 .42957 .5009 .42526 .49506 Mtetra
.802 .765 .818 r
.42526 .49506 .42957 .5009 .43708 .49259 .43279 .48672 Mtetra
.815 .765 .807 r
.43279 .48672 .43708 .49259 .44461 .48347 .44033 .47757 Mtetra
.826 .765 .795 r
.44033 .47757 .44461 .48347 .45215 .47352 .44789 .4676 Mtetra
.216 .504 .907 r
.60836 .40053 .61234 .40679 .62037 .41048 .6164 .4042 Mtetra
.289 .549 .922 r
.6164 .4042 .62037 .41048 .62843 .41333 .62448 .40705 Mtetra
.355 .588 .932 r
.62448 .40705 .62843 .41333 .63652 .41539 .63258 .40911 Mtetra
.413 .62 .937 r
.63258 .40911 .63652 .41539 .64463 .41667 .6407 .41038 Mtetra
.463 .647 .938 r
.6407 .41038 .64463 .41667 .65276 .41722 .64884 .41093 Mtetra
.506 .669 .936 r
.64884 .41093 .65276 .41722 .66091 .41708 .65699 .41079 Mtetra
.543 .687 .933 r
.65699 .41079 .66091 .41708 .66906 .41628 .66516 .40999 Mtetra
.575 .702 .929 r
.66516 .40999 .66906 .41628 .67723 .41489 .67334 .40859 Mtetra
.603 .715 .923 r
.67334 .40859 .67723 .41489 .6854 .41292 .68153 .40662 Mtetra
.626 .725 .918 r
.68153 .40662 .6854 .41292 .69358 .41043 .68973 .40412 Mtetra
.647 .734 .913 r
.68973 .40412 .69358 .41043 .70177 .40744 .69793 .40112 Mtetra
.665 .741 .907 r
.69793 .40112 .70177 .40744 .70996 .40399 .70614 .39766 Mtetra
.68 .747 .902 r
.70614 .39766 .70996 .40399 .71815 .40012 .71435 .39378 Mtetra
.694 .752 .897 r
.71435 .39378 .71815 .40012 .72635 .39586 .72256 .38951 Mtetra
.706 .757 .892 r
.72256 .38951 .72635 .39586 .73454 .39123 .73077 .38487 Mtetra
.716 .761 .888 r
.73077 .38487 .73454 .39123 .74274 .38627 .73899 .3799 Mtetra
.725 .764 .884 r
.73899 .3799 .74274 .38627 .75093 .38101 .7472 .37462 Mtetra
.733 .767 .88 r
.7472 .37462 .75093 .38101 .75913 .37546 .75541 .36906 Mtetra
.74 .77 .876 r
.75541 .36906 .75913 .37546 .76732 .36967 .76363 .36325 Mtetra
.747 .772 .873 r
.76363 .36325 .76732 .36967 .77552 .36364 .77184 .35721 Mtetra
.752 .774 .871 r
.77184 .35721 .77552 .36364 .78371 .35741 .78006 .35096 Mtetra
.757 .775 .868 r
.78006 .35096 .78371 .35741 .79191 .35101 .78827 .34454 Mtetra
.76 .777 .866 r
.78827 .34454 .79191 .35101 .8001 .34444 .79649 .33796 Mtetra
.764 .778 .864 r
.79649 .33796 .8001 .34444 .8083 .33775 .8047 .33125 Mtetra
.766 .779 .863 r
.8047 .33125 .8083 .33775 .8165 .33094 .81292 .32442 Mtetra
.769 .78 .862 r
.81292 .32442 .8165 .33094 .8247 .32404 .82114 .31751 Mtetra
.77 .78 .861 r
.82114 .31751 .8247 .32404 .8329 .31708 .82937 .31052 Mtetra
.771 .781 .861 r
.82937 .31052 .8329 .31708 .84112 .31006 .8376 .30349 Mtetra
.772 .781 .861 r
.8376 .30349 .84112 .31006 .84934 .30302 .84584 .29643 Mtetra
.442 .662 .955 r
.23657 .54434 .24119 .54966 .24783 .55012 .24321 .54479 Mtetra
.444 .663 .955 r
.24321 .54479 .24783 .55012 .25449 .55056 .24989 .54523 Mtetra
.447 .664 .955 r
.24989 .54523 .25449 .55056 .26119 .55097 .2566 .54562 Mtetra
.453 .667 .954 r
.2566 .54562 .26119 .55097 .26793 .55132 .26333 .54597 Mtetra
.46 .67 .954 r
.26333 .54597 .26793 .55132 .27469 .5516 .27011 .54623 Mtetra
.469 .674 .954 r
.27011 .54623 .27469 .5516 .28149 .55177 .27691 .54639 Mtetra
.479 .678 .953 r
.27691 .54639 .28149 .55177 .28833 .55183 .28376 .54644 Mtetra
.491 .683 .952 r
.28376 .54644 .28833 .55183 .2952 .55174 .29064 .54634 Mtetra
.504 .689 .95 r
.29064 .54634 .2952 .55174 .30211 .55149 .29755 .54608 Mtetra
.518 .695 .949 r
.29755 .54608 .30211 .55149 .30906 .55105 .30451 .54563 Mtetra
.534 .701 .946 r
.30451 .54563 .30906 .55105 .31604 .5504 .3115 .54496 Mtetra
.55 .707 .944 r
.3115 .54496 .31604 .5504 .32307 .5495 .31854 .54406 Mtetra
.567 .713 .94 r
.31854 .54406 .32307 .5495 .33013 .54835 .32561 .54289 Mtetra
.585 .72 .936 r
.32561 .54289 .33013 .54835 .33723 .5469 .33272 .54143 Mtetra
.603 .726 .931 r
.33272 .54143 .33723 .5469 .34437 .54514 .33987 .53965 Mtetra
.621 .732 .926 r
.33987 .53965 .34437 .54514 .35155 .54302 .34706 .53752 Mtetra
.64 .738 .92 r
.34706 .53752 .35155 .54302 .35877 .54053 .35429 .53501 Mtetra
.658 .743 .913 r
.35429 .53501 .35877 .54053 .36602 .53762 .36156 .53209 Mtetra
.677 .748 .905 r
.36156 .53209 .36602 .53762 .37331 .53426 .36886 .52872 Mtetra
.695 .753 .896 r
.36886 .52872 .37331 .53426 .38064 .53043 .3762 .52486 Mtetra
.712 .757 .887 r
.3762 .52486 .38064 .53043 .388 .52607 .38358 .52049 Mtetra
.729 .76 .877 r
.38358 .52049 .388 .52607 .39539 .52115 .39098 .51556 Mtetra
.746 .763 .867 r
.39098 .51556 .39539 .52115 .40282 .51564 .39842 .51002 Mtetra
.762 .766 .856 r
.39842 .51002 .40282 .51564 .41027 .50948 .40589 .50385 Mtetra
.777 .768 .845 r
.40589 .50385 .41027 .50948 .41775 .50264 .41339 .49698 Mtetra
.791 .769 .833 r
.41339 .49698 .41775 .50264 .42526 .49506 .42092 .48939 Mtetra
.805 .77 .821 r
.42092 .48939 .42526 .49506 .43279 .48672 .42846 .48102 Mtetra
.817 .771 .809 r
.42846 .48102 .43279 .48672 .44033 .47757 .43603 .47185 Mtetra
.829 .771 .798 r
.43603 .47185 .44033 .47757 .44789 .4676 .44361 .46186 Mtetra
.201 .504 .908 r
.60437 .39444 .60836 .40053 .6164 .4042 .61242 .3981 Mtetra
.277 .551 .926 r
.61242 .3981 .6164 .4042 .62448 .40705 .6205 .40095 Mtetra
.345 .591 .936 r
.6205 .40095 .62448 .40705 .63258 .40911 .62861 .40299 Mtetra
.406 .624 .942 r
.62861 .40299 .63258 .40911 .6407 .41038 .63674 .40425 Mtetra
.458 .652 .943 r
.63674 .40425 .6407 .41038 .64884 .41093 .6449 .40479 Mtetra
.502 .674 .941 r
.6449 .40479 .64884 .41093 .65699 .41079 .65306 .40463 Mtetra
.541 .692 .938 r
.65306 .40463 .65699 .41079 .66516 .40999 .66125 .40382 Mtetra
.573 .707 .933 r
.66125 .40382 .66516 .40999 .67334 .40859 .66944 .4024 Mtetra
.601 .72 .928 r
.66944 .4024 .67334 .40859 .68153 .40662 .67765 .40041 Mtetra
.626 .73 .922 r
.67765 .40041 .68153 .40662 .68973 .40412 .68586 .39789 Mtetra
.647 .738 .916 r
.68586 .39789 .68973 .40412 .69793 .40112 .69408 .39488 Mtetra
.665 .745 .91 r
.69408 .39488 .69793 .40112 .70614 .39766 .7023 .3914 Mtetra
.68 .751 .905 r
.7023 .3914 .70614 .39766 .71435 .39378 .71053 .3875 Mtetra
.694 .756 .899 r
.71053 .3875 .71435 .39378 .72256 .38951 .71876 .38321 Mtetra
.706 .76 .894 r
.71876 .38321 .72256 .38951 .73077 .38487 .72699 .37855 Mtetra
.717 .764 .89 r
.72699 .37855 .73077 .38487 .73899 .3799 .73522 .37356 Mtetra
.726 .767 .885 r
.73522 .37356 .73899 .3799 .7472 .37462 .74345 .36826 Mtetra
.734 .77 .881 r
.74345 .36826 .7472 .37462 .75541 .36906 .75168 .36268 Mtetra
.741 .772 .878 r
.75168 .36268 .75541 .36906 .76363 .36325 .75992 .35685 Mtetra
.747 .774 .875 r
.75992 .35685 .76363 .36325 .77184 .35721 .76815 .35079 Mtetra
.752 .775 .872 r
.76815 .35079 .77184 .35721 .78006 .35096 .77638 .34452 Mtetra
.757 .777 .869 r
.77638 .34452 .78006 .35096 .78827 .34454 .78462 .33808 Mtetra
.761 .778 .867 r
.78462 .33808 .78827 .34454 .79649 .33796 .79285 .33148 Mtetra
.764 .779 .865 r
.79285 .33148 .79649 .33796 .8047 .33125 .80109 .32474 Mtetra
.767 .78 .864 r
.80109 .32474 .8047 .33125 .81292 .32442 .80933 .31789 Mtetra
.769 .78 .862 r
.80933 .31789 .81292 .32442 .82114 .31751 .81757 .31096 Mtetra
.77 .781 .861 r
.81757 .31096 .82114 .31751 .82937 .31052 .82582 .30395 Mtetra
.771 .781 .861 r
.82582 .30395 .82937 .31052 .8376 .30349 .83407 .29689 Mtetra
.772 .781 .861 r
.83407 .29689 .8376 .30349 .84584 .29643 .84233 .28981 Mtetra
.441 .662 .955 r
.23193 .539 .23657 .54434 .24321 .54479 .23858 .53944 Mtetra
.443 .663 .955 r
.23858 .53944 .24321 .54479 .24989 .54523 .24526 .53987 Mtetra
.446 .664 .955 r
.24526 .53987 .24989 .54523 .2566 .54562 .25197 .54027 Mtetra
.452 .667 .955 r
.25197 .54027 .2566 .54562 .26333 .54597 .25872 .5406 Mtetra
.459 .67 .955 r
.25872 .5406 .26333 .54597 .27011 .54623 .2655 .54086 Mtetra
.467 .674 .954 r
.2655 .54086 .27011 .54623 .27691 .54639 .27231 .54102 Mtetra
.478 .679 .954 r
.27231 .54102 .27691 .54639 .28376 .54644 .27916 .54106 Mtetra
.489 .684 .953 r
.27916 .54106 .28376 .54644 .29064 .54634 .28605 .54095 Mtetra
.502 .69 .952 r
.28605 .54095 .29064 .54634 .29755 .54608 .29298 .54068 Mtetra
.517 .696 .95 r
.29298 .54068 .29755 .54608 .30451 .54563 .29994 .54023 Mtetra
.532 .702 .948 r
.29994 .54023 .30451 .54563 .3115 .54496 .30694 .53956 Mtetra
.549 .709 .946 r
.30694 .53956 .3115 .54496 .31854 .54406 .31398 .53865 Mtetra
.566 .715 .942 r
.31398 .53865 .31854 .54406 .32561 .54289 .32107 .53747 Mtetra
.584 .722 .938 r
.32107 .53747 .32561 .54289 .33272 .54143 .32819 .536 Mtetra
.602 .729 .934 r
.32819 .536 .33272 .54143 .33987 .53965 .33535 .53422 Mtetra
.62 .735 .929 r
.33535 .53422 .33987 .53965 .34706 .53752 .34255 .53208 Mtetra
.639 .741 .922 r
.34255 .53208 .34706 .53752 .35429 .53501 .34979 .52957 Mtetra
.658 .747 .916 r
.34979 .52957 .35429 .53501 .36156 .53209 .35707 .52664 Mtetra
.676 .752 .908 r
.35707 .52664 .36156 .53209 .36886 .52872 .36438 .52326 Mtetra
.695 .757 .9 r
.36438 .52326 .36886 .52872 .3762 .52486 .37174 .5194 Mtetra
.713 .761 .891 r
.37174 .5194 .3762 .52486 .38358 .52049 .37912 .51502 Mtetra
.73 .765 .881 r
.37912 .51502 .38358 .52049 .39098 .51556 .38655 .51008 Mtetra
.747 .769 .871 r
.38655 .51008 .39098 .51556 .39842 .51002 .394 .50454 Mtetra
.763 .771 .86 r
.394 .50454 .39842 .51002 .40589 .50385 .40149 .49835 Mtetra
.779 .774 .848 r
.40149 .49835 .40589 .50385 .41339 .49698 .40901 .49148 Mtetra
.793 .775 .836 r
.40901 .49148 .41339 .49698 .42092 .48939 .41655 .48388 Mtetra
.807 .776 .824 r
.41655 .48388 .42092 .48939 .42846 .48102 .42411 .4755 Mtetra
.82 .777 .812 r
.42411 .4755 .42846 .48102 .43603 .47185 .4317 .46631 Mtetra
.832 .777 .801 r
.4317 .46631 .43603 .47185 .44361 .46186 .4393 .45629 Mtetra
.186 .504 .909 r
.60036 .38853 .60437 .39444 .61242 .3981 .60842 .39219 Mtetra
.265 .552 .928 r
.60842 .39219 .61242 .3981 .6205 .40095 .61651 .39501 Mtetra
.336 .594 .941 r
.61651 .39501 .6205 .40095 .62861 .40299 .62463 .39703 Mtetra
.399 .629 .947 r
.62463 .39703 .62861 .40299 .63674 .40425 .63278 .39827 Mtetra
.453 .657 .948 r
.63278 .39827 .63674 .40425 .6449 .40479 .64094 .39878 Mtetra
.499 .679 .946 r
.64094 .39878 .6449 .40479 .65306 .40463 .64912 .3986 Mtetra
.539 .698 .943 r
.64912 .3986 .65306 .40463 .66125 .40382 .65732 .39776 Mtetra
.572 .713 .937 r
.65732 .39776 .66125 .40382 .66944 .4024 .66553 .39632 Mtetra
.601 .725 .932 r
.66553 .39632 .66944 .4024 .67765 .40041 .67375 .3943 Mtetra
.625 .735 .926 r
.67375 .3943 .67765 .40041 .68586 .39789 .68197 .39176 Mtetra
.647 .743 .919 r
.68197 .39176 .68586 .39789 .69408 .39488 .69021 .38872 Mtetra
.665 .749 .913 r
.69021 .38872 .69408 .39488 .7023 .3914 .69845 .38522 Mtetra
.681 .755 .907 r
.69845 .38522 .7023 .3914 .71053 .3875 .70669 .38129 Mtetra
.695 .76 .902 r
.70669 .38129 .71053 .3875 .71876 .38321 .71494 .37697 Mtetra
.707 .764 .896 r
.71494 .37697 .71876 .38321 .72699 .37855 .72319 .37228 Mtetra
.717 .767 .892 r
.72319 .37228 .72699 .37855 .73522 .37356 .73144 .36726 Mtetra
.727 .77 .887 r
.73144 .36726 .73522 .37356 .74345 .36826 .73969 .36193 Mtetra
.735 .772 .883 r
.73969 .36193 .74345 .36826 .75168 .36268 .74794 .35633 Mtetra
.742 .774 .879 r
.74794 .35633 .75168 .36268 .75992 .35685 .75619 .35047 Mtetra
.748 .776 .876 r
.75619 .35047 .75992 .35685 .76815 .35079 .76444 .34438 Mtetra
.753 .777 .873 r
.76444 .34438 .76815 .35079 .77638 .34452 .77269 .33809 Mtetra
.758 .778 .87 r
.77269 .33809 .77638 .34452 .78462 .33808 .78095 .33162 Mtetra
.761 .779 .868 r
.78095 .33162 .78462 .33808 .79285 .33148 .7892 .32499 Mtetra
.765 .78 .866 r
.7892 .32499 .79285 .33148 .80109 .32474 .79746 .31822 Mtetra
.767 .781 .864 r
.79746 .31822 .80109 .32474 .80933 .31789 .80572 .31135 Mtetra
.769 .781 .863 r
.80572 .31135 .80933 .31789 .81757 .31096 .81398 .30438 Mtetra
.771 .781 .862 r
.81398 .30438 .81757 .31096 .82582 .30395 .82225 .29735 Mtetra
.772 .781 .861 r
.82225 .29735 .82582 .30395 .83407 .29689 .83052 .29026 Mtetra
.83052 .29026 .83407 .29689 .84233 .28981 .8388 .28315 Mtetra
.441 .661 .955 r
.22727 .53363 .23193 .539 .23858 .53944 .23392 .53407 Mtetra
.442 .662 .955 r
.23392 .53407 .23858 .53944 .24526 .53987 .24061 .5345 Mtetra
.445 .664 .955 r
.24061 .5345 .24526 .53987 .25197 .54027 .24733 .5349 Mtetra
.45 .667 .955 r
.24733 .5349 .25197 .54027 .25872 .5406 .25408 .53523 Mtetra
.457 .67 .955 r
.25408 .53523 .25872 .5406 .2655 .54086 .26086 .53549 Mtetra
.466 .675 .955 r
.26086 .53549 .2655 .54086 .27231 .54102 .26769 .53565 Mtetra
.476 .679 .955 r
.26769 .53565 .27231 .54102 .27916 .54106 .27454 .53569 Mtetra
.487 .685 .954 r
.27454 .53569 .27916 .54106 .28605 .54095 .28144 .53558 Mtetra
.5 .691 .953 r
.28144 .53558 .28605 .54095 .29298 .54068 .28837 .53531 Mtetra
.515 .697 .952 r
.28837 .53531 .29298 .54068 .29994 .54023 .29534 .53485 Mtetra
.53 .704 .95 r
.29534 .53485 .29994 .54023 .30694 .53956 .30235 .53418 Mtetra
.547 .711 .948 r
.30235 .53418 .30694 .53956 .31398 .53865 .3094 .53327 Mtetra
.564 .717 .945 r
.3094 .53327 .31398 .53865 .32107 .53747 .31649 .5321 Mtetra
.582 .724 .941 r
.31649 .5321 .32107 .53747 .32819 .536 .32362 .53063 Mtetra
.6 .731 .936 r
.32362 .53063 .32819 .536 .33535 .53422 .3308 .52885 Mtetra
.619 .738 .931 r
.3308 .52885 .33535 .53422 .34255 .53208 .33801 .52671 Mtetra
.638 .744 .926 r
.33801 .52671 .34255 .53208 .34979 .52957 .34526 .5242 Mtetra
.657 .75 .919 r
.34526 .5242 .34979 .52957 .35707 .52664 .35255 .52127 Mtetra
.676 .756 .911 r
.35255 .52127 .35707 .52664 .36438 .52326 .35988 .51789 Mtetra
.695 .761 .903 r
.35988 .51789 .36438 .52326 .37174 .5194 .36724 .51404 Mtetra
.713 .766 .894 r
.36724 .51404 .37174 .5194 .37912 .51502 .37464 .50966 Mtetra
.731 .77 .885 r
.37464 .50966 .37912 .51502 .38655 .51008 .38208 .50472 Mtetra
.748 .774 .874 r
.38208 .50472 .38655 .51008 .394 .50454 .38955 .49919 Mtetra
.764 .777 .863 r
.38955 .49919 .394 .50454 .40149 .49835 .39706 .493 Mtetra
.78 .779 .852 r
.39706 .493 .40149 .49835 .40901 .49148 .40459 .48613 Mtetra
.795 .781 .84 r
.40459 .48613 .40901 .49148 .41655 .48388 .41215 .47853 Mtetra
.809 .783 .828 r
.41215 .47853 .41655 .48388 .42411 .4755 .41973 .47015 Mtetra
.822 .783 .816 r
.41973 .47015 .42411 .4755 .4317 .46631 .42734 .46095 Mtetra
.834 .783 .803 r
.42734 .46095 .4317 .46631 .4393 .45629 .43496 .45091 Mtetra
.17 .503 .909 r
.59634 .38281 .60036 .38853 .60842 .39219 .6044 .38645 Mtetra
.252 .554 .931 r
.6044 .38645 .60842 .39219 .61651 .39501 .61251 .38925 Mtetra
.327 .598 .944 r
.61251 .38925 .61651 .39501 .62463 .39703 .62064 .39124 Mtetra
.392 .634 .951 r
.62064 .39124 .62463 .39703 .63278 .39827 .62879 .39245 Mtetra
.449 .662 .953 r
.62879 .39245 .63278 .39827 .64094 .39878 .63697 .39292 Mtetra
.496 .685 .951 r
.63697 .39292 .64094 .39878 .64912 .3986 .64516 .3927 Mtetra
.537 .704 .947 r
.64516 .3927 .64912 .3986 .65732 .39776 .65337 .39182 Mtetra
.571 .718 .942 r
.65337 .39182 .65732 .39776 .66553 .39632 .66159 .39034 Mtetra
.601 .73 .936 r
.66159 .39034 .66553 .39632 .67375 .3943 .66983 .38829 Mtetra
.626 .74 .929 r
.66983 .38829 .67375 .3943 .68197 .39176 .67807 .38571 Mtetra
.647 .748 .923 r
.67807 .38571 .68197 .39176 .69021 .38872 .68632 .38263 Mtetra
.666 .754 .916 r
.68632 .38263 .69021 .38872 .69845 .38522 .69458 .3791 Mtetra
.682 .759 .91 r
.69458 .3791 .69845 .38522 .70669 .38129 .70284 .37513 Mtetra
.696 .763 .904 r
.70284 .37513 .70669 .38129 .71494 .37697 .7111 .37078 Mtetra
.708 .767 .899 r
.7111 .37078 .71494 .37697 .72319 .37228 .71937 .36606 Mtetra
.718 .77 .893 r
.71937 .36606 .72319 .37228 .73144 .36726 .72764 .361 Mtetra
.728 .773 .889 r
.72764 .361 .73144 .36726 .73969 .36193 .7359 .35564 Mtetra
.736 .775 .884 r
.7359 .35564 .73969 .36193 .74794 .35633 .74417 .35 Mtetra
.743 .776 .88 r
.74417 .35 .74794 .35633 .75619 .35047 .75244 .34411 Mtetra
.749 .778 .877 r
.75244 .34411 .75619 .35047 .76444 .34438 .76072 .33799 Mtetra
.754 .779 .874 r
.76072 .33799 .76444 .34438 .77269 .33809 .76899 .33166 Mtetra
.758 .78 .871 r
.76899 .33166 .77269 .33809 .78095 .33162 .77726 .32515 Mtetra
.762 .781 .868 r
.77726 .32515 .78095 .33162 .7892 .32499 .78553 .31849 Mtetra
.765 .781 .866 r
.78553 .31849 .7892 .32499 .79746 .31822 .79381 .3117 Mtetra
.768 .782 .864 r
.79381 .3117 .79746 .31822 .80572 .31135 .80209 .30479 Mtetra
.77 .782 .863 r
.80209 .30479 .80572 .31135 .81398 .30438 .81037 .29779 Mtetra
.771 .782 .862 r
.81037 .29779 .81398 .30438 .82225 .29735 .81866 .29072 Mtetra
.772 .782 .861 r
.81866 .29072 .82225 .29735 .83052 .29026 .82695 .2836 Mtetra
.82695 .2836 .83052 .29026 .8388 .28315 .83525 .27646 Mtetra
.439 .661 .955 r
.22258 .52823 .22727 .53363 .23392 .53407 .22924 .52868 Mtetra
.44 .662 .955 r
.22924 .52868 .23392 .53407 .24061 .5345 .23594 .52912 Mtetra
.443 .664 .955 r
.23594 .52912 .24061 .5345 .24733 .5349 .24266 .52951 Mtetra
.448 .667 .956 r
.24266 .52951 .24733 .5349 .25408 .53523 .24942 .52985 Mtetra
.455 .67 .956 r
.24942 .52985 .25408 .53523 .26086 .53549 .25621 .53012 Mtetra
.463 .675 .956 r
.25621 .53012 .26086 .53549 .26769 .53565 .26303 .53028 Mtetra
.473 .68 .956 r
.26303 .53028 .26769 .53565 .27454 .53569 .2699 .53032 Mtetra
.485 .685 .955 r
.2699 .53032 .27454 .53569 .28144 .53558 .2768 .53022 Mtetra
.498 .692 .954 r
.2768 .53022 .28144 .53558 .28837 .53531 .28374 .52996 Mtetra
.512 .698 .953 r
.28374 .52996 .28837 .53531 .29534 .53485 .29072 .52951 Mtetra
.528 .705 .952 r
.29072 .52951 .29534 .53485 .30235 .53418 .29774 .52884 Mtetra
.544 .712 .95 r
.29774 .52884 .30235 .53418 .3094 .53327 .3048 .52794 Mtetra
.562 .719 .947 r
.3048 .52794 .3094 .53327 .31649 .5321 .31189 .52677 Mtetra
.58 .727 .943 r
.31189 .52677 .31649 .5321 .32362 .53063 .31903 .52531 Mtetra
.598 .734 .939 r
.31903 .52531 .32362 .53063 .3308 .52885 .32622 .52353 Mtetra
.617 .741 .934 r
.32622 .52353 .3308 .52885 .33801 .52671 .33344 .52141 Mtetra
.636 .748 .929 r
.33344 .52141 .33801 .52671 .34526 .5242 .3407 .5189 Mtetra
.656 .754 .922 r
.3407 .5189 .34526 .5242 .35255 .52127 .348 .51598 Mtetra
.675 .76 .915 r
.348 .51598 .35255 .52127 .35988 .51789 .35534 .51262 Mtetra
.694 .766 .907 r
.35534 .51262 .35988 .51789 .36724 .51404 .36272 .50877 Mtetra
.712 .771 .898 r
.36272 .50877 .36724 .51404 .37464 .50966 .37014 .50441 Mtetra
.731 .775 .888 r
.37014 .50441 .37464 .50966 .38208 .50472 .37759 .49949 Mtetra
.748 .779 .878 r
.37759 .49949 .38208 .50472 .38955 .49919 .38508 .49396 Mtetra
.765 .782 .867 r
.38508 .49396 .38955 .49919 .39706 .493 .3926 .4878 Mtetra
.781 .785 .856 r
.3926 .4878 .39706 .493 .40459 .48613 .40015 .48094 Mtetra
.797 .787 .844 r
.40015 .48094 .40459 .48613 .41215 .47853 .40772 .47335 Mtetra
.811 .789 .831 r
.40772 .47335 .41215 .47853 .41973 .47015 .41533 .46498 Mtetra
.825 .79 .819 r
.41533 .46498 .41973 .47015 .42734 .46095 .42295 .45578 Mtetra
.837 .79 .806 r
.42295 .45578 .42734 .46095 .43496 .45091 .4306 .44572 Mtetra
.153 .501 .909 r
.59229 .37727 .59634 .38281 .6044 .38645 .60037 .3809 Mtetra
.24 .556 .933 r
.60037 .3809 .6044 .38645 .61251 .38925 .60848 .38367 Mtetra
.318 .602 .948 r
.60848 .38367 .61251 .38925 .62064 .39124 .61662 .38561 Mtetra
.387 .639 .956 r
.61662 .38561 .62064 .39124 .62879 .39245 .62479 .38677 Mtetra
.445 .668 .958 r
.62479 .38677 .62879 .39245 .63697 .39292 .63298 .3872 Mtetra
.494 .692 .956 r
.63298 .3872 .63697 .39292 .64516 .3927 .64118 .38693 Mtetra
.536 .71 .952 r
.64118 .38693 .64516 .3927 .65337 .39182 .64941 .386 Mtetra
.571 .724 .946 r
.64941 .386 .65337 .39182 .66159 .39034 .65764 .38448 Mtetra
.601 .736 .939 r
.65764 .38448 .66159 .39034 .66983 .38829 .66589 .38238 Mtetra
.626 .745 .933 r
.66589 .38238 .66983 .38829 .67807 .38571 .67415 .37975 Mtetra
.648 .752 .926 r
.67415 .37975 .67807 .38571 .68632 .38263 .68242 .37663 Mtetra
.667 .758 .919 r
.68242 .37663 .68632 .38263 .69458 .3791 .69069 .37305 Mtetra
.683 .763 .912 r
.69069 .37305 .69458 .3791 .70284 .37513 .69897 .36904 Mtetra
.697 .767 .906 r
.69897 .36904 .70284 .37513 .7111 .37078 .70725 .36464 Mtetra
.709 .771 .9 r
.70725 .36464 .7111 .37078 .71937 .36606 .71553 .35988 Mtetra
.72 .773 .895 r
.71553 .35988 .71937 .36606 .72764 .361 .72382 .35479 Mtetra
.729 .776 .89 r
.72382 .35479 .72764 .361 .7359 .35564 .7321 .34938 Mtetra
.737 .777 .886 r
.7321 .34938 .7359 .35564 .74417 .35 .74039 .3437 Mtetra
.744 .779 .881 r
.74039 .3437 .74417 .35 .75244 .34411 .74868 .33777 Mtetra
.75 .78 .878 r
.74868 .33777 .75244 .34411 .76072 .33799 .75697 .33161 Mtetra
.755 .781 .874 r
.75697 .33161 .76072 .33799 .76899 .33166 .76526 .32524 Mtetra
.759 .782 .871 r
.76526 .32524 .76899 .33166 .77726 .32515 .77355 .3187 Mtetra
.763 .782 .869 r
.77355 .3187 .77726 .32515 .78553 .31849 .78185 .31199 Mtetra
.766 .783 .867 r
.78185 .31199 .78553 .31849 .79381 .3117 .79014 .30516 Mtetra
.768 .783 .865 r
.79014 .30516 .79381 .3117 .80209 .30479 .79844 .29821 Mtetra
.77 .783 .863 r
.79844 .29821 .80209 .30479 .81037 .29779 .80674 .29117 Mtetra
.772 .783 .862 r
.80674 .29117 .81037 .29779 .81866 .29072 .81505 .28407 Mtetra
.772 .782 .861 r
.81505 .28407 .81866 .29072 .82695 .2836 .82336 .27691 Mtetra
.773 .782 .86 r
.82336 .27691 .82695 .2836 .83525 .27646 .83168 .26973 Mtetra
.437 .66 .955 r
.21788 .52281 .22258 .52823 .22924 .52868 .22454 .52327 Mtetra
.438 .661 .955 r
.22454 .52327 .22924 .52868 .23594 .52912 .23124 .52371 Mtetra
.441 .663 .956 r
.23124 .52371 .23594 .52912 .24266 .52951 .23797 .52412 Mtetra
.446 .666 .956 r
.23797 .52412 .24266 .52951 .24942 .52985 .24473 .52447 Mtetra
.452 .67 .956 r
.24473 .52447 .24942 .52985 .25621 .53012 .25152 .52474 Mtetra
.461 .675 .957 r
.25152 .52474 .25621 .53012 .26303 .53028 .25836 .52491 Mtetra
.471 .68 .957 r
.25836 .52491 .26303 .53028 .2699 .53032 .26523 .52497 Mtetra
.482 .686 .956 r
.26523 .52497 .2699 .53032 .2768 .53022 .27213 .52488 Mtetra
.495 .692 .956 r
.27213 .52488 .2768 .53022 .28374 .52996 .27908 .52463 Mtetra
.509 .699 .955 r
.27908 .52463 .28374 .52996 .29072 .52951 .28607 .52418 Mtetra
.525 .706 .954 r
.28607 .52418 .29072 .52951 .29774 .52884 .29309 .52353 Mtetra
.541 .713 .952 r
.29309 .52353 .29774 .52884 .3048 .52794 .30016 .52264 Mtetra
.559 .721 .949 r
.30016 .52264 .3048 .52794 .31189 .52677 .30727 .52149 Mtetra
.577 .729 .946 r
.30727 .52149 .31189 .52677 .31903 .52531 .31442 .52004 Mtetra
.596 .736 .942 r
.31442 .52004 .31903 .52531 .32622 .52353 .32161 .51828 Mtetra
.615 .744 .937 r
.32161 .51828 .32622 .52353 .33344 .52141 .32884 .51617 Mtetra
.634 .751 .932 r
.32884 .51617 .33344 .52141 .3407 .5189 .33611 .51368 Mtetra
.654 .757 .926 r
.33611 .51368 .3407 .5189 .348 .51598 .34342 .51078 Mtetra
.673 .764 .919 r
.34342 .51078 .348 .51598 .35534 .51262 .35078 .50743 Mtetra
.693 .77 .911 r
.35078 .50743 .35534 .51262 .36272 .50877 .35817 .50361 Mtetra
.712 .775 .902 r
.35817 .50361 .36272 .50877 .37014 .50441 .3656 .49927 Mtetra
.73 .78 .893 r
.3656 .49927 .37014 .50441 .37759 .49949 .37307 .49437 Mtetra
.748 .784 .882 r
.37307 .49437 .37759 .49949 .38508 .49396 .38057 .48887 Mtetra
.766 .788 .871 r
.38057 .48887 .38508 .49396 .3926 .4878 .3881 .48273 Mtetra
.782 .791 .86 r
.3881 .48273 .3926 .4878 .40015 .48094 .39567 .4759 Mtetra
.798 .794 .848 r
.39567 .4759 .40015 .48094 .40772 .47335 .40327 .46834 Mtetra
.813 .795 .835 r
.40327 .46834 .40772 .47335 .41533 .46498 .41089 .45999 Mtetra
.827 .796 .822 r
.41089 .45999 .41533 .46498 .42295 .45578 .41854 .4508 Mtetra
.84 .796 .809 r
.41854 .4508 .42295 .45578 .4306 .44572 .4262 .44072 Mtetra
.136 .5 .908 r
.58823 .37192 .59229 .37727 .60037 .3809 .59632 .37554 Mtetra
.228 .559 .935 r
.59632 .37554 .60037 .3809 .60848 .38367 .60444 .37826 Mtetra
.31 .607 .952 r
.60444 .37826 .60848 .38367 .61662 .38561 .61259 .38015 Mtetra
.381 .645 .96 r
.61259 .38015 .61662 .38561 .62479 .38677 .62077 .38125 Mtetra
.442 .675 .962 r
.62077 .38125 .62479 .38677 .63298 .3872 .62897 .38162 Mtetra
.493 .698 .96 r
.62897 .38162 .63298 .3872 .64118 .38693 .63719 .38129 Mtetra
.535 .716 .956 r
.63719 .38129 .64118 .38693 .64941 .386 .64543 .3803 Mtetra
.571 .731 .95 r
.64543 .3803 .64941 .386 .65764 .38448 .65368 .37872 Mtetra
.602 .742 .943 r
.65368 .37872 .65764 .38448 .66589 .38238 .66194 .37656 Mtetra
.627 .751 .936 r
.66194 .37656 .66589 .38238 .67415 .37975 .67022 .37388 Mtetra
.649 .758 .929 r
.67022 .37388 .67415 .37975 .68242 .37663 .6785 .3707 Mtetra
.668 .763 .921 r
.6785 .3707 .68242 .37663 .69069 .37305 .68679 .36707 Mtetra
.684 .768 .915 r
.68679 .36707 .69069 .37305 .69897 .36904 .69508 .36301 Mtetra
.698 .771 .908 r
.69508 .36301 .69897 .36904 .70725 .36464 .70338 .35856 Mtetra
.71 .774 .902 r
.70338 .35856 .70725 .36464 .71553 .35988 .71168 .35375 Mtetra
.721 .777 .897 r
.71168 .35375 .71553 .35988 .72382 .35479 .71998 .34861 Mtetra
.73 .779 .891 r
.71998 .34861 .72382 .35479 .7321 .34938 .72829 .34316 Mtetra
.738 .78 .887 r
.72829 .34316 .7321 .34938 .74039 .3437 .73659 .33743 Mtetra
.745 .781 .882 r
.73659 .33743 .74039 .3437 .74868 .33777 .7449 .33145 Mtetra
.751 .782 .879 r
.7449 .33145 .74868 .33777 .75697 .33161 .75321 .32524 Mtetra
.756 .783 .875 r
.75321 .32524 .75697 .33161 .76526 .32524 .76152 .31883 Mtetra
.76 .783 .872 r
.76152 .31883 .76526 .32524 .77355 .3187 .76983 .31224 Mtetra
.764 .784 .869 r
.76983 .31224 .77355 .3187 .78185 .31199 .77814 .30549 Mtetra
.767 .784 .867 r
.77814 .30549 .78185 .31199 .79014 .30516 .78646 .29861 Mtetra
.769 .784 .865 r
.78646 .29861 .79014 .30516 .79844 .29821 .79478 .29162 Mtetra
.771 .784 .863 r
.79478 .29162 .79844 .29821 .80674 .29117 .8031 .28454 Mtetra
.772 .783 .862 r
.8031 .28454 .80674 .29117 .81505 .28407 .81142 .27738 Mtetra
.773 .783 .861 r
.81142 .27738 .81505 .28407 .82336 .27691 .81975 .27019 Mtetra
.773 .782 .86 r
.81975 .27019 .82336 .27691 .83168 .26973 .82809 .26296 Mtetra
.435 .659 .955 r
.21314 .51736 .21788 .52281 .22454 .52327 .21981 .51784 Mtetra
.436 .66 .955 r
.21981 .51784 .22454 .52327 .23124 .52371 .22651 .51829 Mtetra
.438 .663 .956 r
.22651 .51829 .23124 .52371 .23797 .52412 .23325 .51871 Mtetra
.443 .666 .957 r
.23325 .51871 .23797 .52412 .24473 .52447 .24001 .51908 Mtetra
.449 .67 .957 r
.24001 .51908 .24473 .52447 .25152 .52474 .24682 .51936 Mtetra
.457 .674 .957 r
.24682 .51936 .25152 .52474 .25836 .52491 .25365 .51955 Mtetra
.467 .68 .958 r
.25365 .51955 .25836 .52491 .26523 .52497 .26053 .51962 Mtetra
.479 .686 .958 r
.26053 .51962 .26523 .52497 .27213 .52488 .26744 .51955 Mtetra
.492 .692 .957 r
.26744 .51955 .27213 .52488 .27908 .52463 .2744 .51931 Mtetra
.506 .699 .957 r
.2744 .51931 .27908 .52463 .28607 .52418 .28139 .51889 Mtetra
.521 .707 .955 r
.28139 .51889 .28607 .52418 .29309 .52353 .28842 .51825 Mtetra
.538 .715 .954 r
.28842 .51825 .29309 .52353 .30016 .52264 .2955 .51738 Mtetra
.556 .722 .952 r
.2955 .51738 .30016 .52264 .30727 .52149 .30261 .51625 Mtetra
.574 .73 .949 r
.30261 .51625 .30727 .52149 .31442 .52004 .30977 .51482 Mtetra
.593 .738 .945 r
.30977 .51482 .31442 .52004 .32161 .51828 .31697 .51308 Mtetra
.612 .746 .941 r
.31697 .51308 .32161 .51828 .32884 .51617 .32421 .51099 Mtetra
.632 .754 .935 r
.32421 .51099 .32884 .51617 .33611 .51368 .3315 .50853 Mtetra
.652 .761 .929 r
.3315 .50853 .33611 .51368 .34342 .51078 .33882 .50566 Mtetra
.672 .768 .922 r
.33882 .50566 .34342 .51078 .35078 .50743 .34618 .50234 Mtetra
.691 .774 .915 r
.34618 .50234 .35078 .50743 .35817 .50361 .35359 .49854 Mtetra
.711 .78 .906 r
.35359 .49854 .35817 .50361 .3656 .49927 .36103 .49424 Mtetra
.73 .785 .897 r
.36103 .49424 .3656 .49927 .37307 .49437 .36851 .48937 Mtetra
.748 .79 .887 r
.36851 .48937 .37307 .49437 .38057 .48887 .37603 .48391 Mtetra
.766 .794 .876 r
.37603 .48391 .38057 .48887 .3881 .48273 .38358 .47781 Mtetra
.783 .797 .864 r
.38358 .47781 .3881 .48273 .39567 .4759 .39116 .47102 Mtetra
.799 .8 .852 r
.39116 .47102 .39567 .4759 .40327 .46834 .39878 .46349 Mtetra
.815 .802 .839 r
.39878 .46349 .40327 .46834 .41089 .45999 .40642 .45518 Mtetra
.829 .803 .826 r
.40642 .45518 .41089 .45999 .41854 .4508 .41409 .44601 Mtetra
.843 .803 .812 r
.41409 .44601 .41854 .4508 .4262 .44072 .42178 .43594 Mtetra
.118 .499 .906 r
.58415 .36679 .58823 .37192 .59632 .37554 .59225 .37037 Mtetra
.217 .562 .936 r
.59225 .37037 .59632 .37554 .60444 .37826 .60038 .37304 Mtetra
.303 .612 .955 r
.60038 .37304 .60444 .37826 .61259 .38015 .60854 .37486 Mtetra
.377 .651 .964 r
.60854 .37486 .61259 .38015 .62077 .38125 .61673 .37589 Mtetra
.44 .682 .967 r
.61673 .37589 .62077 .38125 .62897 .38162 .62494 .37618 Mtetra
.492 .705 .965 r
.62494 .37618 .62897 .38162 .63719 .38129 .63318 .37577 Mtetra
.535 .723 .96 r
.63318 .37577 .63719 .38129 .64543 .3803 .64143 .37472 Mtetra
.572 .737 .954 r
.64143 .37472 .64543 .3803 .65368 .37872 .64969 .37306 Mtetra
.603 .748 .946 r
.64969 .37306 .65368 .37872 .66194 .37656 .65797 .37084 Mtetra
.629 .756 .939 r
.65797 .37084 .66194 .37656 .67022 .37388 .66626 .36809 Mtetra
.651 .763 .931 r
.66626 .36809 .67022 .37388 .6785 .3707 .67456 .36486 Mtetra
.67 .768 .924 r
.67456 .36486 .6785 .3707 .68679 .36707 .68286 .36116 Mtetra
.686 .772 .917 r
.68286 .36116 .68679 .36707 .69508 .36301 .69117 .35705 Mtetra
.7 .775 .91 r
.69117 .35705 .69508 .36301 .70338 .35856 .69949 .35254 Mtetra
.712 .778 .904 r
.69949 .35254 .70338 .35856 .71168 .35375 .70781 .34767 Mtetra
.723 .78 .898 r
.70781 .34767 .71168 .35375 .71998 .34861 .71613 .34247 Mtetra
.732 .782 .893 r
.71613 .34247 .71998 .34861 .72829 .34316 .72445 .33696 Mtetra
.739 .783 .888 r
.72445 .33696 .72829 .34316 .73659 .33743 .73278 .33118 Mtetra
.746 .784 .883 r
.73278 .33118 .73659 .33743 .7449 .33145 .7411 .32515 Mtetra
.752 .784 .879 r
.7411 .32515 .7449 .33145 .75321 .32524 .74943 .31889 Mtetra
.757 .785 .876 r
.74943 .31889 .75321 .32524 .76152 .31883 .75776 .31242 Mtetra
.761 .785 .873 r
.75776 .31242 .76152 .31883 .76983 .31224 .76609 .30578 Mtetra
.765 .785 .87 r
.76609 .30578 .76983 .31224 .77814 .30549 .77442 .29898 Mtetra
.768 .785 .867 r
.77442 .29898 .77814 .30549 .78646 .29861 .78275 .29205 Mtetra
.77 .785 .865 r
.78275 .29205 .78646 .29861 .79478 .29162 .79109 .28501 Mtetra
.772 .785 .863 r
.79109 .28501 .79478 .29162 .8031 .28454 .79943 .27788 Mtetra
.773 .784 .862 r
.79943 .27788 .8031 .28454 .81142 .27738 .80778 .27068 Mtetra
.774 .783 .861 r
.80778 .27068 .81142 .27738 .81975 .27019 .81613 .26343 Mtetra
.774 .783 .86 r
.81613 .26343 .81975 .27019 .82809 .26296 .82449 .25615 Mtetra
.432 .658 .955 r
.20839 .51189 .21314 .51736 .21981 .51784 .21506 .51238 Mtetra
.433 .659 .956 r
.21506 .51238 .21981 .51784 .22651 .51829 .22177 .51285 Mtetra
.435 .662 .956 r
.22177 .51285 .22651 .51829 .23325 .51871 .2285 .51329 Mtetra
.44 .665 .957 r
.2285 .51329 .23325 .51871 .24001 .51908 .23528 .51368 Mtetra
.446 .669 .958 r
.23528 .51368 .24001 .51908 .24682 .51936 .24208 .51398 Mtetra
.454 .674 .958 r
.24208 .51398 .24682 .51936 .25365 .51955 .24893 .51419 Mtetra
.463 .679 .959 r
.24893 .51419 .25365 .51955 .26053 .51962 .25581 .51428 Mtetra
.475 .686 .959 r
.25581 .51428 .26053 .51962 .26744 .51955 .26273 .51423 Mtetra
.488 .692 .959 r
.26273 .51423 .26744 .51955 .2744 .51931 .26968 .51402 Mtetra
.502 .7 .958 r
.26968 .51402 .2744 .51931 .28139 .51889 .27668 .51362 Mtetra
.517 .708 .957 r
.27668 .51362 .28139 .51889 .28842 .51825 .28372 .513 Mtetra
.534 .716 .956 r
.28372 .513 .28842 .51825 .2955 .51738 .29081 .51216 Mtetra
.552 .724 .954 r
.29081 .51216 .2955 .51738 .30261 .51625 .29793 .51105 Mtetra
.57 .732 .951 r
.29793 .51105 .30261 .51625 .30977 .51482 .3051 .50965 Mtetra
.589 .74 .948 r
.3051 .50965 .30977 .51482 .31697 .51308 .31231 .50794 Mtetra
.609 .749 .944 r
.31231 .50794 .31697 .51308 .32421 .51099 .31956 .50588 Mtetra
.629 .756 .939 r
.31956 .50588 .32421 .51099 .3315 .50853 .32685 .50345 Mtetra
.649 .764 .933 r
.32685 .50345 .3315 .50853 .33882 .50566 .33418 .50061 Mtetra
.669 .771 .926 r
.33418 .50061 .33882 .50566 .34618 .50234 .34156 .49733 Mtetra
.689 .778 .919 r
.34156 .49733 .34618 .50234 .35359 .49854 .34898 .49358 Mtetra
.709 .784 .911 r
.34898 .49358 .35359 .49854 .36103 .49424 .35643 .48931 Mtetra
.728 .79 .901 r
.35643 .48931 .36103 .49424 .36851 .48937 .36393 .48449 Mtetra
.747 .795 .891 r
.36393 .48449 .36851 .48937 .37603 .48391 .37146 .47908 Mtetra
.765 .799 .881 r
.37146 .47908 .37603 .48391 .38358 .47781 .37903 .47303 Mtetra
.783 .803 .869 r
.37903 .47303 .38358 .47781 .39116 .47102 .38663 .46629 Mtetra
.8 .806 .857 r
.38663 .46629 .39116 .47102 .39878 .46349 .39426 .45882 Mtetra
.816 .808 .844 r
.39426 .45882 .39878 .46349 .40642 .45518 .40192 .45055 Mtetra
.831 .81 .83 r
.40192 .45055 .40642 .45518 .41409 .44601 .40961 .44143 Mtetra
.845 .81 .816 r
.40961 .44143 .41409 .44601 .42178 .43594 .41732 .43137 Mtetra
.859 .809 .8 r
.41732 .43137 .42178 .43594 .42949 .42488 .42506 .42029 Mtetra
0 .418 .853 r
.57198 .35734 .57609 .36224 .58415 .36679 .58004 .36188 Mtetra
.101 .499 .903 r
.58004 .36188 .58415 .36679 .59225 .37037 .58815 .36541 Mtetra
.206 .566 .938 r
.58815 .36541 .59225 .37037 .60038 .37304 .5963 .368 Mtetra
.297 .618 .958 r
.5963 .368 .60038 .37304 .60854 .37486 .60447 .36974 Mtetra
.374 .659 .968 r
.60447 .36974 .60854 .37486 .61673 .37589 .61267 .37068 Mtetra
.438 .689 .971 r
.61267 .37068 .61673 .37589 .62494 .37618 .6209 .37088 Mtetra
.492 .713 .969 r
.6209 .37088 .62494 .37618 .63318 .37577 .62915 .37039 Mtetra
.536 .73 .964 r
.62915 .37039 .63318 .37577 .64143 .37472 .63741 .36926 Mtetra
.573 .744 .957 r
.63741 .36926 .64143 .37472 .64969 .37306 .64569 .36752 Mtetra
.604 .754 .95 r
.64569 .36752 .64969 .37306 .65797 .37084 .65398 .36522 Mtetra
.631 .762 .942 r
.65398 .36522 .65797 .37084 .66626 .36809 .66229 .3624 Mtetra
.653 .768 .934 r
.66229 .3624 .66626 .36809 .67456 .36486 .6706 .35909 Mtetra
.672 .773 .926 r
.6706 .35909 .67456 .36486 .68286 .36116 .67892 .35532 Mtetra
.688 .777 .919 r
.67892 .35532 .68286 .36116 .69117 .35705 .68725 .35114 Mtetra
.702 .78 .912 r
.68725 .35114 .69117 .35705 .69949 .35254 .69558 .34656 Mtetra
.714 .782 .905 r
.69558 .34656 .69949 .35254 .70781 .34767 .70392 .34163 Mtetra
.724 .784 .899 r
.70392 .34163 .70781 .34767 .71613 .34247 .71226 .33637 Mtetra
.733 .785 .894 r
.71226 .33637 .71613 .34247 .72445 .33696 .7206 .3308 Mtetra
.741 .786 .889 r
.7206 .3308 .72445 .33696 .73278 .33118 .72894 .32496 Mtetra
.748 .786 .884 r
.72894 .32496 .73278 .33118 .7411 .32515 .73729 .31886 Mtetra
.754 .787 .88 r
.73729 .31886 .7411 .32515 .74943 .31889 .74563 .31255 Mtetra
.759 .787 .876 r
.74563 .31255 .74943 .31889 .75776 .31242 .75398 .30602 Mtetra
.763 .787 .873 r
.75398 .30602 .75776 .31242 .76609 .30578 .76233 .29932 Mtetra
.766 .787 .87 r
.76233 .29932 .76609 .30578 .77442 .29898 .77068 .29247 Mtetra
.769 .787 .867 r
.77068 .29247 .77442 .29898 .78275 .29205 .77903 .28548 Mtetra
.771 .786 .865 r
.77903 .28548 .78275 .29205 .79109 .28501 .78739 .27839 Mtetra
.773 .786 .863 r
.78739 .27839 .79109 .28501 .79943 .27788 .79575 .2712 Mtetra
.774 .785 .862 r
.79575 .2712 .79943 .27788 .80778 .27068 .80411 .26394 Mtetra
.775 .784 .861 r
.80411 .26394 .80778 .27068 .81613 .26343 .81248 .25664 Mtetra
.775 .783 .86 r
.81248 .25664 .81613 .26343 .82449 .25615 .82086 .24931 Mtetra
.429 .656 .955 r
.20361 .50638 .20839 .51189 .21506 .51238 .21029 .5069 Mtetra
.429 .658 .956 r
.21029 .5069 .21506 .51238 .22177 .51285 .217 .5074 Mtetra
.431 .66 .957 r
.217 .5074 .22177 .51285 .2285 .51329 .22374 .50786 Mtetra
.436 .664 .958 r
.22374 .50786 .2285 .51329 .23528 .51368 .23051 .50827 Mtetra
.442 .668 .958 r
.23051 .50827 .23528 .51368 .24208 .51398 .23732 .5086 Mtetra
.449 .673 .959 r
.23732 .5086 .24208 .51398 .24893 .51419 .24417 .50883 Mtetra
.459 .679 .96 r
.24417 .50883 .24893 .51419 .25581 .51428 .25106 .50895 Mtetra
.47 .685 .96 r
.25106 .50895 .25581 .51428 .26273 .51423 .25798 .50893 Mtetra
.483 .692 .96 r
.25798 .50893 .26273 .51423 .26968 .51402 .26495 .50874 Mtetra
.497 .7 .96 r
.26495 .50874 .26968 .51402 .27668 .51362 .27195 .50837 Mtetra
.513 .708 .959 r
.27195 .50837 .27668 .51362 .28372 .513 .279 .50779 Mtetra
.53 .716 .958 r
.279 .50779 .28372 .513 .29081 .51216 .28609 .50697 Mtetra
.547 .725 .956 r
.28609 .50697 .29081 .51216 .29793 .51105 .29322 .5059 Mtetra
.566 .734 .954 r
.29322 .5059 .29793 .51105 .3051 .50965 .30039 .50453 Mtetra
.585 .742 .951 r
.30039 .50453 .3051 .50965 .31231 .50794 .30761 .50286 Mtetra
.605 .751 .947 r
.30761 .50286 .31231 .50794 .31956 .50588 .31487 .50084 Mtetra
.625 .759 .943 r
.31487 .50084 .31956 .50588 .32685 .50345 .32217 .49845 Mtetra
.646 .767 .937 r
.32217 .49845 .32685 .50345 .33418 .50061 .32952 .49565 Mtetra
.666 .775 .931 r
.32952 .49565 .33418 .50061 .34156 .49733 .33691 .49242 Mtetra
.687 .782 .923 r
.33691 .49242 .34156 .49733 .34898 .49358 .34433 .48871 Mtetra
.707 .789 .915 r
.34433 .48871 .34898 .49358 .35643 .48931 .3518 .4845 Mtetra
.727 .795 .906 r
.3518 .4845 .35643 .48931 .36393 .48449 .35931 .47973 Mtetra
.746 .8 .896 r
.35931 .47973 .36393 .48449 .37146 .47908 .36686 .47438 Mtetra
.765 .805 .886 r
.36686 .47438 .37146 .47908 .37903 .47303 .37444 .46839 Mtetra
.783 .809 .874 r
.37444 .46839 .37903 .47303 .38663 .46629 .38206 .46172 Mtetra
.8 .813 .862 r
.38206 .46172 .38663 .46629 .39426 .45882 .38971 .45431 Mtetra
.817 .815 .849 r
.38971 .45431 .39426 .45882 .40192 .45055 .39739 .44611 Mtetra
.832 .817 .835 r
.39739 .44611 .40192 .45055 .40961 .44143 .4051 .43705 Mtetra
.847 .818 .82 r
.4051 .43705 .40961 .44143 .41732 .43137 .41283 .42704 Mtetra
.862 .817 .804 r
.41283 .42704 .41732 .43137 .42506 .42029 .42059 .41598 Mtetra
0 .412 .843 r
.56784 .35271 .57198 .35734 .58004 .36188 .57592 .35721 Mtetra
.085 .5 .9 r
.57592 .35721 .58004 .36188 .58815 .36541 .58404 .36065 Mtetra
.196 .571 .939 r
.58404 .36065 .58815 .36541 .5963 .368 .59219 .36315 Mtetra
.291 .625 .961 r
.59219 .36315 .5963 .368 .60447 .36974 .60038 .36479 Mtetra
.371 .667 .972 r
.60038 .36479 .60447 .36974 .61267 .37068 .60859 .36563 Mtetra
.438 .698 .975 r
.60859 .36563 .61267 .37068 .6209 .37088 .61683 .36573 Mtetra
.492 .721 .973 r
.61683 .36573 .6209 .37088 .62915 .37039 .62509 .36514 Mtetra
.538 .738 .968 r
.62509 .36514 .62915 .37039 .63741 .36926 .63337 .36391 Mtetra
.575 .751 .961 r
.63337 .36391 .63741 .36926 .64569 .36752 .64167 .36208 Mtetra
.607 .761 .953 r
.64167 .36208 .64569 .36752 .65398 .36522 .64998 .35969 Mtetra
.633 .768 .945 r
.64998 .35969 .65398 .36522 .66229 .3624 .6583 .35679 Mtetra
.655 .774 .936 r
.6583 .35679 .66229 .3624 .6706 .35909 .66663 .3534 Mtetra
.674 .778 .928 r
.66663 .3534 .6706 .35909 .67892 .35532 .67497 .34955 Mtetra
.69 .781 .921 r
.67497 .34955 .67892 .35532 .68725 .35114 .68331 .34529 Mtetra
.704 .784 .913 r
.68331 .34529 .68725 .35114 .69558 .34656 .69166 .34064 Mtetra
.716 .786 .907 r
.69166 .34064 .69558 .34656 .70392 .34163 .70001 .33564 Mtetra
.726 .787 .901 r
.70001 .33564 .70392 .34163 .71226 .33637 .70837 .33031 Mtetra
.735 .788 .895 r
.70837 .33031 .71226 .33637 .7206 .3308 .71673 .32467 Mtetra
.743 .789 .89 r
.71673 .32467 .7206 .3308 .72894 .32496 .72509 .31876 Mtetra
.75 .789 .885 r
.72509 .31876 .72894 .32496 .73729 .31886 .73345 .3126 Mtetra
.755 .789 .881 r
.73345 .3126 .73729 .31886 .74563 .31255 .74182 .30622 Mtetra
.76 .789 .877 r
.74182 .30622 .74563 .31255 .75398 .30602 .75018 .29963 Mtetra
.764 .789 .873 r
.75018 .29963 .75398 .30602 .76233 .29932 .75855 .29287 Mtetra
.768 .788 .87 r
.75855 .29287 .76233 .29932 .77068 .29247 .76692 .28595 Mtetra
.77 .788 .867 r
.76692 .28595 .77068 .29247 .77903 .28548 .77529 .2789 Mtetra
.772 .787 .865 r
.77529 .2789 .77903 .28548 .78739 .27839 .78366 .27174 Mtetra
.774 .787 .863 r
.78366 .27174 .78739 .27839 .79575 .2712 .79204 .2645 Mtetra
.775 .786 .861 r
.79204 .2645 .79575 .2712 .80411 .26394 .80042 .25718 Mtetra
.776 .785 .86 r
.80042 .25718 .80411 .26394 .81248 .25664 .80881 .24982 Mtetra
.776 .783 .859 r
.80881 .24982 .81248 .25664 .82086 .24931 .81721 .24243 Mtetra
.425 .654 .955 r
.19881 .50085 .20361 .50638 .21029 .5069 .20549 .5014 Mtetra
.425 .656 .956 r
.20549 .5014 .21029 .5069 .217 .5074 .2122 .50192 Mtetra
.427 .659 .957 r
.2122 .50192 .217 .5074 .22374 .50786 .21894 .50242 Mtetra
.431 .662 .958 r
.21894 .50242 .22374 .50786 .23051 .50827 .22572 .50285 Mtetra
.437 .667 .959 r
.22572 .50285 .23051 .50827 .23732 .5086 .23254 .50322 Mtetra
.445 .672 .96 r
.23254 .50322 .23732 .5086 .24417 .50883 .23939 .50348 Mtetra
.454 .678 .961 r
.23939 .50348 .24417 .50883 .25106 .50895 .24628 .50363 Mtetra
.465 .685 .961 r
.24628 .50363 .25106 .50895 .25798 .50893 .25321 .50364 Mtetra
.478 .692 .961 r
.25321 .50364 .25798 .50893 .26495 .50874 .26018 .50348 Mtetra
.492 .7 .962 r
.26018 .50348 .26495 .50874 .27195 .50837 .26719 .50315 Mtetra
.508 .708 .961 r
.26719 .50315 .27195 .50837 .279 .50779 .27424 .5026 Mtetra
.524 .717 .96 r
.27424 .5026 .279 .50779 .28609 .50697 .28134 .50182 Mtetra
.542 .726 .959 r
.28134 .50182 .28609 .50697 .29322 .5059 .28848 .50079 Mtetra
.561 .735 .957 r
.28848 .50079 .29322 .5059 .30039 .50453 .29566 .49946 Mtetra
.581 .744 .954 r
.29566 .49946 .30039 .50453 .30761 .50286 .30288 .49783 Mtetra
.601 .753 .951 r
.30288 .49783 .30761 .50286 .31487 .50084 .31015 .49586 Mtetra
.621 .762 .946 r
.31015 .49586 .31487 .50084 .32217 .49845 .31747 .49352 Mtetra
.642 .77 .941 r
.31747 .49352 .32217 .49845 .32952 .49565 .32482 .49077 Mtetra
.663 .778 .935 r
.32482 .49077 .32952 .49565 .33691 .49242 .33222 .48759 Mtetra
.683 .786 .928 r
.33222 .48759 .33691 .49242 .34433 .48871 .33966 .48394 Mtetra
.704 .793 .92 r
.33966 .48394 .34433 .48871 .3518 .4845 .34714 .47979 Mtetra
.724 .8 .911 r
.34714 .47979 .3518 .4845 .35931 .47973 .35466 .47509 Mtetra
.744 .806 .901 r
.35466 .47509 .35931 .47973 .36686 .47438 .36222 .46981 Mtetra
.763 .811 .891 r
.36222 .46981 .36686 .47438 .37444 .46839 .36982 .4639 Mtetra
.782 .816 .879 r
.36982 .4639 .37444 .46839 .38206 .46172 .37745 .4573 Mtetra
.8 .819 .867 r
.37745 .4573 .38206 .46172 .38971 .45431 .38512 .44998 Mtetra
.817 .822 .854 r
.38512 .44998 .38971 .45431 .39739 .44611 .39282 .44186 Mtetra
.833 .825 .84 r
.39282 .44186 .39739 .44611 .4051 .43705 .40055 .43288 Mtetra
.849 .826 .824 r
.40055 .43288 .4051 .43705 .41283 .42704 .40831 .42295 Mtetra
.864 .825 .808 r
.40831 .42295 .41283 .42704 .42059 .41598 .41609 .41194 Mtetra
0 .409 .833 r
.56369 .34836 .56784 .35271 .57592 .35721 .57177 .35277 Mtetra
.072 .503 .897 r
.57177 .35277 .57592 .35721 .58404 .36065 .5799 .3561 Mtetra
.189 .577 .939 r
.5799 .3561 .58404 .36065 .59219 .36315 .58807 .35849 Mtetra
.288 .633 .964 r
.58807 .35849 .59219 .36315 .60038 .36479 .59627 .36 Mtetra
.37 .675 .976 r
.59627 .36 .60038 .36479 .60859 .36563 .6045 .36072 Mtetra
.438 .706 .979 r
.6045 .36072 .60859 .36563 .61683 .36573 .61275 .36071 Mtetra
.494 .729 .977 r
.61275 .36071 .61683 .36573 .62509 .36514 .62102 .36001 Mtetra
.54 .746 .971 r
.62102 .36001 .62509 .36514 .63337 .36391 .62932 .35868 Mtetra
.578 .758 .964 r
.62932 .35868 .63337 .36391 .64167 .36208 .63763 .35675 Mtetra
.609 .768 .956 r
.63763 .35675 .64167 .36208 .64998 .35969 .64595 .35426 Mtetra
.636 .775 .947 r
.64595 .35426 .64998 .35969 .6583 .35679 .65429 .35126 Mtetra
.658 .78 .938 r
.65429 .35126 .6583 .35679 .66663 .3534 .66263 .34778 Mtetra
.677 .783 .93 r
.66263 .34778 .66663 .3534 .67497 .34955 .67099 .34385 Mtetra
.693 .786 .922 r
.67099 .34385 .67497 .34955 .68331 .34529 .67935 .33951 Mtetra
.707 .788 .915 r
.67935 .33951 .68331 .34529 .69166 .34064 .68771 .33478 Mtetra
.718 .79 .908 r
.68771 .33478 .69166 .34064 .70001 .33564 .69609 .32969 Mtetra
.729 .791 .902 r
.69609 .32969 .70001 .33564 .70837 .33031 .70446 .32428 Mtetra
.737 .791 .896 r
.70446 .32428 .70837 .33031 .71673 .32467 .71284 .31857 Mtetra
.745 .792 .89 r
.71284 .31857 .71673 .32467 .72509 .31876 .72122 .31259 Mtetra
.751 .792 .885 r
.72122 .31259 .72509 .31876 .73345 .3126 .7296 .30635 Mtetra
.757 .791 .881 r
.7296 .30635 .73345 .3126 .74182 .30622 .73798 .2999 Mtetra
.762 .791 .877 r
.73798 .2999 .74182 .30622 .75018 .29963 .74636 .29324 Mtetra
.766 .791 .873 r
.74636 .29324 .75018 .29963 .75855 .29287 .75475 .28641 Mtetra
.769 .79 .87 r
.75475 .28641 .75855 .29287 .76692 .28595 .76314 .27943 Mtetra
.772 .789 .867 r
.76314 .27943 .76692 .28595 .77529 .2789 .77153 .27231 Mtetra
.774 .789 .865 r
.77153 .27231 .77529 .2789 .78366 .27174 .77992 .26509 Mtetra
.775 .788 .863 r
.77992 .26509 .78366 .27174 .79204 .2645 .78832 .25777 Mtetra
.776 .786 .861 r
.78832 .25777 .79204 .2645 .80042 .25718 .79672 .25039 Mtetra
.777 .785 .86 r
.79672 .25039 .80042 .25718 .80881 .24982 .80512 .24296 Mtetra
.777 .784 .859 r
.80512 .24296 .80881 .24982 .81721 .24243 .81354 .23551 Mtetra
.42 .652 .955 r
.19398 .49529 .19881 .50085 .20549 .5014 .20067 .49587 Mtetra
.42 .654 .956 r
.20067 .49587 .20549 .5014 .2122 .50192 .20738 .49643 Mtetra
.422 .657 .957 r
.20738 .49643 .2122 .50192 .21894 .50242 .21413 .49696 Mtetra
.426 .661 .958 r
.21413 .49696 .21894 .50242 .22572 .50285 .22091 .49743 Mtetra
.432 .665 .959 r
.22091 .49743 .22572 .50285 .23254 .50322 .22772 .49783 Mtetra
.439 .671 .961 r
.22772 .49783 .23254 .50322 .23939 .50348 .23458 .49813 Mtetra
.449 .677 .961 r
.23458 .49813 .23939 .50348 .24628 .50363 .24147 .49831 Mtetra
.46 .684 .962 r
.24147 .49831 .24628 .50363 .25321 .50364 .24841 .49836 Mtetra
.472 .691 .963 r
.24841 .49836 .25321 .50364 .26018 .50348 .25538 .49824 Mtetra
.486 .699 .963 r
.25538 .49824 .26018 .50348 .26719 .50315 .2624 .49795 Mtetra
.502 .708 .963 r
.2624 .49795 .26719 .50315 .27424 .5026 .26946 .49744 Mtetra
.519 .717 .962 r
.26946 .49744 .27424 .5026 .28134 .50182 .27656 .49671 Mtetra
.537 .726 .961 r
.27656 .49671 .28134 .50182 .28848 .50079 .28371 .49572 Mtetra
.556 .736 .96 r
.28371 .49572 .28848 .50079 .29566 .49946 .2909 .49444 Mtetra
.575 .745 .957 r
.2909 .49444 .29566 .49946 .30288 .49783 .29813 .49286 Mtetra
.596 .755 .954 r
.29813 .49286 .30288 .49783 .31015 .49586 .30541 .49094 Mtetra
.616 .764 .95 r
.30541 .49094 .31015 .49586 .31747 .49352 .31273 .48865 Mtetra
.637 .773 .945 r
.31273 .48865 .31747 .49352 .32482 .49077 .32009 .48597 Mtetra
.659 .782 .939 r
.32009 .48597 .32482 .49077 .33222 .48759 .3275 .48285 Mtetra
.68 .79 .933 r
.3275 .48285 .33222 .48759 .33966 .48394 .33495 .47927 Mtetra
.701 .797 .925 r
.33495 .47927 .33966 .48394 .34714 .47979 .34245 .47519 Mtetra
.721 .804 .916 r
.34245 .47519 .34714 .47979 .35466 .47509 .34998 .47057 Mtetra
.742 .811 .907 r
.34998 .47057 .35466 .47509 .36222 .46981 .35755 .46537 Mtetra
.761 .817 .896 r
.35755 .46537 .36222 .46981 .36982 .4639 .36517 .45954 Mtetra
.78 .822 .885 r
.36517 .45954 .36982 .4639 .37745 .4573 .37282 .45304 Mtetra
.799 .826 .873 r
.37282 .45304 .37745 .4573 .38512 .44998 .3805 .44582 Mtetra
.817 .83 .859 r
.3805 .44582 .38512 .44998 .39282 .44186 .38822 .43781 Mtetra
.834 .832 .845 r
.38822 .43781 .39282 .44186 .40055 .43288 .39597 .42893 Mtetra
.85 .834 .83 r
.39597 .42893 .40055 .43288 .40831 .42295 .40375 .4191 Mtetra
.866 .834 .813 r
.40375 .4191 .40831 .42295 .41609 .41194 .41155 .40819 Mtetra
0 .408 .823 r
.55951 .3443 .56369 .34836 .57177 .35277 .56761 .34858 Mtetra
.061 .508 .894 r
.56761 .34858 .57177 .35277 .5799 .3561 .57575 .35177 Mtetra
.183 .585 .94 r
.57575 .35177 .5799 .3561 .58807 .35849 .58392 .35401 Mtetra
.286 .642 .966 r
.58392 .35401 .58807 .35849 .59627 .36 .59213 .35539 Mtetra
.371 .685 .979 r
.59213 .35539 .59627 .36 .6045 .36072 .60038 .35598 Mtetra
.44 .716 .983 r
.60038 .35598 .6045 .36072 .61275 .36071 .60864 .35584 Mtetra
.496 .738 .98 r
.60864 .35584 .61275 .36071 .62102 .36001 .61693 .35501 Mtetra
.543 .754 .975 r
.61693 .35501 .62102 .36001 .62932 .35868 .62524 .35356 Mtetra
.581 .766 .967 r
.62524 .35356 .62932 .35868 .63763 .35675 .63356 .35152 Mtetra
.613 .775 .958 r
.63356 .35152 .63763 .35675 .64595 .35426 .6419 .34893 Mtetra
.639 .781 .949 r
.6419 .34893 .64595 .35426 .65429 .35126 .65026 .34582 Mtetra
.661 .786 .94 r
.65026 .34582 .65429 .35126 .66263 .34778 .65862 .34224 Mtetra
.68 .789 .932 r
.65862 .34224 .66263 .34778 .67099 .34385 .66699 .33822 Mtetra
.696 .791 .924 r
.66699 .33822 .67099 .34385 .67935 .33951 .67537 .33378 Mtetra
.709 .793 .916 r
.67537 .33378 .67935 .33951 .68771 .33478 .68375 .32896 Mtetra
.721 .794 .909 r
.68375 .32896 .68771 .33478 .69609 .32969 .69214 .32379 Mtetra
.731 .794 .902 r
.69214 .32379 .69609 .32969 .70446 .32428 .70053 .31829 Mtetra
.74 .795 .896 r
.70053 .31829 .70446 .32428 .71284 .31857 .70893 .3125 Mtetra
.747 .795 .891 r
.70893 .3125 .71284 .31857 .72122 .31259 .71733 .30644 Mtetra
.754 .794 .886 r
.71733 .30644 .72122 .31259 .7296 .30635 .72572 .30013 Mtetra
.759 .794 .881 r
.72572 .30013 .7296 .30635 .73798 .2999 .73413 .29359 Mtetra
.764 .793 .877 r
.73413 .29359 .73798 .2999 .74636 .29324 .74253 .28686 Mtetra
.768 .793 .873 r
.74253 .28686 .74636 .29324 .75475 .28641 .75093 .27996 Mtetra
.771 .792 .87 r
.75093 .27996 .75475 .28641 .76314 .27943 .75934 .2729 Mtetra
.773 .791 .867 r
.75934 .2729 .76314 .27943 .77153 .27231 .76775 .26571 Mtetra
.775 .79 .865 r
.76775 .26571 .77153 .27231 .77992 .26509 .77616 .25841 Mtetra
.777 .789 .863 r
.77616 .25841 .77992 .26509 .78832 .25777 .78457 .25102 Mtetra
.778 .787 .861 r
.78457 .25102 .78832 .25777 .79672 .25039 .79299 .24357 Mtetra
.778 .786 .859 r
.79299 .24357 .79672 .25039 .80512 .24296 .80142 .23607 Mtetra
.778 .784 .858 r
.80142 .23607 .80512 .24296 .81354 .23551 .80985 .22855 Mtetra
.416 .65 .955 r
.18913 .48971 .19398 .49529 .20067 .49587 .19582 .49032 Mtetra
.415 .652 .956 r
.19582 .49032 .20067 .49587 .20738 .49643 .20253 .49092 Mtetra
.417 .655 .957 r
.20253 .49092 .20738 .49643 .21413 .49696 .20928 .49149 Mtetra
.421 .659 .959 r
.20928 .49149 .21413 .49696 .22091 .49743 .21607 .492 Mtetra
.426 .663 .96 r
.21607 .492 .22091 .49743 .22772 .49783 .22289 .49243 Mtetra
.433 .669 .961 r
.22289 .49243 .22772 .49783 .23458 .49813 .22974 .49278 Mtetra
.443 .675 .962 r
.22974 .49278 .23458 .49813 .24147 .49831 .23664 .493 Mtetra
.454 .683 .963 r
.23664 .493 .24147 .49831 .24841 .49836 .24358 .49309 Mtetra
.466 .69 .964 r
.24358 .49309 .24841 .49836 .25538 .49824 .25056 .49302 Mtetra
.48 .699 .965 r
.25056 .49302 .25538 .49824 .2624 .49795 .25758 .49277 Mtetra
.496 .708 .965 r
.25758 .49277 .2624 .49795 .26946 .49744 .26464 .49232 Mtetra
.512 .717 .965 r
.26464 .49232 .26946 .49744 .27656 .49671 .27175 .49163 Mtetra
.53 .727 .964 r
.27175 .49163 .27656 .49671 .28371 .49572 .2789 .49069 Mtetra
.549 .736 .963 r
.2789 .49069 .28371 .49572 .2909 .49444 .2861 .48947 Mtetra
.569 .746 .96 r
.2861 .48947 .2909 .49444 .29813 .49286 .29334 .48795 Mtetra
.59 .756 .958 r
.29334 .48795 .29813 .49286 .30541 .49094 .30063 .48609 Mtetra
.611 .766 .954 r
.30063 .48609 .30541 .49094 .31273 .48865 .30796 .48386 Mtetra
.632 .776 .949 r
.30796 .48386 .31273 .48865 .32009 .48597 .31533 .48125 Mtetra
.654 .785 .944 r
.31533 .48125 .32009 .48597 .3275 .48285 .32275 .4782 Mtetra
.675 .793 .937 r
.32275 .4782 .3275 .48285 .33495 .47927 .33021 .4747 Mtetra
.697 .802 .93 r
.33021 .4747 .33495 .47927 .34245 .47519 .33772 .4707 Mtetra
.718 .809 .922 r
.33772 .4707 .34245 .47519 .34998 .47057 .34526 .46616 Mtetra
.739 .816 .912 r
.34526 .46616 .34998 .47057 .35755 .46537 .35285 .46105 Mtetra
.759 .822 .902 r
.35285 .46105 .35755 .46537 .36517 .45954 .36048 .45533 Mtetra
.778 .828 .891 r
.36048 .45533 .36517 .45954 .37282 .45304 .36814 .44894 Mtetra
.798 .833 .879 r
.36814 .44894 .37282 .45304 .3805 .44582 .37584 .44183 Mtetra
.816 .837 .865 r
.37584 .44183 .3805 .44582 .38822 .43781 .38358 .43394 Mtetra
.834 .84 .851 r
.38358 .43394 .38822 .43781 .39597 .42893 .39135 .42519 Mtetra
.851 .842 .836 r
.39135 .42519 .39597 .42893 .40375 .4191 .39915 .4155 Mtetra
.868 .843 .819 r
.39915 .4155 .40375 .4191 .41155 .40819 .40697 .40474 Mtetra
0 .411 .814 r
.5553 .34054 .55951 .3443 .56761 .34858 .56341 .34463 Mtetra
.053 .515 .891 r
.56341 .34463 .56761 .34858 .57575 .35177 .57156 .34765 Mtetra
.18 .594 .941 r
.57156 .34765 .57575 .35177 .58392 .35401 .57975 .34973 Mtetra
.286 .652 .969 r
.57975 .34973 .58392 .35401 .59213 .35539 .58798 .35095 Mtetra
.372 .695 .982 r
.58798 .35095 .59213 .35539 .60038 .35598 .59623 .35139 Mtetra
.443 .725 .986 r
.59623 .35139 .60038 .35598 .60864 .35584 .60451 .3511 Mtetra
.5 .747 .983 r
.60451 .3511 .60864 .35584 .61693 .35501 .61282 .35014 Mtetra
.547 .763 .977 r
.61282 .35014 .61693 .35501 .62524 .35356 .62114 .34856 Mtetra
.585 .774 .969 r
.62114 .34856 .62524 .35356 .63356 .35152 .62948 .34639 Mtetra
.616 .782 .961 r
.62948 .34639 .63356 .35152 .6419 .34893 .63783 .34368 Mtetra
.643 .787 .951 r
.63783 .34368 .6419 .34893 .65026 .34582 .6462 .34047 Mtetra
.665 .791 .942 r
.6462 .34047 .65026 .34582 .65862 .34224 .65458 .33678 Mtetra
.683 .794 .933 r
.65458 .33678 .65862 .34224 .66699 .33822 .66297 .33265 Mtetra
.699 .796 .925 r
.66297 .33265 .66699 .33822 .67537 .33378 .67137 .32811 Mtetra
.712 .797 .917 r
.67137 .32811 .67537 .33378 .68375 .32896 .67977 .32319 Mtetra
.724 .798 .91 r
.67977 .32319 .68375 .32896 .69214 .32379 .68817 .31793 Mtetra
.734 .798 .903 r
.68817 .31793 .69214 .32379 .70053 .31829 .69658 .31234 Mtetra
.742 .798 .897 r
.69658 .31234 .70053 .31829 .70893 .3125 .705 .30646 Mtetra
.75 .798 .891 r
.705 .30646 .70893 .3125 .71733 .30644 .71341 .30031 Mtetra
.756 .797 .886 r
.71341 .30031 .71733 .30644 .72572 .30013 .72183 .29391 Mtetra
.761 .796 .881 r
.72183 .29391 .72572 .30013 .73413 .29359 .73025 .2873 Mtetra
.766 .795 .877 r
.73025 .2873 .73413 .29359 .74253 .28686 .73867 .28048 Mtetra
.769 .795 .873 r
.73867 .28048 .74253 .28686 .75093 .27996 .74709 .2735 Mtetra
.772 .793 .87 r
.74709 .2735 .75093 .27996 .75934 .2729 .75552 .26636 Mtetra
.775 .792 .867 r
.75552 .26636 .75934 .2729 .76775 .26571 .76395 .25909 Mtetra
.777 .791 .864 r
.76395 .25909 .76775 .26571 .77616 .25841 .77237 .25172 Mtetra
.778 .79 .862 r
.77237 .25172 .77616 .25841 .78457 .25102 .78081 .24425 Mtetra
.779 .788 .86 r
.78081 .24425 .78457 .25102 .79299 .24357 .78925 .23672 Mtetra
.779 .787 .859 r
.78925 .23672 .79299 .24357 .80142 .23607 .79769 .22915 Mtetra
.779 .785 .857 r
.79769 .22915 .80142 .23607 .80985 .22855 .80614 .22155 Mtetra
.41 .647 .955 r
.18426 .48409 .18913 .48971 .19582 .49032 .19094 .48475 Mtetra
.41 .65 .956 r
.19094 .48475 .19582 .49032 .20253 .49092 .19766 .48539 Mtetra
.411 .653 .958 r
.19766 .48539 .20253 .49092 .20928 .49149 .20441 .486 Mtetra
.415 .657 .959 r
.20441 .486 .20928 .49149 .21607 .492 .2112 .48656 Mtetra
.42 .661 .96 r
.2112 .48656 .21607 .492 .22289 .49243 .21802 .48704 Mtetra
.427 .667 .962 r
.21802 .48704 .22289 .49243 .22974 .49278 .22488 .48743 Mtetra
.436 .674 .963 r
.22488 .48743 .22974 .49278 .23664 .493 .23178 .4877 Mtetra
.447 .681 .964 r
.23178 .4877 .23664 .493 .24358 .49309 .23872 .48784 Mtetra
.459 .689 .965 r
.23872 .48784 .24358 .49309 .25056 .49302 .24571 .48782 Mtetra
.473 .698 .966 r
.24571 .48782 .25056 .49302 .25758 .49277 .25273 .48762 Mtetra
.489 .707 .967 r
.25273 .48762 .25758 .49277 .26464 .49232 .2598 .48722 Mtetra
.506 .717 .967 r
.2598 .48722 .26464 .49232 .27175 .49163 .26691 .48659 Mtetra
.524 .727 .966 r
.26691 .48659 .27175 .49163 .2789 .49069 .27407 .48571 Mtetra
.543 .737 .965 r
.27407 .48571 .2789 .49069 .2861 .48947 .28127 .48455 Mtetra
.563 .747 .964 r
.28127 .48455 .2861 .48947 .29334 .48795 .28852 .48309 Mtetra
.583 .758 .961 r
.28852 .48309 .29334 .48795 .30063 .48609 .29581 .4813 Mtetra
.605 .768 .958 r
.29581 .4813 .30063 .48609 .30796 .48386 .30315 .47914 Mtetra
.626 .778 .954 r
.30315 .47914 .30796 .48386 .31533 .48125 .31054 .4766 Mtetra
.648 .788 .949 r
.31054 .4766 .31533 .48125 .32275 .4782 .31796 .47363 Mtetra
.67 .797 .942 r
.31796 .47363 .32275 .4782 .33021 .4747 .32544 .47021 Mtetra
.692 .806 .935 r
.32544 .47021 .33021 .4747 .33772 .4707 .33295 .46631 Mtetra
.714 .814 .927 r
.33295 .46631 .33772 .4707 .34526 .46616 .34051 .46187 Mtetra
.735 .821 .918 r
.34051 .46187 .34526 .46616 .35285 .46105 .34811 .45687 Mtetra
.756 .828 .908 r
.34811 .45687 .35285 .46105 .36048 .45533 .35575 .45125 Mtetra
.776 .834 .897 r
.35575 .45125 .36048 .45533 .36814 .44894 .36343 .44498 Mtetra
.795 .84 .885 r
.36343 .44498 .36814 .44894 .37584 .44183 .37115 .438 Mtetra
.814 .844 .872 r
.37115 .438 .37584 .44183 .38358 .43394 .3789 .43026 Mtetra
.833 .848 .858 r
.3789 .43026 .38358 .43394 .39135 .42519 .38669 .42167 Mtetra
.851 .851 .842 r
.38669 .42167 .39135 .42519 .39915 .4155 .39451 .41215 Mtetra
.868 .853 .825 r
.39451 .41215 .39915 .4155 .40697 .40474 .40236 .40157 Mtetra
.885 .854 .807 r
.40236 .40157 .40697 .40474 .41483 .39273 .41024 .38979 Mtetra
0 .286 .688 r
.543 .332 .54724 .33521 .5553 .34054 .55107 .33707 Mtetra
0 .418 .807 r
.55107 .33707 .5553 .34054 .56341 .34463 .55919 .34093 Mtetra
.05 .524 .889 r
.55919 .34093 .56341 .34463 .57156 .34765 .56736 .34375 Mtetra
.18 .604 .942 r
.56736 .34375 .57156 .34765 .57975 .34973 .57556 .34563 Mtetra
.288 .663 .971 r
.57556 .34563 .57975 .34973 .58798 .35095 .5838 .34668 Mtetra
.376 .706 .985 r
.5838 .34668 .58798 .35095 .59623 .35139 .59207 .34694 Mtetra
.447 .736 .989 r
.59207 .34694 .59623 .35139 .60451 .3511 .60036 .3465 Mtetra
.504 .757 .986 r
.60036 .3465 .60451 .3511 .61282 .35014 .60868 .34539 Mtetra
.551 .772 .98 r
.60868 .34539 .61282 .35014 .62114 .34856 .61702 .34367 Mtetra
.589 .782 .972 r
.61702 .34367 .62114 .34856 .62948 .34639 .62537 .34137 Mtetra
.621 .789 .963 r
.62537 .34137 .62948 .34639 .63783 .34368 .63374 .33853 Mtetra
.647 .794 .953 r
.63374 .33853 .63783 .34368 .6462 .34047 .64213 .33519 Mtetra
.669 .797 .944 r
.64213 .33519 .6462 .34047 .65458 .33678 .65053 .33139 Mtetra
.687 .8 .935 r
.65053 .33139 .65458 .33678 .66297 .33265 .65893 .32714 Mtetra
.702 .801 .926 r
.65893 .32714 .66297 .33265 .67137 .32811 .66734 .3225 Mtetra
.716 .802 .918 r
.66734 .3225 .67137 .32811 .67977 .32319 .67576 .31748 Mtetra
.727 .802 .911 r
.67576 .31748 .67977 .32319 .68817 .31793 .68419 .31211 Mtetra
.737 .802 .904 r
.68419 .31211 .68817 .31793 .69658 .31234 .69262 .30643 Mtetra
.745 .801 .897 r
.69262 .30643 .69658 .31234 .705 .30646 .70105 .30045 Mtetra
.752 .801 .892 r
.70105 .30045 .705 .30646 .71341 .30031 .70948 .2942 Mtetra
.758 .8 .886 r
.70948 .2942 .71341 .30031 .72183 .29391 .71792 .28772 Mtetra
.763 .799 .882 r
.71792 .28772 .72183 .29391 .73025 .2873 .72636 .28101 Mtetra
.768 .798 .877 r
.72636 .28101 .73025 .2873 .73867 .28048 .73479 .27411 Mtetra
.771 .796 .873 r
.73479 .27411 .73867 .28048 .74709 .2735 .74324 .26704 Mtetra
.774 .795 .87 r
.74324 .26704 .74709 .2735 .75552 .26636 .75168 .25982 Mtetra
.777 .794 .867 r
.75168 .25982 .75552 .26636 .76395 .25909 .76012 .25246 Mtetra
.779 .792 .864 r
.76012 .25246 .76395 .25909 .77237 .25172 .76857 .24501 Mtetra
.78 .791 .862 r
.76857 .24501 .77237 .25172 .78081 .24425 .77702 .23746 Mtetra
.781 .789 .86 r
.77702 .23746 .78081 .24425 .78925 .23672 .78548 .22985 Mtetra
.781 .787 .858 r
.78548 .22985 .78925 .23672 .79769 .22915 .79394 .22219 Mtetra
.781 .786 .857 r
.79394 .22219 .79769 .22915 .80614 .22155 .80241 .21451 Mtetra
.404 .645 .955 r
.17936 .47845 .18426 .48409 .19094 .48475 .18605 .47915 Mtetra
.403 .647 .956 r
.18605 .47915 .19094 .48475 .19766 .48539 .19276 .47984 Mtetra
.405 .65 .958 r
.19276 .47984 .19766 .48539 .20441 .486 .19952 .4805 Mtetra
.408 .654 .959 r
.19952 .4805 .20441 .486 .2112 .48656 .2063 .48111 Mtetra
.413 .659 .961 r
.2063 .48111 .2112 .48656 .21802 .48704 .21313 .48164 Mtetra
.42 .665 .962 r
.21313 .48164 .21802 .48704 .22488 .48743 .21999 .48208 Mtetra
.429 .672 .964 r
.21999 .48208 .22488 .48743 .23178 .4877 .22689 .4824 Mtetra
.439 .679 .965 r
.22689 .4824 .23178 .4877 .23872 .48784 .23384 .4826 Mtetra
.452 .687 .967 r
.23384 .4826 .23872 .48784 .24571 .48782 .24082 .48263 Mtetra
.466 .696 .968 r
.24082 .48263 .24571 .48782 .25273 .48762 .24785 .48249 Mtetra
.481 .706 .968 r
.24785 .48249 .25273 .48762 .2598 .48722 .25493 .48215 Mtetra
.498 .716 .969 r
.25493 .48215 .2598 .48722 .26691 .48659 .26205 .48158 Mtetra
.516 .726 .969 r
.26205 .48158 .26691 .48659 .27407 .48571 .26921 .48076 Mtetra
.535 .737 .968 r
.26921 .48076 .27407 .48571 .28127 .48455 .27642 .47967 Mtetra
.555 .748 .967 r
.27642 .47967 .28127 .48455 .28852 .48309 .28367 .47828 Mtetra
.576 .759 .965 r
.28367 .47828 .28852 .48309 .29581 .4813 .29097 .47656 Mtetra
.598 .769 .962 r
.29097 .47656 .29581 .4813 .30315 .47914 .29832 .47449 Mtetra
.62 .78 .958 r
.29832 .47449 .30315 .47914 .31054 .4766 .30571 .47203 Mtetra
.642 .79 .953 r
.30571 .47203 .31054 .4766 .31796 .47363 .31315 .46915 Mtetra
.664 .8 .947 r
.31315 .46915 .31796 .47363 .32544 .47021 .32063 .46583 Mtetra
.687 .809 .941 r
.32063 .46583 .32544 .47021 .33295 .46631 .32816 .46202 Mtetra
.709 .818 .933 r
.32816 .46202 .33295 .46631 .34051 .46187 .33573 .45769 Mtetra
.73 .826 .924 r
.33573 .45769 .34051 .46187 .34811 .45687 .34334 .4528 Mtetra
.752 .834 .915 r
.34334 .4528 .34811 .45687 .35575 .45125 .35099 .44731 Mtetra
.772 .841 .904 r
.35099 .44731 .35575 .45125 .36343 .44498 .35869 .44118 Mtetra
.793 .847 .892 r
.35869 .44118 .36343 .44498 .37115 .438 .36642 .43435 Mtetra
.812 .852 .879 r
.36642 .43435 .37115 .438 .3789 .43026 .37419 .42676 Mtetra
.831 .856 .865 r
.37419 .42676 .3789 .43026 .38669 .42167 .38199 .41835 Mtetra
.85 .86 .85 r
.38199 .41835 .38669 .42167 .39451 .41215 .38983 .40903 Mtetra
.867 .863 .833 r
.38983 .40903 .39451 .41215 .40236 .40157 .3977 .39869 Mtetra
.885 .865 .814 r
.3977 .39869 .40236 .40157 .41024 .38979 .4056 .3872 Mtetra
0 .295 .677 r
.53873 .32913 .543 .332 .55107 .33707 .54681 .33388 Mtetra
0 .429 .801 r
.54681 .33388 .55107 .33707 .55919 .34093 .55495 .33747 Mtetra
.051 .536 .888 r
.55495 .33747 .55919 .34093 .56736 .34375 .56312 .34005 Mtetra
.183 .617 .943 r
.56312 .34005 .56736 .34375 .57556 .34563 .57134 .34172 Mtetra
.292 .676 .974 r
.57134 .34172 .57556 .34563 .5838 .34668 .57959 .34257 Mtetra
.381 .717 .988 r
.57959 .34257 .5838 .34668 .59207 .34694 .58787 .34265 Mtetra
.452 .747 .992 r
.58787 .34265 .59207 .34694 .60036 .3465 .59618 .34204 Mtetra
.51 .767 .989 r
.59618 .34204 .60036 .3465 .60868 .34539 .60452 .34077 Mtetra
.556 .781 .982 r
.60452 .34077 .60868 .34539 .61702 .34367 .61287 .33889 Mtetra
.594 .79 .974 r
.61287 .33889 .61702 .34367 .62537 .34137 .62124 .33645 Mtetra
.625 .797 .964 r
.62124 .33645 .62537 .34137 .63374 .33853 .62963 .33347 Mtetra
.651 .801 .955 r
.62963 .33347 .63374 .33853 .64213 .33519 .63803 .33 Mtetra
.673 .803 .945 r
.63803 .33 .64213 .33519 .65053 .33139 .64645 .32607 Mtetra
.691 .805 .936 r
.64645 .32607 .65053 .33139 .65893 .32714 .65487 .32171 Mtetra
.706 .806 .927 r
.65487 .32171 .65893 .32714 .66734 .3225 .6633 .31694 Mtetra
.719 .806 .919 r
.6633 .31694 .66734 .3225 .67576 .31748 .67174 .31181 Mtetra
.73 .806 .911 r
.67174 .31181 .67576 .31748 .68419 .31211 .68018 .30634 Mtetra
.74 .805 .904 r
.68018 .30634 .68419 .31211 .69262 .30643 .68863 .30055 Mtetra
.748 .804 .898 r
.68863 .30055 .69262 .30643 .70105 .30045 .69708 .29447 Mtetra
.755 .804 .892 r
.69708 .29447 .70105 .30045 .70948 .2942 .70553 .28812 Mtetra
.761 .802 .886 r
.70553 .28812 .70948 .2942 .71792 .28772 .71398 .28154 Mtetra
.766 .801 .881 r
.71398 .28154 .71792 .28772 .72636 .28101 .72244 .27474 Mtetra
.77 .8 .877 r
.72244 .27474 .72636 .28101 .73479 .27411 .7309 .26774 Mtetra
.774 .798 .873 r
.7309 .26774 .73479 .27411 .74324 .26704 .73936 .26058 Mtetra
.776 .797 .87 r
.73936 .26058 .74324 .26704 .75168 .25982 .74782 .25326 Mtetra
.779 .795 .866 r
.74782 .25326 .75168 .25982 .76012 .25246 .75628 .24582 Mtetra
.78 .794 .864 r
.75628 .24582 .76012 .25246 .76857 .24501 .76475 .23827 Mtetra
.782 .792 .861 r
.76475 .23827 .76857 .24501 .77702 .23746 .77322 .23064 Mtetra
.782 .79 .859 r
.77322 .23064 .77702 .23746 .78548 .22985 .78169 .22294 Mtetra
.782 .788 .857 r
.78169 .22294 .78548 .22985 .79394 .22219 .79017 .2152 Mtetra
.782 .786 .856 r
.79017 .2152 .79394 .22219 .80241 .21451 .79866 .20743 Mtetra
.398 .641 .955 r
.17444 .47277 .17936 .47845 .18605 .47915 .18112 .47353 Mtetra
.397 .644 .956 r
.18112 .47353 .18605 .47915 .19276 .47984 .18784 .47428 Mtetra
.398 .647 .958 r
.18784 .47428 .19276 .47984 .19952 .4805 .19459 .47499 Mtetra
.401 .651 .959 r
.19459 .47499 .19952 .4805 .2063 .48111 .20138 .47565 Mtetra
.405 .656 .961 r
.20138 .47565 .2063 .48111 .21313 .48164 .20821 .47623 Mtetra
.412 .662 .963 r
.20821 .47623 .21313 .48164 .21999 .48208 .21507 .47673 Mtetra
.421 .669 .965 r
.21507 .47673 .21999 .48208 .22689 .4824 .22198 .47711 Mtetra
.431 .677 .966 r
.22198 .47711 .22689 .4824 .23384 .4826 .22892 .47737 Mtetra
.443 .686 .968 r
.22892 .47737 .23384 .4826 .24082 .48263 .23591 .47746 Mtetra
.457 .695 .969 r
.23591 .47746 .24082 .48263 .24785 .48249 .24295 .47738 Mtetra
.473 .705 .97 r
.24295 .47738 .24785 .48249 .25493 .48215 .25002 .47711 Mtetra
.489 .715 .971 r
.25002 .47711 .25493 .48215 .26205 .48158 .25714 .47661 Mtetra
.508 .726 .971 r
.25714 .47661 .26205 .48158 .26921 .48076 .26431 .47586 Mtetra
.527 .737 .971 r
.26431 .47586 .26921 .48076 .27642 .47967 .27153 .47484 Mtetra
.547 .748 .97 r
.27153 .47484 .27642 .47967 .28367 .47828 .27879 .47353 Mtetra
.568 .759 .968 r
.27879 .47353 .28367 .47828 .29097 .47656 .28609 .47189 Mtetra
.59 .771 .966 r
.28609 .47189 .29097 .47656 .29832 .47449 .29345 .4699 Mtetra
.612 .782 .962 r
.29345 .4699 .29832 .47449 .30571 .47203 .30085 .46754 Mtetra
.635 .793 .958 r
.30085 .46754 .30571 .47203 .31315 .46915 .30829 .46476 Mtetra
.658 .803 .953 r
.30829 .46476 .31315 .46915 .32063 .46583 .31578 .46153 Mtetra
.68 .813 .946 r
.31578 .46153 .32063 .46583 .32816 .46202 .32332 .45783 Mtetra
.703 .822 .939 r
.32332 .45783 .32816 .46202 .33573 .45769 .3309 .45362 Mtetra
.725 .831 .931 r
.3309 .45362 .33573 .45769 .34334 .4528 .33853 .44886 Mtetra
.747 .839 .921 r
.33853 .44886 .34334 .4528 .35099 .44731 .34619 .44351 Mtetra
.768 .847 .911 r
.34619 .44351 .35099 .44731 .35869 .44118 .3539 .43753 Mtetra
.789 .854 .899 r
.3539 .43753 .35869 .44118 .36642 .43435 .36165 .43086 Mtetra
.809 .86 .886 r
.36165 .43086 .36642 .43435 .37419 .42676 .36944 .42345 Mtetra
.828 .865 .872 r
.36944 .42345 .37419 .42676 .38199 .41835 .37726 .41524 Mtetra
.847 .869 .857 r
.37726 .41524 .38199 .41835 .38983 .40903 .38511 .40615 Mtetra
.866 .873 .841 r
.38511 .40615 .38983 .40903 .3977 .39869 .393 .39609 Mtetra
.884 .877 .823 r
.393 .39609 .3977 .39869 .4056 .3872 .40092 .38493 Mtetra
0 .311 .672 r
.53443 .32659 .53873 .32913 .54681 .33388 .54252 .33096 Mtetra
0 .444 .799 r
.54252 .33096 .54681 .33388 .55495 .33747 .55067 .33425 Mtetra
.057 .551 .888 r
.55067 .33425 .55495 .33747 .56312 .34005 .55886 .33656 Mtetra
.189 .631 .944 r
.55886 .33656 .56312 .34005 .57134 .34172 .56709 .33799 Mtetra
.299 .689 .976 r
.56709 .33799 .57134 .34172 .57959 .34257 .57536 .33862 Mtetra
.388 .73 .99 r
.57536 .33862 .57959 .34257 .58787 .34265 .58366 .33851 Mtetra
.459 .758 .994 r
.58366 .33851 .58787 .34265 .59618 .34204 .59198 .33771 Mtetra
.516 .777 .991 r
.59198 .33771 .59618 .34204 .60452 .34077 .60033 .33626 Mtetra
.562 .79 .984 r
.60033 .33626 .60452 .34077 .61287 .33889 .6087 .33422 Mtetra
.6 .798 .976 r
.6087 .33422 .61287 .33889 .62124 .33645 .61709 .33162 Mtetra
.631 .804 .966 r
.61709 .33162 .62124 .33645 .62963 .33347 .6255 .3285 Mtetra
.656 .808 .956 r
.6255 .3285 .62963 .33347 .63803 .33 .63392 .32489 Mtetra
.677 .81 .946 r
.63392 .32489 .63803 .33 .64645 .32607 .64235 .32082 Mtetra
.695 .811 .937 r
.64235 .32082 .64645 .32607 .65487 .32171 .65079 .31633 Mtetra
.71 .811 .928 r
.65079 .31633 .65487 .32171 .6633 .31694 .65924 .31144 Mtetra
.723 .811 .919 r
.65924 .31144 .6633 .31694 .67174 .31181 .66769 .30619 Mtetra
.734 .81 .912 r
.66769 .30619 .67174 .31181 .68018 .30634 .67615 .3006 Mtetra
.743 .809 .904 r
.67615 .3006 .68018 .30634 .68863 .30055 .68462 .2947 Mtetra
.751 .808 .898 r
.68462 .2947 .68863 .30055 .69708 .29447 .69308 .28851 Mtetra
.758 .807 .892 r
.69308 .28851 .69708 .29447 .70553 .28812 .70156 .28206 Mtetra
.763 .805 .886 r
.70156 .28206 .70553 .28812 .71398 .28154 .71003 .27537 Mtetra
.768 .804 .881 r
.71003 .27537 .71398 .28154 .72244 .27474 .7185 .26847 Mtetra
.772 .802 .877 r
.7185 .26847 .72244 .27474 .7309 .26774 .72698 .26138 Mtetra
.776 .8 .873 r
.72698 .26138 .7309 .26774 .73936 .26058 .73546 .25411 Mtetra
.779 .799 .869 r
.73546 .25411 .73936 .26058 .74782 .25326 .74394 .2467 Mtetra
.781 .797 .866 r
.74394 .2467 .74782 .25326 .75628 .24582 .75242 .23917 Mtetra
.782 .795 .863 r
.75242 .23917 .75628 .24582 .76475 .23827 .7609 .23153 Mtetra
.783 .793 .86 r
.7609 .23153 .76475 .23827 .77322 .23064 .76939 .2238 Mtetra
.784 .791 .858 r
.76939 .2238 .77322 .23064 .78169 .22294 .77788 .21601 Mtetra
.784 .789 .856 r
.77788 .21601 .78169 .22294 .79017 .2152 .78638 .20817 Mtetra
.784 .787 .855 r
.78638 .20817 .79017 .2152 .79866 .20743 .79488 .20031 Mtetra
.39 .638 .954 r
.16949 .46707 .17444 .47277 .18112 .47353 .17617 .46789 Mtetra
.389 .64 .956 r
.17617 .46789 .18112 .47353 .18784 .47428 .18289 .46869 Mtetra
.39 .644 .958 r
.18289 .46869 .18784 .47428 .19459 .47499 .18964 .46946 Mtetra
.393 .648 .959 r
.18964 .46946 .19459 .47499 .20138 .47565 .19643 .47018 Mtetra
.397 .653 .961 r
.19643 .47018 .20138 .47565 .20821 .47623 .20326 .47083 Mtetra
.404 .66 .963 r
.20326 .47083 .20821 .47623 .21507 .47673 .21012 .47138 Mtetra
.412 .667 .965 r
.21012 .47138 .21507 .47673 .22198 .47711 .21703 .47183 Mtetra
.423 .675 .967 r
.21703 .47183 .22198 .47711 .22892 .47737 .22398 .47214 Mtetra
.435 .683 .969 r
.22398 .47214 .22892 .47737 .23591 .47746 .23097 .47231 Mtetra
.448 .693 .97 r
.23097 .47231 .23591 .47746 .24295 .47738 .23801 .4723 Mtetra
.464 .703 .972 r
.23801 .4723 .24295 .47738 .25002 .47711 .24509 .47209 Mtetra
.48 .714 .973 r
.24509 .47209 .25002 .47711 .25714 .47661 .25221 .47166 Mtetra
.498 .725 .973 r
.25221 .47166 .25714 .47661 .26431 .47586 .25938 .471 Mtetra
.518 .736 .973 r
.25938 .471 .26431 .47586 .27153 .47484 .2666 .47006 Mtetra
.538 .748 .973 r
.2666 .47006 .27153 .47484 .27879 .47353 .27387 .46883 Mtetra
.559 .76 .972 r
.27387 .46883 .27879 .47353 .28609 .47189 .28118 .46728 Mtetra
.581 .771 .97 r
.28118 .46728 .28609 .47189 .29345 .4699 .28854 .46539 Mtetra
.604 .783 .967 r
.28854 .46539 .29345 .4699 .30085 .46754 .29595 .46312 Mtetra
.627 .795 .963 r
.29595 .46312 .30085 .46754 .30829 .46476 .3034 .46044 Mtetra
.65 .806 .958 r
.3034 .46044 .30829 .46476 .31578 .46153 .3109 .45733 Mtetra
.673 .816 .952 r
.3109 .45733 .31578 .46153 .32332 .45783 .31845 .45375 Mtetra
.696 .826 .945 r
.31845 .45375 .32332 .45783 .3309 .45362 .32604 .44966 Mtetra
.719 .836 .937 r
.32604 .44966 .3309 .45362 .33853 .44886 .33368 .44504 Mtetra
.741 .845 .928 r
.33368 .44504 .33853 .44886 .34619 .44351 .34136 .43984 Mtetra
.763 .853 .918 r
.34136 .43984 .34619 .44351 .3539 .43753 .34908 .43402 Mtetra
.784 .86 .906 r
.34908 .43402 .3539 .43753 .36165 .43086 .35684 .42753 Mtetra
.805 .867 .894 r
.35684 .42753 .36165 .43086 .36944 .42345 .36464 .42032 Mtetra
.825 .873 .881 r
.36464 .42032 .36944 .42345 .37726 .41524 .37248 .41233 Mtetra
.844 .879 .866 r
.37248 .41233 .37726 .41524 .38511 .40615 .38035 .4035 Mtetra
.863 .884 .85 r
.38035 .4035 .38511 .40615 .393 .39609 .38826 .39374 Mtetra
.881 .888 .833 r
.38826 .39374 .393 .39609 .40092 .38493 .39619 .38295 Mtetra
.899 .893 .815 r
.39619 .38295 .40092 .38493 .40886 .37253 .40416 .37105 Mtetra
.407 0 0 r
.52204 .31926 .52639 .32098 .53443 .32659 .5301 .32434 Mtetra
0 .333 .672 r
.5301 .32434 .53443 .32659 .54252 .33096 .53821 .3283 Mtetra
0 .463 .799 r
.53821 .3283 .54252 .33096 .55067 .33425 .54637 .33125 Mtetra
.068 .568 .889 r
.54637 .33125 .55067 .33425 .55886 .33656 .55457 .33327 Mtetra
.199 .647 .946 r
.55457 .33327 .55886 .33656 .56709 .33799 .56282 .33444 Mtetra
.308 .703 .978 r
.56282 .33444 .56709 .33799 .57536 .33862 .5711 .33484 Mtetra
.396 .743 .993 r
.5711 .33484 .57536 .33862 .58366 .33851 .57942 .33451 Mtetra
.467 .769 .996 r
.57942 .33451 .58366 .33851 .59198 .33771 .58776 .33351 Mtetra
.524 .787 .993 r
.58776 .33351 .59198 .33771 .60033 .33626 .59612 .33188 Mtetra
.569 .799 .986 r
.59612 .33188 .60033 .33626 .6087 .33422 .60451 .32966 Mtetra
.606 .807 .977 r
.60451 .32966 .6087 .33422 .61709 .33162 .61292 .3269 Mtetra
.637 .812 .967 r
.61292 .3269 .61709 .33162 .6255 .3285 .62134 .32362 Mtetra
.662 .814 .957 r
.62134 .32362 .6255 .3285 .63392 .32489 .62978 .31986 Mtetra
.682 .816 .947 r
.62978 .31986 .63392 .32489 .64235 .32082 .63822 .31565 Mtetra
.7 .816 .937 r
.63822 .31565 .64235 .32082 .65079 .31633 .64668 .31102 Mtetra
.714 .816 .928 r
.64668 .31102 .65079 .31633 .65924 .31144 .65515 .306 Mtetra
.727 .815 .92 r
.65515 .306 .65924 .31144 .66769 .30619 .66362 .30062 Mtetra
.737 .814 .912 r
.66362 .30062 .66769 .30619 .67615 .3006 .6721 .29491 Mtetra
.746 .813 .904 r
.6721 .29491 .67615 .3006 .68462 .2947 .68058 .28889 Mtetra
.754 .811 .898 r
.68058 .28889 .68462 .2947 .69308 .28851 .68907 .28258 Mtetra
.761 .81 .892 r
.68907 .28258 .69308 .28851 .70156 .28206 .69756 .27602 Mtetra
.766 .808 .886 r
.69756 .27602 .70156 .28206 .71003 .27537 .70605 .26922 Mtetra
.771 .806 .881 r
.70605 .26922 .71003 .27537 .7185 .26847 .71455 .26221 Mtetra
.775 .804 .876 r
.71455 .26221 .7185 .26847 .72698 .26138 .72304 .25501 Mtetra
.778 .802 .872 r
.72304 .25501 .72698 .26138 .73546 .25411 .73154 .24765 Mtetra
.781 .8 .869 r
.73154 .24765 .73546 .25411 .74394 .2467 .74004 .24013 Mtetra
.783 .798 .865 r
.74004 .24013 .74394 .2467 .75242 .23917 .74854 .2325 Mtetra
.784 .796 .862 r
.74854 .2325 .75242 .23917 .7609 .23153 .75704 .22476 Mtetra
.785 .794 .86 r
.75704 .22476 .7609 .23153 .76939 .2238 .76554 .21693 Mtetra
.786 .792 .857 r
.76554 .21693 .76939 .2238 .77788 .21601 .77405 .20904 Mtetra
.786 .79 .856 r
.77405 .20904 .77788 .21601 .78638 .20817 .78257 .20111 Mtetra
.785 .787 .854 r
.78257 .20111 .78638 .20817 .79488 .20031 .79109 .19315 Mtetra
.383 .634 .954 r
.16452 .46134 .16949 .46707 .17617 .46789 .1712 .46222 Mtetra
.381 .637 .956 r
.1712 .46222 .17617 .46789 .18289 .46869 .17792 .46308 Mtetra
.382 .64 .957 r
.17792 .46308 .18289 .46869 .18964 .46946 .18467 .46392 Mtetra
.384 .645 .959 r
.18467 .46392 .18964 .46946 .19643 .47018 .19146 .4647 Mtetra
.389 .65 .961 r
.19146 .4647 .19643 .47018 .20326 .47083 .19828 .46541 Mtetra
.395 .656 .963 r
.19828 .46541 .20326 .47083 .21012 .47138 .20515 .46603 Mtetra
.403 .663 .965 r
.20515 .46603 .21012 .47138 .21703 .47183 .21206 .46655 Mtetra
.413 .672 .967 r
.21206 .46655 .21703 .47183 .22398 .47214 .21901 .46693 Mtetra
.425 .681 .969 r
.21901 .46693 .22398 .47214 .23097 .47231 .226 .46717 Mtetra
.438 .69 .971 r
.226 .46717 .23097 .47231 .23801 .4723 .23304 .46723 Mtetra
.454 .701 .973 r
.23304 .46723 .23801 .4723 .24509 .47209 .24012 .4671 Mtetra
.47 .712 .974 r
.24012 .4671 .24509 .47209 .25221 .47166 .24725 .46676 Mtetra
.488 .723 .975 r
.24725 .46676 .25221 .47166 .25938 .471 .25442 .46617 Mtetra
.508 .735 .976 r
.25442 .46617 .25938 .471 .2666 .47006 .26165 .46532 Mtetra
.528 .747 .976 r
.26165 .46532 .2666 .47006 .27387 .46883 .26892 .46418 Mtetra
.55 .76 .975 r
.26892 .46418 .27387 .46883 .28118 .46728 .27624 .46273 Mtetra
.572 .772 .973 r
.27624 .46273 .28118 .46728 .28854 .46539 .2836 .46093 Mtetra
.595 .784 .971 r
.2836 .46093 .28854 .46539 .29595 .46312 .29102 .45877 Mtetra
.618 .796 .967 r
.29102 .45877 .29595 .46312 .3034 .46044 .29848 .45621 Mtetra
.641 .808 .963 r
.29848 .45621 .3034 .46044 .3109 .45733 .30599 .45321 Mtetra
.665 .819 .958 r
.30599 .45321 .3109 .45733 .31845 .45375 .31354 .44976 Mtetra
.688 .83 .951 r
.31354 .44976 .31845 .45375 .32604 .44966 .32115 .44581 Mtetra
.712 .84 .943 r
.32115 .44581 .32604 .44966 .33368 .44504 .32879 .44134 Mtetra
.734 .85 .935 r
.32879 .44134 .33368 .44504 .34136 .43984 .33648 .4363 Mtetra
.757 .859 .925 r
.33648 .4363 .34136 .43984 .34908 .43402 .34422 .43065 Mtetra
.778 .867 .914 r
.34422 .43065 .34908 .43402 .35684 .42753 .35199 .42435 Mtetra
.8 .874 .902 r
.35199 .42435 .35684 .42753 .36464 .42032 .35981 .41735 Mtetra
.82 .881 .889 r
.35981 .41735 .36464 .42032 .37248 .41233 .36766 .40961 Mtetra
.84 .888 .875 r
.36766 .40961 .37248 .41233 .38035 .4035 .37555 .40105 Mtetra
.859 .894 .86 r
.37555 .40105 .38035 .4035 .38826 .39374 .38347 .39163 Mtetra
.877 .9 .843 r
.38347 .39163 .38826 .39374 .39619 .38295 .39142 .38125 Mtetra
.895 .906 .826 r
.39142 .38125 .39619 .38295 .40416 .37105 .3994 .36987 Mtetra
.379 0 0 r
.51766 .31785 .52204 .31926 .5301 .32434 .52573 .32237 Mtetra
0 .359 .677 r
.52573 .32237 .5301 .32434 .53821 .3283 .53386 .32588 Mtetra
0 .485 .802 r
.53386 .32588 .53821 .3283 .54637 .33125 .54203 .32846 Mtetra
.082 .587 .891 r
.54203 .32846 .54637 .33125 .55457 .33327 .55026 .33016 Mtetra
.212 .664 .948 r
.55026 .33016 .55457 .33327 .56282 .33444 .55852 .33106 Mtetra
.32 .718 .98 r
.55852 .33106 .56282 .33444 .5711 .33484 .56682 .3312 Mtetra
.407 .756 .994 r
.56682 .3312 .5711 .33484 .57942 .33451 .57515 .33065 Mtetra
.476 .781 .998 r
.57515 .33065 .57942 .33451 .58776 .33351 .5835 .32943 Mtetra
.532 .798 .994 r
.5835 .32943 .58776 .33351 .59612 .33188 .59189 .32761 Mtetra
.577 .809 .987 r
.59189 .32761 .59612 .33188 .60451 .32966 .60029 .3252 Mtetra
.613 .815 .978 r
.60029 .3252 .60451 .32966 .61292 .3269 .60872 .32226 Mtetra
.643 .819 .968 r
.60872 .32226 .61292 .3269 .62134 .32362 .61716 .31882 Mtetra
.667 .821 .957 r
.61716 .31882 .62134 .32362 .62978 .31986 .62561 .3149 Mtetra
.688 .822 .947 r
.62561 .3149 .62978 .31986 .63822 .31565 .63408 .31054 Mtetra
.705 .822 .937 r
.63408 .31054 .63822 .31565 .64668 .31102 .64255 .30577 Mtetra
.719 .821 .928 r
.64255 .30577 .64668 .31102 .65515 .306 .65104 .30061 Mtetra
.731 .82 .92 r
.65104 .30061 .65515 .306 .66362 .30062 .65953 .2951 Mtetra
.741 .818 .912 r
.65953 .2951 .66362 .30062 .6721 .29491 .66803 .28925 Mtetra
.75 .816 .904 r
.66803 .28925 .6721 .29491 .68058 .28889 .67653 .28311 Mtetra
.758 .814 .898 r
.67653 .28311 .68058 .28889 .68907 .28258 .68504 .27668 Mtetra
.764 .813 .891 r
.68504 .27668 .68907 .28258 .69756 .27602 .69354 .27 Mtetra
.769 .811 .886 r
.69354 .27 .69756 .27602 .70605 .26922 .70206 .26308 Mtetra
.774 .808 .881 r
.70206 .26308 .70605 .26922 .71455 .26221 .71057 .25596 Mtetra
.778 .806 .876 r
.71057 .25596 .71455 .26221 .72304 .25501 .71908 .24865 Mtetra
.781 .804 .872 r
.71908 .24865 .72304 .25501 .73154 .24765 .7276 .24118 Mtetra
.783 .802 .868 r
.7276 .24118 .73154 .24765 .74004 .24013 .73611 .23356 Mtetra
.785 .8 .865 r
.73611 .23356 .74004 .24013 .74854 .2325 .74463 .22581 Mtetra
.787 .798 .862 r
.74463 .22581 .74854 .2325 .75704 .22476 .75315 .21797 Mtetra
.787 .795 .859 r
.75315 .21797 .75704 .22476 .76554 .21693 .76168 .21004 Mtetra
.788 .793 .857 r
.76168 .21004 .76554 .21693 .77405 .20904 .7702 .20205 Mtetra
.788 .791 .855 r
.7702 .20205 .77405 .20904 .78257 .20111 .77874 .19401 Mtetra
.787 .788 .853 r
.77874 .19401 .78257 .20111 .79109 .19315 .78727 .18595 Mtetra
.374 .63 .953 r
.15952 .45558 .16452 .46134 .1712 .46222 .1662 .45653 Mtetra
.373 .633 .955 r
.1662 .45653 .1712 .46222 .17792 .46308 .17291 .45746 Mtetra
.373 .636 .957 r
.17291 .45746 .17792 .46308 .18467 .46392 .17966 .45836 Mtetra
.375 .641 .959 r
.17966 .45836 .18467 .46392 .19146 .4647 .18645 .45921 Mtetra
.379 .646 .961 r
.18645 .45921 .19146 .4647 .19828 .46541 .19328 .45999 Mtetra
.385 .653 .963 r
.19328 .45999 .19828 .46541 .20515 .46603 .20014 .46068 Mtetra
.393 .66 .966 r
.20014 .46068 .20515 .46603 .21206 .46655 .20705 .46127 Mtetra
.403 .668 .968 r
.20705 .46127 .21206 .46655 .21901 .46693 .214 .46173 Mtetra
.414 .677 .97 r
.214 .46173 .21901 .46693 .226 .46717 .221 .46204 Mtetra
.428 .687 .972 r
.221 .46204 .226 .46717 .23304 .46723 .22804 .46219 Mtetra
.443 .698 .974 r
.22804 .46219 .23304 .46723 .24012 .4671 .23512 .46214 Mtetra
.46 .709 .976 r
.23512 .46214 .24012 .4671 .24725 .46676 .24225 .46188 Mtetra
.478 .721 .977 r
.24225 .46188 .24725 .46676 .25442 .46617 .24943 .46138 Mtetra
.497 .734 .978 r
.24943 .46138 .25442 .46617 .26165 .46532 .25666 .46062 Mtetra
.518 .746 .978 r
.25666 .46062 .26165 .46532 .26892 .46418 .26393 .45958 Mtetra
.539 .759 .978 r
.26393 .45958 .26892 .46418 .27624 .46273 .27126 .45823 Mtetra
.561 .772 .977 r
.27126 .45823 .27624 .46273 .2836 .46093 .27863 .45654 Mtetra
.584 .785 .975 r
.27863 .45654 .2836 .46093 .29102 .45877 .28605 .45449 Mtetra
.608 .797 .972 r
.28605 .45449 .29102 .45877 .29848 .45621 .29352 .45205 Mtetra
.632 .81 .968 r
.29352 .45205 .29848 .45621 .30599 .45321 .30103 .44919 Mtetra
.656 .822 .963 r
.30103 .44919 .30599 .45321 .31354 .44976 .3086 .44587 Mtetra
.68 .833 .957 r
.3086 .44587 .31354 .44976 .32115 .44581 .31621 .44207 Mtetra
.703 .844 .95 r
.31621 .44207 .32115 .44581 .32879 .44134 .32387 .43775 Mtetra
.726 .855 .942 r
.32387 .43775 .32879 .44134 .33648 .4363 .33157 .43288 Mtetra
.749 .864 .933 r
.33157 .43288 .33648 .4363 .34422 .43065 .33931 .42742 Mtetra
.771 .873 .922 r
.33931 .42742 .34422 .43065 .35199 .42435 .3471 .42133 Mtetra
.793 .882 .911 r
.3471 .42133 .35199 .42435 .35981 .41735 .35493 .41456 Mtetra
.814 .889 .898 r
.35493 .41456 .35981 .41735 .36766 .40961 .3628 .40707 Mtetra
.834 .897 .884 r
.3628 .40707 .36766 .40961 .37555 .40105 .3707 .39881 Mtetra
.853 .904 .87 r
.3707 .39881 .37555 .40105 .38347 .39163 .37864 .38974 Mtetra
.871 .911 .854 r
.37864 .38974 .38347 .39163 .39142 .38125 .3866 .37979 Mtetra
.888 .919 .838 r
.3866 .37979 .39142 .38125 .3994 .36987 .3946 .36895 Mtetra
.904 .929 .822 r
.3946 .36895 .3994 .36987 .4074 .35744 .40261 .35721 Mtetra
.469 0 0 r
.50521 .31187 .50965 .31229 .51766 .31785 .51324 .31669 Mtetra
.345 0 0 r
.51324 .31669 .51766 .31785 .52573 .32237 .52133 .32063 Mtetra
0 .39 .686 r
.52133 .32063 .52573 .32237 .53386 .32588 .52947 .32369 Mtetra
0 .511 .808 r
.52947 .32369 .53386 .32588 .54203 .32846 .53767 .32587 Mtetra
.102 .609 .895 r
.53767 .32587 .54203 .32846 .55026 .33016 .54591 .32724 Mtetra
.228 .682 .951 r
.54591 .32724 .55026 .33016 .55852 .33106 .55419 .32784 Mtetra
.333 .734 .982 r
.55419 .32784 .55852 .33106 .56682 .3312 .5625 .32772 Mtetra
.418 .77 .996 r
.5625 .32772 .56682 .3312 .57515 .33065 .57085 .32692 Mtetra
.487 .793 .999 r
.57085 .32692 .57515 .33065 .5835 .32943 .57922 .32548 Mtetra
.541 .808 .995 r
.57922 .32548 .5835 .32943 .59189 .32761 .58762 .32345 Mtetra
.585 .818 .988 r
.58762 .32345 .59189 .32761 .60029 .3252 .59605 .32085 Mtetra
.621 .824 .978 r
.59605 .32085 .60029 .3252 .60872 .32226 .60449 .31772 Mtetra
.65 .827 .968 r
.60449 .31772 .60872 .32226 .61716 .31882 .61295 .3141 Mtetra
.673 .828 .958 r
.61295 .3141 .61716 .31882 .62561 .3149 .62142 .31002 Mtetra
.693 .828 .947 r
.62142 .31002 .62561 .3149 .63408 .31054 .62991 .3055 Mtetra
.71 .827 .937 r
.62991 .3055 .63408 .31054 .64255 .30577 .6384 .30057 Mtetra
.724 .826 .928 r
.6384 .30057 .64255 .30577 .65104 .30061 .64691 .29527 Mtetra
.735 .824 .919 r
.64691 .29527 .65104 .30061 .65953 .2951 .65542 .28962 Mtetra
.745 .822 .911 r
.65542 .28962 .65953 .2951 .66803 .28925 .66393 .28364 Mtetra
.754 .82 .904 r
.66393 .28364 .66803 .28925 .67653 .28311 .67245 .27736 Mtetra
.761 .818 .897 r
.67245 .27736 .67653 .28311 .68504 .27668 .68098 .2708 Mtetra
.767 .815 .891 r
.68098 .2708 .68504 .27668 .69354 .27 .68951 .26399 Mtetra
.772 .813 .885 r
.68951 .26399 .69354 .27 .70206 .26308 .69804 .25696 Mtetra
.777 .811 .88 r
.69804 .25696 .70206 .26308 .71057 .25596 .70657 .24972 Mtetra
.78 .809 .875 r
.70657 .24972 .71057 .25596 .71908 .24865 .7151 .24229 Mtetra
.783 .806 .871 r
.7151 .24229 .71908 .24865 .7276 .24118 .72363 .2347 Mtetra
.786 .804 .867 r
.72363 .2347 .7276 .24118 .73611 .23356 .73217 .22697 Mtetra
.787 .801 .864 r
.73217 .22697 .73611 .23356 .74463 .22581 .74071 .21911 Mtetra
.789 .799 .861 r
.74071 .21911 .74463 .22581 .75315 .21797 .74924 .21116 Mtetra
.79 .796 .858 r
.74924 .21116 .75315 .21797 .76168 .21004 .75779 .20312 Mtetra
.79 .794 .856 r
.75779 .20312 .76168 .21004 .7702 .20205 .76633 .19502 Mtetra
.79 .791 .854 r
.76633 .19502 .7702 .20205 .77874 .19401 .77488 .18688 Mtetra
.789 .789 .852 r
.77488 .18688 .77874 .19401 .78727 .18595 .78343 .17871 Mtetra
.365 .626 .953 r
.1545 .44979 .15952 .45558 .1662 .45653 .16117 .45081 Mtetra
.363 .628 .955 r
.16117 .45081 .1662 .45653 .17291 .45746 .16789 .45181 Mtetra
.363 .632 .957 r
.16789 .45181 .17291 .45746 .17966 .45836 .17463 .45278 Mtetra
.365 .636 .959 r
.17463 .45278 .17966 .45836 .18645 .45921 .18142 .45371 Mtetra
.369 .642 .961 r
.18142 .45371 .18645 .45921 .19328 .45999 .18824 .45456 Mtetra
.375 .649 .963 r
.18824 .45456 .19328 .45999 .20014 .46068 .19511 .45533 Mtetra
.382 .656 .966 r
.19511 .45533 .20014 .46068 .20705 .46127 .20202 .456 Mtetra
.392 .665 .968 r
.20202 .456 .20705 .46127 .214 .46173 .20897 .45654 Mtetra
.403 .674 .97 r
.20897 .45654 .214 .46173 .221 .46204 .21596 .45693 Mtetra
.417 .684 .973 r
.21596 .45693 .221 .46204 .22804 .46219 .223 .45716 Mtetra
.431 .695 .975 r
.223 .45716 .22804 .46219 .23512 .46214 .23009 .4572 Mtetra
.448 .707 .977 r
.23009 .4572 .23512 .46214 .24225 .46188 .23722 .45703 Mtetra
.466 .719 .979 r
.23722 .45703 .24225 .46188 .24943 .46138 .2444 .45663 Mtetra
.485 .732 .98 r
.2444 .45663 .24943 .46138 .25666 .46062 .25163 .45597 Mtetra
.506 .745 .981 r
.25163 .45597 .25666 .46062 .26393 .45958 .25891 .45503 Mtetra
.527 .758 .981 r
.25891 .45503 .26393 .45958 .27126 .45823 .26624 .45379 Mtetra
.55 .771 .98 r
.26624 .45379 .27126 .45823 .27863 .45654 .27362 .45222 Mtetra
.573 .785 .979 r
.27362 .45222 .27863 .45654 .28605 .45449 .28104 .45029 Mtetra
.597 .798 .977 r
.28104 .45029 .28605 .45449 .29352 .45205 .28852 .44797 Mtetra
.621 .811 .973 r
.28852 .44797 .29352 .45205 .30103 .44919 .29604 .44524 Mtetra
.645 .824 .969 r
.29604 .44524 .30103 .44919 .3086 .44587 .30362 .44207 Mtetra
.67 .836 .963 r
.30362 .44207 .3086 .44587 .31621 .44207 .31124 .43843 Mtetra
.694 .848 .957 r
.31124 .43843 .31621 .44207 .32387 .43775 .3189 .43428 Mtetra
.717 .859 .949 r
.3189 .43428 .32387 .43775 .33157 .43288 .32661 .42959 Mtetra
.741 .869 .94 r
.32661 .42959 .33157 .43288 .33931 .42742 .33437 .42432 Mtetra
.763 .879 .93 r
.33437 .42432 .33931 .42742 .3471 .42133 .34217 .41845 Mtetra
.785 .888 .919 r
.34217 .41845 .3471 .42133 .35493 .41456 .35001 .41192 Mtetra
.806 .897 .907 r
.35001 .41192 .35493 .41456 .3628 .40707 .35789 .40471 Mtetra
.826 .906 .894 r
.35789 .40471 .3628 .40707 .3707 .39881 .36581 .39676 Mtetra
.846 .914 .88 r
.36581 .39676 .3707 .39881 .37864 .38974 .37376 .38805 Mtetra
.864 .922 .866 r
.37376 .38805 .37864 .38974 .3866 .37979 .38174 .37855 Mtetra
.88 .931 .851 r
.38174 .37855 .3866 .37979 .3946 .36895 .38975 .36825 Mtetra
.894 .942 .836 r
.38975 .36825 .3946 .36895 .40261 .35721 .39778 .3572 Mtetra
.903 .956 .821 r
.39778 .3572 .40261 .35721 .41064 .34468 .40581 .34552 Mtetra
.509 0 0 r
.49274 .30693 .49725 .30626 .50521 .31187 .50073 .31165 Mtetra
.424 0 0 r
.50073 .31165 .50521 .31187 .51324 .31669 .50879 .31576 Mtetra
.305 0 0 r
.50879 .31576 .51324 .31669 .52133 .32063 .51689 .31912 Mtetra
0 .425 .699 r
.51689 .31912 .52133 .32063 .52947 .32369 .52506 .32169 Mtetra
0 .539 .815 r
.52506 .32169 .52947 .32369 .53767 .32587 .53327 .32348 Mtetra
.124 .632 .899 r
.53327 .32348 .53767 .32587 .54591 .32724 .54153 .32449 Mtetra
.247 .701 .953 r
.54153 .32449 .54591 .32724 .55419 .32784 .54982 .32478 Mtetra
.349 .751 .983 r
.54982 .32478 .55419 .32784 .5625 .32772 .55816 .32438 Mtetra
.432 .784 .997 r
.55816 .32438 .5625 .32772 .57085 .32692 .56652 .32333 Mtetra
.498 .805 1 r
.56652 .32333 .57085 .32692 .57922 .32548 .57492 .32165 Mtetra
.551 .819 .996 r
.57492 .32165 .57922 .32548 .58762 .32345 .58333 .3194 Mtetra
.594 .827 .988 r
.58333 .3194 .58762 .32345 .59605 .32085 .59178 .3166 Mtetra
.629 .832 .979 r
.59178 .3166 .59605 .32085 .60449 .31772 .60024 .31328 Mtetra
.657 .834 .968 r
.60024 .31328 .60449 .31772 .61295 .3141 .60871 .30947 Mtetra
.68 .834 .958 r
.60871 .30947 .61295 .3141 .62142 .31002 .61721 .30521 Mtetra
.699 .834 .947 r
.61721 .30521 .62142 .31002 .62991 .3055 .62571 .30052 Mtetra
.715 .832 .937 r
.62571 .30052 .62991 .3055 .6384 .30057 .63422 .29544 Mtetra
.729 .831 .928 r
.63422 .29544 .6384 .30057 .64691 .29527 .64275 .28998 Mtetra
.74 .828 .919 r
.64275 .28998 .64691 .29527 .65542 .28962 .65128 .28418 Mtetra
.75 .826 .911 r
.65128 .28418 .65542 .28962 .66393 .28364 .65981 .27806 Mtetra
.758 .824 .904 r
.65981 .27806 .66393 .28364 .67245 .27736 .66835 .27164 Mtetra
.765 .821 .897 r
.66835 .27164 .67245 .27736 .68098 .2708 .6769 .26495 Mtetra
.771 .818 .89 r
.6769 .26495 .68098 .2708 .68951 .26399 .68544 .25801 Mtetra
.776 .816 .885 r
.68544 .25801 .68951 .26399 .69804 .25696 .69399 .25085 Mtetra
.78 .813 .879 r
.69399 .25085 .69804 .25696 .70657 .24972 .70254 .24348 Mtetra
.783 .811 .875 r
.70254 .24348 .70657 .24972 .7151 .24229 .7111 .23593 Mtetra
.786 .808 .87 r
.7111 .23593 .7151 .24229 .72363 .2347 .71965 .22822 Mtetra
.788 .806 .866 r
.71965 .22822 .72363 .2347 .73217 .22697 .7282 .22037 Mtetra
.79 .803 .863 r
.7282 .22037 .73217 .22697 .74071 .21911 .73676 .2124 Mtetra
.791 .8 .86 r
.73676 .2124 .74071 .21911 .74924 .21116 .74531 .20433 Mtetra
.792 .798 .857 r
.74531 .20433 .74924 .21116 .75779 .20312 .75387 .19617 Mtetra
.792 .795 .855 r
.75387 .19617 .75779 .20312 .76633 .19502 .76244 .18796 Mtetra
.792 .792 .852 r
.76244 .18796 .76633 .19502 .77488 .18688 .771 .1797 Mtetra
.791 .789 .851 r
.771 .1797 .77488 .18688 .78343 .17871 .77958 .17143 Mtetra
.356 .621 .952 r
.14945 .44397 .1545 .44979 .16117 .45081 .15612 .44506 Mtetra
.353 .624 .954 r
.15612 .44506 .16117 .45081 .16789 .45181 .16283 .44614 Mtetra
.353 .627 .956 r
.16283 .44614 .16789 .45181 .17463 .45278 .16958 .44719 Mtetra
.355 .632 .958 r
.16958 .44719 .17463 .45278 .18142 .45371 .17636 .44819 Mtetra
.358 .637 .96 r
.17636 .44819 .18142 .45371 .18824 .45456 .18318 .44913 Mtetra
.363 .644 .963 r
.18318 .44913 .18824 .45456 .19511 .45533 .19005 .44998 Mtetra
.371 .652 .965 r
.19005 .44998 .19511 .45533 .20202 .456 .19695 .45073 Mtetra
.38 .66 .968 r
.19695 .45073 .20202 .456 .20897 .45654 .2039 .45135 Mtetra
.391 .67 .971 r
.2039 .45135 .20897 .45654 .21596 .45693 .2109 .45184 Mtetra
.404 .68 .973 r
.2109 .45184 .21596 .45693 .223 .45716 .21794 .45215 Mtetra
.419 .691 .976 r
.21794 .45215 .223 .45716 .23009 .4572 .22502 .45229 Mtetra
.435 .703 .978 r
.22502 .45229 .23009 .4572 .23722 .45703 .23216 .45221 Mtetra
.453 .716 .98 r
.23216 .45221 .23722 .45703 .2444 .45663 .23934 .45191 Mtetra
.472 .729 .982 r
.23934 .45191 .2444 .45663 .25163 .45597 .24658 .45136 Mtetra
.493 .743 .983 r
.24658 .45136 .25163 .45597 .25891 .45503 .25386 .45053 Mtetra
.515 .756 .984 r
.25386 .45053 .25891 .45503 .26624 .45379 .26119 .4494 Mtetra
.537 .77 .984 r
.26119 .4494 .26624 .45379 .27362 .45222 .26857 .44795 Mtetra
.561 .784 .983 r
.26857 .44795 .27362 .45222 .28104 .45029 .276 .44615 Mtetra
.585 .798 .981 r
.276 .44615 .28104 .45029 .28852 .44797 .28348 .44397 Mtetra
.609 .812 .978 r
.28348 .44397 .28852 .44797 .29604 .44524 .29101 .44139 Mtetra
.634 .826 .974 r
.29101 .44139 .29604 .44524 .30362 .44207 .29859 .43837 Mtetra
.658 .839 .969 r
.29859 .43837 .30362 .44207 .31124 .43843 .30622 .43489 Mtetra
.683 .851 .963 r
.30622 .43489 .31124 .43843 .3189 .43428 .3139 .43091 Mtetra
.707 .863 .956 r
.3139 .43091 .3189 .43428 .32661 .42959 .32162 .42641 Mtetra
.731 .874 .948 r
.32162 .42641 .32661 .42959 .33437 .42432 .32939 .42136 Mtetra
.754 .885 .938 r
.32939 .42136 .33437 .42432 .34217 .41845 .3372 .41571 Mtetra
.776 .895 .928 r
.3372 .41571 .34217 .41845 .35001 .41192 .34505 .40944 Mtetra
.797 .905 .916 r
.34505 .40944 .35001 .41192 .35789 .40471 .35294 .40251 Mtetra
.817 .914 .904 r
.35294 .40251 .35789 .40471 .36581 .39676 .36087 .39489 Mtetra
.836 .923 .891 r
.36087 .39489 .36581 .39676 .37376 .38805 .36884 .38656 Mtetra
.854 .932 .877 r
.36884 .38656 .37376 .38805 .38174 .37855 .37683 .3775 Mtetra
.869 .943 .863 r
.37683 .3775 .38174 .37855 .38975 .36825 .38485 .36774 Mtetra
.881 .954 .849 r
.38485 .36774 .38975 .36825 .39778 .3572 .39289 .35734 Mtetra
.887 .968 .835 r
.39289 .35734 .39778 .3572 .40581 .34552 .40094 .34646 Mtetra
.456 0 0 r
.4882 .3077 .49274 .30693 .50073 .31165 .49622 .31159 Mtetra
.374 0 0 r
.49622 .31159 .50073 .31165 .50879 .31576 .50429 .31501 Mtetra
.26 0 0 r
.50429 .31501 .50879 .31576 .51689 .31912 .51242 .3178 Mtetra
0 .462 .715 r
.51242 .3178 .51689 .31912 .52506 .32169 .52061 .31988 Mtetra
.016 .569 .824 r
.52061 .31988 .52506 .32169 .53327 .32348 .52884 .32125 Mtetra
.15 .656 .904 r
.52884 .32125 .53327 .32348 .54153 .32449 .53711 .32191 Mtetra
.268 .721 .956 r
.53711 .32191 .54153 .32449 .54982 .32478 .54543 .32188 Mtetra
.366 .767 .985 r
.54543 .32188 .54982 .32478 .55816 .32438 .55378 .32118 Mtetra
.446 .798 .998 r
.55378 .32118 .55816 .32438 .56652 .32333 .56217 .31986 Mtetra
.511 .818 1 r
.56217 .31986 .56652 .32333 .57492 .32165 .57058 .31794 Mtetra
.562 .83 .996 r
.57058 .31794 .57492 .32165 .58333 .3194 .57902 .31546 Mtetra
.603 .837 .988 r
.57902 .31546 .58333 .3194 .59178 .3166 .58748 .31244 Mtetra
.637 .84 .978 r
.58748 .31244 .59178 .3166 .60024 .31328 .59596 .30892 Mtetra
.664 .841 .968 r
.59596 .30892 .60024 .31328 .60871 .30947 .60445 .30492 Mtetra
.687 .841 .957 r
.60445 .30492 .60871 .30947 .61721 .30521 .61297 .30047 Mtetra
.705 .84 .947 r
.61297 .30047 .61721 .30521 .62571 .30052 .62149 .29561 Mtetra
.721 .838 .937 r
.62149 .29561 .62571 .30052 .63422 .29544 .63002 .29036 Mtetra
.734 .835 .927 r
.63002 .29036 .63422 .29544 .64275 .28998 .63857 .28474 Mtetra
.745 .833 .919 r
.63857 .28474 .64275 .28998 .65128 .28418 .64712 .27878 Mtetra
.754 .83 .91 r
.64712 .27878 .65128 .28418 .65981 .27806 .65567 .27251 Mtetra
.762 .827 .903 r
.65567 .27251 .65981 .27806 .66835 .27164 .66423 .26595 Mtetra
.769 .824 .896 r
.66423 .26595 .66835 .27164 .6769 .26495 .67279 .25912 Mtetra
.774 .821 .89 r
.67279 .25912 .6769 .26495 .68544 .25801 .68136 .25204 Mtetra
.779 .818 .884 r
.68136 .25204 .68544 .25801 .69399 .25085 .68993 .24474 Mtetra
.783 .816 .878 r
.68993 .24474 .69399 .25085 .70254 .24348 .6985 .23725 Mtetra
.786 .813 .874 r
.6985 .23725 .70254 .24348 .7111 .23593 .70707 .22957 Mtetra
.789 .81 .869 r
.70707 .22957 .7111 .23593 .71965 .22822 .71564 .22173 Mtetra
.791 .807 .865 r
.71564 .22173 .71965 .22822 .7282 .22037 .72421 .21376 Mtetra
.792 .804 .862 r
.72421 .21376 .7282 .22037 .73676 .2124 .73279 .20566 Mtetra
.793 .802 .859 r
.73279 .20566 .73676 .2124 .74531 .20433 .74136 .19747 Mtetra
.794 .799 .856 r
.74136 .19747 .74531 .20433 .75387 .19617 .74994 .1892 Mtetra
.794 .796 .853 r
.74994 .1892 .75387 .19617 .76244 .18796 .75852 .18087 Mtetra
.794 .793 .851 r
.75852 .18087 .76244 .18796 .771 .1797 .76711 .1725 Mtetra
.793 .79 .849 r
.76711 .1725 .771 .1797 .77958 .17143 .77569 .1641 Mtetra
.345 .616 .951 r
.14437 .43812 .14945 .44397 .15612 .44506 .15104 .43929 Mtetra
.343 .619 .953 r
.15104 .43929 .15612 .44506 .16283 .44614 .15775 .44045 Mtetra
.342 .622 .955 r
.15775 .44045 .16283 .44614 .16958 .44719 .16449 .44159 Mtetra
.343 .627 .957 r
.16449 .44159 .16958 .44719 .17636 .44819 .17127 .44267 Mtetra
.346 .632 .96 r
.17127 .44267 .17636 .44819 .18318 .44913 .17809 .44369 Mtetra
.352 .639 .962 r
.17809 .44369 .18318 .44913 .19005 .44998 .18495 .44463 Mtetra
.359 .647 .965 r
.18495 .44463 .19005 .44998 .19695 .45073 .19186 .44546 Mtetra
.368 .656 .968 r
.19186 .44546 .19695 .45073 .2039 .45135 .19881 .44618 Mtetra
.378 .665 .97 r
.19881 .44618 .2039 .45135 .2109 .45184 .2058 .44675 Mtetra
.391 .676 .973 r
.2058 .44675 .2109 .45184 .21794 .45215 .21284 .44716 Mtetra
.406 .687 .976 r
.21284 .44716 .21794 .45215 .22502 .45229 .21993 .4474 Mtetra
.422 .7 .979 r
.21993 .4474 .22502 .45229 .23216 .45221 .22706 .44743 Mtetra
.44 .712 .981 r
.22706 .44743 .23216 .45221 .23934 .45191 .23425 .44723 Mtetra
.459 .726 .983 r
.23425 .44723 .23934 .45191 .24658 .45136 .24148 .44679 Mtetra
.479 .74 .985 r
.24148 .44679 .24658 .45136 .25386 .45053 .24877 .44608 Mtetra
.501 .754 .986 r
.24877 .44608 .25386 .45053 .26119 .4494 .2561 .44507 Mtetra
.524 .769 .987 r
.2561 .44507 .26119 .4494 .26857 .44795 .26349 .44375 Mtetra
.547 .783 .986 r
.26349 .44375 .26857 .44795 .276 .44615 .27092 .44208 Mtetra
.571 .798 .985 r
.27092 .44208 .276 .44615 .28348 .44397 .27841 .44004 Mtetra
.596 .812 .983 r
.27841 .44004 .28348 .44397 .29101 .44139 .28594 .43761 Mtetra
.621 .827 .979 r
.28594 .43761 .29101 .44139 .29859 .43837 .29353 .43475 Mtetra
.646 .84 .975 r
.29353 .43475 .29859 .43837 .30622 .43489 .30117 .43144 Mtetra
.671 .854 .97 r
.30117 .43144 .30622 .43489 .3139 .43091 .30885 .42765 Mtetra
.695 .866 .963 r
.30885 .42765 .3139 .43091 .32162 .42641 .31658 .42335 Mtetra
.719 .878 .955 r
.31658 .42335 .32162 .42641 .32939 .42136 .32436 .41851 Mtetra
.742 .89 .946 r
.32436 .41851 .32939 .42136 .3372 .41571 .33218 .4131 Mtetra
.765 .901 .936 r
.33218 .4131 .3372 .41571 .34505 .40944 .34004 .4071 Mtetra
.786 .911 .925 r
.34004 .4071 .34505 .40944 .35294 .40251 .34795 .40046 Mtetra
.807 .921 .914 r
.34795 .40046 .35294 .40251 .36087 .39489 .35589 .39318 Mtetra
.825 .931 .901 r
.35589 .39318 .36087 .39489 .36884 .38656 .36387 .38523 Mtetra
.842 .942 .888 r
.36387 .38523 .36884 .38656 .37683 .3775 .37187 .37662 Mtetra
.856 .953 .875 r
.37187 .37662 .37683 .3775 .38485 .36774 .37991 .36739 Mtetra
.866 .965 .862 r
.37991 .36739 .38485 .36774 .39289 .35734 .38796 .35762 Mtetra
.869 .978 .848 r
.38796 .35762 .39289 .35734 .40094 .34646 .39602 .34746 Mtetra
.858 .992 .833 r
.39602 .34746 .40094 .34646 .40899 .33537 .40408 .3372 Mtetra
.822 1 .812 r
.40408 .3372 .40899 .33537 .41702 .32456 .41213 .32724 Mtetra
.453 0 0 r
.46767 .30242 .47233 .29984 .48024 .30363 .47562 .30532 Mtetra
.444 0 0 r
.47562 .30532 .48024 .30363 .4882 .3077 .48361 .30854 Mtetra
.399 0 0 r
.48361 .30854 .4882 .3077 .49622 .31159 .49165 .31167 Mtetra
.32 0 0 r
.49165 .31167 .49622 .31159 .50429 .31501 .49976 .31442 Mtetra
.212 0 0 r
.49976 .31442 .50429 .31501 .51242 .3178 .50791 .31665 Mtetra
0 .5 .732 r
.50791 .31665 .51242 .3178 .52061 .31988 .51612 .31825 Mtetra
.051 .599 .835 r
.51612 .31825 .52061 .31988 .52884 .32125 .52437 .31919 Mtetra
.178 .681 .91 r
.52437 .31919 .52884 .32125 .53711 .32191 .53267 .31948 Mtetra
.291 .741 .959 r
.53267 .31948 .53711 .32191 .54543 .32188 .541 .31911 Mtetra
.385 .784 .986 r
.541 .31911 .54543 .32188 .55378 .32118 .54937 .31812 Mtetra
.462 .812 .998 r
.54937 .31812 .55378 .32118 .56217 .31986 .55778 .31652 Mtetra
.524 .83 1 r
.55778 .31652 .56217 .31986 .57058 .31794 .56621 .31434 Mtetra
.573 .84 .995 r
.56621 .31434 .57058 .31794 .57902 .31546 .57467 .31162 Mtetra
.613 .846 .987 r
.57467 .31162 .57902 .31546 .58748 .31244 .58315 .30838 Mtetra
.646 .848 .978 r
.58315 .30838 .58748 .31244 .59596 .30892 .59165 .30464 Mtetra
.672 .848 .967 r
.59165 .30464 .59596 .30892 .60445 .30492 .60017 .30044 Mtetra
.694 .847 .956 r
.60017 .30044 .60445 .30492 .61297 .30047 .6087 .29581 Mtetra
.712 .845 .946 r
.6087 .29581 .61297 .30047 .62149 .29561 .61724 .29076 Mtetra
.727 .843 .936 r
.61724 .29076 .62149 .29561 .63002 .29036 .6258 .28534 Mtetra
.739 .84 .927 r
.6258 .28534 .63002 .29036 .63857 .28474 .63436 .27955 Mtetra
.75 .837 .918 r
.63436 .27955 .63857 .28474 .64712 .27878 .64293 .27343 Mtetra
.759 .834 .91 r
.64293 .27343 .64712 .27878 .65567 .27251 .6515 .267 Mtetra
.766 .831 .902 r
.6515 .267 .65567 .27251 .66423 .26595 .66008 .26029 Mtetra
.772 .827 .895 r
.66008 .26029 .66423 .26595 .67279 .25912 .66867 .25331 Mtetra
.778 .824 .889 r
.66867 .25331 .67279 .25912 .68136 .25204 .67725 .24609 Mtetra
.782 .821 .883 r
.67725 .24609 .68136 .25204 .68993 .24474 .68584 .23865 Mtetra
.786 .818 .878 r
.68584 .23865 .68993 .24474 .6985 .23725 .69443 .23102 Mtetra
.789 .815 .873 r
.69443 .23102 .6985 .23725 .70707 .22957 .70302 .22321 Mtetra
.792 .812 .868 r
.70302 .22321 .70707 .22957 .71564 .22173 .71161 .21524 Mtetra
.794 .809 .864 r
.71161 .21524 .71564 .22173 .72421 .21376 .7202 .20714 Mtetra
.795 .806 .861 r
.7202 .20714 .72421 .21376 .73279 .20566 .72879 .19892 Mtetra
.796 .803 .858 r
.72879 .19892 .73279 .20566 .74136 .19747 .73739 .1906 Mtetra
.796 .8 .855 r
.73739 .1906 .74136 .19747 .74994 .1892 .74598 .1822 Mtetra
.797 .797 .852 r
.74598 .1822 .74994 .1892 .75852 .18087 .75458 .17375 Mtetra
.796 .794 .85 r
.75458 .17375 .75852 .18087 .76711 .1725 .76318 .16525 Mtetra
.795 .791 .848 r
.76318 .16525 .76711 .1725 .77569 .1641 .77179 .15673 Mtetra
.334 .61 .95 r
.13927 .43224 .14437 .43812 .15104 .43929 .14594 .4335 Mtetra
.331 .613 .952 r
.14594 .4335 .15104 .43929 .15775 .44045 .15264 .43474 Mtetra
.33 .617 .954 r
.15264 .43474 .15775 .44045 .16449 .44159 .15938 .43596 Mtetra
.331 .621 .956 r
.15938 .43596 .16449 .44159 .17127 .44267 .16615 .43713 Mtetra
.334 .627 .959 r
.16615 .43713 .17127 .44267 .17809 .44369 .17297 .43824 Mtetra
.339 .634 .961 r
.17297 .43824 .17809 .44369 .18495 .44463 .17983 .43927 Mtetra
.346 .641 .964 r
.17983 .43927 .18495 .44463 .19186 .44546 .18673 .4402 Mtetra
.354 .65 .967 r
.18673 .4402 .19186 .44546 .19881 .44618 .19368 .44101 Mtetra
.365 .66 .97 r
.19368 .44101 .19881 .44618 .2058 .44675 .20067 .44168 Mtetra
.377 .671 .973 r
.20067 .44168 .2058 .44675 .21284 .44716 .20771 .44219 Mtetra
.391 .683 .976 r
.20771 .44219 .21284 .44716 .21993 .4474 .2148 .44253 Mtetra
.407 .695 .979 r
.2148 .44253 .21993 .4474 .22706 .44743 .22193 .44266 Mtetra
.425 .708 .982 r
.22193 .44266 .22706 .44743 .23425 .44723 .22912 .44258 Mtetra
.444 .722 .985 r
.22912 .44258 .23425 .44723 .24148 .44679 .23635 .44226 Mtetra
.464 .736 .987 r
.23635 .44226 .24148 .44679 .24877 .44608 .24364 .44167 Mtetra
.486 .751 .988 r
.24364 .44167 .24877 .44608 .2561 .44507 .25098 .44079 Mtetra
.509 .766 .989 r
.25098 .44079 .2561 .44507 .26349 .44375 .25836 .4396 Mtetra
.532 .782 .989 r
.25836 .4396 .26349 .44375 .27092 .44208 .2658 .43807 Mtetra
.556 .797 .989 r
.2658 .43807 .27092 .44208 .27841 .44004 .27329 .43618 Mtetra
.581 .812 .987 r
.27329 .43618 .27841 .44004 .28594 .43761 .28084 .43391 Mtetra
.606 .827 .984 r
.28084 .43391 .28594 .43761 .29353 .43475 .28843 .43122 Mtetra
.632 .841 .981 r
.28843 .43122 .29353 .43475 .30117 .43144 .29607 .42809 Mtetra
.657 .855 .976 r
.29607 .42809 .30117 .43144 .30885 .42765 .30376 .4245 Mtetra
.682 .869 .97 r
.30376 .4245 .30885 .42765 .31658 .42335 .3115 .42041 Mtetra
.706 .882 .963 r
.3115 .42041 .31658 .42335 .32436 .41851 .31929 .41579 Mtetra
.73 .894 .954 r
.31929 .41579 .32436 .41851 .33218 .4131 .32712 .41063 Mtetra
.752 .906 .945 r
.32712 .41063 .33218 .4131 .34004 .4071 .33499 .40489 Mtetra
.774 .917 .935 r
.33499 .40489 .34004 .4071 .34795 .40046 .34291 .39856 Mtetra
.794 .928 .923 r
.34291 .39856 .34795 .40046 .35589 .39318 .35086 .39162 Mtetra
.812 .939 .911 r
.35086 .39162 .35589 .39318 .36387 .38523 .35885 .38406 Mtetra
.828 .95 .899 r
.35885 .38406 .36387 .38523 .37187 .37662 .36687 .3759 Mtetra
.841 .961 .886 r
.36687 .3759 .37187 .37662 .37991 .36739 .37492 .36718 Mtetra
.848 .973 .873 r
.37492 .36718 .37991 .36739 .38796 .35762 .38298 .358 Mtetra
.848 .985 .86 r
.38298 .358 .38796 .35762 .39602 .34746 .39105 .34851 Mtetra
.833 .996 .844 r
.39105 .34851 .39602 .34746 .40408 .3372 .39913 .33897 Mtetra
.792 .999 .822 r
.39913 .33897 .40408 .3372 .41213 .32724 .40719 .32974 Mtetra
.706 .979 .782 r
.40719 .32974 .41213 .32724 .42015 .31815 .41523 .32126 Mtetra
.361 0 0 r
.45502 .30345 .45976 .3004 .46767 .30242 .46297 .30482 Mtetra
.392 0 0 r
.46297 .30482 .46767 .30242 .47562 .30532 .47095 .30696 Mtetra
.384 0 0 r
.47095 .30696 .47562 .30532 .48361 .30854 .47898 .30942 Mtetra
.34 0 0 r
.47898 .30942 .48361 .30854 .49165 .31167 .48705 .31184 Mtetra
.264 0 0 r
.48705 .31184 .49165 .31167 .49976 .31442 .49518 .31397 Mtetra
.161 0 0 r
.49518 .31397 .49976 .31442 .50791 .31665 .50336 .31564 Mtetra
0 .539 .75 r
.50336 .31564 .50791 .31665 .51612 .31825 .51159 .31676 Mtetra
.088 .631 .845 r
.51159 .31676 .51612 .31825 .52437 .31919 .51987 .31728 Mtetra
.209 .706 .915 r
.51987 .31728 .52437 .31919 .53267 .31948 .52818 .31719 Mtetra
.315 .761 .961 r
.52818 .31719 .53267 .31948 .541 .31911 .53654 .31648 Mtetra
.405 .8 .987 r
.53654 .31648 .541 .31911 .54937 .31812 .54494 .31518 Mtetra
.479 .826 .998 r
.54494 .31518 .54937 .31812 .55778 .31652 .55336 .31329 Mtetra
.538 .841 .999 r
.55336 .31329 .55778 .31652 .56621 .31434 .56181 .31085 Mtetra
.585 .85 .994 r
.56181 .31085 .56621 .31434 .57467 .31162 .57029 .30788 Mtetra
.624 .855 .986 r
.57029 .30788 .57467 .31162 .58315 .30838 .57879 .30441 Mtetra
.655 .856 .977 r
.57879 .30441 .58315 .30838 .59165 .30464 .58731 .30045 Mtetra
.68 .855 .966 r
.58731 .30045 .59165 .30464 .60017 .30044 .59585 .29604 Mtetra
.701 .854 .955 r
.59585 .29604 .60017 .30044 .6087 .29581 .6044 .29121 Mtetra
.718 .851 .945 r
.6044 .29121 .6087 .29581 .61724 .29076 .61297 .28598 Mtetra
.733 .848 .935 r
.61297 .28598 .61724 .29076 .6258 .28534 .62154 .28037 Mtetra
.745 .845 .926 r
.62154 .28037 .6258 .28534 .63436 .27955 .63013 .2744 Mtetra
.755 .841 .917 r
.63013 .2744 .63436 .27955 .64293 .27343 .63872 .26812 Mtetra
.763 .838 .909 r
.63872 .26812 .64293 .27343 .6515 .267 .64731 .26152 Mtetra
.77 .834 .901 r
.64731 .26152 .6515 .267 .66008 .26029 .65591 .25465 Mtetra
.776 .83 .894 r
.65591 .25465 .66008 .26029 .66867 .25331 .66451 .24752 Mtetra
.782 .827 .888 r
.66451 .24752 .66867 .25331 .67725 .24609 .67312 .24015 Mtetra
.786 .824 .882 r
.67312 .24015 .67725 .24609 .68584 .23865 .68173 .23257 Mtetra
.789 .82 .876 r
.68173 .23257 .68584 .23865 .69443 .23102 .69034 .22479 Mtetra
.792 .817 .872 r
.69034 .22479 .69443 .23102 .70302 .22321 .69895 .21684 Mtetra
.795 .814 .867 r
.69895 .21684 .70302 .22321 .71161 .21524 .70756 .20874 Mtetra
.796 .811 .863 r
.70756 .20874 .71161 .21524 .7202 .20714 .71617 .2005 Mtetra
.798 .807 .86 r
.71617 .2005 .7202 .20714 .72879 .19892 .72478 .19215 Mtetra
.799 .804 .856 r
.72478 .19215 .72879 .19892 .73739 .1906 .73339 .1837 Mtetra
.799 .801 .853 r
.73339 .1837 .73739 .1906 .74598 .1822 .74201 .17518 Mtetra
.799 .798 .851 r
.74201 .17518 .74598 .1822 .75458 .17375 .75062 .16659 Mtetra
.798 .795 .849 r
.75062 .16659 .75458 .17375 .76318 .16525 .75924 .15797 Mtetra
.798 .791 .847 r
.75924 .15797 .76318 .16525 .77179 .15673 .76786 .14932 Mtetra
.323 .604 .949 r
.13415 .42633 .13927 .43224 .14594 .4335 .14081 .42768 Mtetra
.319 .607 .951 r
.14081 .42768 .14594 .4335 .15264 .43474 .1475 .42901 Mtetra
.318 .61 .953 r
.1475 .42901 .15264 .43474 .15938 .43596 .15423 .43032 Mtetra
.318 .615 .955 r
.15423 .43032 .15938 .43596 .16615 .43713 .16101 .43159 Mtetra
.321 .621 .957 r
.16101 .43159 .16615 .43713 .17297 .43824 .16782 .43279 Mtetra
.325 .628 .96 r
.16782 .43279 .17297 .43824 .17983 .43927 .17467 .43391 Mtetra
.332 .635 .963 r
.17467 .43391 .17983 .43927 .18673 .4402 .18157 .43494 Mtetra
.34 .644 .966 r
.18157 .43494 .18673 .4402 .19368 .44101 .18852 .43584 Mtetra
.35 .654 .969 r
.18852 .43584 .19368 .44101 .20067 .44168 .19551 .43662 Mtetra
.362 .665 .972 r
.19551 .43662 .20067 .44168 .20771 .44219 .20254 .43724 Mtetra
.376 .677 .976 r
.20254 .43724 .20771 .44219 .2148 .44253 .20963 .43768 Mtetra
.392 .69 .979 r
.20963 .43768 .2148 .44253 .22193 .44266 .21677 .43793 Mtetra
.409 .703 .982 r
.21677 .43793 .22193 .44266 .22912 .44258 .22395 .43797 Mtetra
.428 .718 .985 r
.22395 .43797 .22912 .44258 .23635 .44226 .23119 .43776 Mtetra
.448 .732 .988 r
.23119 .43776 .23635 .44226 .24364 .44167 .23847 .4373 Mtetra
.47 .748 .99 r
.23847 .4373 .24364 .44167 .25098 .44079 .24581 .43656 Mtetra
.492 .763 .991 r
.24581 .43656 .25098 .44079 .25836 .4396 .2532 .43551 Mtetra
.516 .779 .992 r
.2532 .43551 .25836 .4396 .2658 .43807 .26065 .43413 Mtetra
.54 .795 .992 r
.26065 .43413 .2658 .43807 .27329 .43618 .26814 .4324 Mtetra
.565 .811 .991 r
.26814 .4324 .27329 .43618 .28084 .43391 .27569 .43029 Mtetra
.591 .826 .989 r
.27569 .43029 .28084 .43391 .28843 .43122 .28328 .42778 Mtetra
.616 .842 .986 r
.28328 .42778 .28843 .43122 .29607 .42809 .29093 .42484 Mtetra
.641 .856 .981 r
.29093 .42484 .29607 .42809 .30376 .4245 .29863 .42144 Mtetra
.666 .871 .976 r
.29863 .42144 .30376 .4245 .3115 .42041 .30638 .41757 Mtetra
.691 .885 .969 r
.30638 .41757 .3115 .42041 .31929 .41579 .31417 .41319 Mtetra
.715 .898 .962 r
.31417 .41319 .31929 .41579 .32712 .41063 .32201 .40828 Mtetra
.738 .91 .953 r
.32201 .40828 .32712 .41063 .33499 .40489 .3299 .40282 Mtetra
.759 .922 .943 r
.3299 .40282 .33499 .40489 .34291 .39856 .33782 .3968 Mtetra
.779 .934 .933 r
.33782 .3968 .34291 .39856 .35086 .39162 .34579 .3902 Mtetra
.797 .945 .921 r
.34579 .3902 .35086 .39162 .35885 .38406 .35379 .38303 Mtetra
.812 .957 .909 r
.35379 .38303 .35885 .38406 .36687 .3759 .36182 .3753 Mtetra
.823 .968 .897 r
.36182 .3753 .36687 .3759 .37492 .36718 .36988 .36708 Mtetra
.828 .979 .884 r
.36988 .36708 .37492 .36718 .38298 .358 .37795 .35846 Mtetra
.824 .99 .87 r
.37795 .35846 .38298 .358 .39105 .34851 .38604 .34958 Mtetra
.806 .998 .853 r
.38604 .34958 .39105 .34851 .39913 .33897 .39413 .34068 Mtetra
.763 .996 .83 r
.39413 .34068 .39913 .33897 .40719 .32974 .40221 .33207 Mtetra
.683 .974 .792 r
.40221 .33207 .40719 .32974 .41523 .32126 .41027 .3241 Mtetra
.556 .916 .733 r
.41027 .3241 .41523 .32126 .42324 .31402 .41832 .31714 Mtetra
.397 .824 .659 r
.41832 .31714 .42324 .31402 .43122 .30837 .42633 .31142 Mtetra
0 0 0 r
.42633 .31142 .43122 .30837 .43917 .3048 .43431 .30784 Mtetra
.099 0 0 r
.43431 .30784 .43917 .3048 .44709 .30333 .44227 .3064 Mtetra
.229 0 0 r
.44227 .3064 .44709 .30333 .45502 .30345 .45024 .30622 Mtetra
.303 0 0 r
.45024 .30622 .45502 .30345 .46297 .30482 .45822 .30705 Mtetra
.332 0 0 r
.45822 .30705 .46297 .30482 .47095 .30696 .46624 .30854 Mtetra
.323 0 0 r
.46624 .30854 .47095 .30696 .47898 .30942 .4743 .31032 Mtetra
.28 0 0 r
.4743 .31032 .47898 .30942 .48705 .31184 .48241 .3121 Mtetra
.207 0 0 r
.48241 .3121 .48705 .31184 .49518 .31397 .49056 .31363 Mtetra
.108 0 0 r
.49056 .31363 .49518 .31397 .50336 .31564 .49877 .31477 Mtetra
.007 .578 .769 r
.49877 .31477 .50336 .31564 .51159 .31676 .50702 .31542 Mtetra
.127 .662 .856 r
.50702 .31542 .51159 .31676 .51987 .31728 .51532 .31551 Mtetra
.24 .731 .921 r
.51532 .31551 .51987 .31728 .52818 .31719 .52367 .31504 Mtetra
.341 .781 .963 r
.52367 .31504 .52818 .31719 .53654 .31648 .53205 .31398 Mtetra
.426 .816 .987 r
.53205 .31398 .53654 .31648 .54494 .31518 .54046 .31236 Mtetra
.496 .839 .997 r
.54046 .31236 .54494 .31518 .55336 .31329 .54891 .31018 Mtetra
.552 .853 .998 r
.54891 .31018 .55336 .31329 .56181 .31085 .55739 .30747 Mtetra
.598 .86 .993 r
.55739 .30747 .56181 .31085 .57029 .30788 .56589 .30424 Mtetra
.634 .863 .985 r
.56589 .30424 .57029 .30788 .57879 .30441 .57441 .30052 Mtetra
.664 .864 .975 r
.57441 .30052 .57879 .30441 .58731 .30045 .58295 .29634 Mtetra
.688 .862 .965 r
.58295 .29634 .58731 .30045 .59585 .29604 .59151 .29172 Mtetra
.708 .86 .954 r
.59151 .29172 .59585 .29604 .6044 .29121 .60008 .28668 Mtetra
.725 .856 .944 r
.60008 .28668 .6044 .29121 .61297 .28598 .60867 .28125 Mtetra
.739 .853 .934 r
.60867 .28125 .61297 .28598 .62154 .28037 .61726 .27545 Mtetra
.75 .849 .924 r
.61726 .27545 .62154 .28037 .63013 .2744 .62587 .2693 Mtetra
.76 .845 .916 r
.62587 .2693 .63013 .2744 .63872 .26812 .63448 .26284 Mtetra
.768 .841 .907 r
.63448 .26284 .63872 .26812 .64731 .26152 .64309 .25608 Mtetra
.775 .837 .9 r
.64309 .25608 .64731 .26152 .65591 .25465 .65171 .24904 Mtetra
.781 .833 .893 r
.65171 .24904 .65591 .25465 .66451 .24752 .66034 .24175 Mtetra
.785 .83 .886 r
.66034 .24175 .66451 .24752 .67312 .24015 .66896 .23423 Mtetra
.789 .826 .881 r
.66896 .23423 .67312 .24015 .68173 .23257 .67759 .22649 Mtetra
.793 .823 .875 r
.67759 .22649 .68173 .23257 .69034 .22479 .68622 .21857 Mtetra
.796 .819 .87 r
.68622 .21857 .69034 .22479 .69895 .21684 .69485 .21048 Mtetra
.798 .816 .866 r
.69485 .21048 .69895 .21684 .70756 .20874 .70348 .20223 Mtetra
.799 .812 .862 r
.70348 .20223 .70756 .20874 .71617 .2005 .71211 .19385 Mtetra
.8 .809 .858 r
.71211 .19385 .71617 .2005 .72478 .19215 .72074 .18536 Mtetra
.801 .806 .855 r
.72074 .18536 .72478 .19215 .73339 .1837 .72937 .17678 Mtetra
.801 .802 .852 r
.72937 .17678 .73339 .1837 .74201 .17518 .73801 .16812 Mtetra
.801 .799 .849 r
.73801 .16812 .74201 .17518 .75062 .16659 .74664 .1594 Mtetra
.801 .796 .847 r
.74664 .1594 .75062 .16659 .75924 .15797 .75528 .15065 Mtetra
.8 .792 .845 r
.75528 .15065 .75924 .15797 .76786 .14932 .76391 .14187 Mtetra
.31 .598 .947 r
.12899 .42039 .13415 .42633 .14081 .42768 .13565 .42183 Mtetra
.307 .6 .949 r
.13565 .42183 .14081 .42768 .1475 .42901 .14234 .42326 Mtetra
.305 .604 .951 r
.14234 .42326 .1475 .42901 .15423 .43032 .14906 .42466 Mtetra
.305 .609 .953 r
.14906 .42466 .15423 .43032 .16101 .43159 .15583 .42602 Mtetra
.307 .614 .956 r
.15583 .42602 .16101 .43159 .16782 .43279 .16264 .42732 Mtetra
.311 .621 .958 r
.16264 .42732 .16782 .43279 .17467 .43391 .16949 .42855 Mtetra
.317 .629 .961 r
.16949 .42855 .17467 .43391 .18157 .43494 .17638 .42967 Mtetra
.325 .638 .964 r
.17638 .42967 .18157 .43494 .18852 .43584 .18332 .43069 Mtetra
.335 .648 .968 r
.18332 .43069 .18852 .43584 .19551 .43662 .19031 .43157 Mtetra
.346 .659 .971 r
.19031 .43157 .19551 .43662 .20254 .43724 .19735 .4323 Mtetra
.36 .671 .975 r
.19735 .4323 .20254 .43724 .20963 .43768 .20443 .43286 Mtetra
.375 .684 .979 r
.20443 .43286 .20963 .43768 .21677 .43793 .21156 .43322 Mtetra
.392 .698 .982 r
.21156 .43322 .21677 .43793 .22395 .43797 .21875 .43338 Mtetra
.411 .712 .985 r
.21875 .43338 .22395 .43797 .23119 .43776 .22598 .43331 Mtetra
.431 .727 .988 r
.22598 .43331 .23119 .43776 .23847 .4373 .23327 .43298 Mtetra
.452 .743 .991 r
.23327 .43298 .23847 .4373 .24581 .43656 .24061 .43237 Mtetra
.475 .759 .993 r
.24061 .43237 .24581 .43656 .2532 .43551 .24801 .43147 Mtetra
.498 .775 .994 r
.24801 .43147 .2532 .43551 .26065 .43413 .25545 .43025 Mtetra
.523 .792 .994 r
.25545 .43025 .26065 .43413 .26814 .4324 .26295 .42868 Mtetra
.548 .808 .994 r
.26295 .42868 .26814 .4324 .27569 .43029 .2705 .42674 Mtetra
.573 .825 .993 r
.2705 .42674 .27569 .43029 .28328 .42778 .2781 .42441 Mtetra
.599 .841 .99 r
.2781 .42441 .28328 .42778 .29093 .42484 .28575 .42167 Mtetra
.624 .856 .987 r
.28575 .42167 .29093 .42484 .29863 .42144 .29346 .41848 Mtetra
.649 .872 .982 r
.29346 .41848 .29863 .42144 .30638 .41757 .30121 .41483 Mtetra
.674 .886 .976 r
.30121 .41483 .30638 .41757 .31417 .41319 .30901 .41069 Mtetra
.698 .9 .969 r
.30901 .41069 .31417 .41319 .32201 .40828 .31686 .40604 Mtetra
.721 .914 .961 r
.31686 .40604 .32201 .40828 .3299 .40282 .32475 .40087 Mtetra
.742 .926 .951 r
.32475 .40087 .3299 .40282 .33782 .3968 .33269 .39516 Mtetra
.762 .939 .941 r
.33269 .39516 .33782 .3968 .34579 .3902 .34066 .38891 Mtetra
.779 .95 .93 r
.34066 .38891 .34579 .3902 .35379 .38303 .34868 .38212 Mtetra
.793 .962 .918 r
.34868 .38212 .35379 .38303 .36182 .3753 .35672 .37483 Mtetra
.802 .973 .906 r
.35672 .37483 .36182 .3753 .36988 .36708 .36479 .36709 Mtetra
.805 .983 .893 r
.36479 .36709 .36988 .36708 .37795 .35846 .37288 .35899 Mtetra
.799 .992 .878 r
.37288 .35899 .37795 .35846 .38604 .34958 .38098 .35067 Mtetra
.778 .996 .86 r
.38098 .35067 .38604 .34958 .39413 .34068 .38908 .34234 Mtetra
.735 .991 .836 r
.38908 .34234 .39413 .34068 .40221 .33207 .39718 .33426 Mtetra
.662 .968 .8 r
.39718 .33426 .40221 .33207 .41027 .3241 .40527 .32671 Mtetra
.556 .92 .751 r
.40527 .32671 .41027 .3241 .41832 .31714 .41334 .31997 Mtetra
.435 .853 .696 r
.41334 .31997 .41832 .31714 .42633 .31142 .4214 .31418 Mtetra
0 0 0 r
.4214 .31418 .42633 .31142 .43431 .30784 .42942 .31059 Mtetra
.078 0 0 r
.42942 .31059 .43431 .30784 .44227 .3064 .4374 .30919 Mtetra
.185 0 0 r
.4374 .30919 .44227 .3064 .45024 .30622 .4454 .30876 Mtetra
.248 0 0 r
.4454 .30876 .45024 .30622 .45822 .30705 .45343 .30914 Mtetra
.272 0 0 r
.45343 .30914 .45822 .30705 .46624 .30854 .46148 .31006 Mtetra
.262 0 0 r
.46148 .31006 .46624 .30854 .4743 .31032 .46958 .31124 Mtetra
.219 0 0 r
.46958 .31124 .4743 .31032 .48241 .3121 .47772 .31242 Mtetra
.149 0 0 r
.47772 .31242 .48241 .3121 .49056 .31363 .4859 .3134 Mtetra
.055 0 0 r
.4859 .3134 .49056 .31363 .49877 .31477 .49414 .31402 Mtetra
.054 .616 .787 r
.49414 .31402 .49877 .31477 .50702 .31542 .50242 .3142 Mtetra
.166 .693 .867 r
.50242 .3142 .50702 .31542 .51532 .31551 .51075 .31387 Mtetra
.273 .755 .926 r
.51075 .31387 .51532 .31551 .52367 .31504 .51911 .31301 Mtetra
.368 .801 .965 r
.51911 .31301 .52367 .31504 .53205 .31398 .52752 .3116 Mtetra
.448 .832 .987 r
.52752 .3116 .53205 .31398 .54046 .31236 .53596 .30966 Mtetra
.514 .852 .996 r
.53596 .30966 .54046 .31236 .54891 .31018 .54443 .30718 Mtetra
.567 .864 .996 r
.54443 .30718 .54891 .31018 .55739 .30747 .55292 .30418 Mtetra
.611 .87 .991 r
.55292 .30418 .55739 .30747 .56589 .30424 .56145 .30069 Mtetra
.645 .872 .983 r
.56145 .30069 .56589 .30424 .57441 .30052 .56999 .29673 Mtetra
.674 .871 .973 r
.56999 .29673 .57441 .30052 .58295 .29634 .57856 .29231 Mtetra
.697 .869 .963 r
.57856 .29231 .58295 .29634 .59151 .29172 .58714 .28746 Mtetra
.716 .866 .952 r
.58714 .28746 .59151 .29172 .60008 .28668 .59573 .28221 Mtetra
.732 .862 .942 r
.59573 .28221 .60008 .28668 .60867 .28125 .60434 .27657 Mtetra
.745 .858 .932 r
.60434 .27657 .60867 .28125 .61726 .27545 .61295 .27058 Mtetra
.756 .853 .923 r
.61295 .27058 .61726 .27545 .62587 .2693 .62158 .26424 Mtetra
.765 .849 .914 r
.62158 .26424 .62587 .2693 .63448 .26284 .63021 .2576 Mtetra
.773 .845 .906 r
.63021 .2576 .63448 .26284 .64309 .25608 .63885 .25066 Mtetra
.779 .841 .898 r
.63885 .25066 .64309 .25608 .65171 .24904 .64749 .24346 Mtetra
.785 .836 .892 r
.64749 .24346 .65171 .24904 .66034 .24175 .65614 .236 Mtetra
.789 .832 .885 r
.65614 .236 .66034 .24175 .66896 .23423 .66478 .22832 Mtetra
.793 .829 .879 r
.66478 .22832 .66896 .23423 .67759 .22649 .67343 .22043 Mtetra
.796 .825 .874 r
.67343 .22043 .67759 .22649 .68622 .21857 .68208 .21235 Mtetra
.799 .821 .869 r
.68208 .21235 .68622 .21857 .69485 .21048 .69073 .20411 Mtetra
.801 .817 .865 r
.69073 .20411 .69485 .21048 .70348 .20223 .69938 .19571 Mtetra
.802 .814 .861 r
.69938 .19571 .70348 .20223 .71211 .19385 .70803 .18719 Mtetra
.803 .81 .857 r
.70803 .18719 .71211 .19385 .72074 .18536 .71668 .17856 Mtetra
.804 .807 .854 r
.71668 .17856 .72074 .18536 .72937 .17678 .72533 .16984 Mtetra
.804 .803 .851 r
.72533 .16984 .72937 .17678 .73801 .16812 .73398 .16104 Mtetra
.804 .8 .848 r
.73398 .16104 .73801 .16812 .74664 .1594 .74263 .15218 Mtetra
.803 .796 .846 r
.74263 .15218 .74664 .1594 .75528 .15065 .75129 .14329 Mtetra
.802 .793 .844 r
.75129 .14329 .75528 .15065 .76391 .14187 .75994 .13438 Mtetra
.297 .591 .945 r
.12382 .41442 .12899 .42039 .13565 .42183 .13046 .41596 Mtetra
.293 .593 .947 r
.13046 .41596 .13565 .42183 .14234 .42326 .13714 .41749 Mtetra
.291 .597 .949 r
.13714 .41749 .14234 .42326 .14906 .42466 .14386 .41899 Mtetra
.29 .601 .951 r
.14386 .41899 .14906 .42466 .15583 .42602 .15062 .42045 Mtetra
.292 .607 .954 r
.15062 .42045 .15583 .42602 .16264 .42732 .15743 .42185 Mtetra
.296 .614 .956 r
.15743 .42185 .16264 .42732 .16949 .42855 .16427 .42318 Mtetra
.301 .622 .959 r
.16427 .42318 .16949 .42855 .17638 .42967 .17116 .42441 Mtetra
.309 .631 .963 r
.17116 .42441 .17638 .42967 .18332 .43069 .1781 .42553 Mtetra
.318 .641 .966 r
.1781 .42553 .18332 .43069 .19031 .43157 .18508 .42653 Mtetra
.329 .652 .97 r
.18508 .42653 .19031 .43157 .19735 .4323 .19211 .42737 Mtetra
.343 .664 .974 r
.19211 .42737 .19735 .4323 .20443 .43286 .1992 .42805 Mtetra
.357 .677 .977 r
.1992 .42805 .20443 .43286 .21156 .43322 .20633 .42854 Mtetra
.374 .691 .981 r
.20633 .42854 .21156 .43322 .21875 .43338 .21351 .42883 Mtetra
.392 .706 .985 r
.21351 .42883 .21875 .43338 .22598 .43331 .22075 .42889 Mtetra
.412 .722 .988 r
.22075 .42889 .22598 .43331 .23327 .43298 .22803 .4287 Mtetra
.433 .738 .991 r
.22803 .4287 .23327 .43298 .24061 .43237 .23537 .42824 Mtetra
.456 .754 .993 r
.23537 .42824 .24061 .43237 .24801 .43147 .24277 .42749 Mtetra
.479 .771 .995 r
.24277 .42749 .24801 .43147 .25545 .43025 .25021 .42643 Mtetra
.503 .788 .996 r
.25021 .42643 .25545 .43025 .26295 .42868 .25771 .42503 Mtetra
.528 .805 .997 r
.25771 .42503 .26295 .42868 .2705 .42674 .26527 .42327 Mtetra
.554 .822 .996 r
.26527 .42327 .2705 .42674 .2781 .42441 .27287 .42113 Mtetra
.579 .839 .994 r
.27287 .42113 .2781 .42441 .28575 .42167 .28053 .41859 Mtetra
.605 .855 .991 r
.28053 .41859 .28575 .42167 .29346 .41848 .28824 .41561 Mtetra
.63 .871 .987 r
.28824 .41561 .29346 .41848 .30121 .41483 .296 .41219 Mtetra
.655 .887 .982 r
.296 .41219 .30121 .41483 .30901 .41069 .30381 .4083 Mtetra
.679 .902 .975 r
.30381 .4083 .30901 .41069 .31686 .40604 .31166 .40392 Mtetra
.702 .916 .968 r
.31166 .40392 .31686 .40604 .32475 .40087 .31956 .39904 Mtetra
.723 .929 .959 r
.31956 .39904 .32475 .40087 .33269 .39516 .32751 .39365 Mtetra
.742 .942 .949 r
.32751 .39365 .33269 .39516 .34066 .38891 .33549 .38774 Mtetra
.759 .954 .938 r
.33549 .38774 .34066 .38891 .34868 .38212 .34352 .38134 Mtetra
.771 .965 .926 r
.34352 .38134 .34868 .38212 .35672 .37483 .35157 .37447 Mtetra
.779 .976 .914 r
.35157 .37447 .35672 .37483 .36479 .36709 .35965 .36718 Mtetra
.78 .985 .9 r
.35965 .36718 .36479 .36709 .37288 .35899 .36775 .35957 Mtetra
.772 .992 .884 r
.36775 .35957 .37288 .35899 .38098 .35067 .37587 .35177 Mtetra
.749 .993 .865 r
.37587 .35177 .38098 .35067 .38908 .34234 .38399 .34396 Mtetra
.707 .985 .84 r
.38399 .34396 .38908 .34234 .39718 .33426 .39211 .33634 Mtetra
.642 .963 .806 r
.39211 .33634 .39718 .33426 .40527 .32671 .40023 .32915 Mtetra
.556 .923 .765 r
.40023 .32915 .40527 .32671 .41334 .31997 .40833 .32257 Mtetra
.464 .873 .724 r
.40833 .32257 .41334 .31997 .4214 .31418 .41642 .31672 Mtetra
0 0 0 r
.41642 .31672 .4214 .31418 .42942 .31059 .42447 .31311 Mtetra
.063 0 0 r
.42447 .31311 .42942 .31059 .4374 .30919 .43249 .31175 Mtetra
.146 0 0 r
.43249 .31175 .4374 .30919 .4454 .30876 .44053 .31112 Mtetra
.197 0 0 r
.44053 .31112 .4454 .30876 .45343 .30914 .44859 .31111 Mtetra
.215 0 0 r
.44859 .31111 .45343 .30914 .46148 .31006 .45668 .31154 Mtetra
.202 0 0 r
.45668 .31154 .46148 .31006 .46958 .31124 .46481 .31218 Mtetra
.16 0 0 r
.46481 .31218 .46958 .31124 .47772 .31242 .47298 .3128 Mtetra
.091 0 0 r
.47298 .3128 .47772 .31242 .4859 .3134 .4812 .31325 Mtetra
0 .576 .717 r
.4812 .31325 .4859 .3134 .49414 .31402 .48947 .31338 Mtetra
.101 .653 .804 r
.48947 .31338 .49414 .31402 .50242 .3142 .49778 .3131 Mtetra
.206 .722 .877 r
.49778 .3131 .50242 .3142 .51075 .31387 .50613 .31235 Mtetra
.306 .778 .931 r
.50613 .31235 .51075 .31387 .51911 .31301 .51452 .3111 Mtetra
.394 .819 .966 r
.51452 .3111 .51911 .31301 .52752 .3116 .52295 .30934 Mtetra
.47 .847 .986 r
.52295 .30934 .52752 .3116 .53596 .30966 .53141 .30706 Mtetra
.532 .865 .994 r
.53141 .30706 .53596 .30966 .54443 .30718 .53991 .30428 Mtetra
.583 .875 .994 r
.53991 .30428 .54443 .30718 .55292 .30418 .54843 .30099 Mtetra
.623 .879 .989 r
.54843 .30099 .55292 .30418 .56145 .30069 .55698 .29723 Mtetra
.657 .88 .981 r
.55698 .29723 .56145 .30069 .56999 .29673 .56554 .29301 Mtetra
.684 .878 .971 r
.56554 .29301 .56999 .29673 .57856 .29231 .57413 .28835 Mtetra
.706 .875 .961 r
.57413 .28835 .57856 .29231 .58714 .28746 .58273 .28327 Mtetra
.724 .871 .95 r
.58273 .28327 .58714 .28746 .59573 .28221 .59135 .2778 Mtetra
.739 .867 .94 r
.59135 .2778 .59573 .28221 .60434 .27657 .59998 .27195 Mtetra
.751 .862 .93 r
.59998 .27195 .60434 .27657 .61295 .27058 .60862 .26575 Mtetra
.762 .858 .921 r
.60862 .26575 .61295 .27058 .62158 .26424 .61727 .25923 Mtetra
.77 .853 .912 r
.61727 .25923 .62158 .26424 .63021 .2576 .62592 .25239 Mtetra
.778 .848 .904 r
.62592 .25239 .63021 .2576 .63885 .25066 .63458 .24528 Mtetra
.784 .844 .897 r
.63458 .24528 .63885 .25066 .64749 .24346 .64324 .23789 Mtetra
.789 .839 .89 r
.64324 .23789 .64749 .24346 .65614 .236 .65191 .23027 Mtetra
.793 .835 .884 r
.65191 .23027 .65614 .236 .66478 .22832 .66058 .22242 Mtetra
.797 .831 .878 r
.66058 .22242 .66478 .22832 .67343 .22043 .66925 .21437 Mtetra
.8 .827 .872 r
.66925 .21437 .67343 .22043 .68208 .21235 .67792 .20613 Mtetra
.802 .823 .868 r
.67792 .20613 .68208 .21235 .69073 .20411 .68659 .19773 Mtetra
.804 .819 .863 r
.68659 .19773 .69073 .20411 .69938 .19571 .69526 .18919 Mtetra
.805 .815 .859 r
.69526 .18919 .69938 .19571 .70803 .18719 .70393 .18052 Mtetra
.806 .812 .855 r
.70393 .18052 .70803 .18719 .71668 .17856 .71259 .17174 Mtetra
.807 .808 .852 r
.71259 .17174 .71668 .17856 .72533 .16984 .72126 .16287 Mtetra
.807 .805 .849 r
.72126 .16287 .72533 .16984 .73398 .16104 .72993 .15392 Mtetra
.806 .801 .846 r
.72993 .15392 .73398 .16104 .74263 .15218 .7386 .14493 Mtetra
.806 .797 .844 r
.7386 .14493 .74263 .15218 .75129 .14329 .74727 .13589 Mtetra
.805 .794 .842 r
.74727 .13589 .75129 .14329 .75994 .13438 .75595 .12684 Mtetra
.283 .584 .943 r
.11861 .40842 .12382 .41442 .13046 .41596 .12525 .41006 Mtetra
.279 .586 .945 r
.12525 .41006 .13046 .41596 .13714 .41749 .13192 .41169 Mtetra
.276 .589 .947 r
.13192 .41169 .13714 .41749 .14386 .41899 .13863 .41329 Mtetra
.275 .594 .949 r
.13863 .41329 .14386 .41899 .15062 .42045 .14539 .41486 Mtetra
.276 .599 .951 r
.14539 .41486 .15062 .42045 .15743 .42185 .15218 .41637 Mtetra
.28 .606 .954 r
.15218 .41637 .15743 .42185 .16427 .42318 .15902 .4178 Mtetra
.285 .614 .957 r
.15902 .4178 .16427 .42318 .17116 .42441 .16591 .41915 Mtetra
.292 .623 .96 r
.16591 .41915 .17116 .42441 .1781 .42553 .17284 .42038 Mtetra
.301 .633 .964 r
.17284 .42038 .1781 .42553 .18508 .42653 .17982 .42149 Mtetra
.311 .644 .968 r
.17982 .42149 .18508 .42653 .19211 .42737 .18685 .42246 Mtetra
.324 .657 .972 r
.18685 .42246 .19211 .42737 .1992 .42805 .19393 .42326 Mtetra
.339 .67 .976 r
.19393 .42326 .1992 .42805 .20633 .42854 .20105 .42388 Mtetra
.355 .684 .98 r
.20105 .42388 .20633 .42854 .21351 .42883 .20824 .4243 Mtetra
.373 .699 .983 r
.20824 .4243 .21351 .42883 .22075 .42889 .21547 .4245 Mtetra
.392 .715 .987 r
.21547 .4245 .22075 .42889 .22803 .4287 .22276 .42445 Mtetra
.413 .731 .991 r
.22276 .42445 .22803 .4287 .23537 .42824 .2301 .42415 Mtetra
.435 .748 .994 r
.2301 .42415 .23537 .42824 .24277 .42749 .23749 .42356 Mtetra
.458 .765 .996 r
.23749 .42356 .24277 .42749 .25021 .42643 .24494 .42266 Mtetra
.482 .783 .998 r
.24494 .42266 .25021 .42643 .25771 .42503 .25244 .42144 Mtetra
.507 .801 .998 r
.25244 .42144 .25771 .42503 .26527 .42327 .25999 .41987 Mtetra
.533 .818 .998 r
.25999 .41987 .26527 .42327 .27287 .42113 .2676 .41792 Mtetra
.558 .836 .997 r
.2676 .41792 .27287 .42113 .28053 .41859 .27526 .41559 Mtetra
.584 .853 .995 r
.27526 .41559 .28053 .41859 .28824 .41561 .28298 .41284 Mtetra
.609 .87 .991 r
.28298 .41284 .28824 .41561 .296 .41219 .29074 .40965 Mtetra
.634 .886 .987 r
.29074 .40965 .296 .41219 .30381 .4083 .29856 .40601 Mtetra
.658 .901 .981 r
.29856 .40601 .30381 .4083 .31166 .40392 .30642 .40191 Mtetra
.681 .916 .973 r
.30642 .40191 .31166 .40392 .31956 .39904 .31433 .39732 Mtetra
.701 .93 .965 r
.31433 .39732 .31956 .39904 .32751 .39365 .32228 .39225 Mtetra
.72 .943 .955 r
.32228 .39225 .32751 .39365 .33549 .38774 .33027 .38669 Mtetra
.736 .956 .945 r
.33027 .38669 .33549 .38774 .34352 .38134 .33831 .38066 Mtetra
.747 .967 .933 r
.33831 .38066 .34352 .38134 .35157 .37447 .34637 .3742 Mtetra
.754 .977 .92 r
.34637 .3742 .35157 .37447 .35965 .36718 .35446 .36736 Mtetra
.753 .984 .905 r
.35446 .36736 .35965 .36718 .36775 .35957 .36258 .36021 Mtetra
.743 .989 .888 r
.36258 .36021 .36775 .35957 .37587 .35177 .37071 .35289 Mtetra
.72 .988 .868 r
.37071 .35289 .37587 .35177 .38399 .34396 .37885 .34554 Mtetra
.68 .978 .842 r
.37885 .34554 .38399 .34396 .39211 .33634 .38699 .33833 Mtetra
.623 .957 .81 r
.38699 .33833 .39211 .33634 .40023 .32915 .39513 .33144 Mtetra
.553 .924 .775 r
.39513 .33144 .40023 .32915 .40833 .32257 .40327 .32502 Mtetra
.485 .888 .744 r
.40327 .32502 .40833 .32257 .41642 .31672 .4114 .31912 Mtetra
0 0 0 r
.4114 .31912 .41642 .31672 .42447 .31311 .41948 .31549 Mtetra
.051 0 0 r
.41948 .31549 .42447 .31311 .43249 .31175 .42753 .31415 Mtetra
.113 0 0 r
.42753 .31415 .43249 .31175 .44053 .31112 .4356 .31334 Mtetra
.151 0 0 r
.4356 .31334 .44053 .31112 .44859 .31111 .4437 .31299 Mtetra
.161 0 0 r
.4437 .31299 .44859 .31111 .45668 .31154 .45183 .31298 Mtetra
.145 0 0 r
.45183 .31298 .45668 .31154 .46481 .31218 .45999 .31312 Mtetra
.101 0 0 r
.45999 .31312 .46481 .31218 .47298 .3128 .4682 .31324 Mtetra
.035 0 0 r
.4682 .31324 .47298 .3128 .4812 .31325 .47645 .31318 Mtetra
.051 .618 .74 r
.47645 .31318 .4812 .31325 .48947 .31338 .48475 .31283 Mtetra
.147 .688 .82 r
.48475 .31283 .48947 .31338 .49778 .3131 .49309 .31211 Mtetra
.246 .751 .886 r
.49309 .31211 .49778 .3131 .50613 .31235 .50147 .31094 Mtetra
.339 .801 .935 r
.50147 .31094 .50613 .31235 .51452 .3111 .50989 .30931 Mtetra
.421 .837 .967 r
.50989 .30931 .51452 .3111 .52295 .30934 .51835 .30719 Mtetra
.492 .862 .985 r
.51835 .30719 .52295 .30934 .53141 .30706 .52684 .30457 Mtetra
.55 .877 .992 r
.52684 .30457 .53141 .30706 .53991 .30428 .53535 .30147 Mtetra
.598 .885 .991 r
.53535 .30147 .53991 .30428 .54843 .30099 .5439 .2979 Mtetra
.637 .888 .986 r
.5439 .2979 .54843 .30099 .55698 .29723 .55247 .29386 Mtetra
.668 .887 .978 r
.55247 .29386 .55698 .29723 .56554 .29301 .56106 .28938 Mtetra
.694 .885 .969 r
.56106 .28938 .56554 .29301 .57413 .28835 .56967 .28447 Mtetra
.714 .881 .958 r
.56967 .28447 .57413 .28835 .58273 .28327 .5783 .27915 Mtetra
.732 .877 .948 r
.5783 .27915 .58273 .28327 .59135 .2778 .58694 .27345 Mtetra
.746 .872 .938 r
.58694 .27345 .59135 .2778 .59998 .27195 .59559 .26738 Mtetra
.758 .867 .928 r
.59559 .26738 .59998 .27195 .60862 .26575 .60426 .26098 Mtetra
.767 .862 .919 r
.60426 .26098 .60862 .26575 .61727 .25923 .61293 .25425 Mtetra
.776 .857 .911 r
.61293 .25425 .61727 .25923 .62592 .25239 .6216 .24722 Mtetra
.783 .852 .903 r
.6216 .24722 .62592 .25239 .63458 .24528 .63028 .23992 Mtetra
.788 .847 .895 r
.63028 .23992 .63458 .24528 .64324 .23789 .63897 .23235 Mtetra
.793 .842 .888 r
.63897 .23235 .64324 .23789 .65191 .23027 .64766 .22455 Mtetra
.797 .838 .882 r
.64766 .22455 .65191 .23027 .66058 .22242 .65635 .21653 Mtetra
.801 .833 .876 r
.65635 .21653 .66058 .22242 .66925 .21437 .66504 .20831 Mtetra
.803 .829 .871 r
.66504 .20831 .66925 .21437 .67792 .20613 .67373 .19991 Mtetra
.806 .825 .866 r
.67373 .19991 .67792 .20613 .68659 .19773 .68242 .19135 Mtetra
.807 .821 .862 r
.68242 .19135 .68659 .19773 .69526 .18919 .69111 .18265 Mtetra
.808 .817 .858 r
.69111 .18265 .69526 .18919 .70393 .18052 .6998 .17382 Mtetra
.809 .813 .854 r
.6998 .17382 .70393 .18052 .71259 .17174 .70849 .16489 Mtetra
.809 .809 .851 r
.70849 .16489 .71259 .17174 .72126 .16287 .71717 .15587 Mtetra
.809 .806 .848 r
.71717 .15587 .72126 .16287 .72993 .15392 .72586 .14678 Mtetra
.809 .802 .845 r
.72586 .14678 .72993 .15392 .7386 .14493 .73455 .13764 Mtetra
.808 .798 .842 r
.73455 .13764 .7386 .14493 .74727 .13589 .74324 .12845 Mtetra
.807 .794 .84 r
.74324 .12845 .74727 .13589 .75595 .12684 .75193 .11925 Mtetra
.268 .576 .94 r
.11338 .40239 .11861 .40842 .12525 .41006 .12 .40413 Mtetra
.264 .578 .942 r
.12 .40413 .12525 .41006 .13192 .41169 .12667 .40587 Mtetra
.26 .581 .944 r
.12667 .40587 .13192 .41169 .13863 .41329 .13337 .40758 Mtetra
.259 .586 .946 r
.13337 .40758 .13863 .41329 .14539 .41486 .14012 .40926 Mtetra
.26 .591 .948 r
.14012 .40926 .14539 .41486 .15218 .41637 .14691 .41088 Mtetra
.263 .598 .951 r
.14691 .41088 .15218 .41637 .15902 .4178 .15374 .41243 Mtetra
.267 .606 .954 r
.15374 .41243 .15902 .4178 .16591 .41915 .16062 .41388 Mtetra
.274 .615 .957 r
.16062 .41388 .16591 .41915 .17284 .42038 .16755 .41524 Mtetra
.282 .625 .961 r
.16755 .41524 .17284 .42038 .17982 .42149 .17452 .41647 Mtetra
.292 .636 .965 r
.17452 .41647 .17982 .42149 .18685 .42246 .18155 .41756 Mtetra
.305 .648 .969 r
.18155 .41756 .18685 .42246 .19393 .42326 .18862 .41849 Mtetra
.319 .661 .973 r
.18862 .41849 .19393 .42326 .20105 .42388 .19575 .41925 Mtetra
.334 .676 .977 r
.19575 .41925 .20105 .42388 .20824 .4243 .20292 .4198 Mtetra
.352 .691 .981 r
.20292 .4198 .20824 .4243 .21547 .4245 .21015 .42015 Mtetra
.371 .707 .986 r
.21015 .42015 .21547 .4245 .22276 .42445 .21744 .42025 Mtetra
.391 .724 .989 r
.21744 .42025 .22276 .42445 .2301 .42415 .22478 .4201 Mtetra
.413 .741 .993 r
.22478 .4201 .2301 .42415 .23749 .42356 .23217 .41968 Mtetra
.436 .759 .996 r
.23217 .41968 .23749 .42356 .24494 .42266 .23962 .41895 Mtetra
.46 .777 .998 r
.23962 .41895 .24494 .42266 .25244 .42144 .24712 .41791 Mtetra
.484 .795 .999 r
.24712 .41791 .25244 .42144 .25999 .41987 .25468 .41653 Mtetra
.51 .813 1 r
.25468 .41653 .25999 .41987 .2676 .41792 .26229 .41479 Mtetra
.535 .831 .999 r
.26229 .41479 .2676 .41792 .27526 .41559 .26995 .41267 Mtetra
.561 .849 .997 r
.26995 .41267 .27526 .41559 .28298 .41284 .27767 .41014 Mtetra
.586 .867 .995 r
.27767 .41014 .28298 .41284 .29074 .40965 .28544 .4072 Mtetra
.611 .884 .99 r
.28544 .4072 .29074 .40965 .29856 .40601 .29326 .40382 Mtetra
.634 .9 .985 r
.29326 .40382 .29856 .40601 .30642 .40191 .30113 .4 Mtetra
.657 .915 .978 r
.30113 .4 .30642 .40191 .31433 .39732 .30904 .39571 Mtetra
.677 .929 .97 r
.30904 .39571 .31433 .39732 .32228 .39225 .317 .39096 Mtetra
.695 .943 .961 r
.317 .39096 .32228 .39225 .33027 .38669 .32501 .38574 Mtetra
.71 .955 .95 r
.32501 .38574 .33027 .38669 .33831 .38066 .33305 .38009 Mtetra
.721 .966 .938 r
.33305 .38009 .33831 .38066 .34637 .3742 .34112 .37403 Mtetra
.726 .975 .924 r
.34112 .37403 .34637 .3742 .35446 .36736 .34923 .36761 Mtetra
.724 .981 .909 r
.34923 .36761 .35446 .36736 .36258 .36021 .35735 .36091 Mtetra
.712 .984 .891 r
.35735 .36091 .36258 .36021 .37071 .35289 .3655 .35403 Mtetra
.689 .981 .869 r
.3655 .35403 .37071 .35289 .37885 .34554 .37366 .3471 Mtetra
.653 .97 .843 r
.37366 .3471 .37885 .34554 .38699 .33833 .38182 .34026 Mtetra
.604 .95 .813 r
.38182 .34026 .38699 .33833 .39513 .33144 .38999 .33364 Mtetra
.549 .923 .782 r
.38999 .33364 .39513 .33144 .40327 .32502 .39816 .32736 Mtetra
.499 .897 .758 r
.39816 .32736 .40327 .32502 .4114 .31912 .40633 .32142 Mtetra
0 0 0 r
.40633 .32142 .4114 .31912 .41948 .31549 .41445 .31778 Mtetra
.042 0 0 r
.41445 .31778 .41948 .31549 .42753 .31415 .42252 .31644 Mtetra
.084 0 0 r
.42252 .31644 .42753 .31415 .4356 .31334 .43063 .31546 Mtetra
.108 0 0 r
.43063 .31546 .4356 .31334 .4437 .31299 .43876 .31481 Mtetra
.111 0 0 r
.43876 .31481 .4437 .31299 .45183 .31298 .44693 .3144 Mtetra
.09 0 0 r
.44693 .3144 .45183 .31298 .45999 .31312 .45513 .31408 Mtetra
.045 0 0 r
.45513 .31408 .45999 .31312 .4682 .31324 .46338 .31372 Mtetra
0 0 0 r
.46338 .31372 .4682 .31324 .47645 .31318 .47166 .31319 Mtetra
.102 .657 .762 r
.47166 .31319 .47645 .31318 .48475 .31283 .47999 .31238 Mtetra
.192 .721 .834 r
.47999 .31238 .48475 .31283 .49309 .31211 .48836 .31121 Mtetra
.284 .777 .894 r
.48836 .31121 .49309 .31211 .50147 .31094 .49677 .30964 Mtetra
.371 .822 .938 r
.49677 .30964 .50147 .31094 .50989 .30931 .50522 .30762 Mtetra
.448 .854 .967 r
.50522 .30762 .50989 .30931 .51835 .30719 .5137 .30514 Mtetra
.514 .876 .983 r
.5137 .30514 .51835 .30719 .52684 .30457 .52222 .30219 Mtetra
.569 .888 .989 r
.52222 .30219 .52684 .30457 .53535 .30147 .53076 .29877 Mtetra
.613 .894 .988 r
.53076 .29877 .53535 .30147 .5439 .2979 .53934 .29489 Mtetra
.65 .896 .983 r
.53934 .29489 .5439 .2979 .55247 .29386 .54793 .29057 Mtetra
.679 .895 .975 r
.54793 .29057 .55247 .29386 .56106 .28938 .55655 .28582 Mtetra
.704 .891 .966 r
.55655 .28582 .56106 .28938 .56967 .28447 .56518 .28065 Mtetra
.723 .887 .956 r
.56518 .28065 .56967 .28447 .5783 .27915 .57384 .27509 Mtetra
.739 .882 .945 r
.57384 .27509 .5783 .27915 .58694 .27345 .5825 .26916 Mtetra
.753 .876 .936 r
.5825 .26916 .58694 .27345 .59559 .26738 .59118 .26287 Mtetra
.764 .871 .926 r
.59118 .26287 .59559 .26738 .60426 .26098 .59986 .25625 Mtetra
.773 .865 .917 r
.59986 .25625 .60426 .26098 .61293 .25425 .60856 .24931 Mtetra
.781 .86 .909 r
.60856 .24931 .61293 .25425 .6216 .24722 .61726 .24208 Mtetra
.788 .855 .901 r
.61726 .24208 .6216 .24722 .63028 .23992 .62596 .23458 Mtetra
.793 .85 .893 r
.62596 .23458 .63028 .23992 .63897 .23235 .63467 .22683 Mtetra
.798 .845 .887 r
.63467 .22683 .63897 .23235 .64766 .22455 .64338 .21885 Mtetra
.801 .84 .88 r
.64338 .21885 .64766 .22455 .65635 .21653 .65209 .21065 Mtetra
.805 .835 .875 r
.65209 .21065 .65635 .21653 .66504 .20831 .6608 .20226 Mtetra
.807 .831 .869 r
.6608 .20226 .66504 .20831 .67373 .19991 .66951 .19369 Mtetra
.809 .827 .864 r
.66951 .19369 .67373 .19991 .68242 .19135 .67822 .18496 Mtetra
.81 .823 .86 r
.67822 .18496 .68242 .19135 .69111 .18265 .68693 .1761 Mtetra
.811 .819 .856 r
.68693 .1761 .69111 .18265 .6998 .17382 .69564 .16712 Mtetra
.812 .815 .852 r
.69564 .16712 .6998 .17382 .70849 .16489 .70435 .15803 Mtetra
.812 .811 .849 r
.70435 .15803 .70849 .16489 .71717 .15587 .71306 .14885 Mtetra
.812 .807 .846 r
.71306 .14885 .71717 .15587 .72586 .14678 .72177 .13961 Mtetra
.812 .803 .843 r
.72177 .13961 .72586 .14678 .73455 .13764 .73047 .13031 Mtetra
.811 .799 .841 r
.73047 .13031 .73455 .13764 .74324 .12845 .73918 .12098 Mtetra
.81 .795 .838 r
.73918 .12098 .74324 .12845 .75193 .11925 .74789 .11163 Mtetra
.253 .567 .937 r
.10812 .39633 .11338 .40239 .12 .40413 .11473 .39818 Mtetra
.248 .569 .939 r
.11473 .39818 .12 .40413 .12667 .40587 .12139 .40003 Mtetra
.244 .572 .941 r
.12139 .40003 .12667 .40587 .13337 .40758 .12809 .40185 Mtetra
.242 .577 .942 r
.12809 .40185 .13337 .40758 .14012 .40926 .13482 .40364 Mtetra
.243 .582 .945 r
.13482 .40364 .14012 .40926 .14691 .41088 .1416 .40537 Mtetra
.245 .589 .947 r
.1416 .40537 .14691 .41088 .15374 .41243 .14843 .40704 Mtetra
.249 .596 .95 r
.14843 .40704 .15374 .41243 .16062 .41388 .1553 .40862 Mtetra
.255 .605 .954 r
.1553 .40862 .16062 .41388 .16755 .41524 .16222 .4101 Mtetra
.263 .615 .957 r
.16222 .4101 .16755 .41524 .17452 .41647 .16919 .41145 Mtetra
.272 .626 .961 r
.16919 .41145 .17452 .41647 .18155 .41756 .17621 .41267 Mtetra
.284 .639 .965 r
.17621 .41267 .18155 .41756 .18862 .41849 .18328 .41374 Mtetra
.297 .652 .97 r
.18328 .41374 .18862 .41849 .19575 .41925 .1904 .41463 Mtetra
.313 .667 .974 r
.1904 .41463 .19575 .41925 .20292 .4198 .19757 .41533 Mtetra
.329 .682 .979 r
.19757 .41533 .20292 .4198 .21015 .42015 .2048 .41582 Mtetra
.348 .698 .983 r
.2048 .41582 .21015 .42015 .21744 .42025 .21208 .41609 Mtetra
.368 .715 .987 r
.21208 .41609 .21744 .42025 .22478 .4201 .21942 .4161 Mtetra
.389 .733 .991 r
.21942 .4161 .22478 .4201 .23217 .41968 .22681 .41584 Mtetra
.412 .751 .994 r
.22681 .41584 .23217 .41968 .23962 .41895 .23426 .4153 Mtetra
.435 .769 .997 r
.23426 .4153 .23962 .41895 .24712 .41791 .24176 .41444 Mtetra
.459 .788 .999 r
.24176 .41444 .24712 .41791 .25468 .41653 .24932 .41326 Mtetra
.484 .807 1 r
.24932 .41326 .25468 .41653 .26229 .41479 .25693 .41173 Mtetra
.51 .825 1 r
.25693 .41173 .26229 .41479 .26995 .41267 .2646 .40982 Mtetra
.535 .844 .999 r
.2646 .40982 .26995 .41267 .27767 .41014 .27232 .40754 Mtetra
.56 .862 .996 r
.27232 .40754 .27767 .41014 .28544 .4072 .28009 .40484 Mtetra
.585 .879 .993 r
.28009 .40484 .28544 .4072 .29326 .40382 .28791 .40173 Mtetra
.608 .896 .988 r
.28791 .40173 .29326 .40382 .30113 .4 .29579 .39818 Mtetra
.63 .912 .981 r
.29579 .39818 .30113 .4 .30904 .39571 .30371 .39419 Mtetra
.65 .927 .974 r
.30371 .39419 .30904 .39571 .317 .39096 .31168 .38976 Mtetra
.667 .94 .964 r
.31168 .38976 .317 .39096 .32501 .38574 .31969 .3849 Mtetra
.681 .952 .953 r
.31969 .3849 .32501 .38574 .33305 .38009 .32774 .37962 Mtetra
.691 .963 .941 r
.32774 .37962 .33305 .38009 .34112 .37403 .33582 .37394 Mtetra
.695 .971 .927 r
.33582 .37394 .34112 .37403 .34923 .36761 .34394 .36793 Mtetra
.692 .976 .91 r
.34394 .36793 .34923 .36761 .35735 .36091 .35208 .36165 Mtetra
.68 .977 .891 r
.35208 .36165 .35735 .36091 .3655 .35403 .36024 .35518 Mtetra
.658 .972 .868 r
.36024 .35518 .3655 .35403 .37366 .3471 .36842 .34864 Mtetra
.626 .961 .842 r
.36842 .34864 .37366 .3471 .38182 .34026 .37661 .34214 Mtetra
.585 .942 .813 r
.37661 .34214 .38182 .34026 .38999 .33364 .3848 .33578 Mtetra
.541 .92 .786 r
.3848 .33578 .38999 .33364 .39816 .32736 .393 .32962 Mtetra
.506 .901 .766 r
.393 .32962 .39816 .32736 .40633 .32142 .40121 .32367 Mtetra
.246 .744 .67 r
.40121 .32367 .40633 .32142 .41445 .31778 .40936 .32001 Mtetra
.035 0 0 r
.40936 .32001 .41445 .31778 .42252 .31644 .41747 .31866 Mtetra
.058 0 0 r
.41747 .31866 .42252 .31644 .43063 .31546 .42561 .31752 Mtetra
.07 0 0 r
.42561 .31752 .43063 .31546 .43876 .31481 .43378 .31659 Mtetra
.064 0 0 r
.43378 .31659 .43876 .31481 .44693 .3144 .44198 .3158 Mtetra
.038 0 0 r
.44198 .3158 .44693 .3144 .45513 .31408 .45022 .31506 Mtetra
0 0 0 r
.45022 .31506 .45513 .31408 .46338 .31372 .4585 .31425 Mtetra
.072 .634 .71 r
.4585 .31425 .46338 .31372 .47166 .31319 .46682 .31326 Mtetra
.151 .694 .781 r
.46682 .31326 .47166 .31319 .47999 .31238 .47519 .31201 Mtetra
.236 .752 .846 r
.47519 .31201 .47999 .31238 .48836 .31121 .48359 .31041 Mtetra
.322 .802 .9 r
.48359 .31041 .48836 .31121 .49677 .30964 .49203 .30843 Mtetra
.403 .842 .94 r
.49203 .30843 .49677 .30964 .50522 .30762 .50051 .30603 Mtetra
.475 .87 .966 r
.50051 .30603 .50522 .30762 .5137 .30514 .50902 .30318 Mtetra
.536 .888 .981 r
.50902 .30318 .5137 .30514 .52222 .30219 .51757 .29989 Mtetra
.587 .899 .986 r
.51757 .29989 .52222 .30219 .53076 .29877 .52614 .29615 Mtetra
.629 .903 .985 r
.52614 .29615 .53076 .29877 .53934 .29489 .53474 .29197 Mtetra
.663 .904 .979 r
.53474 .29197 .53934 .29489 .54793 .29057 .54336 .28736 Mtetra
.691 .901 .972 r
.54336 .28736 .54793 .29057 .55655 .28582 .552 .28233 Mtetra
.714 .897 .962 r
.552 .28233 .55655 .28582 .56518 .28065 .56066 .2769 Mtetra
.732 .892 .953 r
.56066 .2769 .56518 .28065 .57384 .27509 .56934 .27109 Mtetra
.747 .887 .943 r
.56934 .27109 .57384 .27509 .5825 .26916 .57803 .26492 Mtetra
.76 .881 .933 r
.57803 .26492 .5825 .26916 .59118 .26287 .58673 .2584 Mtetra
.771 .875 .923 r
.58673 .2584 .59118 .26287 .59986 .25625 .59544 .25156 Mtetra
.779 .869 .915 r
.59544 .25156 .59986 .25625 .60856 .24931 .60416 .24441 Mtetra
.787 .863 .906 r
.60416 .24441 .60856 .24931 .61726 .24208 .61288 .23697 Mtetra
.793 .858 .898 r
.61288 .23697 .61726 .24208 .62596 .23458 .62161 .22928 Mtetra
.798 .853 .891 r
.62161 .22928 .62596 .23458 .63467 .22683 .63034 .22133 Mtetra
.802 .847 .885 r
.63034 .22133 .63467 .22683 .64338 .21885 .63907 .21316 Mtetra
.806 .842 .878 r
.63907 .21316 .64338 .21885 .65209 .21065 .6478 .20478 Mtetra
.808 .838 .873 r
.6478 .20478 .65209 .21065 .6608 .20226 .65654 .19621 Mtetra
.811 .833 .867 r
.65654 .19621 .6608 .20226 .66951 .19369 .66527 .18747 Mtetra
.812 .829 .863 r
.66527 .18747 .66951 .19369 .67822 .18496 .674 .17857 Mtetra
.814 .824 .858 r
.674 .17857 .67822 .18496 .68693 .1761 .68274 .16954 Mtetra
.815 .82 .854 r
.68274 .16954 .68693 .1761 .69564 .16712 .69147 .16039 Mtetra
.815 .816 .85 r
.69147 .16039 .69564 .16712 .70435 .15803 .70019 .15114 Mtetra
.815 .812 .847 r
.70019 .15114 .70435 .15803 .71306 .14885 .70892 .14181 Mtetra
.815 .808 .844 r
.70892 .14181 .71306 .14885 .72177 .13961 .71765 .1324 Mtetra
.814 .804 .841 r
.71765 .1324 .72177 .13961 .73047 .13031 .72637 .12295 Mtetra
.813 .8 .839 r
.72637 .12295 .73047 .13031 .73918 .12098 .7351 .11346 Mtetra
.812 .796 .837 r
.7351 .11346 .73918 .12098 .74789 .11163 .74382 .10395 Mtetra
.237 .558 .934 r
.10283 .39023 .10812 .39633 .11473 .39818 .10944 .3922 Mtetra
.231 .56 .935 r
.10944 .3922 .11473 .39818 .12139 .40003 .11608 .39416 Mtetra
.227 .563 .937 r
.11608 .39416 .12139 .40003 .12809 .40185 .12277 .3961 Mtetra
.225 .567 .939 r
.12277 .3961 .12809 .40185 .13482 .40364 .1295 .39801 Mtetra
.224 .572 .941 r
.1295 .39801 .13482 .40364 .1416 .40537 .13627 .39986 Mtetra
.226 .579 .943 r
.13627 .39986 .1416 .40537 .14843 .40704 .14309 .40165 Mtetra
.229 .586 .946 r
.14309 .40165 .14843 .40704 .1553 .40862 .14995 .40335 Mtetra
.235 .595 .949 r
.14995 .40335 .1553 .40862 .16222 .4101 .15686 .40495 Mtetra
.242 .605 .953 r
.15686 .40495 .16222 .4101 .16919 .41145 .16382 .40644 Mtetra
.251 .616 .957 r
.16382 .40644 .16919 .41145 .17621 .41267 .17084 .4078 Mtetra
.262 .629 .961 r
.17084 .4078 .17621 .41267 .18328 .41374 .1779 .409 Mtetra
.275 .642 .966 r
.1779 .409 .18328 .41374 .1904 .41463 .18501 .41004 Mtetra
.29 .656 .97 r
.18501 .41004 .1904 .41463 .19757 .41533 .19218 .41089 Mtetra
.306 .672 .975 r
.19218 .41089 .19757 .41533 .2048 .41582 .19941 .41153 Mtetra
.324 .688 .979 r
.19941 .41153 .2048 .41582 .21208 .41609 .20669 .41196 Mtetra
.343 .705 .984 r
.20669 .41196 .21208 .41609 .21942 .4161 .21402 .41214 Mtetra
.364 .723 .988 r
.21402 .41214 .21942 .4161 .22681 .41584 .22141 .41205 Mtetra
.386 .741 .992 r
.22141 .41205 .22681 .41584 .23426 .4153 .22885 .41169 Mtetra
.409 .76 .995 r
.22885 .41169 .23426 .4153 .24176 .41444 .23636 .41103 Mtetra
.433 .779 .997 r
.23636 .41103 .24176 .41444 .24932 .41326 .24391 .41005 Mtetra
.457 .798 .999 r
.24391 .41005 .24932 .41326 .25693 .41173 .25153 .40873 Mtetra
.482 .818 .999 r
.25153 .40873 .25693 .41173 .2646 .40982 .25919 .40706 Mtetra
.507 .837 .999 r
.25919 .40706 .2646 .40982 .27232 .40754 .26692 .40501 Mtetra
.532 .855 .997 r
.26692 .40501 .27232 .40754 .28009 .40484 .27469 .40257 Mtetra
.556 .873 .994 r
.27469 .40257 .28009 .40484 .28791 .40173 .28252 .39972 Mtetra
.579 .89 .989 r
.28252 .39972 .28791 .40173 .29579 .39818 .2904 .39646 Mtetra
.601 .907 .983 r
.2904 .39646 .29579 .39818 .30371 .39419 .29833 .39278 Mtetra
.62 .922 .975 r
.29833 .39278 .30371 .39419 .31168 .38976 .3063 .38867 Mtetra
.637 .935 .966 r
.3063 .38867 .31168 .38976 .31969 .3849 .31432 .38415 Mtetra
.65 .947 .955 r
.31432 .38415 .31969 .3849 .32774 .37962 .32238 .37923 Mtetra
.659 .957 .942 r
.32238 .37923 .32774 .37962 .33582 .37394 .33047 .37394 Mtetra
.662 .964 .926 r
.33047 .37394 .33582 .37394 .34394 .36793 .3386 .36832 Mtetra
.658 .968 .909 r
.3386 .36832 .34394 .36793 .35208 .36165 .34675 .36244 Mtetra
.646 .967 .888 r
.34675 .36244 .35208 .36165 .36024 .35518 .35493 .35637 Mtetra
.626 .961 .865 r
.35493 .35637 .36024 .35518 .36842 .34864 .36313 .3502 Mtetra
.598 .95 .839 r
.36313 .3502 .36842 .34864 .37661 .34214 .37134 .34401 Mtetra
.564 .934 .811 r
.37134 .34401 .37661 .34214 .3848 .33578 .37956 .33788 Mtetra
.531 .916 .787 r
.37956 .33788 .3848 .33578 .393 .32962 .38779 .33186 Mtetra
.508 .903 .77 r
.38779 .33186 .393 .32962 .40121 .32367 .39603 .32591 Mtetra
.25 .747 .674 r
.39603 .32591 .40121 .32367 .40936 .32001 .40422 .32224 Mtetra
.028 0 0 r
.40422 .32224 .40936 .32001 .41747 .31866 .41236 .32085 Mtetra
.035 0 0 r
.41236 .32085 .41747 .31866 .42561 .31752 .42054 .31954 Mtetra
.42054 .31954 .42561 .31752 .43378 .31659 .42874 .31834 Mtetra
.02 0 0 r
.42874 .31834 .43378 .31659 .44198 .3158 .43699 .31721 Mtetra
0 0 0 r
.43699 .31721 .44198 .3158 .45022 .31506 .44527 .31607 Mtetra
.44527 .31607 .45022 .31506 .4585 .31425 .45358 .31483 Mtetra
.122 .672 .732 r
.45358 .31483 .4585 .31425 .46682 .31326 .46194 .31341 Mtetra
.197 .727 .797 r
.46194 .31341 .46682 .31326 .47519 .31201 .47034 .31172 Mtetra
.278 .78 .857 r
.47034 .31172 .47519 .31201 .48359 .31041 .47877 .3097 Mtetra
.359 .825 .906 r
.47877 .3097 .48359 .31041 .49203 .30843 .48725 .30732 Mtetra
.434 .86 .942 r
.48725 .30732 .49203 .30843 .50051 .30603 .49576 .30453 Mtetra
.5 .885 .965 r
.49576 .30453 .50051 .30603 .50902 .30318 .5043 .30133 Mtetra
.557 .9 .978 r
.5043 .30133 .50902 .30318 .51757 .29989 .51287 .29769 Mtetra
.605 .909 .982 r
.51287 .29769 .51757 .29989 .52614 .29615 .52147 .29362 Mtetra
.644 .912 .981 r
.52147 .29362 .52614 .29615 .53474 .29197 .5301 .28913 Mtetra
.676 .911 .975 r
.5301 .28913 .53474 .29197 .54336 .28736 .53875 .28422 Mtetra
.702 .908 .968 r
.53875 .28422 .54336 .28736 .552 .28233 .54742 .27891 Mtetra
.723 .903 .959 r
.54742 .27891 .552 .28233 .56066 .2769 .55611 .27322 Mtetra
.741 .897 .949 r
.55611 .27322 .56066 .2769 .56934 .27109 .56481 .26715 Mtetra
.755 .891 .939 r
.56481 .26715 .56934 .27109 .57803 .26492 .57353 .26073 Mtetra
.767 .885 .93 r
.57353 .26073 .57803 .26492 .58673 .2584 .58225 .25398 Mtetra
.777 .879 .921 r
.58225 .25398 .58673 .2584 .59544 .25156 .59099 .24691 Mtetra
.785 .873 .912 r
.59099 .24691 .59544 .25156 .60416 .24441 .59973 .23954 Mtetra
.792 .867 .904 r
.59973 .23954 .60416 .24441 .61288 .23697 .60847 .23189 Mtetra
.798 .861 .896 r
.60847 .23189 .61288 .23697 .62161 .22928 .61723 .22399 Mtetra
.803 .855 .889 r
.61723 .22399 .62161 .22928 .63034 .22133 .62598 .21585 Mtetra
.806 .85 .882 r
.62598 .21585 .63034 .22133 .63907 .21316 .63474 .20748 Mtetra
.81 .845 .876 r
.63474 .20748 .63907 .21316 .6478 .20478 .64349 .19891 Mtetra
.812 .84 .871 r
.64349 .19891 .6478 .20478 .65654 .19621 .65225 .19016 Mtetra
.814 .835 .865 r
.65225 .19016 .65654 .19621 .66527 .18747 .66101 .18124 Mtetra
.816 .83 .861 r
.66101 .18124 .66527 .18747 .674 .17857 .66976 .17217 Mtetra
.817 .826 .856 r
.66976 .17217 .674 .17857 .68274 .16954 .67851 .16297 Mtetra
.818 .821 .852 r
.67851 .16297 .68274 .16954 .69147 .16039 .68726 .15365 Mtetra
.818 .817 .849 r
.68726 .15365 .69147 .16039 .70019 .15114 .69601 .14423 Mtetra
.818 .813 .845 r
.69601 .14423 .70019 .15114 .70892 .14181 .70476 .13473 Mtetra
.818 .809 .842 r
.70476 .13473 .70892 .14181 .71765 .1324 .7135 .12517 Mtetra
.817 .805 .84 r
.7135 .12517 .71765 .1324 .72637 .12295 .72225 .11555 Mtetra
.816 .801 .837 r
.72225 .11555 .72637 .12295 .7351 .11346 .73099 .1059 Mtetra
.815 .797 .835 r
.73099 .1059 .7351 .11346 .74382 .10395 .73974 .09624 Mtetra
.219 .548 .93 r
.09751 .3841 .10283 .39023 .10944 .3922 .10411 .38619 Mtetra
.213 .55 .931 r
.10411 .38619 .10944 .3922 .11608 .39416 .11074 .38827 Mtetra
.209 .553 .933 r
.11074 .38827 .11608 .39416 .12277 .3961 .11742 .39033 Mtetra
.206 .557 .934 r
.11742 .39033 .12277 .3961 .1295 .39801 .12414 .39236 Mtetra
.205 .562 .936 r
.12414 .39236 .1295 .39801 .13627 .39986 .1309 .39433 Mtetra
.206 .568 .938 r
.1309 .39433 .13627 .39986 .14309 .40165 .13771 .39625 Mtetra
.209 .576 .941 r
.13771 .39625 .14309 .40165 .14995 .40335 .14456 .39808 Mtetra
.214 .584 .944 r
.14456 .39808 .14995 .40335 .15686 .40495 .15147 .39981 Mtetra
.221 .594 .948 r
.15147 .39981 .15686 .40495 .16382 .40644 .15842 .40144 Mtetra
.229 .605 .952 r
.15842 .40144 .16382 .40644 .17084 .4078 .16543 .40293 Mtetra
.24 .617 .956 r
.16543 .40293 .17084 .4078 .1779 .409 .17248 .40428 Mtetra
.252 .631 .961 r
.17248 .40428 .1779 .409 .18501 .41004 .17959 .40546 Mtetra
.266 .645 .965 r
.17959 .40546 .18501 .41004 .19218 .41089 .18676 .40647 Mtetra
.281 .66 .97 r
.18676 .40647 .19218 .41089 .19941 .41153 .19398 .40727 Mtetra
.298 .677 .975 r
.19398 .40727 .19941 .41153 .20669 .41196 .20125 .40786 Mtetra
.317 .694 .979 r
.20125 .40786 .20669 .41196 .21402 .41214 .20858 .40821 Mtetra
.337 .712 .984 r
.20858 .40821 .21402 .41214 .22141 .41205 .21597 .40831 Mtetra
.358 .73 .988 r
.21597 .40831 .22141 .41205 .22885 .41169 .22341 .40814 Mtetra
.381 .749 .991 r
.22341 .40814 .22885 .41169 .23636 .41103 .23091 .40768 Mtetra
.404 .769 .994 r
.23091 .40768 .23636 .41103 .24391 .41005 .23846 .40691 Mtetra
.428 .788 .996 r
.23846 .40691 .24391 .41005 .25153 .40873 .24608 .40581 Mtetra
.452 .808 .997 r
.24608 .40581 .25153 .40873 .25919 .40706 .25374 .40436 Mtetra
.477 .827 .997 r
.25374 .40436 .25919 .40706 .26692 .40501 .26147 .40255 Mtetra
.501 .846 .995 r
.26147 .40255 .26692 .40501 .27469 .40257 .26925 .40037 Mtetra
.525 .865 .993 r
.26925 .40037 .27469 .40257 .28252 .39972 .27708 .3978 Mtetra
.547 .882 .988 r
.27708 .3978 .28252 .39972 .2904 .39646 .28496 .39483 Mtetra
.568 .899 .982 r
.28496 .39483 .2904 .39646 .29833 .39278 .29289 .39145 Mtetra
.587 .914 .975 r
.29289 .39145 .29833 .39278 .3063 .38867 .30087 .38767 Mtetra
.603 .927 .965 r
.30087 .38767 .3063 .38867 .31432 .38415 .3089 .38349 Mtetra
.615 .939 .954 r
.3089 .38349 .31432 .38415 .32238 .37923 .31696 .37893 Mtetra
.623 .948 .94 r
.31696 .37893 .32238 .37923 .33047 .37394 .32507 .37401 Mtetra
.626 .954 .924 r
.32507 .37401 .33047 .37394 .3386 .36832 .3332 .36878 Mtetra
.622 .957 .905 r
.3332 .36878 .3386 .36832 .34675 .36244 .34137 .36328 Mtetra
.611 .955 .884 r
.34137 .36328 .34675 .36244 .35493 .35637 .34957 .35759 Mtetra
.593 .949 .86 r
.34957 .35759 .35493 .35637 .36313 .3502 .35778 .35176 Mtetra
.568 .938 .834 r
.35778 .35176 .36313 .3502 .37134 .34401 .36601 .34587 Mtetra
.541 .924 .808 r
.36601 .34587 .37134 .34401 .37956 .33788 .37426 .33998 Mtetra
.517 .91 .785 r
.37426 .33998 .37956 .33788 .38779 .33186 .38253 .33409 Mtetra
.504 .901 .771 r
.38253 .33409 .38779 .33186 .39603 .32591 .3908 .32818 Mtetra
.25 .747 .674 r
.3908 .32818 .39603 .32591 .40422 .32224 .39902 .32449 Mtetra
.02 0 0 r
.39902 .32449 .40422 .32224 .41236 .32085 .4072 .32303 Mtetra
.014 0 0 r
.4072 .32303 .41236 .32085 .42054 .31954 .41541 .32156 Mtetra
.002 0 0 r
.41541 .32156 .42054 .31954 .42874 .31834 .42366 .3201 Mtetra
0 0 0 r
.42366 .3201 .42874 .31834 .43699 .31721 .43194 .31863 Mtetra
.43194 .31863 .43699 .31721 .44527 .31607 .44026 .31711 Mtetra
.44026 .31711 .44527 .31607 .45358 .31483 .44861 .31546 Mtetra
.17 .707 .752 r
.44861 .31546 .45358 .31483 .46194 .31341 .45701 .31361 Mtetra
.242 .758 .812 r
.45701 .31361 .46194 .31341 .47034 .31172 .46544 .31151 Mtetra
.318 .806 .866 r
.46544 .31151 .47034 .31172 .47877 .3097 .47391 .30908 Mtetra
.394 .846 .91 r
.47391 .30908 .47877 .3097 .48725 .30732 .48242 .3063 Mtetra
.464 .877 .942 r
.48242 .3063 .48725 .30732 .49576 .30453 .49096 .30313 Mtetra
.526 .898 .963 r
.49096 .30313 .49576 .30453 .5043 .30133 .49954 .29956 Mtetra
.578 .911 .974 r
.49954 .29956 .5043 .30133 .51287 .29769 .50814 .29557 Mtetra
.623 .918 .978 r
.50814 .29557 .51287 .29769 .52147 .29362 .51677 .29117 Mtetra
.659 .92 .976 r
.51677 .29117 .52147 .29362 .5301 .28913 .52543 .28637 Mtetra
.689 .918 .971 r
.52543 .28637 .5301 .28913 .53875 .28422 .53411 .28116 Mtetra
.713 .914 .964 r
.53411 .28116 .53875 .28422 .54742 .27891 .5428 .27557 Mtetra
.733 .908 .955 r
.5428 .27557 .54742 .27891 .55611 .27322 .55152 .2696 Mtetra
.75 .902 .945 r
.55152 .2696 .55611 .27322 .56481 .26715 .56025 .26327 Mtetra
.763 .896 .936 r
.56025 .26327 .56481 .26715 .57353 .26073 .56899 .25659 Mtetra
.774 .889 .927 r
.56899 .25659 .57353 .26073 .58225 .25398 .57774 .2496 Mtetra
.784 .882 .918 r
.57774 .2496 .58225 .25398 .59099 .24691 .5865 .24229 Mtetra
.791 .876 .909 r
.5865 .24229 .59099 .24691 .59973 .23954 .59527 .2347 Mtetra
.798 .87 .901 r
.59527 .2347 .59973 .23954 .60847 .23189 .60404 .22684 Mtetra
.803 .864 .894 r
.60404 .22684 .60847 .23189 .61723 .22399 .61282 .21873 Mtetra
.807 .858 .887 r
.61282 .21873 .61723 .22399 .62598 .21585 .62159 .21038 Mtetra
.811 .852 .88 r
.62159 .21038 .62598 .21585 .63474 .20748 .63037 .20182 Mtetra
.814 .847 .874 r
.63037 .20182 .63474 .20748 .64349 .19891 .63915 .19305 Mtetra
.816 .842 .869 r
.63915 .19305 .64349 .19891 .65225 .19016 .64793 .18411 Mtetra
.818 .837 .863 r
.64793 .18411 .65225 .19016 .66101 .18124 .65671 .17501 Mtetra
.819 .832 .859 r
.65671 .17501 .66101 .18124 .66976 .17217 .66549 .16576 Mtetra
.82 .827 .854 r
.66549 .16576 .66976 .17217 .67851 .16297 .67426 .15638 Mtetra
.821 .823 .85 r
.67426 .15638 .67851 .16297 .68726 .15365 .68303 .14689 Mtetra
.821 .818 .847 r
.68303 .14689 .68726 .15365 .69601 .14423 .6918 .1373 Mtetra
.821 .814 .843 r
.6918 .1373 .69601 .14423 .70476 .13473 .70057 .12763 Mtetra
.821 .81 .84 r
.70057 .12763 .70476 .13473 .7135 .12517 .70934 .1179 Mtetra
.82 .806 .838 r
.70934 .1179 .7135 .12517 .72225 .11555 .7181 .10812 Mtetra
.819 .801 .835 r
.7181 .10812 .72225 .11555 .73099 .1059 .72686 .09831 Mtetra
.817 .797 .833 r
.72686 .09831 .73099 .1059 .73974 .09624 .73562 .08848 Mtetra
.201 .538 .926 r
.09217 .37794 .09751 .3841 .10411 .38619 .09875 .38015 Mtetra
.195 .539 .927 r
.09875 .38015 .10411 .38619 .11074 .38827 .10538 .38235 Mtetra
.19 .542 .928 r
.10538 .38235 .11074 .38827 .11742 .39033 .11204 .38454 Mtetra
.186 .546 .929 r
.11204 .38454 .11742 .39033 .12414 .39236 .11875 .38669 Mtetra
.185 .551 .931 r
.11875 .38669 .12414 .39236 .1309 .39433 .1255 .3888 Mtetra
.186 .557 .933 r
.1255 .3888 .1309 .39433 .13771 .39625 .1323 .39084 Mtetra
.188 .564 .936 r
.1323 .39084 .13771 .39625 .14456 .39808 .13914 .3928 Mtetra
.192 .573 .939 r
.13914 .3928 .14456 .39808 .15147 .39981 .14604 .39467 Mtetra
.198 .582 .942 r
.14604 .39467 .15147 .39981 .15842 .40144 .15298 .39644 Mtetra
.206 .593 .946 r
.15298 .39644 .15842 .40144 .16543 .40293 .15998 .39807 Mtetra
.216 .605 .95 r
.15998 .39807 .16543 .40293 .17248 .40428 .16703 .39957 Mtetra
.227 .618 .954 r
.16703 .39957 .17248 .40428 .17959 .40546 .17413 .4009 Mtetra
.24 .632 .959 r
.17413 .4009 .17959 .40546 .18676 .40647 .18129 .40207 Mtetra
.255 .648 .964 r
.18129 .40207 .18676 .40647 .19398 .40727 .1885 .40303 Mtetra
.271 .664 .969 r
.1885 .40303 .19398 .40727 .20125 .40786 .19577 .40379 Mtetra
.289 .681 .973 r
.19577 .40379 .20125 .40786 .20858 .40821 .2031 .40433 Mtetra
.308 .699 .978 r
.2031 .40433 .20858 .40821 .21597 .40831 .21048 .40461 Mtetra
.329 .718 .982 r
.21048 .40461 .21597 .40831 .22341 .40814 .21792 .40463 Mtetra
.351 .737 .986 r
.21792 .40463 .22341 .40814 .23091 .40768 .22542 .40438 Mtetra
.373 .757 .989 r
.22542 .40438 .23091 .40768 .23846 .40691 .23297 .40382 Mtetra
.396 .776 .991 r
.23297 .40382 .23846 .40691 .24608 .40581 .24058 .40294 Mtetra
.42 .796 .993 r
.24058 .40294 .24608 .40581 .25374 .40436 .24825 .40173 Mtetra
.444 .816 .993 r
.24825 .40173 .25374 .40436 .26147 .40255 .25597 .40018 Mtetra
.468 .835 .992 r
.25597 .40018 .26147 .40255 .26925 .40037 .26375 .39826 Mtetra
.491 .854 .989 r
.26375 .39826 .26925 .40037 .27708 .3978 .27159 .39596 Mtetra
.513 .872 .985 r
.27159 .39596 .27708 .3978 .28496 .39483 .27947 .39328 Mtetra
.533 .888 .98 r
.27947 .39328 .28496 .39483 .29289 .39145 .28741 .39022 Mtetra
.551 .903 .972 r
.28741 .39022 .29289 .39145 .30087 .38767 .29539 .38676 Mtetra
.566 .917 .962 r
.29539 .38676 .30087 .38767 .3089 .38349 .30342 .38292 Mtetra
.578 .928 .95 r
.30342 .38292 .3089 .38349 .31696 .37893 .3115 .37872 Mtetra
.585 .936 .936 r
.3115 .37872 .31696 .37893 .32507 .37401 .31961 .37417 Mtetra
.587 .942 .919 r
.31961 .37417 .32507 .37401 .3332 .36878 .32776 .36931 Mtetra
.583 .943 .899 r
.32776 .36931 .3332 .36878 .34137 .36328 .33594 .36419 Mtetra
.573 .941 .877 r
.33594 .36419 .34137 .36328 .34957 .35759 .34415 .35885 Mtetra
.558 .934 .853 r
.34415 .35885 .34957 .35759 .35778 .35176 .35238 .35336 Mtetra
.538 .924 .827 r
.35238 .35336 .35778 .35176 .36601 .34587 .36064 .34776 Mtetra
.517 .912 .802 r
.36064 .34776 .36601 .34587 .37426 .33998 .36891 .34209 Mtetra
.501 .902 .782 r
.36891 .34209 .37426 .33998 .38253 .33409 .37721 .33634 Mtetra
.495 .897 .768 r
.37721 .33634 .38253 .33409 .3908 .32818 .38552 .33049 Mtetra
.247 .745 .671 r
.38552 .33049 .3908 .32818 .39902 .32449 .39378 .32679 Mtetra
.012 0 0 r
.39378 .32679 .39902 .32449 .4072 .32303 .40199 .32524 Mtetra
0 0 0 r
.40199 .32524 .4072 .32303 .41541 .32156 .41024 .32359 Mtetra
.41024 .32359 .41541 .32156 .42366 .3201 .41852 .32187 Mtetra
.41852 .32187 .42366 .3201 .43194 .31863 .42684 .32008 Mtetra
.42684 .32008 .43194 .31863 .44026 .31711 .4352 .31819 Mtetra
.152 .691 .712 r
.4352 .31819 .44026 .31711 .44861 .31546 .4436 .31615 Mtetra
.215 .738 .769 r
.4436 .31615 .44861 .31546 .45701 .31361 .45203 .31389 Mtetra
.284 .786 .824 r
.45203 .31389 .45701 .31361 .46544 .31151 .4605 .31137 Mtetra
.357 .829 .873 r
.4605 .31137 .46544 .31151 .47391 .30908 .46901 .30854 Mtetra
.427 .865 .913 r
.46901 .30854 .47391 .30908 .48242 .3063 .47755 .30536 Mtetra
.492 .892 .942 r
.47755 .30536 .48242 .3063 .49096 .30313 .48612 .30181 Mtetra
.55 .911 .961 r
.48612 .30181 .49096 .30313 .49954 .29956 .49473 .29787 Mtetra
.599 .922 .971 r
.49473 .29787 .49954 .29956 .50814 .29557 .50337 .29354 Mtetra
.64 .926 .974 r
.50337 .29354 .50814 .29557 .51677 .29117 .51203 .28881 Mtetra
.674 .927 .972 r
.51203 .28881 .51677 .29117 .52543 .28637 .52072 .28368 Mtetra
.702 .924 .966 r
.52072 .28368 .52543 .28637 .53411 .28116 .52942 .27817 Mtetra
.725 .919 .959 r
.52942 .27817 .53411 .28116 .5428 .27557 .53815 .27228 Mtetra
.743 .913 .951 r
.53815 .27228 .5428 .27557 .55152 .2696 .54689 .26603 Mtetra
.758 .907 .942 r
.54689 .26603 .55152 .2696 .56025 .26327 .55565 .25943 Mtetra
.771 .9 .932 r
.55565 .25943 .56025 .26327 .56899 .25659 .56442 .25251 Mtetra
.781 .893 .923 r
.56442 .25251 .56899 .25659 .57774 .2496 .5732 .24526 Mtetra
.79 .886 .915 r
.5732 .24526 .57774 .2496 .5865 .24229 .58198 .23772 Mtetra
.797 .879 .906 r
.58198 .23772 .5865 .24229 .59527 .2347 .59078 .2299 Mtetra
.803 .873 .898 r
.59078 .2299 .59527 .2347 .60404 .22684 .59958 .22181 Mtetra
.808 .866 .891 r
.59958 .22181 .60404 .22684 .61282 .21873 .60838 .21348 Mtetra
.812 .86 .884 r
.60838 .21348 .61282 .21873 .62159 .21038 .61718 .20492 Mtetra
.815 .854 .878 r
.61718 .20492 .62159 .21038 .63037 .20182 .62598 .19616 Mtetra
.818 .849 .872 r
.62598 .19616 .63037 .20182 .63915 .19305 .63479 .1872 Mtetra
.82 .844 .866 r
.63479 .1872 .63915 .19305 .64793 .18411 .64359 .17806 Mtetra
.822 .839 .861 r
.64359 .17806 .64793 .18411 .65671 .17501 .65239 .16877 Mtetra
.823 .834 .857 r
.65239 .16877 .65671 .17501 .66549 .16576 .66119 .15934 Mtetra
.824 .829 .852 r
.66119 .15934 .66549 .16576 .67426 .15638 .66999 .14978 Mtetra
.824 .824 .848 r
.66999 .14978 .67426 .15638 .68303 .14689 .67878 .14011 Mtetra
.824 .82 .845 r
.67878 .14011 .68303 .14689 .6918 .1373 .68757 .13034 Mtetra
.824 .815 .841 r
.68757 .13034 .6918 .1373 .70057 .12763 .69636 .1205 Mtetra
.824 .811 .838 r
.69636 .1205 .70057 .12763 .70934 .1179 .70514 .1106 Mtetra
.823 .807 .836 r
.70514 .1106 .70934 .1179 .7181 .10812 .71393 .10065 Mtetra
.822 .802 .833 r
.71393 .10065 .7181 .10812 .72686 .09831 .72271 .09067 Mtetra
.82 .798 .831 r
.72271 .09067 .72686 .09831 .73562 .08848 .73149 .08067 Mtetra
.183 .527 .921 r
.0868 .37175 .09217 .37794 .09875 .38015 .09337 .37409 Mtetra
.175 .528 .921 r
.09337 .37409 .09875 .38015 .10538 .38235 .09998 .37642 Mtetra
.17 .531 .922 r
.09998 .37642 .10538 .38235 .11204 .38454 .10663 .37873 Mtetra
.166 .534 .923 r
.10663 .37873 .11204 .38454 .11875 .38669 .11333 .38101 Mtetra
.164 .539 .925 r
.11333 .38101 .11875 .38669 .1255 .3888 .12007 .38325 Mtetra
.164 .545 .927 r
.12007 .38325 .1255 .3888 .1323 .39084 .12685 .38542 Mtetra
.166 .552 .929 r
.12685 .38542 .1323 .39084 .13914 .3928 .13369 .38752 Mtetra
.169 .56 .932 r
.13369 .38752 .13914 .3928 .14604 .39467 .14057 .38953 Mtetra
.175 .57 .935 r
.14057 .38953 .14604 .39467 .15298 .39644 .14751 .39144 Mtetra
.182 .58 .939 r
.14751 .39144 .15298 .39644 .15998 .39807 .1545 .39322 Mtetra
.191 .592 .943 r
.1545 .39322 .15998 .39807 .16703 .39957 .16154 .39487 Mtetra
.201 .605 .947 r
.16154 .39487 .16703 .39957 .17413 .4009 .16863 .39636 Mtetra
.213 .619 .952 r
.16863 .39636 .17413 .4009 .18129 .40207 .17578 .39769 Mtetra
.227 .634 .957 r
.17578 .39769 .18129 .40207 .1885 .40303 .18299 .39883 Mtetra
.243 .65 .961 r
.18299 .39883 .1885 .40303 .19577 .40379 .19025 .39976 Mtetra
.26 .667 .966 r
.19025 .39976 .19577 .40379 .2031 .40433 .19757 .40048 Mtetra
.278 .685 .971 r
.19757 .40048 .2031 .40433 .21048 .40461 .20495 .40095 Mtetra
.298 .704 .975 r
.20495 .40095 .21048 .40461 .21792 .40463 .21239 .40117 Mtetra
.319 .723 .979 r
.21239 .40117 .21792 .40463 .22542 .40438 .21988 .40112 Mtetra
.34 .742 .982 r
.21988 .40112 .22542 .40438 .23297 .40382 .22743 .40079 Mtetra
.363 .762 .985 r
.22743 .40079 .23297 .40382 .24058 .40294 .23504 .40014 Mtetra
.386 .782 .987 r
.23504 .40014 .24058 .40294 .24825 .40173 .24271 .39917 Mtetra
.409 .802 .987 r
.24271 .39917 .24825 .40173 .25597 .40018 .25043 .39787 Mtetra
.432 .822 .986 r
.25043 .39787 .25597 .40018 .26375 .39826 .25821 .39622 Mtetra
.454 .84 .984 r
.25821 .39622 .26375 .39826 .27159 .39596 .26604 .3942 Mtetra
.475 .858 .98 r
.26604 .3942 .27159 .39596 .27947 .39328 .27393 .39182 Mtetra
.494 .875 .974 r
.27393 .39182 .27947 .39328 .28741 .39022 .28187 .38906 Mtetra
.512 .89 .966 r
.28187 .38906 .28741 .39022 .29539 .38676 .28986 .38593 Mtetra
.526 .903 .956 r
.28986 .38593 .29539 .38676 .30342 .38292 .29789 .38243 Mtetra
.537 .914 .943 r
.29789 .38243 .30342 .38292 .3115 .37872 .30598 .37858 Mtetra
.544 .921 .928 r
.30598 .37858 .3115 .37872 .31961 .37417 .3141 .3744 Mtetra
.546 .926 .911 r
.3141 .3744 .31961 .37417 .32776 .36931 .32226 .3699 Mtetra
.543 .927 .89 r
.32226 .3699 .32776 .36931 .33594 .36419 .33045 .36515 Mtetra
.534 .924 .868 r
.33045 .36515 .33594 .36419 .34415 .35885 .33868 .36016 Mtetra
.521 .918 .843 r
.33868 .36016 .34415 .35885 .35238 .35336 .34693 .35499 Mtetra
.506 .909 .818 r
.34693 .35499 .35238 .35336 .36064 .34776 .35521 .34968 Mtetra
.491 .899 .794 r
.35521 .34968 .36064 .34776 .36891 .34209 .36351 .34423 Mtetra
.481 .891 .775 r
.36351 .34423 .36891 .34209 .37721 .33634 .37183 .33865 Mtetra
.482 .89 .763 r
.37183 .33865 .37721 .33634 .38552 .33049 .38018 .33288 Mtetra
.242 .741 .665 r
.38018 .33288 .38552 .33049 .39378 .32679 .38847 .32916 Mtetra
.003 0 0 r
.38847 .32916 .39378 .32679 .40199 .32524 .39672 .3275 Mtetra
0 0 0 r
.39672 .3275 .40199 .32524 .41024 .32359 .405 .32565 Mtetra
.405 .32565 .41024 .32359 .41852 .32187 .41333 .32367 Mtetra
.41333 .32367 .41852 .32187 .42684 .32008 .42169 .32157 Mtetra
.42169 .32157 .42684 .32008 .4352 .31819 .43009 .31932 Mtetra
.194 .721 .729 r
.43009 .31932 .4352 .31819 .4436 .31615 .43853 .31689 Mtetra
.257 .767 .783 r
.43853 .31689 .4436 .31615 .45203 .31389 .447 .31423 Mtetra
.324 .811 .834 r
.447 .31423 .45203 .31389 .4605 .31137 .45551 .31131 Mtetra
.393 .85 .879 r
.45551 .31131 .4605 .31137 .46901 .30854 .46405 .30807 Mtetra
.459 .883 .915 r
.46405 .30807 .46901 .30854 .47755 .30536 .47263 .3045 Mtetra
.52 .906 .941 r
.47263 .3045 .47755 .30536 .48612 .30181 .48124 .30057 Mtetra
.573 .922 .958 r
.48124 .30057 .48612 .30181 .49473 .29787 .48988 .29627 Mtetra
.619 .931 .966 r
.48988 .29627 .49473 .29787 .50337 .29354 .49855 .29158 Mtetra
.657 .934 .969 r
.49855 .29158 .50337 .29354 .51203 .28881 .50725 .28651 Mtetra
.688 .933 .967 r
.50725 .28651 .51203 .28881 .52072 .28368 .51597 .28107 Mtetra
.714 .93 .961 r
.51597 .28107 .52072 .28368 .52942 .27817 .5247 .27524 Mtetra
.736 .924 .954 r
.5247 .27524 .52942 .27817 .53815 .27228 .53346 .26906 Mtetra
.753 .918 .946 r
.53346 .26906 .53815 .27228 .54689 .26603 .54223 .26252 Mtetra
.767 .911 .937 r
.54223 .26252 .54689 .26603 .55565 .25943 .55102 .25565 Mtetra
.779 .904 .928 r
.55102 .25565 .55565 .25943 .56442 .25251 .55982 .24846 Mtetra
.788 .896 .92 r
.55982 .24846 .56442 .25251 .5732 .24526 .56862 .24096 Mtetra
.796 .889 .911 r
.56862 .24096 .5732 .24526 .58198 .23772 .57744 .23318 Mtetra
.803 .882 .903 r
.57744 .23318 .58198 .23772 .59078 .2299 .58626 .22512 Mtetra
.809 .875 .895 r
.58626 .22512 .59078 .2299 .59958 .22181 .59508 .21681 Mtetra
.813 .869 .888 r
.59508 .21681 .59958 .22181 .60838 .21348 .60391 .20826 Mtetra
.817 .863 .882 r
.60391 .20826 .60838 .21348 .61718 .20492 .61273 .19948 Mtetra
.82 .857 .875 r
.61273 .19948 .61718 .20492 .62598 .19616 .62156 .19051 Mtetra
.822 .851 .869 r
.62156 .19051 .62598 .19616 .63479 .1872 .63039 .18135 Mtetra
.824 .845 .864 r
.63039 .18135 .63479 .1872 .64359 .17806 .63922 .17202 Mtetra
.825 .84 .859 r
.63922 .17202 .64359 .17806 .65239 .16877 .64804 .16253 Mtetra
.826 .835 .854 r
.64804 .16253 .65239 .16877 .66119 .15934 .65686 .15291 Mtetra
.827 .83 .85 r
.65686 .15291 .66119 .15934 .66999 .14978 .66568 .14316 Mtetra
.827 .826 .846 r
.66568 .14316 .66999 .14978 .67878 .14011 .6745 .13331 Mtetra
.827 .821 .843 r
.6745 .13331 .67878 .14011 .68757 .13034 .68331 .12336 Mtetra
.827 .816 .839 r
.68331 .12336 .68757 .13034 .69636 .1205 .69212 .11335 Mtetra
.826 .812 .836 r
.69212 .11335 .69636 .1205 .70514 .1106 .70093 .10327 Mtetra
.826 .807 .834 r
.70093 .10327 .70514 .1106 .71393 .10065 .70973 .09314 Mtetra
.824 .803 .831 r
.70973 .09314 .71393 .10065 .72271 .09067 .71853 .08299 Mtetra
.823 .799 .829 r
.71853 .08299 .72271 .09067 .73149 .08067 .72733 .07282 Mtetra
.163 .515 .915 r
.0814 .36553 .0868 .37175 .09337 .37409 .08796 .36799 Mtetra
.155 .516 .916 r
.08796 .36799 .09337 .37409 .09998 .37642 .09455 .37045 Mtetra
.149 .519 .916 r
.09455 .37045 .09998 .37642 .10663 .37873 .10119 .3729 Mtetra
.145 .522 .917 r
.10119 .3729 .10663 .37873 .11333 .38101 .10787 .37531 Mtetra
.142 .526 .918 r
.10787 .37531 .11333 .38101 .12007 .38325 .1146 .37768 Mtetra
.142 .532 .92 r
.1146 .37768 .12007 .38325 .12685 .38542 .12137 .38 Mtetra
.143 .539 .922 r
.12137 .38 .12685 .38542 .13369 .38752 .1282 .38224 Mtetra
.146 .547 .925 r
.1282 .38224 .13369 .38752 .14057 .38953 .13507 .38439 Mtetra
.15 .556 .928 r
.13507 .38439 .14057 .38953 .14751 .39144 .142 .38644 Mtetra
.156 .566 .931 r
.142 .38644 .14751 .39144 .1545 .39322 .14898 .38838 Mtetra
.165 .578 .935 r
.14898 .38838 .1545 .39322 .16154 .39487 .15601 .39018 Mtetra
.174 .59 .939 r
.15601 .39018 .16154 .39487 .16863 .39636 .1631 .39184 Mtetra
.186 .604 .943 r
.1631 .39184 .16863 .39636 .17578 .39769 .17024 .39333 Mtetra
.199 .619 .948 r
.17024 .39333 .17578 .39769 .18299 .39883 .17744 .39464 Mtetra
.213 .635 .953 r
.17744 .39464 .18299 .39883 .19025 .39976 .18469 .39576 Mtetra
.229 .651 .957 r
.18469 .39576 .19025 .39976 .19757 .40048 .19201 .39666 Mtetra
.247 .669 .962 r
.19201 .39666 .19757 .40048 .20495 .40095 .19938 .39733 Mtetra
.265 .688 .966 r
.19938 .39733 .20495 .40095 .21239 .40117 .20681 .39776 Mtetra
.285 .707 .97 r
.20681 .39776 .21239 .40117 .21988 .40112 .2143 .39792 Mtetra
.306 .726 .974 r
.2143 .39792 .21988 .40112 .22743 .40079 .22184 .39781 Mtetra
.327 .746 .976 r
.22184 .39781 .22743 .40079 .23504 .40014 .22945 .3974 Mtetra
.349 .766 .978 r
.22945 .3974 .23504 .40014 .24271 .39917 .23711 .39668 Mtetra
.371 .786 .979 r
.23711 .39668 .24271 .39917 .25043 .39787 .24484 .39563 Mtetra
.393 .805 .978 r
.24484 .39563 .25043 .39787 .25821 .39622 .25261 .39425 Mtetra
.414 .824 .976 r
.25261 .39425 .25821 .39622 .26604 .3942 .26045 .39252 Mtetra
.435 .842 .972 r
.26045 .39252 .26604 .3942 .27393 .39182 .26834 .39044 Mtetra
.453 .858 .966 r
.26834 .39044 .27393 .39182 .28187 .38906 .27628 .38799 Mtetra
.47 .873 .957 r
.27628 .38799 .28187 .38906 .28986 .38593 .28427 .38519 Mtetra
.483 .886 .947 r
.28427 .38519 .28986 .38593 .29789 .38243 .29231 .38203 Mtetra
.494 .896 .934 r
.29231 .38203 .29789 .38243 .30598 .37858 .3004 .37853 Mtetra
.5 .903 .918 r
.3004 .37853 .30598 .37858 .3141 .3744 .30853 .3747 Mtetra
.502 .907 .9 r
.30853 .3747 .3141 .3744 .32226 .3699 .3167 .37057 Mtetra
.5 .908 .879 r
.3167 .37057 .32226 .3699 .33045 .36515 .32491 .36617 Mtetra
.493 .905 .856 r
.32491 .36617 .33045 .36515 .33868 .36016 .33315 .36153 Mtetra
.483 .899 .831 r
.33315 .36153 .33868 .36016 .34693 .35499 .34142 .35668 Mtetra
.471 .891 .807 r
.34142 .35668 .34693 .35499 .35521 .34968 .34972 .35164 Mtetra
.462 .883 .784 r
.34972 .35164 .35521 .34968 .36351 .34423 .35804 .34643 Mtetra
.458 .879 .766 r
.35804 .34643 .36351 .34423 .37183 .33865 .3664 .34102 Mtetra
.464 .88 .755 r
.3664 .34102 .37183 .33865 .38018 .33288 .37478 .33536 Mtetra
0 0 0 r
.37478 .33536 .38018 .33288 .38847 .32916 .38311 .33163 Mtetra
.38311 .33163 .38847 .32916 .39672 .3275 .39139 .32982 Mtetra
.39139 .32982 .39672 .3275 .405 .32565 .39972 .32777 Mtetra
.39972 .32777 .405 .32565 .41333 .32367 .40808 .32553 Mtetra
.40808 .32553 .41333 .32367 .42169 .32157 .41649 .32311 Mtetra
.178 .706 .694 r
.41649 .32311 .42169 .32157 .43009 .31932 .42493 .3205 Mtetra
.235 .749 .744 r
.42493 .3205 .43009 .31932 .43853 .31689 .43341 .31769 Mtetra
.297 .793 .794 r
.43341 .31769 .43853 .31689 .447 .31423 .44192 .31464 Mtetra
.362 .834 .842 r
.44192 .31464 .447 .31423 .45551 .31131 .45047 .31132 Mtetra
.428 .87 .883 r
.45047 .31132 .45551 .31131 .46405 .30807 .45905 .30769 Mtetra
.49 .898 .916 r
.45905 .30769 .46405 .30807 .47263 .3045 .46767 .30373 Mtetra
.546 .919 .939 r
.46767 .30373 .47263 .3045 .48124 .30057 .47632 .29942 Mtetra
.596 .932 .954 r
.47632 .29942 .48124 .30057 .48988 .29627 .48499 .29475 Mtetra
.638 .939 .962 r
.48499 .29475 .48988 .29627 .49855 .29158 .4937 .28971 Mtetra
.673 .941 .964 r
.4937 .28971 .49855 .29158 .50725 .28651 .50243 .2843 Mtetra
.703 .939 .961 r
.50243 .2843 .50725 .28651 .51597 .28107 .51118 .27852 Mtetra
.727 .935 .956 r
.51118 .27852 .51597 .28107 .5247 .27524 .51995 .27238 Mtetra
.746 .929 .949 r
.51995 .27238 .5247 .27524 .53346 .26906 .52873 .2659 Mtetra
.762 .922 .941 r
.52873 .2659 .53346 .26906 .54223 .26252 .53754 .25907 Mtetra
.776 .915 .933 r
.53754 .25907 .54223 .26252 .55102 .25565 .54635 .25192 Mtetra
.786 .907 .924 r
.54635 .25192 .55102 .25565 .55982 .24846 .55518 .24446 Mtetra
.795 .899 .916 r
.55518 .24446 .55982 .24846 .56862 .24096 .56401 .2367 Mtetra
.803 .892 .908 r
.56401 .2367 .56862 .24096 .57744 .23318 .57285 .22867 Mtetra
.809 .885 .9 r
.57285 .22867 .57744 .23318 .58626 .22512 .5817 .22037 Mtetra
.814 .878 .892 r
.5817 .22037 .58626 .22512 .59508 .21681 .59055 .21182 Mtetra
.818 .871 .885 r
.59055 .21182 .59508 .21681 .60391 .20826 .59941 .20305 Mtetra
.821 .865 .879 r
.59941 .20305 .60391 .20826 .61273 .19948 .60826 .19405 Mtetra
.824 .859 .873 r
.60826 .19405 .61273 .19948 .62156 .19051 .61711 .18487 Mtetra
.826 .853 .867 r
.61711 .18487 .62156 .19051 .63039 .18135 .62597 .1755 Mtetra
.828 .847 .862 r
.62597 .1755 .63039 .18135 .63922 .17202 .63482 .16596 Mtetra
.829 .842 .857 r
.63482 .16596 .63922 .17202 .64804 .16253 .64367 .15628 Mtetra
.83 .837 .852 r
.64367 .15628 .64804 .16253 .65686 .15291 .65251 .14646 Mtetra
.831 .832 .848 r
.65251 .14646 .65686 .15291 .66568 .14316 .66135 .13652 Mtetra
.831 .827 .844 r
.66135 .13652 .66568 .14316 .6745 .13331 .67019 .12649 Mtetra
.831 .822 .841 r
.67019 .12649 .6745 .13331 .68331 .12336 .67903 .11636 Mtetra
.83 .817 .837 r
.67903 .11636 .68331 .12336 .69212 .11335 .68786 .10616 Mtetra
.829 .813 .834 r
.68786 .10616 .69212 .11335 .70093 .10327 .69668 .0959 Mtetra
.828 .808 .832 r
.69668 .0959 .70093 .10327 .70973 .09314 .7055 .0856 Mtetra
.827 .804 .829 r
.7055 .0856 .70973 .09314 .71853 .08299 .71432 .07526 Mtetra
.826 .799 .827 r
.71432 .07526 .71853 .08299 .72733 .07282 .72314 .06492 Mtetra
.142 .503 .909 r
.07597 .35928 .0814 .36553 .08796 .36799 .08251 .36187 Mtetra
.134 .504 .909 r
.08251 .36187 .08796 .36799 .09455 .37045 .08909 .36446 Mtetra
.128 .506 .909 r
.08909 .36446 .09455 .37045 .10119 .3729 .09572 .36704 Mtetra
.123 .509 .91 r
.09572 .36704 .10119 .3729 .10787 .37531 .10239 .36959 Mtetra
.12 .513 .911 r
.10239 .36959 .10787 .37531 .1146 .37768 .1091 .3721 Mtetra
.118 .518 .912 r
.1091 .3721 .1146 .37768 .12137 .38 .11586 .37456 Mtetra
.119 .525 .914 r
.11586 .37456 .12137 .38 .1282 .38224 .12267 .37694 Mtetra
.121 .532 .916 r
.12267 .37694 .1282 .38224 .13507 .38439 .12954 .37925 Mtetra
.125 .541 .919 r
.12954 .37925 .13507 .38439 .142 .38644 .13645 .38145 Mtetra
.13 .551 .922 r
.13645 .38145 .142 .38644 .14898 .38838 .14342 .38354 Mtetra
.137 .562 .925 r
.14342 .38354 .14898 .38838 .15601 .39018 .15044 .38551 Mtetra
.146 .575 .929 r
.15044 .38551 .15601 .39018 .1631 .39184 .15752 .38733 Mtetra
.157 .588 .934 r
.15752 .38733 .1631 .39184 .17024 .39333 .16465 .38899 Mtetra
.169 .602 .938 r
.16465 .38899 .17024 .39333 .17744 .39464 .17184 .39048 Mtetra
.182 .618 .943 r
.17184 .39048 .17744 .39464 .18469 .39576 .17909 .39178 Mtetra
.197 .634 .947 r
.17909 .39178 .18469 .39576 .19201 .39666 .1864 .39288 Mtetra
.213 .652 .952 r
.1864 .39288 .19201 .39666 .19938 .39733 .19376 .39375 Mtetra
.231 .67 .956 r
.19376 .39375 .19938 .39733 .20681 .39776 .20118 .39439 Mtetra
.25 .689 .96 r
.20118 .39439 .20681 .39776 .2143 .39792 .20867 .39477 Mtetra
.269 .708 .963 r
.20867 .39477 .2143 .39792 .22184 .39781 .21621 .39488 Mtetra
.29 .728 .966 r
.21621 .39488 .22184 .39781 .22945 .3974 .22381 .39471 Mtetra
.31 .747 .967 r
.22381 .39471 .22945 .3974 .23711 .39668 .23147 .39424 Mtetra
.331 .767 .968 r
.23147 .39424 .23711 .39668 .24484 .39563 .23919 .39346 Mtetra
.352 .786 .967 r
.23919 .39346 .24484 .39563 .25261 .39425 .24697 .39235 Mtetra
.372 .805 .965 r
.24697 .39235 .25261 .39425 .26045 .39252 .2548 .39091 Mtetra
.391 .822 .96 r
.2548 .39091 .26045 .39252 .26834 .39044 .26269 .38913 Mtetra
.409 .838 .954 r
.26269 .38913 .26834 .39044 .27628 .38799 .27064 .387 Mtetra
.425 .853 .945 r
.27064 .387 .27628 .38799 .28427 .38519 .27863 .38453 Mtetra
.438 .865 .934 r
.27863 .38453 .28427 .38519 .29231 .38203 .28668 .38171 Mtetra
.448 .875 .921 r
.28668 .38171 .29231 .38203 .3004 .37853 .29477 .37855 Mtetra
.454 .882 .905 r
.29477 .37855 .3004 .37853 .30853 .3747 .30291 .37508 Mtetra
.456 .885 .886 r
.30291 .37508 .30853 .3747 .3167 .37057 .31109 .37131 Mtetra
.455 .885 .864 r
.31109 .37131 .3167 .37057 .32491 .36617 .31931 .36726 Mtetra
.45 .883 .841 r
.31931 .36726 .32491 .36617 .33315 .36153 .32756 .36296 Mtetra
.442 .877 .817 r
.32756 .36296 .33315 .36153 .34142 .35668 .33585 .35842 Mtetra
.435 .871 .793 r
.33585 .35842 .34142 .35668 .34972 .35164 .34417 .35367 Mtetra
.43 .865 .772 r
.34417 .35367 .34972 .35164 .35804 .34643 .35252 .34869 Mtetra
.431 .863 .755 r
.35252 .34869 .35804 .34643 .3664 .34102 .3609 .34347 Mtetra
.442 .867 .744 r
.3609 .34347 .3664 .34102 .37478 .33536 .36932 .33795 Mtetra
0 0 0 r
.36932 .33795 .37478 .33536 .38311 .33163 .37768 .3342 Mtetra
.37768 .3342 .38311 .33163 .39139 .32982 .386 .33223 Mtetra
.386 .33223 .39139 .32982 .39972 .32777 .39437 .32996 Mtetra
.39437 .32996 .39972 .32777 .40808 .32553 .40278 .32744 Mtetra
.40278 .32744 .40808 .32553 .41649 .32311 .41123 .3247 Mtetra
.215 .731 .708 r
.41123 .3247 .41649 .32311 .42493 .3205 .41971 .32175 Mtetra
.273 .774 .756 r
.41971 .32175 .42493 .3205 .43341 .31769 .42823 .31856 Mtetra
.334 .816 .804 r
.42823 .31856 .43341 .31769 .44192 .31464 .43679 .31512 Mtetra
.398 .855 .848 r
.43679 .31512 .44192 .31464 .45047 .31132 .44538 .3114 Mtetra
.46 .887 .886 r
.44538 .3114 .45047 .31132 .45905 .30769 .454 .30738 Mtetra
.518 .913 .915 r
.454 .30738 .45905 .30769 .46767 .30373 .46266 .30303 Mtetra
.571 .931 .937 r
.46266 .30303 .46767 .30373 .47632 .29942 .47134 .29834 Mtetra
.617 .942 .95 r
.47134 .29834 .47632 .29942 .48499 .29475 .48006 .2933 Mtetra
.656 .947 .957 r
.48006 .2933 .48499 .29475 .4937 .28971 .4888 .2879 Mtetra
.689 .947 .958 r
.4888 .2879 .4937 .28971 .50243 .2843 .49756 .28215 Mtetra
.716 .945 .956 r
.49756 .28215 .50243 .2843 .51118 .27852 .50634 .27604 Mtetra
.738 .94 .951 r
.50634 .27604 .51118 .27852 .51995 .27238 .51515 .26958 Mtetra
.757 .933 .944 r
.51515 .26958 .51995 .27238 .52873 .2659 .52397 .26279 Mtetra
.772 .926 .937 r
.52397 .26279 .52873 .2659 .53754 .25907 .5328 .25567 Mtetra
.784 .918 .928 r
.5328 .25567 .53754 .25907 .54635 .25192 .54165 .24823 Mtetra
.794 .91 .92 r
.54165 .24823 .54635 .25192 .55518 .24446 .5505 .2405 Mtetra
.802 .902 .912 r
.5505 .2405 .55518 .24446 .56401 .2367 .55937 .23248 Mtetra
.809 .895 .904 r
.55937 .23248 .56401 .2367 .57285 .22867 .56824 .22419 Mtetra
.815 .887 .896 r
.56824 .22419 .57285 .22867 .5817 .22037 .57711 .21564 Mtetra
.819 .88 .889 r
.57711 .21564 .5817 .22037 .59055 .21182 .58599 .20686 Mtetra
.823 .873 .882 r
.58599 .20686 .59055 .21182 .59941 .20305 .59487 .19785 Mtetra
.826 .867 .876 r
.59487 .19785 .59941 .20305 .60826 .19405 .60375 .18864 Mtetra
.828 .861 .87 r
.60375 .18864 .60826 .19405 .61711 .18487 .61263 .17923 Mtetra
.83 .855 .864 r
.61263 .17923 .61711 .18487 .62597 .1755 .62151 .16965 Mtetra
.832 .849 .859 r
.62151 .16965 .62597 .1755 .63482 .16596 .63039 .15991 Mtetra
.833 .843 .854 r
.63039 .15991 .63482 .16596 .64367 .15628 .63926 .15002 Mtetra
.834 .838 .85 r
.63926 .15002 .64367 .15628 .65251 .14646 .64813 .14 Mtetra
.834 .833 .846 r
.64813 .14 .65251 .14646 .66135 .13652 .657 .12987 Mtetra
.834 .828 .842 r
.657 .12987 .66135 .13652 .67019 .12649 .66586 .11964 Mtetra
.834 .823 .838 r
.66586 .11964 .67019 .12649 .67903 .11636 .67471 .10933 Mtetra
.833 .818 .835 r
.67471 .10933 .67903 .11636 .68786 .10616 .68357 .09894 Mtetra
.832 .814 .832 r
.68357 .09894 .68786 .10616 .69668 .0959 .69241 .0885 Mtetra
.831 .809 .829 r
.69241 .0885 .69668 .0959 .7055 .0856 .70125 .07801 Mtetra
.83 .805 .827 r
.70125 .07801 .7055 .0856 .71432 .07526 .71009 .0675 Mtetra
.828 .8 .825 r
.71009 .0675 .71432 .07526 .72314 .06492 .71893 .05697 Mtetra
.121 .49 .902 r
.07052 .35299 .07597 .35928 .08251 .36187 .07704 .35572 Mtetra
.112 .49 .902 r
.07704 .35572 .08251 .36187 .08909 .36446 .0836 .35845 Mtetra
.105 .492 .902 r
.0836 .35845 .08909 .36446 .09572 .36704 .09021 .36117 Mtetra
.1 .495 .902 r
.09021 .36117 .09572 .36704 .10239 .36959 .09687 .36386 Mtetra
.096 .499 .902 r
.09687 .36386 .10239 .36959 .1091 .3721 .10357 .36651 Mtetra
.094 .504 .903 r
.10357 .36651 .1091 .3721 .11586 .37456 .11032 .36911 Mtetra
.094 .51 .905 r
.11032 .36911 .11586 .37456 .12267 .37694 .11711 .37164 Mtetra
.095 .517 .907 r
.11711 .37164 .12267 .37694 .12954 .37925 .12396 .3741 Mtetra
.098 .526 .909 r
.12396 .3741 .12954 .37925 .13645 .38145 .13087 .37646 Mtetra
.103 .535 .912 r
.13087 .37646 .13645 .38145 .14342 .38354 .13782 .37871 Mtetra
.109 .546 .915 r
.13782 .37871 .14342 .38354 .15044 .38551 .14483 .38084 Mtetra
.117 .558 .919 r
.14483 .38084 .15044 .38551 .15752 .38733 .1519 .38283 Mtetra
.127 .571 .922 r
.1519 .38283 .15752 .38733 .16465 .38899 .15902 .38467 Mtetra
.138 .585 .926 r
.15902 .38467 .16465 .38899 .17184 .39048 .1662 .38634 Mtetra
.15 .6 .931 r
.1662 .38634 .17184 .39048 .17909 .39178 .17344 .38783 Mtetra
.164 .616 .935 r
.17344 .38783 .17909 .39178 .1864 .39288 .18074 .38912 Mtetra
.179 .633 .939 r
.18074 .38912 .1864 .39288 .19376 .39375 .1881 .3902 Mtetra
.195 .65 .943 r
.1881 .3902 .19376 .39375 .20118 .39439 .19551 .39105 Mtetra
.213 .669 .947 r
.19551 .39105 .20118 .39439 .20867 .39477 .20299 .39166 Mtetra
.231 .688 .95 r
.20299 .39166 .20867 .39477 .21621 .39488 .21053 .392 Mtetra
.25 .707 .952 r
.21053 .392 .21621 .39488 .22381 .39471 .21813 .39208 Mtetra
.269 .726 .954 r
.21813 .39208 .22381 .39471 .23147 .39424 .22578 .39186 Mtetra
.289 .745 .954 r
.22578 .39186 .23147 .39424 .23919 .39346 .2335 .39135 Mtetra
.309 .764 .953 r
.2335 .39135 .23919 .39346 .24697 .39235 .24127 .39052 Mtetra
.328 .782 .95 r
.24127 .39052 .24697 .39235 .2548 .39091 .24911 .38938 Mtetra
.346 .8 .946 r
.24911 .38938 .2548 .39091 .26269 .38913 .25699 .3879 Mtetra
.362 .815 .939 r
.25699 .3879 .26269 .38913 .27064 .387 .26494 .38609 Mtetra
.377 .829 .93 r
.26494 .38609 .27064 .387 .27863 .38453 .27294 .38394 Mtetra
.389 .841 .919 r
.27294 .38394 .27863 .38453 .28668 .38171 .28098 .38146 Mtetra
.399 .85 .904 r
.28098 .38146 .28668 .38171 .29477 .37855 .28908 .37866 Mtetra
.405 .856 .888 r
.28908 .37866 .29477 .37855 .30291 .37508 .29723 .37554 Mtetra
.408 .86 .868 r
.29723 .37554 .30291 .37508 .31109 .37131 .30542 .37212 Mtetra
.407 .86 .847 r
.30542 .37212 .31109 .37131 .31931 .36726 .31365 .36842 Mtetra
.404 .857 .824 r
.31365 .36842 .31931 .36726 .32756 .36296 .32192 .36445 Mtetra
.4 .853 .8 r
.32192 .36445 .32756 .36296 .33585 .35842 .33022 .36024 Mtetra
.396 .848 .777 r
.33022 .36024 .33585 .35842 .34417 .35367 .33856 .35577 Mtetra
.396 .845 .757 r
.33856 .35577 .34417 .35367 .35252 .34869 .34694 .35104 Mtetra
.401 .845 .741 r
.34694 .35104 .35252 .34869 .3609 .34347 .35535 .34603 Mtetra
.416 .851 .731 r
.35535 .34603 .3609 .34347 .36932 .33795 .36379 .34066 Mtetra
0 0 0 r
.36379 .34066 .36932 .33795 .37768 .3342 .37219 .33689 Mtetra
.37219 .33689 .37768 .3342 .386 .33223 .38056 .33473 Mtetra
.38056 .33473 .386 .33223 .39437 .32996 .38897 .33222 Mtetra
.38897 .33222 .39437 .32996 .40278 .32744 .39742 .32942 Mtetra
.39742 .32942 .40278 .32744 .41123 .3247 .40591 .32637 Mtetra
.249 .755 .719 r
.40591 .32637 .41123 .3247 .41971 .32175 .41444 .32306 Mtetra
.309 .798 .767 r
.41444 .32306 .41971 .32175 .42823 .31856 .42301 .3195 Mtetra
.37 .838 .812 r
.42301 .3195 .42823 .31856 .43679 .31512 .43161 .31568 Mtetra
.432 .873 .853 r
.43161 .31568 .43679 .31512 .44538 .3114 .44024 .31156 Mtetra
.491 .903 .888 r
.44024 .31156 .44538 .3114 .454 .30738 .4489 .30714 Mtetra
.546 .925 .914 r
.4489 .30714 .454 .30738 .46266 .30303 .4576 .30241 Mtetra
.595 .941 .934 r
.4576 .30241 .46266 .30303 .47134 .29834 .46632 .29734 Mtetra
.638 .95 .945 r
.46632 .29734 .47134 .29834 .48006 .2933 .47508 .29192 Mtetra
.674 .953 .951 r
.47508 .29192 .48006 .2933 .4888 .2879 .48385 .28617 Mtetra
.704 .953 .952 r
.48385 .28617 .4888 .2879 .49756 .28215 .49265 .28006 Mtetra
.729 .949 .95 r
.49265 .28006 .49756 .28215 .50634 .27604 .50147 .27362 Mtetra
.75 .944 .945 r
.50147 .27362 .50634 .27604 .51515 .26958 .51031 .26684 Mtetra
.767 .937 .939 r
.51031 .26684 .51515 .26958 .52397 .26279 .51916 .25974 Mtetra
.781 .929 .931 r
.51916 .25974 .52397 .26279 .5328 .25567 .52803 .25232 Mtetra
.792 .921 .924 r
.52803 .25232 .5328 .25567 .54165 .24823 .53691 .24459 Mtetra
.801 .913 .916 r
.53691 .24459 .54165 .24823 .5505 .2405 .54579 .23658 Mtetra
.809 .905 .908 r
.54579 .23658 .5505 .2405 .55937 .23248 .55469 .22829 Mtetra
.815 .897 .9 r
.55469 .22829 .55937 .23248 .56824 .22419 .56359 .21974 Mtetra
.82 .89 .893 r
.56359 .21974 .56824 .22419 .57711 .21564 .57249 .21094 Mtetra
.825 .882 .886 r
.57249 .21094 .57711 .21564 .58599 .20686 .5814 .20191 Mtetra
.828 .875 .879 r
.5814 .20191 .58599 .20686 .59487 .19785 .59031 .19267 Mtetra
.831 .869 .873 r
.59031 .19267 .59487 .19785 .60375 .18864 .59922 .18322 Mtetra
.833 .862 .867 r
.59922 .18322 .60375 .18864 .61263 .17923 .60812 .1736 Mtetra
.834 .856 .862 r
.60812 .1736 .61263 .17923 .62151 .16965 .61703 .1638 Mtetra
.836 .85 .856 r
.61703 .1638 .62151 .16965 .63039 .15991 .62593 .15384 Mtetra
.837 .845 .852 r
.62593 .15384 .63039 .15991 .63926 .15002 .63483 .14375 Mtetra
.837 .839 .847 r
.63483 .14375 .63926 .15002 .64813 .14 .64372 .13353 Mtetra
.837 .834 .843 r
.64372 .13353 .64813 .14 .657 .12987 .65261 .1232 Mtetra
.837 .829 .84 r
.65261 .1232 .657 .12987 .66586 .11964 .6615 .11278 Mtetra
.837 .824 .836 r
.6615 .11278 .66586 .11964 .67471 .10933 .67038 .10227 Mtetra
.836 .819 .833 r
.67038 .10227 .67471 .10933 .68357 .09894 .67925 .09169 Mtetra
.835 .815 .83 r
.67925 .09169 .68357 .09894 .69241 .0885 .68812 .08106 Mtetra
.834 .81 .827 r
.68812 .08106 .69241 .0885 .70125 .07801 .69698 .07039 Mtetra
.833 .805 .825 r
.69698 .07039 .70125 .07801 .71009 .0675 .70584 .05969 Mtetra
.831 .801 .822 r
.70584 .05969 .71009 .0675 .71893 .05697 .71469 .04898 Mtetra
.099 .476 .895 r
.06503 .34667 .07052 .35299 .07704 .35572 .07154 .34954 Mtetra
.09 .476 .894 r
.07154 .34954 .07704 .35572 .0836 .35845 .07808 .35241 Mtetra
.082 .478 .893 r
.07808 .35241 .0836 .35845 .09021 .36117 .08468 .35527 Mtetra
.076 .48 .893 r
.08468 .35527 .09021 .36117 .09687 .36386 .09131 .35811 Mtetra
.072 .484 .893 r
.09131 .35811 .09687 .36386 .10357 .36651 .098 .3609 Mtetra
.069 .488 .894 r
.098 .3609 .10357 .36651 .11032 .36911 .10473 .36365 Mtetra
.068 .494 .895 r
.10473 .36365 .11032 .36911 .11711 .37164 .11152 .36634 Mtetra
.069 .501 .896 r
.11152 .36634 .11711 .37164 .12396 .3741 .11836 .36895 Mtetra
.071 .509 .898 r
.11836 .36895 .12396 .3741 .13087 .37646 .12524 .37146 Mtetra
.075 .518 .9 r
.12524 .37146 .13087 .37646 .13782 .37871 .13219 .37388 Mtetra
.081 .528 .903 r
.13219 .37388 .13782 .37871 .14483 .38084 .13919 .37618 Mtetra
.087 .54 .906 r
.13919 .37618 .14483 .38084 .1519 .38283 .14624 .37834 Mtetra
.096 .552 .91 r
.14624 .37834 .1519 .38283 .15902 .38467 .15335 .38036 Mtetra
.106 .566 .914 r
.15335 .38036 .15902 .38467 .1662 .38634 .16052 .38222 Mtetra
.117 .58 .917 r
.16052 .38222 .1662 .38634 .17344 .38783 .16775 .3839 Mtetra
.129 .596 .921 r
.16775 .3839 .17344 .38783 .18074 .38912 .17504 .3854 Mtetra
.143 .612 .925 r
.17504 .3854 .18074 .38912 .1881 .3902 .18239 .38669 Mtetra
.158 .629 .929 r
.18239 .38669 .1881 .3902 .19551 .39105 .1898 .38776 Mtetra
.174 .647 .932 r
.1898 .38776 .19551 .39105 .20299 .39166 .19727 .38859 Mtetra
.191 .665 .935 r
.19727 .38859 .20299 .39166 .21053 .392 .2048 .38918 Mtetra
.209 .684 .937 r
.2048 .38918 .21053 .392 .21813 .39208 .21239 .3895 Mtetra
.227 .703 .938 r
.21239 .3895 .21813 .39208 .22578 .39186 .22004 .38954 Mtetra
.245 .721 .938 r
.22004 .38954 .22578 .39186 .2335 .39135 .22775 .3893 Mtetra
.263 .74 .936 r
.22775 .3893 .2335 .39135 .24127 .39052 .23552 .38876 Mtetra
.281 .757 .933 r
.23552 .38876 .24127 .39052 .24911 .38938 .24335 .38791 Mtetra
.298 .774 .928 r
.24335 .38791 .24911 .38938 .25699 .3879 .25124 .38674 Mtetra
.313 .789 .921 r
.25124 .38674 .25699 .3879 .26494 .38609 .25919 .38525 Mtetra
.327 .802 .911 r
.25919 .38525 .26494 .38609 .27294 .38394 .26718 .38343 Mtetra
.339 .813 .899 r
.26718 .38343 .27294 .38394 .28098 .38146 .27524 .38129 Mtetra
.348 .822 .885 r
.27524 .38129 .28098 .38146 .28908 .37866 .28334 .37884 Mtetra
.354 .828 .867 r
.28334 .37884 .28908 .37866 .29723 .37554 .29149 .37607 Mtetra
.357 .831 .848 r
.29149 .37607 .29723 .37554 .30542 .37212 .29969 .37301 Mtetra
.358 .831 .826 r
.29969 .37301 .30542 .37212 .31365 .36842 .30793 .36966 Mtetra
.357 .829 .803 r
.30793 .36966 .31365 .36842 .32192 .36445 .31621 .36603 Mtetra
.356 .826 .78 r
.31621 .36603 .32192 .36445 .33022 .36024 .32453 .36213 Mtetra
.355 .823 .758 r
.32453 .36213 .33022 .36024 .33856 .35577 .33289 .35795 Mtetra
.359 .822 .739 r
.33289 .35795 .33856 .35577 .34694 .35104 .34129 .35349 Mtetra
.368 .825 .724 r
.34129 .35349 .34694 .35104 .35535 .34603 .34973 .34869 Mtetra
.387 .832 .715 r
.34973 .34869 .35535 .34603 .36379 .34066 .3582 .34351 Mtetra
0 0 0 r
.3582 .34351 .36379 .34066 .37219 .33689 .36664 .33973 Mtetra
.36664 .33973 .37219 .33689 .38056 .33473 .37505 .33735 Mtetra
.37505 .33735 .38056 .33473 .38897 .33222 .3835 .33458 Mtetra
.3835 .33458 .38897 .33222 .39742 .32942 .392 .33149 Mtetra
.224 .733 .682 r
.392 .33149 .39742 .32942 .40591 .32637 .40054 .32811 Mtetra
.283 .777 .729 r
.40054 .32811 .40591 .32637 .41444 .32306 .40911 .32445 Mtetra
.343 .819 .775 r
.40911 .32445 .41444 .32306 .42301 .3195 .41772 .32052 Mtetra
.404 .857 .818 r
.41772 .32052 .42301 .3195 .43161 .31568 .42637 .3163 Mtetra
.464 .89 .856 r
.42637 .3163 .43161 .31568 .44024 .31156 .43505 .3118 Mtetra
.52 .917 .888 r
.43505 .3118 .44024 .31156 .4489 .30714 .44375 .30699 Mtetra
.572 .937 .913 r
.44375 .30699 .4489 .30714 .4576 .30241 .45249 .30186 Mtetra
.618 .95 .93 r
.45249 .30186 .4576 .30241 .46632 .29734 .46126 .29641 Mtetra
.657 .957 .94 r
.46126 .29641 .46632 .29734 .47508 .29192 .47005 .29062 Mtetra
.691 .959 .946 r
.47005 .29062 .47508 .29192 .48385 .28617 .47886 .2845 Mtetra
.719 .958 .946 r
.47886 .2845 .48385 .28617 .49265 .28006 .4877 .27805 Mtetra
.742 .954 .944 r
.4877 .27805 .49265 .28006 .50147 .27362 .49656 .27126 Mtetra
.761 .948 .939 r
.49656 .27126 .50147 .27362 .51031 .26684 .50543 .26416 Mtetra
.777 .94 .933 r
.50543 .26416 .51031 .26684 .51916 .25974 .51432 .25673 Mtetra
.79 .932 .926 r
.51432 .25673 .51916 .25974 .52803 .25232 .52322 .24901 Mtetra
.8 .924 .919 r
.52322 .24901 .52803 .25232 .53691 .24459 .53213 .24099 Mtetra
.809 .916 .911 r
.53213 .24099 .53691 .24459 .54579 .23658 .54105 .23269 Mtetra
.816 .907 .903 r
.54105 .23269 .54579 .23658 .55469 .22829 .54997 .22413 Mtetra
.821 .899 .896 r
.54997 .22413 .55469 .22829 .56359 .21974 .5589 .21531 Mtetra
.826 .892 .889 r
.5589 .21531 .56359 .21974 .57249 .21094 .56784 .20626 Mtetra
.83 .884 .882 r
.56784 .20626 .57249 .21094 .5814 .20191 .57678 .19698 Mtetra
.833 .877 .876 r
.57678 .19698 .5814 .20191 .59031 .19267 .58571 .1875 Mtetra
.835 .87 .87 r
.58571 .1875 .59031 .19267 .59922 .18322 .59465 .17782 Mtetra
.837 .864 .864 r
.59465 .17782 .59922 .18322 .60812 .1736 .60358 .16796 Mtetra
.839 .858 .859 r
.60358 .16796 .60812 .1736 .61703 .1638 .61252 .15794 Mtetra
.84 .852 .854 r
.61252 .15794 .61703 .1638 .62593 .15384 .62144 .14777 Mtetra
.84 .846 .849 r
.62144 .14777 .62593 .15384 .63483 .14375 .63037 .13747 Mtetra
.841 .841 .845 r
.63037 .13747 .63483 .14375 .64372 .13353 .63929 .12704 Mtetra
.841 .835 .841 r
.63929 .12704 .64372 .13353 .65261 .1232 .6482 .11651 Mtetra
.84 .83 .837 r
.6482 .11651 .65261 .1232 .6615 .11278 .65711 .10589 Mtetra
.84 .825 .834 r
.65711 .10589 .6615 .11278 .67038 .10227 .66601 .09518 Mtetra
.839 .82 .831 r
.66601 .09518 .67038 .10227 .67925 .09169 .67491 .08441 Mtetra
.838 .815 .828 r
.67491 .08441 .67925 .09169 .68812 .08106 .6838 .07359 Mtetra
.837 .811 .825 r
.6838 .07359 .68812 .08106 .69698 .07039 .69268 .06273 Mtetra
.835 .806 .822 r
.69268 .06273 .69698 .07039 .70584 .05969 .70156 .05184 Mtetra
.834 .801 .82 r
.70156 .05184 .70584 .05969 .71469 .04898 .71043 .04094 Mtetra
.076 .461 .886 r
.05951 .34032 .06503 .34667 .07154 .34954 .066 .34333 Mtetra
.066 .461 .885 r
.066 .34333 .07154 .34954 .07808 .35241 .07253 .34635 Mtetra
.058 .463 .884 r
.07253 .34635 .07808 .35241 .08468 .35527 .07911 .34935 Mtetra
.052 .465 .883 r
.07911 .34935 .08468 .35527 .09131 .35811 .08573 .35233 Mtetra
.047 .468 .883 r
.08573 .35233 .09131 .35811 .098 .3609 .0924 .35528 Mtetra
.044 .472 .883 r
.0924 .35528 .098 .3609 .10473 .36365 .09912 .35818 Mtetra
.042 .477 .884 r
.09912 .35818 .10473 .36365 .11152 .36634 .10589 .36102 Mtetra
.042 .484 .885 r
.10589 .36102 .11152 .36634 .11836 .36895 .11271 .36379 Mtetra
.043 .491 .886 r
.11271 .36379 .11836 .36895 .12524 .37146 .11958 .36647 Mtetra
.046 .5 .888 r
.11958 .36647 .12524 .37146 .13219 .37388 .12651 .36905 Mtetra
.051 .51 .89 r
.12651 .36905 .13219 .37388 .13919 .37618 .1335 .37152 Mtetra
.057 .521 .893 r
.1335 .37152 .13919 .37618 .14624 .37834 .14054 .37386 Mtetra
.064 .532 .896 r
.14054 .37386 .14624 .37834 .15335 .38036 .14764 .37607 Mtetra
.073 .545 .899 r
.14764 .37607 .15335 .38036 .16052 .38222 .1548 .37812 Mtetra
.083 .559 .902 r
.1548 .37812 .16052 .38222 .16775 .3839 .16202 .38 Mtetra
.094 .574 .906 r
.16202 .38 .16775 .3839 .17504 .3854 .1693 .3817 Mtetra
.107 .59 .909 r
.1693 .3817 .17504 .3854 .18239 .38669 .17664 .3832 Mtetra
.12 .606 .912 r
.17664 .3832 .18239 .38669 .1898 .38776 .18404 .3845 Mtetra
.135 .623 .915 r
.18404 .3845 .1898 .38776 .19727 .38859 .1915 .38556 Mtetra
.15 .641 .917 r
.1915 .38556 .19727 .38859 .2048 .38918 .19902 .38639 Mtetra
.166 .659 .919 r
.19902 .38639 .2048 .38918 .21239 .3895 .2066 .38697 Mtetra
.183 .677 .919 r
.2066 .38697 .21239 .3895 .22004 .38954 .21425 .38728 Mtetra
.2 .695 .918 r
.21425 .38728 .22004 .38954 .22775 .3893 .22196 .38731 Mtetra
.216 .712 .916 r
.22196 .38731 .22775 .3893 .23552 .38876 .22972 .38706 Mtetra
.233 .729 .913 r
.22972 .38706 .23552 .38876 .24335 .38791 .23755 .3865 Mtetra
.248 .745 .907 r
.23755 .3865 .24335 .38791 .25124 .38674 .24543 .38565 Mtetra
.262 .759 .899 r
.24543 .38565 .25124 .38674 .25919 .38525 .25338 .38448 Mtetra
.275 .772 .889 r
.25338 .38448 .25919 .38525 .26718 .38343 .26138 .383 Mtetra
.286 .782 .877 r
.26138 .383 .26718 .38343 .27524 .38129 .26943 .3812 Mtetra
.295 .79 .861 r
.26943 .3812 .27524 .38129 .28334 .37884 .27753 .3791 Mtetra
.301 .796 .844 r
.27753 .3791 .28334 .37884 .29149 .37607 .28569 .37669 Mtetra
.305 .799 .824 r
.28569 .37669 .29149 .37607 .29969 .37301 .29389 .37398 Mtetra
.307 .8 .803 r
.29389 .37398 .29969 .37301 .30793 .36966 .30214 .37097 Mtetra
.308 .799 .78 r
.30214 .37097 .30793 .36966 .31621 .36603 .31044 .36768 Mtetra
.31 .797 .758 r
.31044 .36768 .31621 .36603 .32453 .36213 .31878 .3641 Mtetra
.312 .795 .737 r
.31878 .3641 .32453 .36213 .33289 .35795 .32716 .36023 Mtetra
.319 .796 .719 r
.32716 .36023 .33289 .35795 .34129 .35349 .33558 .35603 Mtetra
.332 .801 .705 r
.33558 .35603 .34129 .35349 .34973 .34869 .34404 .35148 Mtetra
.353 .81 .696 r
.34404 .35148 .34973 .34869 .3582 .34351 .35255 .3465 Mtetra
0 0 0 r
.35255 .3465 .3582 .34351 .36664 .33973 .36102 .3427 Mtetra
.36102 .3427 .36664 .33973 .37505 .33735 .36948 .34009 Mtetra
.36948 .34009 .37505 .33735 .3835 .33458 .37798 .33705 Mtetra
.37798 .33705 .3835 .33458 .392 .33149 .38652 .33365 Mtetra
.254 .753 .691 r
.38652 .33365 .392 .33149 .40054 .32811 .39511 .32993 Mtetra
.315 .797 .737 r
.39511 .32993 .40054 .32811 .40911 .32445 .40373 .32591 Mtetra
.376 .838 .782 r
.40373 .32591 .40911 .32445 .41772 .32052 .41239 .32161 Mtetra
.436 .875 .823 r
.41239 .32161 .41772 .32052 .42637 .3163 .42108 .31701 Mtetra
.494 .905 .858 r
.42108 .31701 .42637 .3163 .43505 .3118 .4298 .31211 Mtetra
.547 .929 .888 r
.4298 .31211 .43505 .3118 .44375 .30699 .43855 .3069 Mtetra
.596 .947 .91 r
.43855 .3069 .44375 .30699 .45249 .30186 .44733 .30138 Mtetra
.639 .958 .926 r
.44733 .30138 .45249 .30186 .46126 .29641 .45614 .29555 Mtetra
.676 .964 .935 r
.45614 .29555 .46126 .29641 .47005 .29062 .46497 .28939 Mtetra
.707 .965 .94 r
.46497 .28939 .47005 .29062 .47886 .2845 .47383 .2829 Mtetra
.733 .962 .94 r
.47383 .2829 .47886 .2845 .4877 .27805 .4827 .27609 Mtetra
.755 .957 .938 r
.4827 .27609 .4877 .27805 .49656 .27126 .4916 .26896 Mtetra
.772 .951 .933 r
.4916 .26896 .49656 .27126 .50543 .26416 .50051 .26152 Mtetra
.787 .943 .927 r
.50051 .26152 .50543 .26416 .51432 .25673 .50943 .25378 Mtetra
.798 .935 .921 r
.50943 .25378 .51432 .25673 .52322 .24901 .51837 .24575 Mtetra
.808 .927 .914 r
.51837 .24575 .52322 .24901 .53213 .24099 .52731 .23743 Mtetra
.816 .918 .906 r
.52731 .23743 .53213 .24099 .54105 .23269 .53626 .22884 Mtetra
.822 .91 .899 r
.53626 .22884 .54105 .23269 .54997 .22413 .54522 .22 Mtetra
.827 .902 .892 r
.54522 .22 .54997 .22413 .5589 .21531 .55418 .21091 Mtetra
.832 .894 .885 r
.55418 .21091 .5589 .21531 .56784 .20626 .56315 .2016 Mtetra
.835 .886 .879 r
.56315 .2016 .56784 .20626 .57678 .19698 .57212 .19207 Mtetra
.838 .879 .872 r
.57212 .19207 .57678 .19698 .58571 .1875 .58108 .18234 Mtetra
.84 .872 .866 r
.58108 .18234 .58571 .1875 .59465 .17782 .59005 .17242 Mtetra
.841 .865 .861 r
.59005 .17242 .59465 .17782 .60358 .16796 .59901 .16233 Mtetra
.843 .859 .856 r
.59901 .16233 .60358 .16796 .61252 .15794 .60797 .15209 Mtetra
.843 .853 .851 r
.60797 .15209 .61252 .15794 .62144 .14777 .61693 .1417 Mtetra
.844 .847 .846 r
.61693 .1417 .62144 .14777 .63037 .13747 .62588 .13118 Mtetra
.844 .842 .842 r
.62588 .13118 .63037 .13747 .63929 .12704 .63482 .12054 Mtetra
.844 .836 .838 r
.63482 .12054 .63929 .12704 .6482 .11651 .64376 .1098 Mtetra
.844 .831 .835 r
.64376 .1098 .6482 .11651 .65711 .10589 .65269 .09897 Mtetra
.843 .826 .831 r
.65269 .09897 .65711 .10589 .66601 .09518 .66162 .08807 Mtetra
.842 .821 .828 r
.66162 .08807 .66601 .09518 .67491 .08441 .67053 .0771 Mtetra
.841 .816 .825 r
.67053 .0771 .67491 .08441 .6838 .07359 .67945 .06608 Mtetra
.84 .811 .823 r
.67945 .06608 .6838 .07359 .69268 .06273 .68835 .05503 Mtetra
.838 .807 .82 r
.68835 .05503 .69268 .06273 .70156 .05184 .69725 .04395 Mtetra
.837 .802 .818 r
.69725 .04395 .70156 .05184 .71043 .04094 .70614 .03286 Mtetra
.052 .446 .877 r
.05397 .33393 .05951 .34032 .066 .34333 .06044 .33709 Mtetra
.042 .446 .875 r
.06044 .33709 .066 .34333 .07253 .34635 .06695 .34025 Mtetra
.034 .447 .874 r
.06695 .34025 .07253 .34635 .07911 .34935 .07351 .34341 Mtetra
.027 .448 .873 r
.07351 .34341 .07911 .34935 .08573 .35233 .08011 .34654 Mtetra
.021 .451 .872 r
.08011 .34654 .08573 .35233 .0924 .35528 .08676 .34964 Mtetra
.018 .455 .871 r
.08676 .34964 .0924 .35528 .09912 .35818 .09347 .3527 Mtetra
.015 .46 .872 r
.09347 .3527 .09912 .35818 .10589 .36102 .10022 .3557 Mtetra
.014 .466 .872 r
.10022 .3557 .10589 .36102 .11271 .36379 .10702 .35862 Mtetra
.015 .473 .873 r
.10702 .35862 .11271 .36379 .11958 .36647 .11388 .36147 Mtetra
.017 .481 .874 r
.11388 .36147 .11958 .36647 .12651 .36905 .1208 .36423 Mtetra
.02 .49 .876 r
.1208 .36423 .12651 .36905 .1335 .37152 .12777 .36687 Mtetra
.025 .5 .878 r
.12777 .36687 .1335 .37152 .14054 .37386 .1348 .3694 Mtetra
.032 .512 .88 r
.1348 .3694 .14054 .37386 .14764 .37607 .14189 .37179 Mtetra
.039 .524 .883 r
.14189 .37179 .14764 .37607 .1548 .37812 .14903 .37403 Mtetra
.048 .537 .886 r
.14903 .37403 .1548 .37812 .16202 .38 .15624 .37612 Mtetra
.058 .551 .888 r
.15624 .37612 .16202 .38 .1693 .3817 .16351 .37803 Mtetra
.069 .566 .891 r
.16351 .37803 .1693 .3817 .17664 .3832 .17084 .37975 Mtetra
.081 .581 .894 r
.17084 .37975 .17664 .3832 .18404 .3845 .17823 .38127 Mtetra
.094 .598 .896 r
.17823 .38127 .18404 .3845 .1915 .38556 .18568 .38257 Mtetra
.108 .614 .897 r
.18568 .38257 .1915 .38556 .19902 .38639 .19319 .38365 Mtetra
.123 .631 .898 r
.19319 .38365 .19902 .38639 .2066 .38697 .20077 .38448 Mtetra
.138 .648 .898 r
.20077 .38448 .2066 .38697 .21425 .38728 .2084 .38506 Mtetra
.153 .665 .896 r
.2084 .38506 .21425 .38728 .22196 .38731 .2161 .38538 Mtetra
.168 .682 .894 r
.2161 .38538 .22196 .38731 .22972 .38706 .22387 .38541 Mtetra
.183 .698 .889 r
.22387 .38541 .22972 .38706 .23755 .3865 .23169 .38516 Mtetra
.197 .713 .883 r
.23169 .38516 .23755 .3865 .24543 .38565 .23957 .38462 Mtetra
.21 .726 .874 r
.23957 .38462 .24543 .38565 .25338 .38448 .24751 .38378 Mtetra
.222 .738 .864 r
.24751 .38378 .25338 .38448 .26138 .383 .25551 .38264 Mtetra
.232 .748 .851 r
.25551 .38264 .26138 .383 .26943 .3812 .26356 .38119 Mtetra
.24 .756 .835 r
.26356 .38119 .26943 .3812 .27753 .3791 .27167 .37943 Mtetra
.247 .761 .817 r
.27167 .37943 .27753 .3791 .28569 .37669 .27983 .37738 Mtetra
.252 .764 .797 r
.27983 .37738 .28569 .37669 .29389 .37398 .28804 .37502 Mtetra
.255 .765 .776 r
.28804 .37502 .29389 .37398 .30214 .37097 .2963 .37237 Mtetra
.258 .765 .754 r
.2963 .37237 .30214 .37097 .31044 .36768 .30461 .36942 Mtetra
.262 .765 .733 r
.30461 .36942 .31044 .36768 .31878 .3641 .31296 .36617 Mtetra
.267 .765 .713 r
.31296 .36617 .31878 .3641 .32716 .36023 .32136 .36261 Mtetra
.277 .767 .696 r
.32136 .36261 .32716 .36023 .33558 .35603 .3298 .3587 Mtetra
.293 .774 .683 r
.3298 .3587 .33558 .35603 .34404 .35148 .33829 .3544 Mtetra
.316 .785 .674 r
.33829 .3544 .34404 .35148 .35255 .3465 .34682 .34965 Mtetra
0 0 0 r
.34682 .34965 .35255 .3465 .36102 .3427 .35533 .34584 Mtetra
.35533 .34584 .36102 .3427 .36948 .34009 .36384 .34296 Mtetra
.36384 .34296 .36948 .34009 .37798 .33705 .37239 .33963 Mtetra
.37239 .33963 .37798 .33705 .38652 .33365 .38098 .33591 Mtetra
.284 .772 .698 r
.38098 .33591 .38652 .33365 .39511 .32993 .38961 .33185 Mtetra
.347 .816 .744 r
.38961 .33185 .39511 .32993 .40373 .32591 .39828 .32747 Mtetra
.408 .856 .788 r
.39828 .32747 .40373 .32591 .41239 .32161 .40699 .32278 Mtetra
.467 .89 .826 r
.40699 .32278 .41239 .32161 .42108 .31701 .41573 .31779 Mtetra
.522 .919 .859 r
.41573 .31779 .42108 .31701 .4298 .31211 .4245 .31249 Mtetra
.574 .941 .886 r
.4245 .31249 .4298 .31211 .43855 .3069 .4333 .30689 Mtetra
.619 .956 .907 r
.4333 .30689 .43855 .3069 .44733 .30138 .44212 .30098 Mtetra
.659 .965 .921 r
.44212 .30098 .44733 .30138 .45614 .29555 .45098 .29476 Mtetra
.694 .969 .929 r
.45098 .29476 .45614 .29555 .46497 .28939 .45985 .28822 Mtetra
.723 .969 .933 r
.45985 .28822 .46497 .28939 .47383 .2829 .46875 .28136 Mtetra
.747 .966 .934 r
.46875 .28136 .47383 .2829 .4827 .27609 .47766 .27419 Mtetra
.766 .961 .931 r
.47766 .27419 .4827 .27609 .4916 .26896 .4866 .26672 Mtetra
.783 .954 .927 r
.4866 .26672 .4916 .26896 .50051 .26152 .49554 .25894 Mtetra
.796 .946 .921 r
.49554 .25894 .50051 .26152 .50943 .25378 .5045 .25087 Mtetra
.807 .937 .915 r
.5045 .25087 .50943 .25378 .51837 .24575 .51347 .24252 Mtetra
.815 .929 .908 r
.51347 .24252 .51837 .24575 .52731 .23743 .52245 .2339 Mtetra
.823 .92 .901 r
.52245 .2339 .52731 .23743 .53626 .22884 .53144 .22502 Mtetra
.828 .912 .894 r
.53144 .22502 .53626 .22884 .54522 .22 .54043 .21589 Mtetra
.833 .903 .888 r
.54043 .21589 .54522 .22 .55418 .21091 .54943 .20653 Mtetra
.837 .895 .881 r
.54943 .20653 .55418 .21091 .56315 .2016 .55842 .19695 Mtetra
.84 .888 .875 r
.55842 .19695 .56315 .2016 .57212 .19207 .56742 .18716 Mtetra
.842 .88 .869 r
.56742 .18716 .57212 .19207 .58108 .18234 .57642 .17718 Mtetra
.844 .874 .863 r
.57642 .17718 .58108 .18234 .59005 .17242 .58541 .16702 Mtetra
.846 .867 .858 r
.58541 .16702 .59005 .17242 .59901 .16233 .59441 .1567 Mtetra
.847 .86 .853 r
.59441 .1567 .59901 .16233 .60797 .15209 .60339 .14622 Mtetra
.847 .854 .848 r
.60339 .14622 .60797 .15209 .61693 .1417 .61238 .13561 Mtetra
.847 .849 .844 r
.61238 .13561 .61693 .1417 .62588 .13118 .62135 .12487 Mtetra
.847 .843 .84 r
.62135 .12487 .62588 .13118 .63482 .12054 .63032 .11402 Mtetra
.847 .837 .836 r
.63032 .11402 .63482 .12054 .64376 .1098 .63929 .10307 Mtetra
.847 .832 .832 r
.63929 .10307 .64376 .1098 .65269 .09897 .64824 .09203 Mtetra
.846 .827 .829 r
.64824 .09203 .65269 .09897 .66162 .08807 .65719 .08092 Mtetra
.845 .822 .826 r
.65719 .08092 .66162 .08807 .67053 .0771 .66614 .06976 Mtetra
.844 .817 .823 r
.66614 .06976 .67053 .0771 .67945 .06608 .67507 .05854 Mtetra
.843 .812 .82 r
.67507 .05854 .67945 .06608 .68835 .05503 .684 .04729 Mtetra
.841 .807 .818 r
.684 .04729 .68835 .05503 .69725 .04395 .69292 .03601 Mtetra
.839 .803 .815 r
.69292 .03601 .69725 .04395 .70614 .03286 .70183 .02472 Mtetra
.028 .43 .867 r
.0484 .32751 .05397 .33393 .06044 .33709 .05484 .33082 Mtetra
.017 .43 .865 r
.05484 .33082 .06044 .33709 .06695 .34025 .06134 .33414 Mtetra
.008 .43 .863 r
.06134 .33414 .06695 .34025 .07351 .34341 .06787 .33744 Mtetra
.001 .431 .861 r
.06787 .33744 .07351 .34341 .08011 .34654 .07446 .34073 Mtetra
0 .434 .86 r
.07446 .34073 .08011 .34654 .08676 .34964 .08109 .34398 Mtetra
0 .437 .859 r
.08109 .34398 .08676 .34964 .09347 .3527 .08778 .3472 Mtetra
0 .442 .858 r
.08778 .3472 .09347 .3527 .10022 .3557 .09451 .35036 Mtetra
0 .447 .858 r
.09451 .35036 .10022 .3557 .10702 .35862 .1013 .35345 Mtetra
0 .454 .859 r
.1013 .35345 .10702 .35862 .11388 .36147 .10815 .35647 Mtetra
0 .461 .859 r
.10815 .35647 .11388 .36147 .1208 .36423 .11505 .3594 Mtetra
0 .47 .861 r
.11505 .3594 .1208 .36423 .12777 .36687 .122 .36223 Mtetra
0 .479 .862 r
.122 .36223 .12777 .36687 .1348 .3694 .12902 .36494 Mtetra
0 .49 .864 r
.12902 .36494 .1348 .3694 .14189 .37179 .13609 .36752 Mtetra
.005 .501 .865 r
.13609 .36752 .14189 .37179 .14903 .37403 .14322 .36996 Mtetra
.012 .513 .867 r
.14322 .36996 .14903 .37403 .15624 .37612 .15042 .37226 Mtetra
.021 .526 .869 r
.15042 .37226 .15624 .37612 .16351 .37803 .15767 .37438 Mtetra
.031 .54 .871 r
.15767 .37438 .16351 .37803 .17084 .37975 .16499 .37632 Mtetra
.041 .555 .873 r
.16499 .37632 .17084 .37975 .17823 .38127 .17237 .37808 Mtetra
.053 .57 .874 r
.17237 .37808 .17823 .38127 .18568 .38257 .17981 .37962 Mtetra
.065 .586 .875 r
.17981 .37962 .18568 .38257 .19319 .38365 .18731 .38095 Mtetra
.078 .602 .875 r
.18731 .38095 .19319 .38365 .20077 .38448 .19488 .38204 Mtetra
.091 .618 .874 r
.19488 .38204 .20077 .38448 .2084 .38506 .20251 .3829 Mtetra
.105 .634 .872 r
.20251 .3829 .2084 .38506 .2161 .38538 .2102 .38349 Mtetra
.119 .649 .868 r
.2102 .38349 .2161 .38538 .22387 .38541 .21795 .38383 Mtetra
.132 .664 .863 r
.21795 .38383 .22387 .38541 .23169 .38516 .22577 .38389 Mtetra
.145 .678 .856 r
.22577 .38389 .23169 .38516 .23957 .38462 .23365 .38366 Mtetra
.157 .691 .847 r
.23365 .38366 .23957 .38462 .24751 .38378 .24159 .38315 Mtetra
.167 .702 .835 r
.24159 .38315 .24751 .38378 .25551 .38264 .24958 .38235 Mtetra
.177 .711 .821 r
.24958 .38235 .25551 .38264 .26356 .38119 .25763 .38124 Mtetra
.185 .718 .806 r
.25763 .38124 .26356 .38119 .27167 .37943 .26574 .37985 Mtetra
.192 .723 .788 r
.26574 .37985 .27167 .37943 .27983 .37738 .27391 .37815 Mtetra
.197 .726 .768 r
.27391 .37815 .27983 .37738 .28804 .37502 .28213 .37615 Mtetra
.202 .728 .747 r
.28213 .37615 .28804 .37502 .2963 .37237 .29039 .37386 Mtetra
.207 .729 .726 r
.29039 .37386 .2963 .37237 .30461 .36942 .29871 .37126 Mtetra
.212 .73 .705 r
.29871 .37126 .30461 .36942 .31296 .36617 .30708 .36834 Mtetra
.221 .731 .686 r
.30708 .36834 .31296 .36617 .32136 .36261 .31549 .36509 Mtetra
.233 .736 .67 r
.31549 .36509 .32136 .36261 .3298 .3587 .32396 .36148 Mtetra
0 0 0 r
.32396 .36148 .3298 .3587 .33829 .3544 .33247 .35746 Mtetra
.33247 .35746 .33829 .3544 .34682 .34965 .34103 .35297 Mtetra
.34103 .35297 .34682 .34965 .35533 .34584 .34958 .34914 Mtetra
.34958 .34914 .35533 .34584 .36384 .34296 .35813 .34597 Mtetra
.35813 .34597 .36384 .34296 .37239 .33963 .36673 .34233 Mtetra
.36673 .34233 .37239 .33963 .38098 .33591 .37537 .33828 Mtetra
.313 .79 .704 r
.37537 .33828 .38098 .33591 .38961 .33185 .38406 .33386 Mtetra
.377 .834 .75 r
.38406 .33386 .38961 .33185 .39828 .32747 .39278 .32911 Mtetra
.438 .872 .792 r
.39278 .32911 .39828 .32747 .40699 .32278 .40154 .32404 Mtetra
.496 .905 .828 r
.40154 .32404 .40699 .32278 .41573 .31779 .41033 .31865 Mtetra
.55 .931 .859 r
.41033 .31865 .41573 .31779 .4245 .31249 .41914 .31296 Mtetra
.598 .951 .884 r
.41914 .31296 .4245 .31249 .4333 .30689 .42799 .30696 Mtetra
.641 .964 .903 r
.42799 .30696 .4333 .30689 .44212 .30098 .43686 .30065 Mtetra
.679 .971 .916 r
.43686 .30065 .44212 .30098 .45098 .29476 .44576 .29404 Mtetra
.711 .974 .923 r
.44576 .29404 .45098 .29476 .45985 .28822 .45468 .28712 Mtetra
.737 .973 .927 r
.45468 .28712 .45985 .28822 .46875 .28136 .46362 .27989 Mtetra
.76 .969 .927 r
.46362 .27989 .46875 .28136 .47766 .27419 .47257 .27236 Mtetra
.778 .963 .925 r
.47257 .27236 .47766 .27419 .4866 .26672 .48155 .26453 Mtetra
.793 .956 .921 r
.48155 .26453 .4866 .26672 .49554 .25894 .49053 .25641 Mtetra
.805 .948 .915 r
.49053 .25641 .49554 .25894 .5045 .25087 .49953 .24801 Mtetra
.815 .939 .909 r
.49953 .24801 .5045 .25087 .51347 .24252 .50854 .23934 Mtetra
.823 .931 .903 r
.50854 .23934 .51347 .24252 .52245 .2339 .51756 .23041 Mtetra
.829 .922 .896 r
.51756 .23041 .52245 .2339 .53144 .22502 .52658 .22123 Mtetra
.835 .913 .89 r
.52658 .22123 .53144 .22502 .54043 .21589 .53561 .21181 Mtetra
.839 .905 .883 r
.53561 .21181 .54043 .21589 .54943 .20653 .54463 .20217 Mtetra
.842 .897 .877 r
.54463 .20217 .54943 .20653 .55842 .19695 .55366 .19232 Mtetra
.845 .889 .871 r
.55366 .19232 .55842 .19695 .56742 .18716 .56269 .18227 Mtetra
.847 .882 .865 r
.56269 .18227 .56742 .18716 .57642 .17718 .57172 .17204 Mtetra
.849 .875 .86 r
.57172 .17204 .57642 .17718 .58541 .16702 .58075 .16163 Mtetra
.85 .868 .855 r
.58075 .16163 .58541 .16702 .59441 .1567 .58977 .15107 Mtetra
.85 .862 .85 r
.58977 .15107 .59441 .1567 .60339 .14622 .59879 .14036 Mtetra
.851 .856 .845 r
.59879 .14036 .60339 .14622 .61238 .13561 .6078 .12951 Mtetra
.851 .85 .841 r
.6078 .12951 .61238 .13561 .62135 .12487 .6168 .11855 Mtetra
.851 .844 .837 r
.6168 .11855 .62135 .12487 .63032 .11402 .6258 .10748 Mtetra
.851 .838 .833 r
.6258 .10748 .63032 .11402 .63929 .10307 .63479 .09631 Mtetra
.85 .833 .83 r
.63479 .09631 .63929 .10307 .64824 .09203 .64377 .08507 Mtetra
.849 .828 .826 r
.64377 .08507 .64824 .09203 .65719 .08092 .65274 .07375 Mtetra
.848 .823 .823 r
.65274 .07375 .65719 .08092 .66614 .06976 .66171 .06238 Mtetra
.847 .818 .82 r
.66171 .06238 .66614 .06976 .67507 .05854 .67067 .05096 Mtetra
.845 .813 .818 r
.67067 .05096 .67507 .05854 .684 .04729 .67962 .0395 Mtetra
.844 .808 .815 r
.67962 .0395 .684 .04729 .69292 .03601 .68856 .02803 Mtetra
.842 .803 .813 r
.68856 .02803 .69292 .03601 .70183 .02472 .69749 .01654 Mtetra
.003 .413 .856 r
.04279 .32106 .0484 .32751 .05484 .33082 .04922 .32452 Mtetra
0 .413 .853 r
.04922 .32452 .05484 .33082 .06134 .33414 .05569 .32799 Mtetra
0 .413 .851 r
.05569 .32799 .06134 .33414 .06787 .33744 .06221 .33145 Mtetra
0 .414 .848 r
.06221 .33145 .06787 .33744 .07446 .34073 .06877 .3349 Mtetra
0 .416 .847 r
.06877 .3349 .07446 .34073 .08109 .34398 .07539 .33831 Mtetra
0 .419 .845 r
.07539 .33831 .08109 .34398 .08778 .3472 .08205 .34169 Mtetra
0 .423 .844 r
.08205 .34169 .08778 .3472 .09451 .35036 .08877 .34501 Mtetra
0 .428 .844 r
.08877 .34501 .09451 .35036 .1013 .35345 .09554 .34828 Mtetra
0 .433 .843 r
.09554 .34828 .1013 .35345 .10815 .35647 .10237 .35147 Mtetra
0 .44 .843 r
.10237 .35147 .10815 .35647 .11505 .3594 .10925 .35457 Mtetra
0 .448 .844 r
.10925 .35457 .11505 .3594 .122 .36223 .11619 .35758 Mtetra
0 .457 .844 r
.11619 .35758 .122 .36223 .12902 .36494 .12319 .36048 Mtetra
0 .467 .845 r
.12319 .36048 .12902 .36494 .13609 .36752 .13025 .36326 Mtetra
0 .477 .847 r
.13025 .36326 .13609 .36752 .14322 .36996 .13737 .36591 Mtetra
0 .489 .848 r
.13737 .36591 .14322 .36996 .15042 .37226 .14455 .36841 Mtetra
0 .501 .849 r
.14455 .36841 .15042 .37226 .15767 .37438 .15179 .37075 Mtetra
0 .514 .85 r
.15179 .37075 .15767 .37438 .16499 .37632 .15909 .37292 Mtetra
.001 .527 .851 r
.15909 .37292 .16499 .37632 .17237 .37808 .16646 .37491 Mtetra
.011 .542 .851 r
.16646 .37491 .17237 .37808 .17981 .37962 .17389 .3767 Mtetra
.022 .556 .851 r
.17389 .3767 .17981 .37962 .18731 .38095 .18138 .37829 Mtetra
.033 .571 .85 r
.18138 .37829 .18731 .38095 .19488 .38204 .18894 .37965 Mtetra
.045 .586 .848 r
.18894 .37965 .19488 .38204 .20251 .3829 .19656 .38078 Mtetra
.057 .6 .844 r
.19656 .38078 .20251 .3829 .2102 .38349 .20424 .38166 Mtetra
.069 .615 .84 r
.20424 .38166 .2102 .38349 .21795 .38383 .21199 .3823 Mtetra
.081 .628 .834 r
.21199 .3823 .21795 .38383 .22577 .38389 .2198 .38267 Mtetra
.092 .641 .826 r
.2198 .38267 .22577 .38389 .23365 .38366 .22767 .38277 Mtetra
.103 .653 .816 r
.22767 .38277 .23365 .38366 .24159 .38315 .2356 .38259 Mtetra
.113 .663 .804 r
.2356 .38259 .24159 .38315 .24958 .38235 .2436 .38213 Mtetra
.121 .671 .79 r
.2436 .38213 .24958 .38235 .25763 .38124 .25165 .38138 Mtetra
.129 .678 .773 r
.25165 .38138 .25763 .38124 .26574 .37985 .25976 .38033 Mtetra
.136 .683 .755 r
.25976 .38033 .26574 .37985 .27391 .37815 .26792 .379 Mtetra
.142 .686 .736 r
.26792 .379 .27391 .37815 .28213 .37615 .27614 .37737 Mtetra
.148 .689 .715 r
.27614 .37737 .28213 .37615 .29039 .37386 .28442 .37543 Mtetra
.154 .69 .695 r
.28442 .37543 .29039 .37386 .29871 .37126 .29275 .37318 Mtetra
0 0 0 r
.29275 .37318 .29871 .37126 .30708 .36834 .30113 .37061 Mtetra
.30113 .37061 .30708 .36834 .31549 .36509 .30956 .36769 Mtetra
.30956 .36769 .31549 .36509 .32396 .36148 .31804 .3644 Mtetra
.31804 .3644 .32396 .36148 .33247 .35746 .32657 .36067 Mtetra
.32657 .36067 .33247 .35746 .34103 .35297 .33516 .35646 Mtetra
.33516 .35646 .34103 .35297 .34958 .34914 .34375 .35261 Mtetra
.34375 .35261 .34958 .34914 .35813 .34597 .35235 .34913 Mtetra
.35235 .34913 .35813 .34597 .36673 .34233 .361 .34516 Mtetra
.274 .758 .661 r
.361 .34516 .36673 .34233 .37537 .33828 .3697 .34076 Mtetra
.342 .807 .71 r
.3697 .34076 .37537 .33828 .38406 .33386 .37844 .33598 Mtetra
.407 .851 .755 r
.37844 .33598 .38406 .33386 .39278 .32911 .38722 .33085 Mtetra
.467 .888 .795 r
.38722 .33085 .39278 .32911 .40154 .32404 .39602 .32538 Mtetra
.524 .918 .83 r
.39602 .32538 .40154 .32404 .41033 .31865 .40486 .3196 Mtetra
.575 .942 .859 r
.40486 .3196 .41033 .31865 .41914 .31296 .41373 .3135 Mtetra
.622 .959 .882 r
.41373 .3135 .41914 .31296 .42799 .30696 .42263 .3071 Mtetra
.662 .971 .899 r
.42263 .3071 .42799 .30696 .43686 .30065 .43155 .30039 Mtetra
.697 .977 .91 r
.43155 .30039 .43686 .30065 .44576 .29404 .44049 .29339 Mtetra
.727 .978 .917 r
.44049 .29339 .44576 .29404 .45468 .28712 .44946 .28608 Mtetra
.751 .977 .92 r
.44946 .28608 .45468 .28712 .46362 .27989 .45844 .27847 Mtetra
.772 .972 .92 r
.45844 .27847 .46362 .27989 .47257 .27236 .46744 .27057 Mtetra
.789 .966 .918 r
.46744 .27057 .47257 .27236 .48155 .26453 .47645 .26239 Mtetra
.802 .958 .914 r
.47645 .26239 .48155 .26453 .49053 .25641 .48548 .25392 Mtetra
.814 .95 .909 r
.48548 .25392 .49053 .25641 .49953 .24801 .49452 .24519 Mtetra
.823 .941 .904 r
.49452 .24519 .49953 .24801 .50854 .23934 .50357 .2362 Mtetra
.83 .932 .898 r
.50357 .2362 .50854 .23934 .51756 .23041 .51262 .22695 Mtetra
.836 .923 .891 r
.51262 .22695 .51756 .23041 .52658 .22123 .52168 .21747 Mtetra
.841 .915 .885 r
.52168 .21747 .52658 .22123 .53561 .21181 .53074 .20776 Mtetra
.844 .906 .879 r
.53074 .20776 .53561 .21181 .54463 .20217 .5398 .19783 Mtetra
.847 .898 .873 r
.5398 .19783 .54463 .20217 .55366 .19232 .54887 .18771 Mtetra
.85 .891 .867 r
.54887 .18771 .55366 .19232 .56269 .18227 .55793 .17739 Mtetra
.851 .883 .861 r
.55793 .17739 .56269 .18227 .57172 .17204 .56699 .1669 Mtetra
.853 .876 .856 r
.56699 .1669 .57172 .17204 .58075 .16163 .57605 .15624 Mtetra
.854 .869 .851 r
.57605 .15624 .58075 .16163 .58977 .15107 .5851 .14543 Mtetra
.854 .863 .847 r
.5851 .14543 .58977 .15107 .59879 .14036 .59414 .13448 Mtetra
.855 .857 .842 r
.59414 .13448 .59879 .14036 .6078 .12951 .60318 .1234 Mtetra
.855 .851 .838 r
.60318 .1234 .6078 .12951 .6168 .11855 .61222 .11221 Mtetra
.854 .845 .834 r
.61222 .11221 .6168 .11855 .6258 .10748 .62124 .10092 Mtetra
.854 .839 .83 r
.62124 .10092 .6258 .10748 .63479 .09631 .63026 .08954 Mtetra
.853 .834 .827 r
.63026 .08954 .63479 .09631 .64377 .08507 .63927 .07808 Mtetra
.852 .829 .824 r
.63927 .07808 .64377 .08507 .65274 .07375 .64827 .06655 Mtetra
.851 .824 .821 r
.64827 .06655 .65274 .07375 .66171 .06238 .65726 .05496 Mtetra
.85 .818 .818 r
.65726 .05496 .66171 .06238 .67067 .05096 .66624 .04334 Mtetra
.848 .814 .815 r
.66624 .04334 .67067 .05096 .67962 .0395 .67521 .03168 Mtetra
.847 .809 .813 r
.67521 .03168 .67962 .0395 .68856 .02803 .68417 .02 Mtetra
.845 .804 .811 r
.68417 .02 .68856 .02803 .69749 .01654 .69313 .00831 Mtetra
0 .396 .844 r
.03716 .31458 .04279 .32106 .04922 .32452 .04356 .3182 Mtetra
0 .395 .841 r
.04356 .3182 .04922 .32452 .05569 .32799 .05001 .32182 Mtetra
0 .395 .838 r
.05001 .32182 .05569 .32799 .06221 .33145 .05651 .32544 Mtetra
0 .395 .835 r
.05651 .32544 .06221 .33145 .06877 .3349 .06305 .32904 Mtetra
0 .397 .833 r
.06305 .32904 .06877 .3349 .07539 .33831 .06964 .33262 Mtetra
0 .399 .831 r
.06964 .33262 .07539 .33831 .08205 .34169 .07629 .33616 Mtetra
0 .403 .829 r
.07629 .33616 .08205 .34169 .08877 .34501 .08299 .33965 Mtetra
0 .407 .828 r
.08299 .33965 .08877 .34501 .09554 .34828 .08974 .34309 Mtetra
0 .413 .827 r
.08974 .34309 .09554 .34828 .10237 .35147 .09655 .34646 Mtetra
0 .419 .826 r
.09655 .34646 .10237 .35147 .10925 .35457 .10342 .34974 Mtetra
0 .426 .826 r
.10342 .34974 .10925 .35457 .11619 .35758 .11034 .35294 Mtetra
0 .434 .826 r
.11034 .35294 .11619 .35758 .12319 .36048 .11732 .35603 Mtetra
0 .443 .826 r
.11732 .35603 .12319 .36048 .13025 .36326 .12437 .35901 Mtetra
0 .452 .826 r
.12437 .35901 .13025 .36326 .13737 .36591 .13147 .36187 Mtetra
0 .463 .826 r
.13147 .36187 .13737 .36591 .14455 .36841 .13863 .36458 Mtetra
0 .474 .827 r
.13863 .36458 .14455 .36841 .15179 .37075 .14586 .36715 Mtetra
0 .486 .827 r
.14586 .36715 .15179 .37075 .15909 .37292 .15315 .36955 Mtetra
0 .498 .826 r
.15315 .36955 .15909 .37292 .16646 .37491 .1605 .37178 Mtetra
0 .511 .826 r
.1605 .37178 .16646 .37491 .17389 .3767 .16792 .37382 Mtetra
0 .525 .824 r
.16792 .37382 .17389 .3767 .18138 .37829 .1754 .37566 Mtetra
0 .538 .822 r
.1754 .37566 .18138 .37829 .18894 .37965 .18294 .37729 Mtetra
0 .552 .819 r
.18294 .37729 .18894 .37965 .19656 .38078 .19055 .37871 Mtetra
.008 .565 .815 r
.19055 .37871 .19656 .38078 .20424 .38166 .19823 .37988 Mtetra
.019 .578 .809 r
.19823 .37988 .20424 .38166 .21199 .3823 .20596 .38082 Mtetra
.029 .591 .802 r
.20596 .38082 .21199 .3823 .2198 .38267 .21377 .38151 Mtetra
.039 .602 .793 r
.21377 .38151 .2198 .38267 .22767 .38277 .22163 .38193 Mtetra
.049 .613 .783 r
.22163 .38193 .22767 .38277 .2356 .38259 .22956 .38209 Mtetra
.058 .622 .77 r
.22956 .38209 .2356 .38259 .2436 .38213 .23755 .38198 Mtetra
.066 .63 .755 r
.23755 .38198 .2436 .38213 .25165 .38138 .2456 .38158 Mtetra
.074 .636 .739 r
.2456 .38158 .25165 .38138 .25976 .38033 .25371 .3809 Mtetra
.081 .641 .721 r
.25371 .3809 .25976 .38033 .26792 .379 .26187 .37993 Mtetra
0 0 0 r
.26187 .37993 .26792 .379 .27614 .37737 .2701 .37867 Mtetra
.2701 .37867 .27614 .37737 .28442 .37543 .27838 .3771 Mtetra
.27838 .3771 .28442 .37543 .29275 .37318 .28672 .37521 Mtetra
.28672 .37521 .29275 .37318 .30113 .37061 .29511 .37299 Mtetra
.29511 .37299 .30113 .37061 .30956 .36769 .30355 .37042 Mtetra
.30355 .37042 .30956 .36769 .31804 .3644 .31205 .36745 Mtetra
.31205 .36745 .31804 .3644 .32657 .36067 .3206 .36404 Mtetra
.3206 .36404 .32657 .36067 .33516 .35646 .32921 .36012 Mtetra
.32921 .36012 .33516 .35646 .34375 .35261 .33785 .35626 Mtetra
.33785 .35626 .34375 .35261 .35235 .34913 .3465 .35245 Mtetra
.3465 .35245 .35235 .34913 .361 .34516 .35521 .34813 Mtetra
.302 .775 .666 r
.35521 .34813 .361 .34516 .3697 .34076 .36396 .34337 Mtetra
.371 .824 .715 r
.36396 .34337 .3697 .34076 .37844 .33598 .37276 .33821 Mtetra
.436 .866 .758 r
.37276 .33821 .37844 .33598 .38722 .33085 .38159 .33268 Mtetra
.496 .901 .797 r
.38159 .33268 .38722 .33085 .39602 .32538 .39045 .32682 Mtetra
.55 .93 .83 r
.39045 .32682 .39602 .32538 .40486 .3196 .39934 .32063 Mtetra
.6 .952 .857 r
.39934 .32063 .40486 .3196 .41373 .3135 .40826 .31412 Mtetra
.644 .967 .878 r
.40826 .31412 .41373 .3135 .42263 .3071 .41721 .30732 Mtetra
.682 .977 .894 r
.41721 .30732 .42263 .3071 .43155 .30039 .42618 .30021 Mtetra
.714 .981 .904 r
.42618 .30021 .43155 .30039 .44049 .29339 .43517 .2928 Mtetra
.742 .982 .911 r
.43517 .2928 .44049 .29339 .44946 .28608 .44418 .2851 Mtetra
.765 .979 .914 r
.44418 .2851 .44946 .28608 .45844 .27847 .45321 .27711 Mtetra
.784 .974 .914 r
.45321 .27711 .45844 .27847 .46744 .27057 .46226 .26884 Mtetra
.799 .968 .911 r
.46226 .26884 .46744 .27057 .47645 .26239 .47131 .2603 Mtetra
.812 .96 .908 r
.47131 .2603 .47645 .26239 .48548 .25392 .48038 .25148 Mtetra
.822 .951 .903 r
.48038 .25148 .48548 .25392 .49452 .24519 .48946 .24241 Mtetra
.83 .942 .898 r
.48946 .24241 .49452 .24519 .50357 .2362 .49855 .23308 Mtetra
.837 .934 .892 r
.49855 .23308 .50357 .2362 .51262 .22695 .50764 .22352 Mtetra
.842 .925 .886 r
.50764 .22352 .51262 .22695 .52168 .21747 .51674 .21373 Mtetra
.846 .916 .88 r
.51674 .21373 .52168 .21747 .53074 .20776 .52583 .20372 Mtetra
.85 .908 .874 r
.52583 .20372 .53074 .20776 .5398 .19783 .53493 .19351 Mtetra
.852 .899 .869 r
.53493 .19351 .5398 .19783 .54887 .18771 .54403 .1831 Mtetra
.854 .892 .863 r
.54403 .1831 .54887 .18771 .55793 .17739 .55313 .17251 Mtetra
.856 .884 .858 r
.55313 .17251 .55793 .17739 .56699 .1669 .56222 .16176 Mtetra
.857 .877 .853 r
.56222 .16176 .56699 .1669 .57605 .15624 .57131 .15084 Mtetra
.858 .87 .848 r
.57131 .15084 .57605 .15624 .5851 .14543 .58039 .13978 Mtetra
.858 .864 .843 r
.58039 .13978 .5851 .14543 .59414 .13448 .58947 .12859 Mtetra
.858 .858 .839 r
.58947 .12859 .59414 .13448 .60318 .1234 .59854 .11728 Mtetra
.858 .852 .835 r
.59854 .11728 .60318 .1234 .61222 .11221 .6076 .10586 Mtetra
.858 .846 .831 r
.6076 .10586 .61222 .11221 .62124 .10092 .61666 .09434 Mtetra
.857 .84 .828 r
.61666 .09434 .62124 .10092 .63026 .08954 .6257 .08273 Mtetra
.856 .835 .824 r
.6257 .08273 .63026 .08954 .63927 .07808 .63473 .07105 Mtetra
.855 .829 .821 r
.63473 .07105 .63927 .07808 .64827 .06655 .64376 .05931 Mtetra
.854 .824 .818 r
.64376 .05931 .64827 .06655 .65726 .05496 .65277 .04752 Mtetra
.853 .819 .815 r
.65277 .04752 .65726 .05496 .66624 .04334 .66178 .03568 Mtetra
.851 .814 .813 r
.66178 .03568 .66624 .04334 .67521 .03168 .67078 .02381 Mtetra
.849 .809 .81 r
.67078 .02381 .67521 .03168 .68417 .02 .67976 .01193 Mtetra
.848 .804 .808 r
.67976 .01193 .68417 .02 .69313 .00831 .68874 4e-05 Mtetra
0 g
.68874 0 m
.96935 .52918 L
s
.96935 .52918 m
1 .80566 L
s
1 .80566 m
.70298 .30259 L
s
.70298 .30259 m
.68874 0 L
s
.03716 .31454 m
0 .60363 L
s
0 .60363 m
.70298 .30259 L
s
.70298 .30259 m
.68874 0 L
s
.68874 0 m
.03716 .31454 L
s
.03716 .31454 m
.68874 0 L
s
.03716 .31454 m
.04196 .32006 L
s
[(-4)] .02757 .3035 1 .93395 Mshowa
.18558 .24289 m
.19014 .24871 L
s
[(-2)] .17646 .23126 .96648 1 Mshowa
.34306 .16687 m
.34735 .173 L
s
[(0)] .3345 .15462 .86223 1 Mshowa
.51046 .08606 m
.51442 .09251 L
s
[(2)] .50253 .07317 .75799 1 Mshowa
.68874 0 m
.69233 .00677 L
s
[(4)] .68156 -0.01354 .65374 1 Mshowa
.125 Mabswid
.07346 .29702 m
.0763 .30038 L
s
.11029 .27924 m
.1131 .28264 L
s
.14766 .2612 m
.15043 .26465 L
s
.22407 .22431 m
.22677 .22785 L
s
.26314 .20545 m
.2658 .20903 L
s
.3028 .18631 m
.30541 .18994 L
s
.38395 .14713 m
.38647 .15086 L
s
.42547 .12709 m
.42794 .13086 L
s
.46763 .10674 m
.47006 .11056 L
s
.55397 .06506 m
.55629 .06897 L
s
.59817 .04372 m
.60044 .04768 L
s
.64309 .02204 m
.6453 .02605 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML00?oG8ML00?oG
8ML00?oG8ML00?oG8ML00<OG00<0emL0E]L00<OG00<0emL0E]L00<CG1@1Ge`00a=L0103Ge`1He`00
aML00`3G001He`00a]L205SG0037e`030=OG00_G1017e`00eML00`3Ge`18e`00e]L00`3Ge`17e`00
cmL400CG00<0emL0A]L00=SG00<0emL0AML00<[G0P09e`040=OG04OG0038e`D02ML204SG0036e`80
0]L00j`0001Ce`00a=L200?G00F/d03A001Be`00`]L200CG0j`00`2/001Be`00`=L200GG00R/dJcA
0=6/057G002ne`801]L5[0040:b/057G002le`8000?G0=L01]L02JcA[=40dJcG001@e`00^]L200WG
1Z`01@2/[:`0053G002he`802mL03:cG[=6/d@3A[=6/04oG002fe`803=L7[0030:b/00:/00<0emL0
CML00;CG0P0=e`0?[=N/ejcG[=6/0:cA[=4004kG002Ee`@06ML200kG2Z`00`2/[002[0030=OG04cG
002Ee`030=OG01SG0P02e`030=OG00[G01:/ejcG[=N/ejcA[02/dJcA[01=e`00U]L00`3Ge`0De`<0
4ML;[0030:b/00>/00<0emL0BmL009OG00<0emL04ML201CG01>/ejcG[=N/ejcG[02/dJcA[=4004cG
002He`030=OG00kG0P0De`f/00<0[:`01:`00`3Ge`1:e`00UML0103Ge`0>e`805]L05ZcG[=N/ejcG
[=N/ej`0[=6/dJcA[01;e`00U]L200gG0P000mL0e`0De`j/00<0[:`01Z`00`3Ge`18e`00XmL201SG
01V/ejcG[=N/ejcG[=N/ej`0[=6/dJcA[=4004[G002Qe`806ML@[0030:b/00N/00<0emL0AmL009oG
0P0Je`0L[=N/ejcG[=N/ejcG[=N/ej`0[=6/dJcA[=6/04WG002Me`806mLB[0030:b/00R/00<0emL0
A]L009_G0P0Ne`0M[=N/ejcG[=N/ejcG[=N/ej`0[=6/dJcA[=6/d@00B=L009WG0P000mL0e`0Kea>/
00<0[:`02J`00`3Ge`15e`00UmL200CG00<0emL06ML08:cG[=N/ejcG[=N/ejcG[=N/ej`0[=6/dJcA
[=6/dJ`0AmL009GG0P0Pe`03d:b/01:/00<0[:`02Z`00`3Ge`14e`00TmL202;G02>/ejcG[=N/ejcG
[=N/ejcG[=N/ej`0[=6/dJcA[=6/dJcA0016e`00T=L302;G00?@[=005:`00`2/[00;[0030=OG04?G
002>e`8000?G0=L08]L09ZcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/0:cG[=6/dJcA[=6/dJ`0AML008cG
0P0Ve`03[=2/01F/00<0[:`03:`00`3Ge`12e`00R]L202OG02V/ejcG[=N/ejcG[=N/ejcG[=N/ejcG
[=N/e`3G[=6/dJcA[=6/dJcA0014e`00R=L202WG00?F[:`05j`00`2/[00<[0030=OG047G0026e`80
:mL0:JcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG0=N/ejcA[=6/dJcA[=6/0080@]L006[G0P0He`80
:mL00mJ/eP0I[0030:b/00f/00<0emL0@=L006WG00@0emL05ML200;G00<0emL0:=L0;JcG[=N/ejcG
[=N/ejcG[=N/ejcG[=N/ejcG[=L0ejcA[=6/dJcA[:f/[Jb]0012e`00JML0103Ge`0Ce`80;ML00mJ/
eP0K[0030:b/00j/00<0emL02]L4037G001Ye`040=OG017G0P0_e`0a[=N/ejcG[=N/ejcG[=N/ejcG
[=N/ejcG[=N/ejcG0=N/dJcA[=6/dJb][:f/[Jb]000=e`030=OG033G001Ye`040=OG00oG0P0`e`06
[=J//Zbb6J`00`2/[00?[0030=OG00_G00<0emL0<=L006WG00@0emL03ML2037G03B/ejcG[=N/ejcG
[=N/ejcG[=N/ejcG[=N/ejcG[=N/e`3G[=N/dJcA[:f/[Jb][:f/[J`01=L400CG00<0emL0<=L006[G
0P0<e`8000?G0=L0;mL02ZcF[;://Zbb[;8G[0030:b/012/00<0emL02]L00`3Ge`0`e`00M]L203?G
03N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG0=N/ejb][:f/[Jb][:f/[Jb][:d000WG
0`0be`00LmL303CG00b//Zbb[;://Zbb[;8G[0030:b/016/00<0emL02ML00`3Ge`0`e`00LML203KG
03Z/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=L0ejcG[:f/[Jb][:f/[Jb][:f/[J`0
?ML006oG0P0he`0?/jbb[;://jbc[;>//jbc00>/00>][:`03j`00`2/[00B[0030=OG03_G001]e`80
00?G0=L0=mL0>jcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/e`3G[;>/[Jb][:f/[Jb]
[:f/[Jb][:d003cG001[e`801=L00`3Ge`0ce`0O/jbc[;>//jbc[;>//jbc[:f/[Jb][:f/[Jb][:f/
[@03[005[Jb/[0005J`00`3Ge`0je`00JML203cG03j/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG
[=N/ejcG[=N/e`2c[;>/[Jb][:f/[Jb][:f/[Jb][:f/03_G001We`80?=L0:K>//jbc[;>//jbc[;>/
/jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/[J`001J/00<0emL0>ML006GG0P0ne`11[=N/ejcG[=N/ejcG
[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N//`2c[;>//jb][:f/[Jb][:f/[Jb][:f/[@00>]L006?G
0P000mL0e`0ke`0]/jbc[;>//jbc[;>//jbc[;>//jbc[:f/[Jb][:f/[Jb][:f/[Jb][:f/0:b]00>/
00>][:`03j`00`3Ge`0he`00HML2043G04B/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG
[;>//jbc[;>/0:bc[:f/[Jb][:f/[Jb][:f/[Jb][:f/03WG001Oe`80@ML0<Zbc[;>//jbc[;>//jbc
[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]0:f/[Jb]0j`00jf/[00<[0030=OG03OG001Me`80
@]L0Ak;G/]N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[;>/ejbc[;>//jbc[02//jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:d003SG000oe`@05mL304?G03Z//jbc[;>//jbc[;>//jbc[;>//jbc[;>/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb]0:f/[Jb][:f/[Jb]3Z`00`3Ge`0ee`00?mL00`3Ge`0Fe`@0@mL0B[;G
/]Nbek;G[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[;>//jbc[;>//jbc[;>/0:bc[;>/[Jb][:f/[Jb]
[:f/[Jb][:f/[J`0=mL0043G00<0emL04mL204KG042//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:d0[Jb][:f/[Jb][:f/[Jb]2j`00`3Ge`0de`00>ML400CG00<0emL0
4=L204OG04fbek;G/]NbejcG[=N/ejcG[=N/ejcG[=N/ejbc[;>//jbc[;>//jbc[;>//jbc[;>/0:bc
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]000fe`00@]L00`3Ge`0=e`80B=L0A:bc[;>//jbc[;>//jbc
[;>//jbc[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb]0j`00jf/
[004[0030=OG03?G000oe`040=OG00gG0P19e`1@/]Nbek;G/]Nbek;G[=N/ejcG[;>/ejbc[;>//jbc
[;>//jbc[;>//jbc[;>//jbc[;>/0:bc[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][00ee`00@=L200cG
0P000mL0e`18e`19/jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/[@03[005[Jb/[000==L004cG0P1=e`1A/]Nbek;G/]Nbek;G
/mN//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>/0:bc[:f/[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb][:d003CG001:e`80CML0E;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jb][:f/
[Jb][:f/[Jb][:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]03?G0018e`80CmL02[;G
/]Nbek?G/mL6/`13[K>]/jfc[K>]/jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[02//jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][00203;G0016e`80C]L0F:bc[;>//jbc[;>//jbc[;>//jbc[;>//jbc
[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]
[00be`00A=L3053G00Bbek;G3[<0AJfc[K>]/jfc[K>]/jfc[K>//jbc[;>//jbc[;>//jbc[;>//j`0
[;>/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]000be`00@]L200?G00<0emL0BmL0F[>//jbc[;>/
/jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[:f/[Jb][:f/[Jb][:f/[Jb][:f/[@2][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb]037G0010e`80DmL00k?G/`0A/`16[K>]/jfc[K>]/jfc[K>]/jfc
[;>]/jbc[;>//jbc[;>//jbc[02//jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/037G000ne`80
DmL0GK>b/k:c[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/000`e`00>mL305?G00>cek<05K<0Ajfc
[K>]/jfc[K>]/jfc[K>]/jfc[K>]/jbc[;>//jbc[;>//j`0[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb][:d0033G000ie`800]L00`3Ge`1@e`1Q/[>b/k:c/[>//jbc[;>//jbc[;>8/hRcR;>//hRc
R;>8/jbcR;>//jb][:f/[Jb][:f/[Jb][:f/[Jb][:d0[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb]000_e`00=mL205KG6;<0Bjfc[K>]/jfc[K>]/jfc[K>]/jfc[K>]/jfc[;>//jbc[;>//jbc
[;<0[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]000^e`00=ML205OG06Bb/k:c/[>b/hjc
R;>8/hRcR;>8/hVcR;>9/hRcR;>8/hRcR;>8/hRcR:f8[HR]R:f8[HR][:f/[Jb][:f/[Jb][02/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[J`01mL202GG000ce`80F=LJ/`1<[K>]/jfc[K>]/jfc
[K>]/jfc[K>]/jfc[K>]/jbc[;>//jbc[;>/[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]
[:f/00GG00@0emL09=L001WG00<0emL05ML205WG06Nb/k:cS[>>/hjcS[>8/hVcRK>9/hVcRK>9/hVc
RK>9/hVcR;>8/hRcR;>8[HR]R:f8[HR]R:f8[HR]R:f8[HR]R:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:d000GG00@0emL09=L001WG00<0emL04mL200;G00<0emL0E=L=/`1MSk>c/hnc
Sk>?/hncSk>?/hVcRK>9/hVc[K>]/jfc[K>]/jfc[K>]/jfc[K>]/jbc[;>//jbc[:d0[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:d000CG00@0emL09=L001KG1@0Be`80F]L0Jk>>/hjcS[>>
/hjcS[>9/hVcRK>9/hVcRK>9/hVcRK>9/hVcRK>9/hRcR;>8[HR]R:f8[HR]R:f8[HR]R:f8[HR]R:f8
[HP0R:f8[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[J`000CG00@0emL09=L0017G10001ML0
emL0017G0P1Ke`Fc06R?/hncSk>?/hncSk>?/hncSk>?/hncRK>9/hVcRK>9/hVcRK>9/hVc[K>]/jfc
[K>]/jfc[K>]/jbc[;>//jb][:d0[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/00?G
00@0emL09=L001OG00<0e`003mL205cG06jcS[>>/hjcSXn>ShR?RHn9ShV?RHn9ShV?RHn9ShV?RK>9
/hVcRK>9/hVcRJf9[HR]R:f8[HR]R:f8[HR]R:f8[HR]R:f8[HP0R:f8[HR]R:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb]00CG0P0Ue`006=L200gG0`1Le`07/hncSk>?/`03S`03/hn?00b?05N9ShV?
RHn9/hVcRK>9/hVcRK>9/hVcRK>9/hVc[K>]/jfc[K>]/jfc[K>/[Jb][:d0[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[@00:]L001WG00<0emL02ML205kG04VcSXn>/hj?R8n8SfB?I8n9
SfF?IHmUSfF?IHmUShV?RHn9ShV?RHn9ShV?RJf9[HV]RJf8[HR]R:f8[HR]R:f8[HR]R:f8[HR]0080
02J8[HR]R:f8[HR]R:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/02[G000Se`80G]L018jcS[<6S`0o
JhmUSfF?IHmUSfF?IHmUSfF?IHn9ShV?RHn9ShVcRK>9/hVcRK>9/hVcRK>9/hVcRK>]/jfc[K>]/jfc
[:f/008002V][02/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/000Ye`008=L305oG
01V>Shj?R8mTSfA[I6]TJfA[I6E0ID1U@6E000QU00J9IHUURFD>R@0C[HV]R:f8[HR]R:f8[HR]R:f8
[@02000[R:f8[@2]R:f8[HR]R:f8[HR]R:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]000Ye`007mL2063G
00j>/hj?SXn>JfA[@6E0I@=000a1@450@D1U@6E1ID44I@0SSfF?IHn9ShV?RHn9ShVcRK>9/hVcRK>9
/hVcRK>9/hVcRK<00Zd3000^[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb]02SG000Oe`80GmL01XR?I8mTS`9T0T000`3Ge`0=e`<F0SX2@@03ID5U00=U00R9IHUURFF9I@Z9
00b]RJf8[HR]R:f8[HP2000`[HR]R:f8[HR]R028[HR]R:f8[HR]R:f8[HR][:f/[Jb][:f/[Jb][:f/
[Jb][:f/0P0We`005mL200KG0P000a3Ge`1Je`08Shj?I8mTJ`0He`06>aHk>fE116D06hmUSfF?RHn9
ShVcRK>9/hVcRK>9/hVcRK>9[@0200R]02b/[Jb][02/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb][:f/02OG000Fe`040=OG00GG00<0ea000Q1He`04I8iTI09000<iemL07=L25P8k0T44I@04
RFF9I@f900B8[HR]0`00=Zf8[HR]R:f8[HR]R:f8[HP0R:f8[HR]R:f8[HR]R:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb]02OG000Fe`040=OG00CG00L0emOG4A0A05KG00MTSVATS[:>027G00<@>c/016D018UU
RFD8R@08ShVcRJf9[HT2000:[HV]RJf9[HV]R@>]02f/[Jb][:d0[Jb][:f/[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[@009]L001KG00@0emL01=L200?G111Be`0406ATI0:>0k8Re`0941LF>cYU
>fEO00AU00B9IHUU1hT2000mRJf8[HR]R:f8[HR]R:f8[HR]R:f8[@2]R:f8[HR]R:f8[HR]R:f8[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb]000Ue`005]L0103Ge`04e`030=OG00?G00Dk41L@4@1=e`0406B>?`:>
00BcS[>b9]L2408k00I1>fEURFD9R@<000j]RJf9[HV]RJf9[HV]R@F]02b/[Jb][02/[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/02GG000Fe`040=OG00CG00<0emL01=L00a4@4@0344[G
00P0?fATSXRbSPBb9mL00a0G5P02>`04IEmUG`9U00B9IHUU0P07R@0lR8V8[HR]R:f8[HR]R:f8[HR]
R:f808R]R:f8[HR]R:f8[HR]R:f8[Jb][:f/[Jb][:f/[Jb][:f/[J`09=L001OG0P05e`030=OG00GG
00LG41L@4A0A04OG00aT?hj>/hjcS[>bek8Ye`0343/k008k0VD01HUURFF900801HT04:f9[HV]RJf9
[HV]RJf9[HT3[@0]RJf/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:d002CG
000Ne`030=OG00GG00H@4A0A414244?G00AT001T18h00k>>/`03/P03e[;G02SG00<@5aH00S/00fEO
I@030004REn9I@N903f8RHR9R:f8[HR]R:f8[HR]R:f8[HR]0:f8[HR]R:f8[HR]R:f8[HR]R:f/[Jb]
[:f/[Jb][:f/[Jb][:d002?G000Me`802=L02A0k43/@5a0A400oe`8000mTSXj?S[>b/k:c/]Nbek80
:mL01A0k>fDk008000B9IHUU2XT0?Jf9[HV]RJf9[HV]RJf9[HR][:f/[Jb]0:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb][0008mL001kG00<0emL01mL0210A414@4A0A110ie`0C03mTI8j8
ShjcS[>b/k:c/]JbeP0/e`0=41L003]U>fEOIEn9I@07R@0fR8V8RHR]R:f8[HR]R:f8[HR]R:f8[HP0
R:f8[HR]R:f8[HR]R:f8[HR][:f/[Jb][:f/[Jb]1j`00`3Ge`0Pe`007ML00`3Ge`09e`0=43/@>a0G
41L@5a0G400ee`80015TSfZ?S[>>/k:c/[>bek;G/P0]e`<00S/016DkIEl2I@03RFF900V903b]RJf9
[HV]RJf9[HV]R:f8[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[@0Re`00
7ML00`3Ge`0:e`0:43/@5a0G414@4@@@<ML05`0oJVB?R8n>ShjcS[>b/k:c/]NbeZcF02WG0P02e`8@
04DG=5lkIC]UGfEOREn9PhV3RH>9R8V8RHR]R:f8[HR]R:f8[HR]R:f8[@2]R:f8[HR]R:f8[HR]R:f8
[HR][:f/[Jb][:d02Z`00`3Ge`0Oe`007ML200_G014k4C/A>a0k41L@5a0G41L@5`0/e`0906]TSfZ?
S[>?00Fc00Vb/k;G/]Nbek80:ML200KG00<@>c/00S/01VEOREn9I@R903f]RJf9[HV]RJf9[HV]RJf8
[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[J`0027G000Me`030=OG00cG
014@>a0k43/@5a0G41L@5a0F400We`0J06ATJfB?I8n8ShjcS[>>/k:c/[>b/jcG[=HVe`<02ML00a0k
=002>`0mIC]UGhUOREn9PhV3RH:9PXV8RHR]R:f8[HR]R:f8[HR]R:f8[@2]R:f8[HR]R:f8[HR]R:f8
[Jb][:f/[@0=[0030=OG01kG000Me`030=OG00gG01@e>cDk4C/A>a4k43/@5aHG41L@5b7G00H0@6]T
SfX4S`03/hnc00Fc00cG/]Nbek;G/]Nbek8Re`803ML02a4k>elkIEn9GhUO00R903b]RJf9[HV]RJf9
[HR]R:f8[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[@0Pe`007ML00`3G
e`0=e`0H>a0k43/@>a0G41L@5a0G41L@5a0F41H@6ML00aE0@002I00NJfB?I8n8ShjcS[>>/hjc/[>b
/jbc[=N/eZcF[=J/7mL200oG03lk43/dGc]O>fEOREn9GhV3RH:9PXV2RH:]PZf2[H:]R:f8[HR]R:f8
[HP0R:f8[HR]R:f8[HR]R:f8[HR][:d04:`00`3Ge`0Me`007ML00`3Ge`0>e`Dk01HG>aLk5c/G>aLk
5S/F>aHk5S/F5aHG4=L02aI0@6E0JfA[IHmU00J?00>cSk<01K<03]Ncek;G/]Nbek;G/]N/7]L201?G
00<e>c/00Ul016EOREl:R@0k[HV]RJf9[HV]RJf8[HR]R:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][0007mL001gG00<0emL03mL07c/d>a0k43/@>a0k43/@>a0k41LF>aHG5S/F
5aHG5S/01AH0;40F@3Y1@6E0ID1UI6]TSfF?IHn9ShVcRK>>/hjc[;>//jbc[;>/ejcF[=J/7=L301KG
00<@>cX015l0=FEOREn9GhUNRH:9PXV2RH:9PXV2[H:]PZf2[H:]PZf8[@2]R:f8[HR]R:f8[HR]R:f8
[Jb]016/00<0emL07=L001cG00<0emL04ML=>`075c/k>aLk5`03>`0;5d4k@C]1>d4k@C/014403VE1
IFE[IF]USfF?RHn90Xl01;>?/hl:/`0<ek;G/]NbejcG[=N/6ML201WG00@k=Elk0Ul026EOREn9PhV3
18T0?:f9[HV]RJf9[HV]R:f8[HR][:f/[J`0[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb]01kG000Le`030=OG01;G02Pk=3/d>a0k43/@>a0k5S/F>aHk5S/F>cXk>S/j@CY1>T4jID5U@FE1
16D09XmUSfF?RHn9ShV?RK>9/hRc[;>//jbc[;>//jbc[=J/eZcF[=2/5=L201cG00@k=3/j0Ul0<fEO
REn9GXUNREj9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[H80PZf2[H:]R:f8[HR]R:f8[@0D[0030=OG01_G
000Le`030=OG01;G5C/0444k@C]1>fDkID5U@FE1ID44I@08SfF?IHn9ShT2S`06/hncSk>?2[<03]Nb
ek;G[=N/ejcG[=J/4]L301oG0S/02UlkIEn9GhUORH<6R@0k[HV]RJf9[HV]R:f8[HR]R:f/[Jb][02/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][0001mL401;G000Le`030=OG01CG018k=3/d
>cXk=3/j>cXk>S/j>cX4>`0<@C]1>d4kIC]U>fE126D098mUShV?RHn9ShVcRK>9/hRc[;>//jbc[;>/
/jcG[=J/eZc@[17G0P0Re`0h=3/dGcYOGUmNREj9GXV2RH:9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[@2]
PZf2[H:]PZf8[HR]R:dE[0030=OG00KG00<0emL04ML001_G0`0Fe`03Gc]O00dk00aU>fDkIC]U>fDk
ID48I@0@SfF?IHn9ShV?RK>9/hVcS`Zc00kG/]NbejcG[=N/ejcG[13G0P0Ue`03=Elk009O00YUGhUO
REn9PhV318T0>jf9[HV]RJf8[HR]R:f8[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:f/[J`000OG00<0emL04ML001cG00<0emL05ML03CXk>S/j>cXk>S/j>cX02S/026DkIC]U>fDk
1VD0:HUURFF?IHn9ShV?RK>9/hVcRK>8/hRc[;>//jbc[;>//jbb[=J/d:c@00_G0`0We`0h>cAO>UmN
GeiOGXUNREj9PXV2RH:9PXV2RH:9PZf2[H:]PZf2[H:]PP22[H:]PZf2[H:]PZf8[8PE[0030=OG00GG
00<0emL04ML000SG0P04e`030=OG00;G0`06e`030=OG01KG01TkGc]O>elkGc]O>elkGc]U>fDkIC]U
>fEO00IU01J9IHUURFF?IHn9ShV?RHn9/hVcRK>]0k<05Jfc[K>]/jgG[=N/ejcG[=N/ejcG[009e`80
:mL2>`AO00Z9GhUORH>9PhV30XT0?:f9[HV]R:f8[HR]R:f8[HR][:f/[J`0[:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb]00KG00<0emL04ML000OG00@0emL02mL00`3Ge`02e`030=OG01SG
00Lj>cXk>S/j00Xk00iO>fDkIC]U>fDkIEmUG`AU00B9IHUU18T06hn9ShVcRK>9/hVcR;>//jbc[;>/
/jbc[;://P03[005d:c@[=001ML202kG03Hk=5ljGeiOGXUNREj9PXV2RH:9PXV2RH:9PZf2[H:]PZf2
[H:]PZf208:]PZf2[H:]PZb2[8PF[0030=OG00;G0`0Ce`001mL0103Ge`0;e`030=OG00;G00<0emL0
6ML05c]O>elkGc]O>elkIC]U>fDkIC]U>fEO00IU03:9IHUURFF?IHn9ShV?RK>9/hVcRK>9/jfc[K>]
/jfc[;>/ejcG[=N/ejcG[=N/eZcFe`<0<=L00cAO>`04G`0:REn9GhV3RH>9P`:903^]RJf9[HR]R:f8
[HR]R:f8[Jb][:d0[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/0005e`030=OG017G
0007e`040=OG00SG0`05e`806mL01SYO>UljG`Dk019O>elkGc]O>fDkIC]UGfEOIEl4I@04RFF9I@R9
01FcRK>9/hVcR;>//jbc[;>//jbc[:d01j`00m2/d00203CG03LdGcAOGUmNGej3GXUNRH:9PXV2RH:9
PXV2RH:]PZf2[H:]PZf2[H:]0:f2[H:]PZf2[8:/R:b801F/00<0emL05mL000OG00@0emL02=L00`3G
e`05e`030=OG01[G01IO>elkGc]O>elkIC]U>fDkIEmUGfEO1VD01XUURFF9I@:902J?RHn9ShV?RK>9
/hVcRK>]/jfc[K>]/jbc[;>/ejcG[=N/ejcG[08000?@[=L0<mL00eldG`03G`18Pen9GhUORH>9PhV3
[H>]R:f8[HR]R:f8[HR]R:f/[Jb][02/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:d0
6=L000OG00@0emL02=L00`3Ge`05e`030=OG01cG01/jGcYO>elkGc]O>elkGc]O>fDkIEmUGfEOIEl0
0VD01XUURFF9I@R901F]RJf9/hVcR;>8/jbc[;>//jb][:d01J`30003[=2/03KG03Hk=5mNGeiOGUmN
Pej9PXV2RH:9PXV2RH:]PZf2[H:]PZf2[H:]PZf208:]PZf2[8:/PZb2[:HF[0030=OG01KG0008e`80
2ML400CG00<0emL07ML05C]O>elkIC]U>fDkIEmUGfEOIEmUG`02I@08RFF9IHUURFD4R@0OShV?RK>9
/hVcRK>]/jfc[K>]/jfc[;>/ejcG[=N/e`020005[=N/ej`0=]L00c/dG`03G`19Pen9GhUORH>9PhV3
RH>]PZf8[HR]R:f8[HR]R:f8[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
000Ge`006mL00`3Ge`0Me`0JGcYO>elkGc]O>elkGc]O>fDkIEmUGfEOIEl2I@06RFF9IHUU2XT05:f9
[HR]R:f8[Jb][:f/[Jb][:f/0P08[3KG03Pe=5ldGeiOGX=NPej9GXV2RH:9PXV2RH:]PZf2[H:]PZf2
[H:]PZf2[@2]PZf2[8:/PZb2[:J/YQF/00<0emL05ML001_G00<0emL07]L3G`0A>fDkIEmUGfEOIEmU
GfEOIEl016D01XUURFF9I@J901R?RK>9/hVcRK>9/hVc[K>]/jfc[K>//j`3000;[=N/ejcG[=N/dJ`0
=ML01CAO=5mN009O04R3GhUORH>9PhV3RH:9PZf2[H:]R:f8[HR]R:f8[Jb][:f/[@2][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[@0Fe`006]L00`3Ge`0Pe`0PGc]O>elkGc]O>elkGc]U>fEO
IEmUGfEOIEn9GhUURFD:R@0?[HV]R:f8[HR]R:f/[Jb]008000B/[Jb]2j`ee`0g=5ldGeiOGUmNPej3
GXUNRH:9PXV2RH:9PZf2[H:]PZf2[H:]PZf2[H80PZb2[8:/PZb2[8:/YP0F[0030=OG01CG000Je`03
0=OG027G01aUGfEOIEmUGfEOIEmUGfEOIEmUGhUORFF9IHUU28T04[>9/hVcRK>9/jfc[K>]/jfc[080
01:c[;>//jcG[=N/ejcA[=2/d:`de`1?GcAOGUmNPen9GhV3RH>9PhV2RH:]PZf2[HR]R:f8[HR]R:f8
[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/000Ee`006]L00`3Ge`0Re`0<
Gc]O>elkGc]O>elk0Ul046EOIEmUGfEOIEn9GhUORFD<R@08[HR]R:f8[HP30008[:f/[Jb][:d=[3CG
03Xe=5ldGeiOGX=NPej3GX>2RH:9PXV2RH:]PZf2[H:]PZf2[H:]PZf2[@2/PZb2[8:/PZbV[:J/YZbV
4j`00`3Ge`0Ce`006]L00`3Ge`0Re`0KGfEOIEmUGfEOIEmUGfEOIEmUGhUORFF9IHUU00Z900^]RJf9
/hVcRK>9/`02000H[K>//jbc[;>//jbc[=6/dJcA[=6/d:c@==L0CcAO=5mNPen3GhUORH:9PXV2RH:9
PZf2[H:]PZf8[HR]R:f8[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[@00
5=L001[G0P0Te`09>elkGc]O>elk00AO019UGfEOIEmUGfEOREn9GhUORFD9R@05R:f8[HP00P003Jf8
[HR]R:f/[Jb][:d03Z`ce`0l=CAO=5mNGeiOGX=NPej3PXV2RH:9PXV2RH:]PZf2[H:]PZf2[H:]PZb2
[02/PZb2[8:/YZbV[:J/YZbV4Z`00`3Ge`0Be`006]L00`3Ge`0Te`0KGfEOIEmUGfEOIEmUGfEOIEn9
GhUORFF9IHUU00R900J]RJf9[HT3000NRK>9/jfc[;>//jbc[:f/[JcA[=6/dJcA[=6/d:c@<mL0CemH
GeiOGX=NREj9PXV2RH:9PZf2[H:]PZf2[H:]R:f8[HR]R:f/[Jb][02/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][0004mL001[G00<0emL09ML=G`0@IEmUGfEOIEn9GhUOREn9G`V90P004XR]
R:f8[HR]R:f8[Jb][:f/[@n/<]L2=00jFCAOF5mNPej3GX=NPh:3PXV2RH:9PXV2[H:]PZf2[H:]PZf2
[H:/PZb208:/PZb2[8:/YZbV[:J/YQB/00<0emL04=L001[G00<0emL09]L06EmUGfEOIEmUGfEOIEmU
GhUOREn9IHUURFD02XT20006[HV]RJf91:d06[>][Jbc[:f/[Jb][:f/[JcA[:f/dJc@[=2/<ML0DCAI
=5mHGej3GX=NREj9PXV2RH:9PZf2[H:]PZf2[HR]R:f8[Jb][:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/dJcA000Be`006ML00`3Ge`0Xe`]O019UGfEOIEmUGhUOREn9GhUOREl2R@<0
0XT058R9R:f8[HR]R:f8[HR][:f/[Jb]4:`00jKGe`0_e`0m=5PdGeQOGUmNPej3GX=NPh:9PXV2RH:9
PXV2[H:]PZf2[H:/PZb2[8:/PZ`0[8:/PZb2[:J/YZbV[:J/YP0C[0030=OG00oG000Ie`80:ML066EO
IEmUGfEOIEmUGhUOREn9GhUORFF9I@F90P03R@0:[HV]RJf9[HV]R@F]01R/[Jb][:f/[Jb][:f/[Jb]
[=2/d:c@[=0ae`1AGcAOF5mNGej3GX>2RH:9PXV2RH:]PZf2[H:]PZf2[H:]R:f8[Jb][:f/[Jb]0:f/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][=6/dJ`0017G000Ie`030=OG02[G2El046EOIEmUGfEO
IEn9GhUOREl20003RH>900:901R8RHR9R:f8[HR]R:f8[HR]R:f/[Jb][:d<[004YZbV[37G03aH=5iH
GeQOGX=NPej3GX>2Ph:9PXV2RH:9PZf2[H:]PZf2[H:/PZb2[8:/PP22[8:/PZbV[:J/YZbV[:HD[003
0=OG00kG000Ie`030=OG02_G01EOIEmUGfEOIEn9GhUOREn9GhUORFD00`09R@0W[HV]RJf9[HV]RJf/
[Jb][:f/[Jb][:f/[Jb][:f/[Jc@[=2/d:c@033G054dGeQOF8=NPej3GX>2RH:9PXV2RH:]PZf2[H:]
PZf2[HR]R:f/[Jb][:f/[J`0[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[JcA[=6/d@004=L001WG
00<0emL0:mL:G`09IEmUGfEOIEn90080029OREn9GhUORH>9R8V8RHR9R8V8[HR]R:f8[HR]R:f/[Jb]
2Z`02:J/YZbV[:J/0mL00jcGe`0Xe`0o=5PdGSANF5mNPej3GX=NPej3PX>2RH:9PXV2[H:]PZb2[8:/
PZb2[8:/PZb2[02/PZb2[:J/YZbV[:J/YZbV01>/00<0emL03ML001WG00<0emL0;=L046EOIEmUGfEO
IEn9GhUOREl20004REn9I@b9026]RJf9[HV]RJf9[Jb][:f/[Jb][:f/[Jb][:f/[Jb][=000j`01]2/
d=O@[2[G05=I=5mHGeQOGX=NPej3PX>2RH:9PZf2[H:]PZf2[H:]PZf2[HR][:f/[Jb][:f/[@2][:f/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb][=6/dJcA[=6/000?e`006ML202kG25l016EOIEl3000VGhUOREn9
GhUOREn9PhV2RHR9R8V8RHR]R:f8[HR]R:f8[HR][:d:[00=YZbV[:J/YZbV[:J/YP0Ze`0nF3AHF5iH
GeR3GX=NPej3PX>2Ph:3PXV2RH:]PZf2[8:/PZb2[8:/PZb2[8:/PP22[8:/YZbV[:J/YZbV[:HD[003
0=OG00cG000He`80;mL02UmUGfEOIEn9GhT20009GhUOREn9GhUU00Z902>]RJf9[HV]RJf9[HV]R:f/
[Jb][:f/[Jb][:f/[Jb][:f/[@03[007d:c@[=2/d00Ze`1C=5QHGeR3GX=NPej3GX>2RH:9PXV2[H:]
PZf2[H:]PZf2[H:]PZf/[Jb][:f/[J`0[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][=6/dJcA[=6/d@00
3]L0013G1004e`030=OG033G1Ul2000[IEmUGfEOREn9GhUOREn9GhUORH:9PXV2RHR9R:f8[HR]R:f8
[HR]R:f8[@08[00@YZbV[:J/YZbV[:J/YZbV[2SG00TdF3AH=5iHGUP00Uh0=X=NPej3GX>2Ph:3PXV2
RH:9PZb2[8:/PZb2[8:/PZb2[8:/PZb208:/YZbV[:J/YZbV[:J/YQ>/00<0emL02mL001;G00<0emL0
0mL00`3Ge`0ae`03REl0008000mOREn9GhUOREn9GhUOREl038T07jf9[HV]RJf9[HR]R:f/[Jb][:f/
[Jb][:f/[Jb][:d01J`01]2/[:c@[2OG0eP0DeiHGeQOGX=NPej3PX>2Ph:9PXV2[H:]PZf2[H:]PZf2
[H:]YZf/[Jb][:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][=6/dJcA[=6/dJ`000OG1002e`00
4]L00`3Ge`03e`030=OG037G0P05G`14IEmUGfEOIEn9GhUOREn9GhUOREj9PXV2RH:9PXV2[HR]R:f8
[HR]R:f8[HR/PZbV[:J/YZbV[:J/YZbV[:J/YZbV[:HVe`04F3AH=09H03iNF5iHPUR2GX=NPej3PX>2
Ph:3PXR2R8:/PZb2[8:/PZb2[8:/PZb2[8:/PZ`0[:J/YZbV[:J/YZbV[:J/YQ:/00<0emL01=L00`3G
e`03e`004]L00`3Ge`03e`030=OG02oG0P005=MOREn9GhUOREn9GhUOREn9GhUO38T07Jf9[HV]RJf9
[HR]R:f8[Jb][:f/[Jb][:f/[Jb]00^/00?@[=000mL00m3Ge`0Pe`=H05ANF5mHPej3GX=NPh:3PX>2
RH:9PZf2[H:]PZf2[H:]PZf2[JJ]YZf/[Jb][:f/[J`0[:f/[Jb][:f/[Jb][:f/[Jb][:f/[JcA[=6/
dJcA[=6/d@07e`030=OG00;G000Be`030=OG00?G0P0]e`<01=L7G`16IEmUGfEOREn9GhUOREn9GXV2
RH:9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[H:/PZbV[:J/YZbV[:J/YZbV[:J/YZbV[=N/YB?G0UP00cAH
F002F009GUQNF89NPej300V202Z8PXR2[8:/PZb2[8:/PZb2[8:/PZb2[8:/PP2V[:J/YZbV[:J/YZbV
[:HC[0030=OG00GG00<0emL00ML0013G0`05e`030=OG02[G0P08e`0EGhUOREn9GhUOREn9GhUOREn9
GhV300Z901f]RJf9[HV]RJf8[HR][:f/[Jb][:f/[Jb][:f/[@0<[005Y]2Vd:H07mL00eSGe`02F01E
GUQNF5mHPej3GX>2Ph:3PX>2RH:9PZf2[H:]PZf2[H:]PZf2[JJ][:f/[Jb][:f/[J`0[:f/[Jb][:f/
[Jb][:f/[Jb][=6/dJcA[=6/dJcA[=6/0008e`400ML1e`004]L00`3Ge`03e`030=OG02SG0P0;e`MO
04EUGfEOIEn9GhUOREn9GXUNRH:9PXV2RH:9PXV2RH:]PZf2[H:]PZf2[H:]PZb2[:J/YZbV[:J/YZbV
[:J/YZbV[:F/YJ`07mL00eQGF005F00<GUQNF89HPUj2GX9N2X80:8R2[8:/PZb2[8:/PZb2[8:/PZb2
[8:/PZ`0[:J/YZbV[:J/YZbV[:HD[0030=OG00;G00@0emL00]L001OG00<0emL09mL200kG01EOREn9
GhUOREn9GhUOREn9GhV3RH<02XT06jf9[HV]RJf9[HR]R:f/[Jb][:f/[Jb][:f/[@0:[007YZbV[:J/
YP03e`03Y]OG01WG05]HPUR2F5iHGUR3F8=NPej3PX>2Ph:3PXV2[H:]PZf2[H:]PZf2[H:]PZfV[JJ]
[:f/[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/[JcA[=6/dJcA[=2/d:c@[=0000GG0P03e`005mL00`3G
e`0Te`<04ML5G`19IEmUGfEOREn9GhUOREj9GXUNRH:9PXV2RH:9PXV2RH:]PZf2[H:]PZf2[H:/PZb2
[8:/YZbV[:J/YZbV[:J/YJbU[:F/YMNU[00Je`03EeQG00QH00YNF89HPUR2GX9N2X80:XR2R8:/PZb2
[8:/PZb2[8:/PZb2[8:/PZbV0:J/YZbV[:J/YZbV[:J/YQ6/00?G0=L02ML001OG0P0Se`805=L05XUO
REn9GhUOREn9GhUOREn9GhV3RH<8R@0M[HV]RJf9[HR]R:f8[HR][:f/[Jb][:f/[Jb][:d01Z`03JJ/
YZbV[:J/YZbV[:H00mL01:KGej`Ce`1IPUR2F89HPUR2F8=HPeR3GX>2Ph:3PX>2Ph:9PZf2[H:]PZf2
[H:]PZf2[JJ]YZfV[JJ][:f/[Jb][02/[Jb][:f/[Jb][:f/[Jb][:f/dJc@[=2/d:c@[=000]L00`3G
e`08e`005mL00`3Ge`0Pe`805mL6G`1>IEmUGfEOREn9GXUNREj9GXUNRH:9PXV2RH:9PXV2[H:]PZf2
[H:]PZf2[8:/PZb2[8:/YZbV[:J/YZbV[:J/YJbU[:F/YJbUejFVejJU1ML00h7Ge`0;e`04EgaGO0EH
00YNF5iHPUR2F89N3X80::b2[8:/PZb2[8:/PZb2[8:/PZb2[8:/YZbV0:J/YZbV[:J/YZbV[:H?[0?G
00<0emL02=L001OG00<0emL07ML301_G01MOREn9GhUOREn9GhUOREn9GhV3RH>9P`06R@0K[HV]RJf9
[HR]R:f8[HR][:f/[Jb][:f/[Jb]00B/01JV[:J/YZbV[:J/YZbV[:J/YZbV[:J/1=L00jFVe`0<e`19
PUR2F89HPUR2F89HPej3GX>2Ph:3PX>2Ph:9PZf2[H:]PZf2[H:]PZf2[JJ]YZfV[JJ][:f/[Jb][:d0
[Jb][:f/[Jb][:f/[@03[00;d:c@[=2/d:c@[=001ML00`3Ge`07e`005mL00`3Ge`0Ke`807mL5G`1=
IEmUGhUOREj9GXUNREj9GXUNRH:9PXV2RH:9PXV2[H:]PZf2[H:]PZb2[8:/PZb2[:J/YZbV[:J/YZbV
[:F/YJbU[:F/YJbUYZFVYJH00]L01X6VPMN1YPCG00YkPW^2Nh9GPUMl1EP035iHGUR2F89HPUR2GPb2
02Z/PZb2[8:/PZb2[8:/PZb2[8:/PZb2[8:/YZ`0[:J/YZbV[:J/YZbV[:H<[0GG00<0emL01mL001OG
00<0emL06ML2027G01Z9GhUOREn9GhUOREn9GhUOREn9PhV3RH>9P`:903J]RJf9[HR]R:f8[HR]R:f/
[Jb][:f/[Jb][:f/[JJ/YZbV[:J/YZbV[:J/YZbV[:J/YZbV[:H2e`03[:FV00>V0]L0CjJ2YX:VO89l
PWb2F89HPUR2F89HPUj3GX>2Ph:3PX>2Ph:3PZf2[H:]PZf2[H:]PZf2[H:]YZfV[JJ]YZf/[Jb][:f/
0:b][:f/[Jb][:d01J`02m2/d:c@[=2/d:c@00GG00<0emL01mL001OG00<0emL05]L302CG25l0KVEN
REj9GXUNREj9GXUNRH:9PXV2RH:9PXV2RH:]PZf2[H:]PZf2[8:/PZb2[8:/PZbV[:J/YZbV[:J/YJbU
[:F/YJbUYZFVYJKGYX6VPJJ1Y]NVPH9kPW^2Nh9GPUMlEgaHPUQNF5iHPUR2F89H4880:ZJ2[8:/PZb2
[8:/PZb2[8:/PZb2[:J/YZbV0:J/YZbV[:J/YZbV[:J/YPV/1]L00`3Ge`07e`005]L00`3Ge`0Ee`80
:=L06XUOREn9GhUOREn9GhUOREn9PhV3RH>9PhV30XT0=jf9[HV]R:f8[HR]R:f8[Jb][:f/[Jb][:fV
[JJ/YZbV[:J/YZbV[:J/YZbV[:J/YZbV[:J/YZ`01ZH0C8:VPZJ2YWb2O89lPUR2F89HPUR2F89HPej3
PX>2Ph:3PX>2Ph:]PZf2[H:]PZf2[H:]PZfV[JJ]YZfV[JJ][:f/[Jb][:d0[Jb][:d7[00;d:c@[=2/
d:c@[=001mL00`3Ge`07e`005]L00`3Ge`0Ce`80:]L7G`1^IEiUGXUNREj9GXUNREj9GXUNRH:9PXV2
RH:9PZf2[H:]PZf2[8:/PZb2[8:/PZb2[8:/PZbV[:J/YZbU[:F/YJbUYZFVYJJUYX6VPJJ1YX6VPJJ1
PW^2Nh9kPUN2Eh9GO5R2F89HPUR2F89HPUP@PP0ZYX:/PZb2[8:/PZb2[8:/PZb2[8:/PZbV[:J/0:bV
[:J/YZbV[:J/YZbV1j`8e`030=OG00OG000Fe`030=OG013G0`0]e`1@GhUOREn9GhUOREn9GhUOREn9
PhV3RH>9PhV3RH>]RJf8[HR]R:f8[HR]R:f8[Jb]YZfV[JJ]YZbV[:J/YZbV[:J/YZbV[:J/YZbV[:J/
YZ`6YP08PZJ2YX:VPZH2PP0?O89lPWb2F89HPUR2F89H00:202f3PX>2Ph:3PX>2Ph:]PZf2[H:]PZf2
[H:]PZfV[JJ]YZfV[JJ]YZf/[Jb][:d00Z`00`2/[00:[008d:c@[=2/d:`8e`030=OG00OG000Fe`03
0=OG00kG0P0be`EO06mNIEiUGXUNREj9GXUNREj9GXV2RH:9PXV2RH:9PXV2[H:]PZf2[8:/PZb2[8:/
PZb2[8:/PZbV[8:/YZbU[:F/YJJUYZFVPJJ1YX6VPJJ1YX6VPJIkYW^2Nh9GPUN2Eh9HPUR2F89HPUR2
F89HPUh03880;:J2YX:VPZb2[8:/PZb2[8:/PZb2[8:/PZbV[:J/YP2V[:J/YZbV[:J/YZbV1Z`9e`03
0=OG00OG000Fe`030=OG00cG0P0ee`1=REn9GhUOREn9GhUOREn9GhV3RH>9PhV3RH>9PhV2[H:]R:f2
[HR]PZf2[HR]YZfV[JJ]YZfV[:J/YZbV[:J/YZbV[:J/YZbV[:J/YZ`01ZH028:VPZJ2YX:V0X803gb2
O89lPUR2F89HPUR2F004PP0YPh:3PX>2Ph:3PZf2[H:]PZf2[H:]PZf2[H:]YZfV[JJ]YZfV[Jb][:d0
1J`00`2/[009[006d:c@[=2/2]L00`3Ge`07e`005ML200_G0`0ge`IO06]NGeiUGXUNREj9GXUNREj9
GXV2RH:9PXV2RH:9PXV2[H:]PZf2[8:/PZb2[8:/PZb2[8:/PZb2[:J/PZb2[:FVPJJ1YX6VPJJ1YX6V
PJJ1YX6VNjIkPW^2Nh9GPUN2Eh9HPUR2F89HPUR2F00@PP0/YX:VPZb2[8:/PZb2[8:/PZb2[8:/PZbV
[:J/YZ`0[:J/YZbV[:J/YZbV[:H2[0cG00<0emL01]L001KG00<0emL01mL203_G04aOREn9GhUOREn9
GhUOREn9GhV3RH>9PhV3RH>9PhV2[H:]PZf2[H:]PZf2[H:]YZfV[JJ]YZbV[:J/YZbV[:J/YZbV[:J/
YZbV[:J/2:H05h:VPZJ2YX:VO89lPWb2O89lPUR2O89l00B202J3PX>2Ph:3PX>2[H:]PZf2[H:]PZf2
[H:]PZfV[JJ]YZfV[JJ]YPV/00<0[:`01Z`01]2/d:c@[0gG00<0emL01]L001KG00<0emL01ML203kG
15l0KEiOGUmNGej9GXUNREj9GXUNRH:9PXV2RH:9PXV2RH:9PZf2[H:/PZb2[8:/PZb2[8:/PZb2[8:/
PZb2[8:/PJJ1YX6VPJJ1YX6VPJJ1YX6VPJJ1YW^2Nh9kPUN2Eh9GPUR2F89HPUR2F89HPUP03X80;JJ2
YX:VPZb2[8:/PZb2[8:/PZb2[:J/YZbV[:J/YZ`0[:J/YZbV[:J/YZbV[00=e`030=OG00KG000Ee`03
0=OG00?G0`11e`1<GhUOREn9GhUOREn9GhUOREn9PhV3RH>9PhV3RH>]PZf2[H:]PZf2[H:]PZf2[JJ]
YZfV[JJ/YZbV[:J/YZbV[:J/YZbV[:J/YZbV[0JV00R2YX:VPZJ2YP:200elPWb2O89lPUR2O89l00R2
02:3PX>2Yh:]PZf2[H:]PZf2[H:]PZfV[JJ]YZfV[JJ]YZbV2Z`00`2/[005[005d:c@[=003]L00`3G
e`06e`005ML0103GemL204CG1el0JEiOGUmNREj9GXUNREj9GXV2RH:9PXV2RH:9PXV2RH:]PZf2[8:/
PZb2[8:/PZb2[8:/PZb2[8:/PZJ2YX6VPJJ1YX6VPJJ1YX6VPJJ1YX6VNjIkPW^2Nh9GPUN2F89HPUR2
F89HPUR2F00>PP0[YX:VPZJ2[8:/PZb2[8:/PZb2[8:/PZbV[:J/YZbV[:H0YZbV[:J/YZbV[00?e`03
0=OG00KG000Ee`@0AmL0BfEOIEn9GhUOREn9GhUOREn9PhV3RH>9PhV3RH>9PZf2[H:]PZf2[H:]PZf2
[H:]PZfV[JJ/YZbV[:J/YZbV[:J/YZbV[:J/YZbV[004YP0:PZJ2YX:VPZJ2YP:200elPWb2O89lPWb2
O89l00Z20223PZN2[H:]PZf2[H:]PZf2[H:]PZfV[JJ/YZbV[:J/YP^/00<0[:`01Z`00m2/e`0>e`03
0=OG00KG000Ee`80BmL2G`1[GUmNGeiOGUmNPej9GXUNREj9GXV2RH:9PXV2RH:9PXV2[H:]PZf2[8:/
PZb2[8:/PZb2[8:/PZb2YX:VPZJ1YX6VPJJ1YX6VPJJ1YX6VPJJ1YW^VNh9kPW^2Eh9GPUR2F89HPUR2
F89HPW`03X80:ZJ2YX:VPZJ2[8:/PZb2[8:/PZb2[:J/YZbV[:J/YZbV[02/YZbV[:J/YQ3G00<0emL0
1]L00003e`0000800mL00`3Ge`02e`<01]L00`3Ge`1:e`16GfEOIEn9GhUOREn9GhUOREn9PhV3RH>9
PhV2RH:9PZf2[H:]PZf2[H:]PZf2[H:]YZfV[:J/YZbV[:J/YZbV[:J/YZbV[0JV01N2YX:VPZJ2YX:V
PZIlPWb2O89lPWb2O00@PP0NYh:]PZf2[H:]PZf2[H:]PZfV[:J/YZbV[:J/YZbV2j`00`2/[002[003
d:cG013G00<0emL01]L000?G00<0emL02]L00`3Ge`04e`030=OG04WG0el0JEiOGUmNGeiOGX=NPej9
GXUNREj9GXV2RH:9PXV2RH:9PXV2[H:/PZb2[8:/PZb2[8:/PZb2[8:VPZJ2YX:VPJJ1YX6VPJJ1YX6V
PJJ1YX6VNjIkPW^2Nh9kPUN2Eh9HPUR2F89HPUR2O00>PP0XYX:VPZJ2YX:/PZb2[8:/PZb2[8:/YZbV
[:J/YZbV[:J/YP2V[:J/YQ;G00<0emL01]L000?G00<0emL02]L00`3Ge`05e`030=OG04WG04MUGfEO
REn9GhUOREn9GhUOREn9PhV3RH>9PhV2RH:]PZf2[H:]PZf2[H:]PZf2[JJ]PZbV[:J/YZbV[:J/YZbV
[:J/YZbV[004YP0GPZJ2YX:VPZJ2YX:VO89lPWb2O89lPW`03X808:J2YX:/PZb2[8:/PZb2[8:/YZbV
[:J/YZbV[:J/YZbV3:`0102/[:`De`030=OG00GG0003e`030=OG00OG0`09e`030=OG04WG0el0IeiO
GUmNGeiOGUmNPej9GXUNREj9GXV2RH:9PXV2RH:9PZb2[8:/PZb2[8:/PZb2[8:/PZJ2YX:VPZJ2YX6V
PJJ1YX6VPJJ1YX6VPJJ1YX6VNh9kPW^2Nh9kPUN2F89HPUR2F89HPW`03880::J2YX:VPZJ2YX:VPZb2
[8:/PZb2[8:/PZbV[:J/YZbV[:J/YZ`0[:HEe`030=OG00GG0003e`030=OG00OG00<0emL02]L00`3G
e`19e`15IEmUGfEOIEn9GhUOREn9GhV3RH>9PhV3RH>9PXV2[H:]PZf2[H:]PZf2[H:]PZf2[JJ/YZbV
[:J/YZbV[:J/YZbV[:J/00:V00j2YX:VPZJ2YX:VPZJ2YP:200UlPWb2O89lPW`03X808ZJ2YX:VPZb2
[8:/PZb2[8:/PZbV[:J/YZbV[:J/YZbV[:H;[0030=OG01CG00<0emL01ML00004e`0000WG00<0emL0
2mL00`3Ge`18e`AO06ENGeiOGUmNGej3GX=NPej3GXUNRH:9PXV2RH:9PXV2RH:8PZb2[8:/PZb2[8:/
PZJ2YX:VPZJ2YX:VPJJ1YX6VPJJ1YX6VPJJ1YX6VPJIkYW^2Nh9kPW^2Eh9HPUR2F89lPWb2O00>PP0U
YX:VPZJ2YX:VPZb2[8:/PZb2[8:/YZbV[:J/YZbV[:J/YZbV000Fe`030=OG00GG0003e`030=OG00OG
100;e`030=OG04SG04AOIEmUGfEOIEn9GhUOREn9GhV3RH>9PhV3RH:9PXV2[H:]PZf2[H:]PZf2[H:]
PZf2[8:/PZbV[:J/YZbV[:J/YZbV[0:V00j2YX:VPZJ2YX:VPZJ2YP:200UlPWb2O89lPW`03X808ZJ2
YX:VPZb2[8:/PZb2[8:/PZbV[:J/YZbV[:J/YZbV[:H;[003e`3G01CG00<0emL01ML001gG00<0emL0
B=L0JC]O>UmNGeiOGUmNGeiOGX=NPej3GXUNRH:9PXV2RH:9PXV2RH:8PZb2[8:/PZJ2YX:VPZJ2YX:V
PZJ2YX:VPJJ1YX6VPJJ1YX6VPJJ1YX6VNjIkPW^2Nh9kPW^2Nh9lPWb2O89lPWb2O00<PP0SYX:VPZJ2
YX:VPZb2[8:/PZb2[8:/YZbV[:J/YZbV[:J/YZ`00mL00`3Ge`0Be`030=OG00GG000Ne`030=OG04SG
041OIEmUGfEOIEn9GhUOREn9GhUORH>9PhV3RH:9PXV2RH:]PZf2[H:]PZf2[H:]PZb2[8:/PZb2[8:/
YZbV[:J/0ZH04X:VPZJ2YX:VPZJ2YX:VPZJ2YP:200ElPWb2O00>PP0VYX:VPZJ2YX:/PZb2[8:/PZb2
[:J/YZbV[:J/YZbV[:J/YZbV[:H7[0CG00<0emL04]L00`3Ge`05e`007mL00`3Ge`18e`1W>eljGcYO
GUmNGeiOGX=NPej3GX=NPej3GX>2RH:9PXV2RH:8PXR2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPJJ1YX6V
PJJ1YX6VPJJ1YX6VPJJ1PW^2Nh9kPW^2Nh9lPWb2O89lPWb2O00:PP0SYX:VPZJ2YX:VPZJ2[8:/PZb2
[8:/PZb2[:J/YZbV[:J/YZ`01]L00`3Ge`0Ae`030=OG00GG000Pe`030=OG04SG059OIEmUGfEOIEmU
GhUOREn9GhUORH>9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[H:]PZb2[8:/PZb2[8:/PZb2[8:/PZJ2YX:V
PZJ2YX:VPZJ2YX:V5H809ZJ2YX:VPZJ2YX:/PZb2[8:/PZbV[:J/YZbV[:J/YZbV[:J/YZbV1Z`6e`03
0=OG017G00<0emL01ML0027G00<0emL0B=L08SYO>UmNGeiOGUmNGeiOGX=NPej3GX=NPh:3PX>2Ph:9
PX<5PP0nYX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ1YX6VPJJ1YX6VPJJ1YX6VPJIkPW^2Nh9kPW^2O89l
PWb2O89lPW`<PP0PYX:VPZJ2YX:VPZJ2[8:/PZb2[8:/YZbV[:J/YZbV[:H8e`030=OG017G00<0emL0
1=L002;G00<0emL0B=L7G`19IEmUGhUOREn9GhV3RH>9PXV2RH:9PXV2RH:]PZf2[H:]PZf2[H:/PZb2
[8:/PZb2[8:/PZb2YX:VPZJ2YX:VPZJ2YX:VPZJ2YP0EPP0XYX:VPZJ2YX:VPZb2[8:/PZb2[8:/YZbV
[:J/YZbV[:J/YZbV[:J/YP:/2]L00`3Ge`0@e`030=OG00CG000Se`030=OG04SG028jGcYO>UmNGeiO
GUmNGej3GX=NPej3GX=NPh:3PX>2Ph:31h80>ZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ1YX6VPJJ1YX6VPJJ1
YX6VPJIkPW^2Nh9kPW^2Nh9kPWb2O89lPW`<PP0OYX:VPZJ2YX:VPZJ2[8:/PZb2[8:/YZbV[:J/YZbV
[00:e`030=OG013G00<0emL01=L002CG00<0emL0AmL00elkG`05G`19IEn9GhUOREn9GhUORH:9PXV2
RH:9PXV2[H:]PZf2[H:]PZf2[H:/PZb2[8:/PZb2[8:/PZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YP0CPP0Y
YX:VPZJ2YX:/PZb2[8:/PZb2[:J/YZbV[:J/YZbV[:J/YZbV[:J/YZ`03=L00`3Ge`0?e`030=OG00CG
000Ue`030=OG04OG025O>UljGcYOGUmNGeiOGX=NPej3GX=NPej3PX>2Ph:3PX<02H80>:J2YX:VPZJ2
YX:VPZJ2YX:VPJJ1YX6VPJJ1YX6VPJJ1YW^VNh9kPW^2Nh9kPW^2Nh9lPWb2O89l2X807jJ2YX:VPZJ2
YX:VPZJ2YX:/PZb2[8:/PZbV[:J/YZ`03ML00`3Ge`0?e`030=OG00CG000Ve`030=OG04OG00AO>elk
25l0@hUOREn9GhUOREn9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[8:/PZb2[8:/PZb2YX:VPZJ2YX:VPZJ2
YX:VPZJ2YX:VPZH04H80:JJ2YX:VPZJ2YX:VPZb2[8:/PZb2[:J/YZbV[:J/YZbV[:J/YZbV[:J/00oG
00<0emL03]L00`3Ge`04e`009mL00`3Ge`17e`0Q>cYO>UljGeiOGUmNGeiOGX=NPej3GX=NPh:3PX>2
Ph:300V203JVPZJ2YX:VPZJ2YX:VPZJ2YX6VPJJ1YX6VPJJ1YX6VPJIkPW^2Nh9kPW^2Nh9kPWb2O89l
PW`:PP0NYX:VPZJ2YX:VPZJ2YX:VPZb2[8:/PZb2[:J/YZbV3mL00`3Ge`0>e`030=OG00CG000Xe`03
0=OG04OG00AO>elk25l0@HUOREn9GhUORH:9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[8:/PZb2[8:VPZJ2
YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:V016202RVPZJ2YX:VPZJ2YX:/PZb2[8:/PZb2[:J/YZbV[:J/YZbV
[:J/YZbV4ML00`3Ge`0=e`030=OG00CG000Ye`030=OG04KG020j>cYO>UljGcYOGUmNGeiOGUmNPej3
GX=NPh:3PX>2P`n2032VPZJ2YX:VPZJ2YX6VPJJ1YX6VPJJ1YX6VPJIkYW^2Nh9kPW^2Nh9kPWb2O89l
PW`:PP0LYX:VPZJ2YX:VPZJ2YX:VPZb2[8:/PZbV[:J/YQ?G00<0emL03=L00`3Ge`04e`00:]L00`3G
e`16e`05>elkGc/025l0?h=OREn9GhUORH:9PXV2RH:9PXV2[H:]PZf2[H:]PZb2[8:/PZb2[8:VPZJ2
YX:VPZJ2YX:VPZJ2YX:VPZJ2YP0APP0VYX:VPZJ2YX:VPZJ2YX:/PZb2[8:/YZbV[:J/YZbV[:J/YZbV
[:HDe`030=OG00cG00<0emL01=L002_G00<0emL0AmL07c/dGcYO>UljGeiOGUmNGej3GX=NPej3GX=N
Ph:3PX<03H80<:J2YX:VPZJ2YX:VPJJ1YX6VPJJ1YX6VPJIkYW^VNh9kPW^2Nh9kPW^2Nh9kPWb2O0Z2
01ZVPZJ2YX:VPZJ2YX:VPZJ2[8:/PZb2[:J/YQKG00<0emL03=L00`3Ge`03e`00;=L00`3Ge`17e`04
Gc]O>`YO03f3GhUOREj9PXV2RH:9PXV2RH:]PZf2[H:]PZb2[8:/PZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2
YX:VPZJ2YX:V00f202JVPZJ2YX:VPZJ2YX:VPZJ2[8:/PZb2[:J/YZbV[:J/YZbV[:J/YQOG00<0emL0
3=L00`3Ge`03e`00;ML00`3Ge`16e`0N03/d>cAO>UljGeiOGUmNGeiOGX=NPej3GX=NPh:34H80;:J2
YX:VPZJ2YX6VPJJ1YX6VPJJ1YW^2NjIkPW^2Nh9kPW^2Nh9kPW^2O89l2X806:J2YX:VPZJ2YX:VPZJ2
YX:/PZb2[8:/PQWG00<0emL02mL00`3Ge`03e`00;]L00`3Ge`16e`<k00AO>elk1Ul0?H=OPen3GXUN
RH:9PXV2RH:9PXV2RH:]PZf2[H:/PZb2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH03H809:J2
YX:VPZJ2YX:VPZJ2YX:/PZb2[8:/PZbV[:J/YZbV[:J/YQ_G00<0emL02]L00`3Ge`03e`00;mL00`3G
e`16e`0N43/d>cAO=5ljGeiOGUmNGej3GX=NPej3GX=NPh:34h80:ZJ2YX:VPZJ1YX6VPJJ1YX62PH9k
YW^2Nh9kPW^2Nh9kPW^2Nh9lPWb2O0R201JVPZJ2YX:VPZJ2YX:VPZJ2YX:/PZb27=L00`3Ge`0:e`03
0=OG00?G000`e`030=OG04KG0c/015lkGc/8G`0iPen3GX=NPh:9PXV2RH:9PXV2RH:9PZf2[8:VPZJ2
YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:V00^202BVPZJ2YX:VPZJ2YX:VPZJ2YX:VPZb2[8:/PZbV
[:J/YZbV[:HNe`030=OG00WG00<0emL00mL0037G00<0emL0A]L0710k=3/dGcAO=5mNGeiOGUmNGej3
GX=NPej3GX<GPP0VYX:2PZJ1YX62PH:1PX62Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW`8PP0DYX:VPZJ2
YX:VPZJ2YX:VPZJ2[88Oe`030=OG00WG00<0emL00mL003;G00<0emL0A]L01cDk=ElkGc/01Ul0>H=O
Pej3GX=NPh:3PX>2RH:9PXV2Ph:WPZN2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YP0=PP0P
YX:VPZJ2YX:VPZJ2YX:VPZJ2[8:/PZbV[:J/YZbV[:HQe`030=OG00SG00<0emL00mL003?G00<0emL0
A]L0710k43/d>cAO=5ljGeiOGUmNPej3GX=NPej3GX<JPP0QPH:1PX62Nh9kPW^2Nh9kPW^2Nh9kPW^2
Nh9kPW^2Nh:100J201BVPZJ2YX:VPZJ2YX:VPZJ2YX:VPR?G00<0emL01mL00`3Ge`03e`00==L00`3G
e`15e`04>a0k=@8k00=O>el01El0>H=OPej3GX=NPh:3PX>2Ph:3PX>2Ph:WPZJ2YX:VPZJ2YX:VPZJ2
YX:VPZJ2YX:VPZJ2YX:VPZJ2YP09PP0PYX:VPZJ2YX:VPZJ2YX:VPZJ2YX:/PZb2[:J/YZbV[:HTe`03
0=OG00SG00<0emL00]L003GG00<0emL0AML0714@>a0k=3/dGcAOGUmNGeiOGUmNPej3GX=NPehIPP0U
PH:1PX62PH9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh:1PX62P@02PP0BYX:VPZJ2YX:VPZJ2YX:VPZJ2
9]L00`3Ge`07e`030=OG00;G000fe`030=OG04GG00Pk43/eGc]O>`MO03INPej3GX>2Ph:3PX>2Ph:3
PX>2Ph:3PZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH7PP0PYX:VPZJ2YX:VPZJ2YX:VPZJ2
YX:/PZb2[8:/YZbV[:HWe`030=OG00OG00<0emL00]L003OG00<0emL0AML0714@=A0k=3/dGcAO=5mN
GeiOGX=NPej3GX=NPehIPP0SPH:1PX62Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh:1PX400X804:J2
YX:VPZJ2YX:VPZJ2YX8Ye`030=OG00KG00<0emL00]L003SG00<0emL0AML02Q4@>c@k=ElkGc/3G`0f
GX=NPej3GX=NPh:3PX>2Ph:3PX>2Ph:3PZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:V1h807ZJ2
YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:/PZb2[:J/YR[G00<0emL01]L00`3Ge`02e`00>ML00`3Ge`14e`0O
0=L@=A0k=3/dGcAOF5mHGeiOGUmNPej3GX=NPUj2GP0EPP0cPH:1PW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2
Nh9kPW^2Nh:1PX62PJJ1YX:VPJJ2YX:VPZJ202cG00<0emL01ML00`3Ge`02e`00>]L00`3Ge`13e`0<
0=OG43/d>cEO=Elk0el05UiOGX=NPej3PX>2Ph:3PX>2Ph:3PX<5PP0KYX:VPZJ2YX:VPZJ2YX:VPZJ2
YX:VPZJ2YX:V00F201bVPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2[8:/PZbV;]L00`3Ge`04e`030=OG00;G
000ke`030=OG04;G01l0emLA414@>c@k=5ldGcAOF5mHGej3GX=NPej3GX9N01F20361PX62Nh9kPW^2
Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPX62PJJ1YX6VPJJ1YX6VPJJ202oG00<0emL01=L00`3Ge`02e`00
?=L00`3Ge`11e`030=OG00;G00D@>c@k=@02>`0KGc]OGUmNPej3GX=NPej3PX>2Ph:3PX>2Ph:300>2
01^VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH01H806JJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZ`0
<]L00`3Ge`03e`030=OG00;G000me`030=OG043G00<0emL01=L063D@>c@k=5ldGcAOF5mNGeiOGX=N
Pej2GQN202alPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh:1PX6VPJJ1YX6VPJJ1YS?G00<0emL0
1=L00`3Ge`01e`00?]L00`3Ge`0oe`030=OG00GG01lk43/dGcAO>UmNGeiOGX=NPej3GX>2Ph:3PX>2
Ph:300F201VVPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:V00F201NVPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2
YP0ee`030=OG00?G00<0emL00ML003oG00<0emL0?]L00`3Ge`07e`0I43/d>cAO=5mHGeQOF5mHPej3
GX9NPUj2GP0CPP0ZO89kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2PJJ1YX6VPJJ1YX6V=mL00`3G
e`02e`030=OG007G0010e`030=OG03gG00<0emL02ML07C/dGcAO=5mNGej3GX=NPej3GX>2Ph:3PX>2
Ph:300N201FVPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH01H805JJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YP0he`03
0=OG00;G00<0emL00ML0047G00<0emL0?=L00`3Ge`0;e`0G=3/dGcAO=5mHGeQOF8=HPUj2GX9NPUh0
2h80;Gb2O89lPWb2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPX62PJJ1YX6VP@0ke`050=OGe`00
0mL004;G00<0emL0>mL00`3Ge`0<e`0J=3/dGeiOGUmNGej3GX=NPej3PX>2Ph:3PX<9PP0EYX:VPZJ2
YX:VPZJ2YX:VPZJ2YX:V00>201:VPZJ2YX:VPZJ2YX:VPZJ2YX8le`050=OGe`000mL004?G00<0emL0
>]L00`3Ge`0>e`0F>cAO=5mHGeQOF5mHPUR2F89NPUj2GPV202]lPWb2O89lPWb2Nh9kPW^2Nh9kPW^2
Nh9kPW^2Nh9kPW^2Nh:1PX6VPJJ103kG00@0emL00mL004CG00<0emL0>ML00`3Ge`0@e`0F=5mNGeiO
GUmNPej3GX=NPh:3PX>2P`n200nVPZJ2YX:VPZJ2YX:VPZH00h803jJ2YX:VPZJ2YX:VPZJ2YP10e`04
0=OG00?G0015e`030=OG03SG00<0emL04]L0@UldGcAOF5mHGeR2F89HPUR2F89HPUR2O89lPWb2O89l
PWb2O89kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2PD?G00<0e`000mL004KG00<0emL0=mL00`3G
e`0Ce`0EGeQOGUmNPej3GX=NPej3PX>2Ph:300n201^VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH0
A]L00`3G0002e`00AmL00`3Ge`0fe`030=OG01GG03`dGcAOF5mHPUR2F89HPUR2F89HPWb2O89lPWb2
O89lPWb2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh97e`030=L000;G0018e`030=OG03GG00<0emL0
5mL04EmNGej3GX=NPej3PX>2Ph:300n201VVPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:V04WG0P02e`00
BML00`3Ge`0de`030=OG01WG03EHGeQOF5iHPUR2F89HPUR2F89lPWb2O89lPWb2O89kPW^2Nh9kPW^2
Nh9kPW^2Nh9kPW^2N`1;e`800]L004[G00<0emL0<]L00`3Ge`0Me`0>GX=NPej3GX=NPh:3PX<CPP0?
YX:VPZJ2YX:VPZJ2YX:V04gG0P02e`00BmL00`3Ge`0ae`030=OG01oG02YNF5iHPUR2F89HPUR2F89H
PWb2O89lPWb2O89kPW^2Nh9kPW^2Nh9kPW]>e`<01=L004cG00<0emL0<=L00`3Ge`0Qe`0:GX=NPej3
GX>2PaF200RVPZJ2YX:VPTcG0`07e`00CML00`3Ge`0_e`030=OG02GG0262F89HPUR2F89HPUR2O89l
PWb2O89kPW^2Nh9kPW^2Nh80BmL300[G001>e`030=OG02kG00<0emL0:ML00h:3PP0DPP03YX;G04_G
0`0=e`00CmL00`3Ge`0]e`030=OG02cG019HPUR2F89lPWb2O89lPW^2Nh9=e`<04=L0053G00<0emL0
;=L00`3Ge`28e`<04mL0057G00<0emL0:mL00`3Ge`25e`<05]L005;G00<0emL0:]L00`3Ge`22e`<0
6ML005?G00<0emL0:ML00`3Ge`1ne`@07=L005CG00<0emL0:=L00`3Ge`1ke`<08=L005GG00<0emL0
9mL00`3Ge`1he`<08mL005KG00<0emL09]L00`3Ge`1ee`<09]L005OG00<0emL09ML00`3Ge`1be`<0
:ML005SG00<0emL09=L00`3Ge`1_e`<0;=L005WG00<0emL08mL00`3Ge`1/e`<0;mL005[G00<0emL0
8]L00`3Ge`1Ye`<0<]L005_G00<0emL08ML00`3Ge`1Ve`<0=ML005cG00<0emL08=L00`3Ge`1Se`<0
>=L005gG00<0emL07mL00`3Ge`1Pe`<0>mL005kG00<0emL07]L00`3Ge`1Me`<0?]L005oG00<0emL0
7ML00`3Ge`1Je`<0@ML0063G00<0emL07=L00`3Ge`1Ge`<0A=L0067G00<0emL06mL00`3Ge`1De`<0
AmL006;G00<0emL06]L00`3Ge`1Ae`<0B]L006?G00<0emL06ML00`3Ge`1>e`<0CML006CG00<0emL0
6=L00`3Ge`1:e`@0D=L006GG00<0emL05mL00`3Ge`17e`<0E=L006KG00<0emL05]L00`3Ge`14e`<0
EmL006OG00<0emL05ML00`3Ge`11e`<0F]L006SG00<0emL05=L00`3Ge`0ne`<0GML006WG00<0emL0
4mL00`3Ge`0ke`<0H=L006[G00<0emL04]L00`3Ge`0he`<0HmL006_G00<0emL04ML00`3Ge`0ee`<0
I]L006cG00<0emL04=L00`3Ge`0be`<0JML006gG00<0emL03]L00`3Ge`0`e`<0K=L006kG00<0emL0
3ML00`3Ge`0]e`<0KmL006oG00<0emL03=L00`3Ge`0Ze`<0L]L0073G00<0emL02mL00`3Ge`0We`<0
MML0077G00<0emL02]L00`3Ge`0Te`<0N=L007;G00<0emL02ML00`3Ge`0Qe`<0NmL007?G00<0emL0
2=L00`3Ge`0Ne`<0O]L007CG00<0emL01mL00`3Ge`0Ke`<0PML007GG00<0emL01]L00`3Ge`0Ge`@0
Q=L007KG00<0emL01ML00`3Ge`0De`<0R=L007OG00<0emL01=L00`3Ge`0Ae`<0RmL007SG00<0emL0
0mL00`3Ge`0>e`<0S]L007WG00<0emL00]L00`3Ge`0;e`<0TML007[G00D0emOG000:e`<0U=L007_G
00@0emL01mL309OG001le`030=L000CG0`2Je`00OML20004e`0009gG001ne`80X=L00?oG8ML00?oG
8ML00?oG8ML00?oG8ML00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0766428, 0.0134994, \
0.00360144, 0.00292125}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[PD3,AspectRatio->0.5]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.04977 -0.0418911 0.647101 [
[.02757 .15175 -12 -8.70276 ]
[.02757 .15175 0 .29724 ]
[.17646 .11563 -11.7989 -9 ]
[.17646 .11563 .20112 0 ]
[.3345 .07731 -5.5867 -9 ]
[.3345 .07731 .4133 0 ]
[.50253 .03658 -5.27396 -9 ]
[.50253 .03658 .72604 0 ]
[.68156 -0.00677 -4.96123 -9 ]
[.68156 -0.00677 1.03877 0 ]
[.70096 -0.00295 0 -6.26206 ]
[.70096 -0.00295 12 2.73794 ]
[.78313 .07461 0 -6.13858 ]
[.78313 .07461 12 2.86142 ]
[.8565 .14386 0 -6.03127 ]
[.8565 .14386 6 2.96873 ]
[.9224 .20607 0 -5.93715 ]
[.9224 .20607 6 3.06285 ]
[.98191 .26226 0 -5.85393 ]
[.98191 .26226 6 3.14607 ]
[.02494 .16022 -6 -2.73794 ]
[.02494 .16022 0 6.26206 ]
[.0131 .20598 -18 -2.80073 ]
[.0131 .20598 0 6.19927 ]
[.00067 .25401 -6 -2.86695 ]
[.00067 .25401 0 6.13305 ]
[-0.0124 .30447 -18 -2.93688 ]
[-0.0124 .30447 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .15727 m
.68874 0 L
s
.03716 .15727 m
.04196 .16003 L
s
[(-4)] .02757 .15175 1 .93395 Mshowa
.18558 .12145 m
.19014 .12435 L
s
[(-2)] .17646 .11563 .96648 1 Mshowa
.34306 .08344 m
.34735 .0865 L
s
[(0)] .3345 .07731 .86223 1 Mshowa
.51046 .04303 m
.51442 .04625 L
s
[(2)] .50253 .03658 .75799 1 Mshowa
.68874 0 m
.69233 .00339 L
s
[(4)] .68156 -0.00677 .65374 1 Mshowa
.125 Mabswid
.07346 .14851 m
.0763 .15019 L
s
.11029 .13962 m
.1131 .14132 L
s
.14766 .1306 m
.15043 .13232 L
s
.22407 .11216 m
.22677 .11392 L
s
.26314 .10273 m
.2658 .10452 L
s
.3028 .09315 m
.30541 .09497 L
s
.38395 .07357 m
.38647 .07543 L
s
.42547 .06355 m
.42794 .06543 L
s
.46763 .05337 m
.47006 .05528 L
s
.55397 .03253 m
.55629 .03449 L
s
.59817 .02186 m
.60044 .02384 L
s
.64309 .01102 m
.6453 .01302 L
s
.25 Mabswid
.68874 0 m
.96935 .26459 L
s
.68874 0 m
.68263 .00147 L
s
[(-2)] .70096 -0.00295 -1 .39157 Mshowa
.7708 .07738 m
.76464 .07876 L
s
[(-1)] .78313 .07461 -1 .36413 Mshowa
.84407 .14647 m
.83786 .14777 L
s
[(0)] .8565 .14386 -1 .34028 Mshowa
.9099 .20853 m
.90365 .20976 L
s
[(1)] .9224 .20607 -1 .31937 Mshowa
.96935 .26459 m
.96306 .26576 L
s
[(2)] .98191 .26226 -1 .30087 Mshowa
.125 Mabswid
.70593 .01621 m
.70226 .01708 L
s
.72272 .03204 m
.71904 .0329 L
s
.73912 .0475 m
.73543 .04836 L
s
.75514 .06261 m
.75145 .06345 L
s
.78611 .09182 m
.78241 .09264 L
s
.80108 .10593 m
.79737 .10674 L
s
.81573 .11974 m
.81201 .12054 L
s
.83006 .13325 m
.82633 .13404 L
s
.8578 .15941 m
.85407 .16018 L
s
.87123 .17208 m
.8675 .17284 L
s
.88439 .18448 m
.88065 .18524 L
s
.89727 .19663 m
.89353 .19738 L
s
.92227 .2202 m
.91851 .22093 L
s
.93439 .23163 m
.93063 .23235 L
s
.94627 .24283 m
.94251 .24355 L
s
.95792 .25382 m
.95416 .25452 L
s
.25 Mabswid
.03716 .15727 m
0 .30182 L
s
.03716 .15727 m
.04327 .1558 L
s
[(0)] .02494 .16022 1 -0.39157 Mshowa
.02537 .20312 m
.03151 .2017 L
s
[(0.5)] .0131 .20598 1 -0.37762 Mshowa
.013 .25125 m
.01917 .24987 L
s
[(1)] .00067 .25401 1 -0.3629 Mshowa
0 .30182 m
.0062 .30049 L
s
[(1.5)] -0.0124 .30447 1 -0.34736 Mshowa
.125 Mabswid
.03485 .16627 m
.03852 .16539 L
s
.03251 .17535 m
.03618 .17448 L
s
.03016 .18452 m
.03383 .18365 L
s
.02778 .19378 m
.03145 .19291 L
s
.02295 .21256 m
.02663 .21171 L
s
.0205 .22209 m
.02419 .22125 L
s
.01802 .23172 m
.02172 .23088 L
s
.01552 .24143 m
.01922 .2406 L
s
.01045 .26116 m
.01416 .26034 L
s
.00788 .27117 m
.01159 .27036 L
s
.00528 .28128 m
.00899 .28048 L
s
.00265 .2915 m
.00637 .2907 L
s
.25 Mabswid
.03716 .15727 m
0 .30182 L
s
0 .30182 m
.39787 .5 L
s
.39787 .5 m
.40529 .3692 L
s
.40529 .3692 m
.03716 .15727 L
s
.68874 0 m
.96935 .26459 L
s
.96935 .26459 m
1 .40283 L
s
1 .40283 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.03716 .15727 m
0 .30182 L
s
0 .30182 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.68874 0 m
.03716 .15727 L
s
.40529 .3692 m
.96935 .26459 L
s
.96935 .26459 m
1 .40283 L
s
1 .40283 m
.39787 .5 L
s
.39787 .5 m
.40529 .3692 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.003 .414 .856 r
.40144 .367 .40529 .36922 .41158 .3713 .40774 .369 Mtetra
.028 .422 .864 r
.40774 .369 .41158 .3713 .41791 .37337 .41407 .371 Mtetra
.054 .431 .871 r
.41407 .371 .41791 .37337 .42428 .37545 .42045 .373 Mtetra
.08 .44 .877 r
.42045 .373 .42428 .37545 .43068 .37752 .42686 .37499 Mtetra
.106 .449 .883 r
.42686 .37499 .43068 .37752 .43712 .37958 .4333 .37696 Mtetra
.133 .458 .887 r
.4333 .37696 .43712 .37958 .44359 .38162 .43978 .37892 Mtetra
.159 .466 .89 r
.43978 .37892 .44359 .38162 .4501 .38364 .4463 .38086 Mtetra
.186 .474 .892 r
.4463 .38086 .4501 .38364 .45665 .38564 .45285 .38277 Mtetra
.211 .482 .894 r
.45285 .38277 .45665 .38564 .46324 .3876 .45944 .38465 Mtetra
.237 .49 .894 r
.45944 .38465 .46324 .3876 .46986 .38953 .46607 .38649 Mtetra
.262 .497 .893 r
.46607 .38649 .46986 .38953 .47652 .39142 .47274 .38828 Mtetra
.287 .504 .892 r
.47274 .38828 .47652 .39142 .48322 .39326 .47944 .39003 Mtetra
.311 .51 .889 r
.47944 .39003 .48322 .39326 .48995 .39505 .48617 .39172 Mtetra
.334 .516 .886 r
.48617 .39172 .48995 .39505 .49672 .39678 .49295 .39335 Mtetra
.356 .521 .882 r
.49295 .39335 .49672 .39678 .50353 .39846 .49976 .39492 Mtetra
.378 .526 .878 r
.49976 .39492 .50353 .39846 .51037 .40006 .50661 .39641 Mtetra
.398 .53 .873 r
.50661 .39641 .51037 .40006 .51725 .40159 .51349 .39783 Mtetra
.418 .534 .867 r
.51349 .39783 .51725 .40159 .52416 .40304 .5204 .39916 Mtetra
.437 .537 .861 r
.5204 .39916 .52416 .40304 .53111 .40441 .52735 .40041 Mtetra
.454 .54 .855 r
.52735 .40041 .53111 .40441 .5381 .40569 .53434 .40157 Mtetra
.471 .542 .848 r
.53434 .40157 .5381 .40569 .54511 .40688 .54135 .40262 Mtetra
.487 .544 .841 r
.54135 .40262 .54511 .40688 .55216 .40797 .5484 .40357 Mtetra
.502 .546 .834 r
.5484 .40357 .55216 .40797 .55924 .40895 .55548 .40441 Mtetra
.515 .547 .827 r
.55548 .40441 .55924 .40895 .56635 .40983 .56258 .40514 Mtetra
.528 .548 .819 r
.56258 .40514 .56635 .40983 .57349 .41059 .56972 .40575 Mtetra
.54 .548 .812 r
.56972 .40575 .57349 .41059 .58065 .41124 .57688 .40624 Mtetra
.551 .549 .805 r
.57688 .40624 .58065 .41124 .58785 .41176 .58408 .4066 Mtetra
.561 .549 .798 r
.58408 .4066 .58785 .41176 .59507 .41217 .59129 .40684 Mtetra
.57 .548 .791 r
.59129 .40684 .59507 .41217 .60232 .41245 .59853 .40695 Mtetra
.579 .548 .784 r
.59853 .40695 .60232 .41245 .60959 .4126 .60579 .40693 Mtetra
.587 .547 .777 r
.60579 .40693 .60959 .4126 .61688 .41263 .61308 .40677 Mtetra
.594 .546 .771 r
.61308 .40677 .61688 .41263 .62419 .41252 .62038 .40649 Mtetra
.6 .545 .765 r
.62038 .40649 .62419 .41252 .63153 .41228 .62771 .40607 Mtetra
.606 .545 .759 r
.62771 .40607 .63153 .41228 .63888 .4119 .63505 .40551 Mtetra
.612 .544 .754 r
.63505 .40551 .63888 .4119 .64625 .41137 .64241 .4048 Mtetra
.618 .544 .749 r
.64241 .4048 .64625 .41137 .65364 .41068 .64978 .40394 Mtetra
.624 .544 .744 r
.64978 .40394 .65364 .41068 .66103 .40982 .65717 .40291 Mtetra
.63 .544 .739 r
.65717 .40291 .66103 .40982 .66844 .40875 .66456 .40169 Mtetra
.637 .546 .734 r
.66456 .40169 .66844 .40875 .67585 .40747 .67196 .40025 Mtetra
.63 .539 .733 r
.67196 .40025 .67585 .40747 .68328 .40621 .67939 .39898 Mtetra
.624 .536 .734 r
.67939 .39898 .68328 .40621 .69074 .40497 .68685 .39788 Mtetra
.633 .543 .735 r
.68685 .39788 .69074 .40497 .69819 .4035 .69431 .39655 Mtetra
.64 .55 .737 r
.69431 .39655 .69819 .4035 .70565 .40184 .70178 .39504 Mtetra
.647 .557 .739 r
.70178 .39504 .70565 .40184 .71311 .4 .70925 .39335 Mtetra
.654 .564 .741 r
.70925 .39335 .71311 .4 .72057 .398 .71673 .39151 Mtetra
.66 .571 .743 r
.71673 .39151 .72057 .398 .72803 .39585 .72421 .38952 Mtetra
.666 .578 .746 r
.72421 .38952 .72803 .39585 .73549 .39355 .73169 .38738 Mtetra
.673 .585 .748 r
.73169 .38738 .73549 .39355 .74296 .39111 .73917 .38511 Mtetra
.679 .592 .751 r
.73917 .38511 .74296 .39111 .75041 .38854 .74664 .38269 Mtetra
.686 .6 .754 r
.74664 .38269 .75041 .38854 .75787 .38583 .75412 .38015 Mtetra
.693 .607 .756 r
.75412 .38015 .75787 .38583 .76532 .38298 .76159 .37746 Mtetra
.699 .615 .759 r
.76159 .37746 .76532 .38298 .77276 .38001 .76906 .37464 Mtetra
.706 .623 .761 r
.76906 .37464 .77276 .38001 .7802 .37691 .77652 .37169 Mtetra
.713 .63 .764 r
.77652 .37169 .7802 .37691 .78763 .37367 .78398 .3686 Mtetra
.72 .638 .766 r
.78398 .3686 .78763 .37367 .79505 .37032 .79142 .36539 Mtetra
.727 .646 .768 r
.79142 .36539 .79505 .37032 .80246 .36684 .79886 .36205 Mtetra
.733 .653 .77 r
.79886 .36205 .80246 .36684 .80985 .36325 .80628 .35859 Mtetra
.74 .661 .772 r
.80628 .35859 .80985 .36325 .81724 .35954 .8137 .355 Mtetra
.747 .668 .774 r
.8137 .355 .81724 .35954 .82461 .35573 .8211 .35131 Mtetra
.753 .675 .775 r
.8211 .35131 .82461 .35573 .83198 .35181 .82849 .34751 Mtetra
.759 .682 .777 r
.82849 .34751 .83198 .35181 .83932 .3478 .83587 .3436 Mtetra
.765 .689 .779 r
.83587 .3436 .83932 .3478 .84666 .34368 .84323 .3396 Mtetra
.771 .696 .78 r
.84323 .3396 .84666 .34368 .85398 .33949 .85058 .3355 Mtetra
.777 .703 .782 r
.85058 .3355 .85398 .33949 .86129 .3352 .85792 .33132 Mtetra
.782 .709 .783 r
.85792 .33132 .86129 .3352 .86858 .33084 .86525 .32705 Mtetra
.787 .716 .785 r
.86525 .32705 .86858 .33084 .87586 .32641 .87256 .32271 Mtetra
.792 .722 .786 r
.87256 .32271 .87586 .32641 .88313 .32191 .87985 .3183 Mtetra
.797 .728 .787 r
.87985 .3183 .88313 .32191 .89038 .31735 .88714 .31383 Mtetra
.802 .734 .789 r
.88714 .31383 .89038 .31735 .89762 .31274 .89441 .30929 Mtetra
.806 .74 .79 r
.89441 .30929 .89762 .31274 .90484 .30807 .90166 .30471 Mtetra
.811 .746 .792 r
.90166 .30471 .90484 .30807 .91205 .30336 .90891 .30007 Mtetra
.815 .752 .793 r
.90891 .30007 .91205 .30336 .91925 .2986 .91614 .29539 Mtetra
.819 .758 .795 r
.91614 .29539 .91925 .2986 .92644 .29381 .92336 .29068 Mtetra
.823 .763 .796 r
.92336 .29068 .92644 .29381 .93362 .28899 .93057 .28593 Mtetra
.826 .769 .798 r
.93057 .28593 .93362 .28899 .94078 .28414 .93777 .28115 Mtetra
.83 .775 .8 r
.93777 .28115 .94078 .28414 .94794 .27928 .94496 .27636 Mtetra
.833 .781 .802 r
.94496 .27636 .94794 .27928 .95508 .2744 .95214 .27155 Mtetra
.837 .787 .804 r
.95214 .27155 .95508 .2744 .96222 .2695 .95931 .26673 Mtetra
.84 .793 .806 r
.95931 .26673 .96222 .2695 .96935 .26461 .96648 .2619 Mtetra
.028 .43 .867 r
.39757 .36477 .40144 .367 .40774 .369 .40388 .36669 Mtetra
.052 .438 .874 r
.40388 .36669 .40774 .369 .41407 .371 .41022 .36861 Mtetra
.077 .446 .88 r
.41022 .36861 .41407 .371 .42045 .373 .4166 .37053 Mtetra
.102 .454 .885 r
.4166 .37053 .42045 .373 .42686 .37499 .42302 .37244 Mtetra
.127 .462 .889 r
.42302 .37244 .42686 .37499 .4333 .37696 .42947 .37434 Mtetra
.153 .471 .893 r
.42947 .37434 .4333 .37696 .43978 .37892 .43595 .37622 Mtetra
.178 .478 .896 r
.43595 .37622 .43978 .37892 .4463 .38086 .44248 .37808 Mtetra
.204 .486 .897 r
.44248 .37808 .4463 .38086 .45285 .38277 .44904 .3799 Mtetra
.229 .494 .898 r
.44904 .3799 .45285 .38277 .45944 .38465 .45563 .38169 Mtetra
.254 .501 .898 r
.45563 .38169 .45944 .38465 .46607 .38649 .46227 .38344 Mtetra
.278 .507 .897 r
.46227 .38344 .46607 .38649 .47274 .38828 .46894 .38514 Mtetra
.302 .514 .895 r
.46894 .38514 .47274 .38828 .47944 .39003 .47564 .3868 Mtetra
.326 .519 .892 r
.47564 .3868 .47944 .39003 .48617 .39172 .48238 .38839 Mtetra
.348 .525 .889 r
.48238 .38839 .48617 .39172 .49295 .39335 .48916 .38992 Mtetra
.37 .53 .884 r
.48916 .38992 .49295 .39335 .49976 .39492 .49598 .39138 Mtetra
.391 .534 .88 r
.49598 .39138 .49976 .39492 .50661 .39641 .50283 .39277 Mtetra
.411 .538 .874 r
.50283 .39277 .50661 .39641 .51349 .39783 .50971 .39408 Mtetra
.431 .542 .868 r
.50971 .39408 .51349 .39783 .5204 .39916 .51663 .3953 Mtetra
.449 .545 .862 r
.51663 .3953 .5204 .39916 .52735 .40041 .52358 .39642 Mtetra
.466 .548 .856 r
.52358 .39642 .52735 .40041 .53434 .40157 .53056 .39745 Mtetra
.483 .55 .849 r
.53056 .39745 .53434 .40157 .54135 .40262 .53758 .39838 Mtetra
.498 .552 .841 r
.53758 .39838 .54135 .40262 .5484 .40357 .54463 .39919 Mtetra
.513 .553 .834 r
.54463 .39919 .5484 .40357 .55548 .40441 .55171 .39989 Mtetra
.526 .554 .827 r
.55171 .39989 .55548 .40441 .56258 .40514 .55881 .40047 Mtetra
.539 .555 .819 r
.55881 .40047 .56258 .40514 .56972 .40575 .56595 .40093 Mtetra
.55 .555 .812 r
.56595 .40093 .56972 .40575 .57688 .40624 .57311 .40126 Mtetra
.561 .555 .805 r
.57311 .40126 .57688 .40624 .58408 .4066 .5803 .40146 Mtetra
.571 .555 .797 r
.5803 .40146 .58408 .4066 .59129 .40684 .58751 .40153 Mtetra
.58 .554 .79 r
.58751 .40153 .59129 .40684 .59853 .40695 .59474 .40147 Mtetra
.588 .554 .783 r
.59474 .40147 .59853 .40695 .60579 .40693 .602 .40127 Mtetra
.595 .553 .777 r
.602 .40127 .60579 .40693 .61308 .40677 .60928 .40094 Mtetra
.602 .552 .771 r
.60928 .40094 .61308 .40677 .62038 .40649 .61657 .40048 Mtetra
.608 .551 .765 r
.61657 .40048 .62038 .40649 .62771 .40607 .62389 .39988 Mtetra
.614 .55 .759 r
.62389 .39988 .62771 .40607 .63505 .40551 .63122 .39914 Mtetra
.619 .549 .753 r
.63122 .39914 .63505 .40551 .64241 .4048 .63857 .39827 Mtetra
.624 .548 .748 r
.63857 .39827 .64241 .4048 .64978 .40394 .64593 .39724 Mtetra
.63 .548 .744 r
.64593 .39724 .64978 .40394 .65717 .40291 .6533 .39605 Mtetra
.636 .548 .739 r
.6533 .39605 .65717 .40291 .66456 .40169 .66068 .39468 Mtetra
.642 .549 .734 r
.66068 .39468 .66456 .40169 .67196 .40025 .66807 .3931 Mtetra
.631 .54 .734 r
.66807 .3931 .67196 .40025 .67939 .39898 .67549 .39182 Mtetra
.62 .534 .736 r
.67549 .39182 .67939 .39898 .68685 .39788 .68296 .39084 Mtetra
.628 .541 .737 r
.68296 .39084 .68685 .39788 .69431 .39655 .69043 .38965 Mtetra
.635 .548 .739 r
.69043 .38965 .69431 .39655 .70178 .39504 .69791 .38827 Mtetra
.642 .555 .741 r
.69791 .38827 .70178 .39504 .70925 .39335 .7054 .38673 Mtetra
.648 .561 .743 r
.7054 .38673 .70925 .39335 .71673 .39151 .71289 .38504 Mtetra
.655 .568 .746 r
.71289 .38504 .71673 .39151 .72421 .38952 .72038 .38321 Mtetra
.661 .575 .748 r
.72038 .38321 .72421 .38952 .73169 .38738 .72788 .38124 Mtetra
.667 .583 .751 r
.72788 .38124 .73169 .38738 .73917 .38511 .73537 .37912 Mtetra
.674 .59 .754 r
.73537 .37912 .73917 .38511 .74664 .38269 .74287 .37687 Mtetra
.68 .598 .756 r
.74287 .37687 .74664 .38269 .75412 .38015 .75037 .37449 Mtetra
.687 .605 .759 r
.75037 .37449 .75412 .38015 .76159 .37746 .75787 .37196 Mtetra
.694 .613 .761 r
.75787 .37196 .76159 .37746 .76906 .37464 .76536 .36929 Mtetra
.701 .621 .764 r
.76536 .36929 .76906 .37464 .77652 .37169 .77284 .36649 Mtetra
.708 .629 .766 r
.77284 .36649 .77652 .37169 .78398 .3686 .78032 .36355 Mtetra
.716 .637 .769 r
.78032 .36355 .78398 .3686 .79142 .36539 .78779 .36047 Mtetra
.723 .645 .771 r
.78779 .36047 .79142 .36539 .79886 .36205 .79526 .35727 Mtetra
.729 .653 .773 r
.79526 .35727 .79886 .36205 .80628 .35859 .80271 .35394 Mtetra
.736 .66 .775 r
.80271 .35394 .80628 .35859 .8137 .355 .81015 .35048 Mtetra
.743 .668 .777 r
.81015 .35048 .8137 .355 .8211 .35131 .81758 .3469 Mtetra
.749 .675 .778 r
.81758 .3469 .8211 .35131 .82849 .34751 .825 .34322 Mtetra
.756 .682 .78 r
.825 .34322 .82849 .34751 .83587 .3436 .83241 .33942 Mtetra
.762 .689 .782 r
.83241 .33942 .83587 .3436 .84323 .3396 .8398 .33552 Mtetra
.768 .696 .783 r
.8398 .33552 .84323 .3396 .85058 .3355 .84718 .33152 Mtetra
.774 .703 .784 r
.84718 .33152 .85058 .3355 .85792 .33132 .85455 .32744 Mtetra
.779 .709 .786 r
.85455 .32744 .85792 .33132 .86525 .32705 .8619 .32327 Mtetra
.785 .716 .787 r
.8619 .32327 .86525 .32705 .87256 .32271 .86924 .31902 Mtetra
.79 .722 .789 r
.86924 .31902 .87256 .32271 .87985 .3183 .87657 .31469 Mtetra
.795 .728 .79 r
.87657 .31469 .87985 .3183 .88714 .31383 .88388 .3103 Mtetra
.799 .734 .791 r
.88388 .3103 .88714 .31383 .89441 .30929 .89118 .30585 Mtetra
.804 .74 .793 r
.89118 .30585 .89441 .30929 .90166 .30471 .89847 .30134 Mtetra
.808 .746 .794 r
.89847 .30134 .90166 .30471 .90891 .30007 .90575 .29678 Mtetra
.813 .752 .796 r
.90575 .29678 .90891 .30007 .91614 .29539 .91301 .29218 Mtetra
.817 .758 .797 r
.91301 .29218 .91614 .29539 .92336 .29068 .92027 .28753 Mtetra
.82 .763 .799 r
.92027 .28753 .92336 .29068 .93057 .28593 .92751 .28286 Mtetra
.824 .769 .801 r
.92751 .28286 .93057 .28593 .93777 .28115 .93474 .27816 Mtetra
.828 .775 .802 r
.93474 .27816 .93777 .28115 .94496 .27636 .94197 .27343 Mtetra
.831 .781 .804 r
.94197 .27343 .94496 .27636 .95214 .27155 .94918 .26869 Mtetra
.834 .786 .806 r
.94918 .26869 .95214 .27155 .95931 .26673 .95639 .26394 Mtetra
.837 .792 .809 r
.95639 .26394 .95931 .26673 .96648 .2619 .96359 .25918 Mtetra
.052 .446 .877 r
.39368 .36253 .39757 .36477 .40388 .36669 .4 .36438 Mtetra
.075 .453 .883 r
.4 .36438 .40388 .36669 .41022 .36861 .40635 .36622 Mtetra
.099 .46 .888 r
.40635 .36622 .41022 .36861 .4166 .37053 .41274 .36807 Mtetra
.123 .468 .892 r
.41274 .36807 .4166 .37053 .42302 .37244 .41916 .3699 Mtetra
.147 .475 .896 r
.41916 .3699 .42302 .37244 .42947 .37434 .42562 .37172 Mtetra
.172 .483 .899 r
.42562 .37172 .42947 .37434 .43595 .37622 .43211 .37352 Mtetra
.197 .49 .901 r
.43211 .37352 .43595 .37622 .44248 .37808 .43864 .37529 Mtetra
.221 .497 .902 r
.43864 .37529 .44248 .37808 .44904 .3799 .44521 .37703 Mtetra
.246 .504 .902 r
.44521 .37703 .44904 .3799 .45563 .38169 .45181 .37874 Mtetra
.27 .511 .901 r
.45181 .37874 .45563 .38169 .46227 .38344 .45845 .3804 Mtetra
.294 .517 .9 r
.45845 .3804 .46227 .38344 .46894 .38514 .46512 .38201 Mtetra
.317 .523 .897 r
.46512 .38201 .46894 .38514 .47564 .3868 .47183 .38357 Mtetra
.34 .529 .894 r
.47183 .38357 .47564 .3868 .48238 .38839 .47858 .38507 Mtetra
.362 .534 .891 r
.47858 .38507 .48238 .38839 .48916 .38992 .48536 .3865 Mtetra
.384 .538 .886 r
.48536 .3865 .48916 .38992 .49598 .39138 .49218 .38786 Mtetra
.404 .543 .881 r
.49218 .38786 .49598 .39138 .50283 .39277 .49903 .38914 Mtetra
.424 .547 .876 r
.49903 .38914 .50283 .39277 .50971 .39408 .50592 .39034 Mtetra
.443 .55 .869 r
.50592 .39034 .50971 .39408 .51663 .3953 .51284 .39144 Mtetra
.461 .553 .863 r
.51284 .39144 .51663 .3953 .52358 .39642 .5198 .39245 Mtetra
.478 .555 .856 r
.5198 .39245 .52358 .39642 .53056 .39745 .52678 .39335 Mtetra
.494 .557 .849 r
.52678 .39335 .53056 .39745 .53758 .39838 .5338 .39415 Mtetra
.51 .559 .842 r
.5338 .39415 .53758 .39838 .54463 .39919 .54085 .39483 Mtetra
.524 .56 .834 r
.54085 .39483 .54463 .39919 .55171 .39989 .54793 .39539 Mtetra
.537 .561 .827 r
.54793 .39539 .55171 .39989 .55881 .40047 .55503 .39582 Mtetra
.549 .561 .819 r
.55503 .39582 .55881 .40047 .56595 .40093 .56217 .39613 Mtetra
.561 .562 .812 r
.56217 .39613 .56595 .40093 .57311 .40126 .56932 .3963 Mtetra
.571 .562 .804 r
.56932 .3963 .57311 .40126 .5803 .40146 .57651 .39634 Mtetra
.581 .561 .797 r
.57651 .39634 .5803 .40146 .58751 .40153 .58372 .39624 Mtetra
.589 .56 .79 r
.58372 .39624 .58751 .40153 .59474 .40147 .59095 .39601 Mtetra
.597 .559 .783 r
.59095 .39601 .59474 .40147 .602 .40127 .5982 .39564 Mtetra
.604 .558 .776 r
.5982 .39564 .602 .40127 .60928 .40094 .60547 .39513 Mtetra
.61 .557 .77 r
.60547 .39513 .60928 .40094 .61657 .40048 .61276 .39449 Mtetra
.616 .556 .764 r
.61276 .39449 .61657 .40048 .62389 .39988 .62006 .39371 Mtetra
.621 .554 .758 r
.62006 .39371 .62389 .39988 .63122 .39914 .62739 .39281 Mtetra
.626 .553 .753 r
.62739 .39281 .63122 .39914 .63857 .39827 .63473 .39176 Mtetra
.631 .552 .748 r
.63473 .39176 .63857 .39827 .64593 .39724 .64208 .39058 Mtetra
.636 .552 .743 r
.64208 .39058 .64593 .39724 .6533 .39605 .64944 .38923 Mtetra
.641 .552 .739 r
.64944 .38923 .6533 .39605 .66068 .39468 .65681 .38772 Mtetra
.647 .553 .735 r
.65681 .38772 .66068 .39468 .66807 .3931 .66418 .386 Mtetra
.631 .542 .735 r
.66418 .386 .66807 .3931 .67549 .39182 .67161 .38471 Mtetra
.615 .533 .738 r
.67161 .38471 .67549 .39182 .68296 .39084 .67908 .38385 Mtetra
.623 .54 .739 r
.67908 .38385 .68296 .39084 .69043 .38965 .68656 .38278 Mtetra
.63 .546 .741 r
.68656 .38278 .69043 .38965 .69791 .38827 .69404 .38154 Mtetra
.637 .553 .743 r
.69404 .38154 .69791 .38827 .7054 .38673 .70154 .38015 Mtetra
.643 .559 .745 r
.70154 .38015 .7054 .38673 .71289 .38504 .70904 .37861 Mtetra
.649 .566 .748 r
.70904 .37861 .71289 .38504 .72038 .38321 .71655 .37693 Mtetra
.655 .573 .751 r
.71655 .37693 .72038 .38321 .72788 .38124 .72406 .37512 Mtetra
.661 .58 .753 r
.72406 .37512 .72788 .38124 .73537 .37912 .73158 .37317 Mtetra
.668 .588 .756 r
.73158 .37317 .73537 .37912 .74287 .37687 .7391 .37108 Mtetra
.675 .596 .759 r
.7391 .37108 .74287 .37687 .75037 .37449 .74662 .36885 Mtetra
.682 .604 .762 r
.74662 .36885 .75037 .37449 .75787 .37196 .75413 .36648 Mtetra
.689 .612 .764 r
.75413 .36648 .75787 .37196 .76536 .36929 .76165 .36397 Mtetra
.696 .62 .767 r
.76165 .36397 .76536 .36929 .77284 .36649 .76916 .36131 Mtetra
.704 .628 .769 r
.76916 .36131 .77284 .36649 .78032 .36355 .77666 .35852 Mtetra
.711 .636 .772 r
.77666 .35852 .78032 .36355 .78779 .36047 .78416 .35558 Mtetra
.718 .644 .774 r
.78416 .35558 .78779 .36047 .79526 .35727 .79165 .35251 Mtetra
.725 .652 .776 r
.79165 .35251 .79526 .35727 .80271 .35394 .79913 .3493 Mtetra
.732 .66 .778 r
.79913 .3493 .80271 .35394 .81015 .35048 .8066 .34597 Mtetra
.739 .667 .78 r
.8066 .34597 .81015 .35048 .81758 .3469 .81405 .34251 Mtetra
.746 .675 .781 r
.81405 .34251 .81758 .3469 .825 .34322 .8215 .33894 Mtetra
.753 .682 .783 r
.8215 .33894 .825 .34322 .83241 .33942 .82893 .33525 Mtetra
.759 .689 .784 r
.82893 .33525 .83241 .33942 .8398 .33552 .83636 .33145 Mtetra
.765 .696 .786 r
.83636 .33145 .8398 .33552 .84718 .33152 .84377 .32756 Mtetra
.771 .703 .787 r
.84377 .32756 .84718 .33152 .85455 .32744 .85116 .32357 Mtetra
.776 .709 .789 r
.85116 .32357 .85455 .32744 .8619 .32327 .85855 .31949 Mtetra
.782 .716 .79 r
.85855 .31949 .8619 .32327 .86924 .31902 .86592 .31532 Mtetra
.787 .722 .791 r
.86592 .31532 .86924 .31902 .87657 .31469 .87328 .31109 Mtetra
.792 .728 .793 r
.87328 .31109 .87657 .31469 .88388 .3103 .88062 .30678 Mtetra
.797 .734 .794 r
.88062 .30678 .88388 .3103 .89118 .30585 .88795 .3024 Mtetra
.802 .74 .795 r
.88795 .3024 .89118 .30585 .89847 .30134 .89527 .29797 Mtetra
.806 .746 .797 r
.89527 .29797 .89847 .30134 .90575 .29678 .90258 .29349 Mtetra
.81 .752 .798 r
.90258 .29349 .90575 .29678 .91301 .29218 .90988 .28896 Mtetra
.814 .758 .8 r
.90988 .28896 .91301 .29218 .92027 .28753 .91716 .28439 Mtetra
.818 .763 .801 r
.91716 .28439 .92027 .28753 .92751 .28286 .92444 .27978 Mtetra
.822 .769 .803 r
.92444 .27978 .92751 .28286 .93474 .27816 .9317 .27515 Mtetra
.825 .775 .805 r
.9317 .27515 .93474 .27816 .94197 .27343 .93896 .27049 Mtetra
.828 .78 .807 r
.93896 .27049 .94197 .27343 .94918 .26869 .94621 .26582 Mtetra
.832 .786 .809 r
.94621 .26582 .94918 .26869 .95639 .26394 .95346 .26113 Mtetra
.835 .792 .811 r
.95346 .26113 .95639 .26394 .96359 .25918 .96069 .25644 Mtetra
.076 .461 .886 r
.38978 .36029 .39368 .36253 .4 .36438 .3961 .36206 Mtetra
.097 .468 .891 r
.3961 .36206 .4 .36438 .40635 .36622 .40246 .36383 Mtetra
.12 .474 .895 r
.40246 .36383 .40635 .36622 .41274 .36807 .40886 .36559 Mtetra
.143 .481 .899 r
.40886 .36559 .41274 .36807 .41916 .3699 .41529 .36735 Mtetra
.167 .488 .902 r
.41529 .36735 .41916 .3699 .42562 .37172 .42175 .36909 Mtetra
.19 .495 .904 r
.42175 .36909 .42562 .37172 .43211 .37352 .42825 .37081 Mtetra
.214 .501 .905 r
.42825 .37081 .43211 .37352 .43864 .37529 .43479 .3725 Mtetra
.238 .508 .906 r
.43479 .3725 .43864 .37529 .44521 .37703 .44136 .37416 Mtetra
.262 .515 .905 r
.44136 .37416 .44521 .37703 .45181 .37874 .44797 .37578 Mtetra
.286 .521 .904 r
.44797 .37578 .45181 .37874 .45845 .3804 .45461 .37736 Mtetra
.309 .527 .903 r
.45461 .37736 .45845 .3804 .46512 .38201 .46129 .37888 Mtetra
.332 .532 .9 r
.46129 .37888 .46512 .38201 .47183 .38357 .46801 .38035 Mtetra
.354 .538 .897 r
.46801 .38035 .47183 .38357 .47858 .38507 .47476 .38175 Mtetra
.376 .542 .892 r
.47476 .38175 .47858 .38507 .48536 .3865 .48155 .38309 Mtetra
.397 .547 .888 r
.48155 .38309 .48536 .3865 .49218 .38786 .48837 .38435 Mtetra
.417 .551 .882 r
.48837 .38435 .49218 .38786 .49903 .38914 .49523 .38552 Mtetra
.436 .554 .877 r
.49523 .38552 .49903 .38914 .50592 .39034 .50212 .38661 Mtetra
.455 .558 .87 r
.50212 .38661 .50592 .39034 .51284 .39144 .50904 .3876 Mtetra
.473 .56 .864 r
.50904 .3876 .51284 .39144 .5198 .39245 .516 .38849 Mtetra
.49 .563 .857 r
.516 .38849 .5198 .39245 .52678 .39335 .52299 .38927 Mtetra
.505 .564 .85 r
.52299 .38927 .52678 .39335 .5338 .39415 .53001 .38994 Mtetra
.52 .566 .842 r
.53001 .38994 .5338 .39415 .54085 .39483 .53706 .39048 Mtetra
.534 .567 .834 r
.53706 .39048 .54085 .39483 .54793 .39539 .54414 .3909 Mtetra
.547 .568 .827 r
.54414 .3909 .54793 .39539 .55503 .39582 .55124 .39119 Mtetra
.559 .568 .819 r
.55124 .39119 .55503 .39582 .56217 .39613 .55838 .39135 Mtetra
.571 .568 .811 r
.55838 .39135 .56217 .39613 .56932 .3963 .56553 .39137 Mtetra
.581 .568 .804 r
.56553 .39137 .56932 .3963 .57651 .39634 .57272 .39125 Mtetra
.59 .567 .797 r
.57272 .39125 .57651 .39634 .58372 .39624 .57992 .39098 Mtetra
.598 .566 .789 r
.57992 .39098 .58372 .39624 .59095 .39601 .58715 .39058 Mtetra
.606 .565 .782 r
.58715 .39058 .59095 .39601 .5982 .39564 .59439 .39003 Mtetra
.612 .564 .776 r
.59439 .39003 .5982 .39564 .60547 .39513 .60166 .38935 Mtetra
.618 .562 .769 r
.60166 .38935 .60547 .39513 .61276 .39449 .60894 .38853 Mtetra
.623 .561 .763 r
.60894 .38853 .61276 .39449 .62006 .39371 .61624 .38758 Mtetra
.628 .559 .758 r
.61624 .38758 .62006 .39371 .62739 .39281 .62355 .3865 Mtetra
.632 .558 .752 r
.62355 .3865 .62739 .39281 .63473 .39176 .63088 .38529 Mtetra
.637 .557 .748 r
.63088 .38529 .63473 .39176 .64208 .39058 .63822 .38394 Mtetra
.641 .556 .743 r
.63822 .38394 .64208 .39058 .64944 .38923 .64557 .38245 Mtetra
.646 .556 .739 r
.64557 .38245 .64944 .38923 .65681 .38772 .65293 .3808 Mtetra
.651 .556 .735 r
.65293 .3808 .65681 .38772 .66418 .386 .6603 .37896 Mtetra
.631 .543 .736 r
.6603 .37896 .66418 .386 .67161 .38471 .66772 .37766 Mtetra
.611 .531 .74 r
.66772 .37766 .67161 .38471 .67908 .38385 .67519 .3769 Mtetra
.618 .538 .741 r
.67519 .3769 .67908 .38385 .68656 .38278 .68268 .37595 Mtetra
.625 .544 .743 r
.68268 .37595 .68656 .38278 .69404 .38154 .69018 .37484 Mtetra
.631 .55 .745 r
.69018 .37484 .69404 .38154 .70154 .38015 .69768 .37359 Mtetra
.637 .557 .747 r
.69768 .37359 .70154 .38015 .70904 .37861 .7052 .3722 Mtetra
.643 .563 .75 r
.7052 .3722 .70904 .37861 .71655 .37693 .71272 .37068 Mtetra
.649 .571 .753 r
.71272 .37068 .71655 .37693 .72406 .37512 .72025 .36902 Mtetra
.655 .578 .756 r
.72025 .36902 .72406 .37512 .73158 .37317 .72778 .36723 Mtetra
.662 .586 .759 r
.72778 .36723 .73158 .37317 .7391 .37108 .73532 .36531 Mtetra
.669 .593 .762 r
.73532 .36531 .7391 .37108 .74662 .36885 .74286 .36324 Mtetra
.676 .602 .764 r
.74286 .36324 .74662 .36885 .75413 .36648 .7504 .36103 Mtetra
.684 .61 .767 r
.7504 .36103 .75413 .36648 .76165 .36397 .75793 .35867 Mtetra
.691 .618 .77 r
.75793 .35867 .76165 .36397 .76916 .36131 .76547 .35616 Mtetra
.699 .627 .772 r
.76547 .35616 .76916 .36131 .77666 .35852 .773 .35351 Mtetra
.706 .635 .775 r
.773 .35351 .77666 .35852 .78416 .35558 .78052 .35071 Mtetra
.714 .643 .777 r
.78052 .35071 .78416 .35558 .79165 .35251 .78803 .34777 Mtetra
.721 .651 .779 r
.78803 .34777 .79165 .35251 .79913 .3493 .79554 .34469 Mtetra
.729 .659 .781 r
.79554 .34469 .79913 .3493 .8066 .34597 .80303 .34147 Mtetra
.736 .667 .783 r
.80303 .34147 .8066 .34597 .81405 .34251 .81052 .33813 Mtetra
.743 .674 .784 r
.81052 .33813 .81405 .34251 .8215 .33894 .81799 .33467 Mtetra
.749 .682 .786 r
.81799 .33467 .8215 .33894 .82893 .33525 .82546 .33109 Mtetra
.756 .689 .787 r
.82546 .33109 .82893 .33525 .83636 .33145 .83291 .32739 Mtetra
.762 .696 .789 r
.83291 .32739 .83636 .33145 .84377 .32756 .84034 .3236 Mtetra
.768 .703 .79 r
.84034 .3236 .84377 .32756 .85116 .32357 .84777 .3197 Mtetra
.774 .709 .791 r
.84777 .3197 .85116 .32357 .85855 .31949 .85518 .31571 Mtetra
.779 .716 .793 r
.85518 .31571 .85855 .31949 .86592 .31532 .86258 .31164 Mtetra
.785 .722 .794 r
.86258 .31164 .86592 .31532 .87328 .31109 .86997 .30748 Mtetra
.79 .728 .795 r
.86997 .30748 .87328 .31109 .88062 .30678 .87735 .30325 Mtetra
.795 .734 .796 r
.87735 .30325 .88062 .30678 .88795 .3024 .88471 .29896 Mtetra
.799 .74 .798 r
.88471 .29896 .88795 .3024 .89527 .29797 .89206 .2946 Mtetra
.804 .746 .799 r
.89206 .2946 .89527 .29797 .90258 .29349 .8994 .2902 Mtetra
.808 .752 .801 r
.8994 .2902 .90258 .29349 .90988 .28896 .90673 .28574 Mtetra
.812 .758 .802 r
.90673 .28574 .90988 .28896 .91716 .28439 .91405 .28124 Mtetra
.816 .763 .804 r
.91405 .28124 .91716 .28439 .92444 .27978 .92135 .2767 Mtetra
.819 .769 .805 r
.92135 .2767 .92444 .27978 .9317 .27515 .92865 .27214 Mtetra
.823 .775 .807 r
.92865 .27214 .9317 .27515 .93896 .27049 .93594 .26755 Mtetra
.826 .78 .809 r
.93594 .26755 .93896 .27049 .94621 .26582 .94323 .26294 Mtetra
.829 .786 .811 r
.94323 .26294 .94621 .26582 .95346 .26113 .95051 .25832 Mtetra
.832 .792 .813 r
.95051 .25832 .95346 .26113 .96069 .25644 .95778 .25369 Mtetra
.098 .476 .894 r
.38585 .35803 .38978 .36029 .3961 .36206 .39219 .35973 Mtetra
.119 .481 .898 r
.39219 .35973 .3961 .36206 .40246 .36383 .39856 .36142 Mtetra
.141 .487 .902 r
.39856 .36142 .40246 .36383 .40886 .36559 .40496 .36311 Mtetra
.163 .493 .905 r
.40496 .36311 .40886 .36559 .41529 .36735 .4114 .36479 Mtetra
.185 .499 .907 r
.4114 .36479 .41529 .36735 .42175 .36909 .41787 .36646 Mtetra
.208 .506 .909 r
.41787 .36646 .42175 .36909 .42825 .37081 .42438 .3681 Mtetra
.231 .512 .909 r
.42438 .3681 .42825 .37081 .43479 .3725 .43092 .36971 Mtetra
.255 .518 .909 r
.43092 .36971 .43479 .3725 .44136 .37416 .4375 .37129 Mtetra
.278 .524 .909 r
.4375 .37129 .44136 .37416 .44797 .37578 .44411 .37283 Mtetra
.301 .53 .907 r
.44411 .37283 .44797 .37578 .45461 .37736 .45076 .37432 Mtetra
.323 .536 .905 r
.45076 .37432 .45461 .37736 .46129 .37888 .45745 .37576 Mtetra
.346 .541 .902 r
.45745 .37576 .46129 .37888 .46801 .38035 .46417 .37713 Mtetra
.368 .546 .898 r
.46417 .37713 .46801 .38035 .47476 .38175 .47093 .37845 Mtetra
.389 .551 .894 r
.47093 .37845 .47476 .38175 .48155 .38309 .47772 .37968 Mtetra
.409 .555 .889 r
.47772 .37968 .48155 .38309 .48837 .38435 .48455 .38084 Mtetra
.429 .559 .884 r
.48455 .38084 .48837 .38435 .49523 .38552 .49141 .38191 Mtetra
.448 .562 .878 r
.49141 .38191 .49523 .38552 .50212 .38661 .4983 .38289 Mtetra
.467 .565 .871 r
.4983 .38289 .50212 .38661 .50904 .3876 .50523 .38377 Mtetra
.484 .568 .864 r
.50523 .38377 .50904 .3876 .516 .38849 .51219 .38454 Mtetra
.501 .57 .857 r
.51219 .38454 .516 .38849 .52299 .38927 .51918 .3852 Mtetra
.516 .571 .85 r
.51918 .3852 .52299 .38927 .53001 .38994 .52621 .38574 Mtetra
.531 .573 .842 r
.52621 .38574 .53001 .38994 .53706 .39048 .53326 .38616 Mtetra
.545 .574 .835 r
.53326 .38616 .53706 .39048 .54414 .3909 .54034 .38644 Mtetra
.557 .574 .827 r
.54034 .38644 .54414 .3909 .55124 .39119 .54744 .38659 Mtetra
.569 .574 .819 r
.54744 .38659 .55124 .39119 .55838 .39135 .55458 .38659 Mtetra
.58 .574 .811 r
.55458 .38659 .55838 .39135 .56553 .39137 .56173 .38646 Mtetra
.59 .574 .804 r
.56173 .38646 .56553 .39137 .57272 .39125 .56891 .38617 Mtetra
.599 .573 .796 r
.56891 .38617 .57272 .39125 .57992 .39098 .57612 .38574 Mtetra
.607 .572 .789 r
.57612 .38574 .57992 .39098 .58715 .39058 .58334 .38517 Mtetra
.614 .571 .782 r
.58334 .38517 .58715 .39058 .59439 .39003 .59058 .38445 Mtetra
.621 .569 .775 r
.59058 .38445 .59439 .39003 .60166 .38935 .59784 .38359 Mtetra
.626 .567 .769 r
.59784 .38359 .60166 .38935 .60894 .38853 .60511 .38259 Mtetra
.631 .565 .763 r
.60511 .38259 .60894 .38853 .61624 .38758 .61241 .38146 Mtetra
.635 .564 .757 r
.61241 .38146 .61624 .38758 .62355 .3865 .61971 .38021 Mtetra
.639 .562 .752 r
.61971 .38021 .62355 .3865 .63088 .38529 .62703 .37884 Mtetra
.642 .56 .747 r
.62703 .37884 .63088 .38529 .63822 .38394 .63437 .37734 Mtetra
.646 .559 .743 r
.63437 .37734 .63822 .38394 .64557 .38245 .64171 .37571 Mtetra
.65 .559 .739 r
.64171 .37571 .64557 .38245 .65293 .3808 .64906 .37393 Mtetra
.655 .559 .735 r
.64906 .37393 .65293 .3808 .6603 .37896 .65642 .37197 Mtetra
.632 .544 .738 r
.65642 .37197 .6603 .37896 .66772 .37766 .66383 .37066 Mtetra
.607 .53 .742 r
.66383 .37066 .66772 .37766 .67519 .3769 .67131 .37 Mtetra
.614 .536 .743 r
.67131 .37 .67519 .3769 .68268 .37595 .6788 .36916 Mtetra
.62 .542 .745 r
.6788 .36916 .68268 .37595 .69018 .37484 .68631 .36817 Mtetra
.626 .548 .747 r
.68631 .36817 .69018 .37484 .69768 .37359 .69382 .36705 Mtetra
.631 .554 .75 r
.69382 .36705 .69768 .37359 .7052 .3722 .70135 .36581 Mtetra
.637 .561 .752 r
.70135 .36581 .7052 .3722 .71272 .37068 .70888 .36444 Mtetra
.643 .568 .755 r
.70888 .36444 .71272 .37068 .72025 .36902 .71643 .36295 Mtetra
.649 .575 .758 r
.71643 .36295 .72025 .36902 .72778 .36723 .72398 .36132 Mtetra
.656 .583 .761 r
.72398 .36132 .72778 .36723 .73532 .36531 .73154 .35956 Mtetra
.663 .591 .764 r
.73154 .35956 .73532 .36531 .74286 .36324 .7391 .35765 Mtetra
.67 .6 .767 r
.7391 .35765 .74286 .36324 .7504 .36103 .74666 .3556 Mtetra
.678 .608 .77 r
.74666 .3556 .7504 .36103 .75793 .35867 .75422 .35339 Mtetra
.686 .617 .773 r
.75422 .35339 .75793 .35867 .76547 .35616 .76177 .35103 Mtetra
.694 .625 .775 r
.76177 .35103 .76547 .35616 .773 .35351 .76933 .34852 Mtetra
.702 .634 .778 r
.76933 .34852 .773 .35351 .78052 .35071 .77687 .34585 Mtetra
.709 .642 .78 r
.77687 .34585 .78052 .35071 .78803 .34777 .78441 .34304 Mtetra
.717 .65 .782 r
.78441 .34304 .78803 .34777 .79554 .34469 .79194 .34009 Mtetra
.724 .658 .784 r
.79194 .34009 .79554 .34469 .80303 .34147 .79946 .337 Mtetra
.732 .666 .786 r
.79946 .337 .80303 .34147 .81052 .33813 .80698 .33377 Mtetra
.739 .674 .787 r
.80698 .33377 .81052 .33813 .81799 .33467 .81448 .33042 Mtetra
.746 .681 .789 r
.81448 .33042 .81799 .33467 .82546 .33109 .82197 .32694 Mtetra
.753 .689 .79 r
.82197 .32694 .82546 .33109 .83291 .32739 .82945 .32335 Mtetra
.759 .696 .792 r
.82945 .32335 .83291 .32739 .84034 .3236 .83691 .31965 Mtetra
.765 .703 .793 r
.83691 .31965 .84034 .3236 .84777 .3197 .84437 .31584 Mtetra
.771 .709 .794 r
.84437 .31584 .84777 .3197 .85518 .31571 .85181 .31194 Mtetra
.777 .716 .795 r
.85181 .31194 .85518 .31571 .86258 .31164 .85924 .30795 Mtetra
.782 .722 .797 r
.85924 .30795 .86258 .31164 .86997 .30748 .86666 .30388 Mtetra
.787 .728 .798 r
.86666 .30388 .86997 .30748 .87735 .30325 .87406 .29973 Mtetra
.792 .734 .799 r
.87406 .29973 .87735 .30325 .88471 .29896 .88146 .29552 Mtetra
.797 .74 .8 r
.88146 .29552 .88471 .29896 .89206 .2946 .88884 .29124 Mtetra
.801 .746 .802 r
.88884 .29124 .89206 .2946 .8994 .2902 .89621 .2869 Mtetra
.805 .752 .803 r
.89621 .2869 .8994 .2902 .90673 .28574 .90357 .28251 Mtetra
.81 .758 .804 r
.90357 .28251 .90673 .28574 .91405 .28124 .91092 .27808 Mtetra
.813 .763 .806 r
.91092 .27808 .91405 .28124 .92135 .2767 .91826 .27362 Mtetra
.817 .769 .808 r
.91826 .27362 .92135 .2767 .92865 .27214 .92559 .26912 Mtetra
.82 .774 .809 r
.92559 .26912 .92865 .27214 .93594 .26755 .93291 .26459 Mtetra
.824 .78 .811 r
.93291 .26459 .93594 .26755 .94323 .26294 .94023 .26005 Mtetra
.827 .786 .813 r
.94023 .26005 .94323 .26294 .95051 .25832 .94754 .2555 Mtetra
.829 .791 .816 r
.94754 .2555 .95051 .25832 .95778 .25369 .95485 .25093 Mtetra
.12 .49 .902 r
.38192 .35576 .38585 .35803 .39219 .35973 .38826 .35739 Mtetra
.14 .494 .905 r
.38826 .35739 .39219 .35973 .39856 .36142 .39463 .35901 Mtetra
.16 .5 .908 r
.39463 .35901 .39856 .36142 .40496 .36311 .40105 .36063 Mtetra
.182 .505 .91 r
.40105 .36063 .40496 .36311 .4114 .36479 .40749 .36223 Mtetra
.203 .511 .912 r
.40749 .36223 .4114 .36479 .41787 .36646 .41397 .36382 Mtetra
.225 .517 .913 r
.41397 .36382 .41787 .36646 .42438 .3681 .42048 .36539 Mtetra
.248 .522 .913 r
.42048 .36539 .42438 .3681 .43092 .36971 .42703 .36692 Mtetra
.27 .528 .913 r
.42703 .36692 .43092 .36971 .4375 .37129 .43362 .36842 Mtetra
.293 .534 .912 r
.43362 .36842 .4375 .37129 .44411 .37283 .44024 .36988 Mtetra
.315 .539 .91 r
.44024 .36988 .44411 .37283 .45076 .37432 .4469 .37129 Mtetra
.337 .545 .907 r
.4469 .37129 .45076 .37432 .45745 .37576 .45359 .37264 Mtetra
.359 .55 .904 r
.45359 .37264 .45745 .37576 .46417 .37713 .46032 .37393 Mtetra
.38 .554 .9 r
.46032 .37393 .46417 .37713 .47093 .37845 .46708 .37514 Mtetra
.401 .559 .896 r
.46708 .37514 .47093 .37845 .47772 .37968 .47388 .37629 Mtetra
.421 .563 .89 r
.47388 .37629 .47772 .37968 .48455 .38084 .48071 .37735 Mtetra
.441 .566 .885 r
.48071 .37735 .48455 .38084 .49141 .38191 .48758 .37832 Mtetra
.46 .57 .879 r
.48758 .37832 .49141 .38191 .4983 .38289 .49448 .37919 Mtetra
.478 .572 .872 r
.49448 .37919 .4983 .38289 .50523 .38377 .50141 .37996 Mtetra
.495 .575 .865 r
.50141 .37996 .50523 .38377 .51219 .38454 .50837 .38062 Mtetra
.511 .577 .858 r
.50837 .38062 .51219 .38454 .51918 .3852 .51537 .38116 Mtetra
.527 .578 .85 r
.51537 .38116 .51918 .3852 .52621 .38574 .52239 .38157 Mtetra
.541 .579 .842 r
.52239 .38157 .52621 .38574 .53326 .38616 .52945 .38185 Mtetra
.555 .58 .835 r
.52945 .38185 .53326 .38616 .54034 .38644 .53653 .382 Mtetra
.567 .581 .827 r
.53653 .382 .54034 .38644 .54744 .38659 .54364 .382 Mtetra
.579 .581 .819 r
.54364 .382 .54744 .38659 .55458 .38659 .55077 .38186 Mtetra
.59 .581 .811 r
.55077 .38186 .55458 .38659 .56173 .38646 .55793 .38157 Mtetra
.599 .58 .803 r
.55793 .38157 .56173 .38646 .56891 .38617 .5651 .38113 Mtetra
.608 .579 .795 r
.5651 .38113 .56891 .38617 .57612 .38574 .5723 .38053 Mtetra
.616 .578 .788 r
.5723 .38053 .57612 .38574 .58334 .38517 .57952 .37978 Mtetra
.623 .576 .781 r
.57952 .37978 .58334 .38517 .59058 .38445 .58676 .37889 Mtetra
.629 .574 .774 r
.58676 .37889 .59058 .38445 .59784 .38359 .59402 .37785 Mtetra
.634 .572 .768 r
.59402 .37785 .59784 .38359 .60511 .38259 .60129 .37667 Mtetra
.638 .57 .762 r
.60129 .37667 .60511 .38259 .61241 .38146 .60857 .37537 Mtetra
.642 .568 .756 r
.60857 .37537 .61241 .38146 .61971 .38021 .61587 .37395 Mtetra
.645 .566 .751 r
.61587 .37395 .61971 .38021 .62703 .37884 .62318 .37241 Mtetra
.648 .564 .747 r
.62318 .37241 .62703 .37884 .63437 .37734 .63051 .37076 Mtetra
.651 .563 .742 r
.63051 .37076 .63437 .37734 .64171 .37571 .63784 .36899 Mtetra
.654 .562 .738 r
.63784 .36899 .64171 .37571 .64906 .37393 .64519 .36709 Mtetra
.659 .562 .735 r
.64519 .36709 .64906 .37393 .65642 .37197 .65254 .36503 Mtetra
.632 .545 .739 r
.65254 .36503 .65642 .37197 .66383 .37066 .65995 .36371 Mtetra
.603 .529 .744 r
.65995 .36371 .66383 .37066 .67131 .37 .66743 .36313 Mtetra
.61 .535 .745 r
.66743 .36313 .67131 .37 .6788 .36916 .67493 .3624 Mtetra
.615 .54 .747 r
.67493 .3624 .6788 .36916 .68631 .36817 .68244 .36153 Mtetra
.62 .546 .749 r
.68244 .36153 .68631 .36817 .69382 .36705 .68996 .36054 Mtetra
.625 .552 .752 r
.68996 .36054 .69382 .36705 .70135 .36581 .6975 .35945 Mtetra
.631 .558 .754 r
.6975 .35945 .70135 .36581 .70888 .36444 .70505 .35824 Mtetra
.636 .565 .758 r
.70505 .35824 .70888 .36444 .71643 .36295 .71261 .3569 Mtetra
.643 .573 .761 r
.71261 .3569 .71643 .36295 .72398 .36132 .72018 .35544 Mtetra
.649 .581 .764 r
.72018 .35544 .72398 .36132 .73154 .35956 .72775 .35384 Mtetra
.657 .589 .767 r
.72775 .35384 .73154 .35956 .7391 .35765 .73533 .35209 Mtetra
.664 .597 .77 r
.73533 .35209 .7391 .35765 .74666 .3556 .74291 .35019 Mtetra
.672 .606 .773 r
.74291 .35019 .74666 .3556 .75422 .35339 .75049 .34813 Mtetra
.68 .615 .776 r
.75049 .34813 .75422 .35339 .76177 .35103 .75807 .34592 Mtetra
.688 .624 .779 r
.75807 .34592 .76177 .35103 .76933 .34852 .76565 .34355 Mtetra
.697 .633 .781 r
.76565 .34355 .76933 .34852 .77687 .34585 .77322 .34102 Mtetra
.705 .641 .783 r
.77322 .34102 .77687 .34585 .78441 .34304 .78078 .33834 Mtetra
.713 .65 .785 r
.78078 .33834 .78441 .34304 .79194 .34009 .78834 .33552 Mtetra
.72 .658 .787 r
.78834 .33552 .79194 .34009 .79946 .337 .79589 .33254 Mtetra
.728 .666 .789 r
.79589 .33254 .79946 .337 .80698 .33377 .80343 .32943 Mtetra
.735 .674 .79 r
.80343 .32943 .80698 .33377 .81448 .33042 .81096 .32618 Mtetra
.742 .681 .792 r
.81096 .32618 .81448 .33042 .82197 .32694 .81847 .32281 Mtetra
.749 .689 .793 r
.81847 .32281 .82197 .32694 .82945 .32335 .82598 .31932 Mtetra
.756 .696 .794 r
.82598 .31932 .82945 .32335 .83691 .31965 .83347 .31571 Mtetra
.762 .703 .796 r
.83347 .31571 .83691 .31965 .84437 .31584 .84096 .312 Mtetra
.768 .709 .797 r
.84096 .312 .84437 .31584 .85181 .31194 .84843 .30818 Mtetra
.774 .716 .798 r
.84843 .30818 .85181 .31194 .85924 .30795 .85589 .30428 Mtetra
.779 .722 .799 r
.85589 .30428 .85924 .30795 .86666 .30388 .86333 .30029 Mtetra
.785 .728 .8 r
.86333 .30029 .86666 .30388 .87406 .29973 .87077 .29622 Mtetra
.79 .735 .802 r
.87077 .29622 .87406 .29973 .88146 .29552 .87819 .29207 Mtetra
.794 .74 .803 r
.87819 .29207 .88146 .29552 .88884 .29124 .8856 .28787 Mtetra
.799 .746 .804 r
.8856 .28787 .88884 .29124 .89621 .2869 .893 .2836 Mtetra
.803 .752 .805 r
.893 .2836 .89621 .2869 .90357 .28251 .90039 .27929 Mtetra
.807 .758 .807 r
.90039 .27929 .90357 .28251 .91092 .27808 .90778 .27492 Mtetra
.811 .763 .808 r
.90778 .27492 .91092 .27808 .91826 .27362 .91515 .27052 Mtetra
.815 .769 .81 r
.91515 .27052 .91826 .27362 .92559 .26912 .92251 .26609 Mtetra
.818 .774 .812 r
.92251 .26609 .92559 .26912 .93291 .26459 .92987 .26163 Mtetra
.821 .78 .814 r
.92987 .26163 .93291 .26459 .94023 .26005 .93722 .25715 Mtetra
.824 .785 .816 r
.93722 .25715 .94023 .26005 .94754 .2555 .94457 .25266 Mtetra
.827 .791 .818 r
.94457 .25266 .94754 .2555 .95485 .25093 .95191 .24816 Mtetra
.142 .503 .909 r
.37796 .35349 .38192 .35576 .38826 .35739 .38431 .35504 Mtetra
.16 .507 .911 r
.38431 .35504 .38826 .35739 .39463 .35901 .3907 .35659 Mtetra
.18 .511 .914 r
.3907 .35659 .39463 .35901 .40105 .36063 .39711 .35814 Mtetra
.2 .516 .915 r
.39711 .35814 .40105 .36063 .40749 .36223 .40357 .35967 Mtetra
.221 .521 .916 r
.40357 .35967 .40749 .36223 .41397 .36382 .41005 .36119 Mtetra
.242 .527 .917 r
.41005 .36119 .41397 .36382 .42048 .36539 .41658 .36268 Mtetra
.264 .532 .917 r
.41658 .36268 .42048 .36539 .42703 .36692 .42313 .36413 Mtetra
.285 .538 .916 r
.42313 .36413 .42703 .36692 .43362 .36842 .42973 .36555 Mtetra
.307 .543 .914 r
.42973 .36555 .43362 .36842 .44024 .36988 .43635 .36693 Mtetra
.329 .548 .912 r
.43635 .36693 .44024 .36988 .4469 .37129 .44302 .36825 Mtetra
.351 .553 .909 r
.44302 .36825 .4469 .37129 .45359 .37264 .44971 .36952 Mtetra
.372 .558 .906 r
.44971 .36952 .45359 .37264 .46032 .37393 .45645 .37072 Mtetra
.393 .562 .902 r
.45645 .37072 .46032 .37393 .46708 .37514 .46322 .37185 Mtetra
.413 .566 .897 r
.46322 .37185 .46708 .37514 .47388 .37629 .47002 .3729 Mtetra
.433 .57 .892 r
.47002 .3729 .47388 .37629 .48071 .37735 .47686 .37386 Mtetra
.452 .574 .886 r
.47686 .37386 .48071 .37735 .48758 .37832 .48373 .37473 Mtetra
.471 .577 .879 r
.48373 .37473 .48758 .37832 .49448 .37919 .49063 .3755 Mtetra
.488 .579 .873 r
.49063 .3755 .49448 .37919 .50141 .37996 .49757 .37616 Mtetra
.505 .582 .866 r
.49757 .37616 .50141 .37996 .50837 .38062 .50454 .37671 Mtetra
.521 .583 .858 r
.50454 .37671 .50837 .38062 .51537 .38116 .51154 .37713 Mtetra
.537 .585 .85 r
.51154 .37713 .51537 .38116 .52239 .38157 .51857 .37742 Mtetra
.551 .586 .843 r
.51857 .37742 .52239 .38157 .52945 .38185 .52562 .37757 Mtetra
.564 .587 .835 r
.52562 .37757 .52945 .38185 .53653 .382 .53271 .37758 Mtetra
.577 .587 .826 r
.53271 .37758 .53653 .382 .54364 .382 .53982 .37745 Mtetra
.588 .587 .818 r
.53982 .37745 .54364 .382 .55077 .38186 .54695 .37716 Mtetra
.599 .587 .81 r
.54695 .37716 .55077 .38186 .55793 .38157 .55411 .37671 Mtetra
.608 .586 .803 r
.55411 .37671 .55793 .38157 .5651 .38113 .56129 .37611 Mtetra
.617 .585 .795 r
.56129 .37611 .5651 .38113 .5723 .38053 .56849 .37534 Mtetra
.625 .583 .787 r
.56849 .37534 .5723 .38053 .57952 .37978 .5757 .37442 Mtetra
.631 .582 .78 r
.5757 .37442 .57952 .37978 .58676 .37889 .58294 .37335 Mtetra
.637 .58 .773 r
.58294 .37335 .58676 .37889 .59402 .37785 .59019 .37214 Mtetra
.642 .577 .767 r
.59019 .37214 .59402 .37785 .60129 .37667 .59745 .37078 Mtetra
.646 .575 .761 r
.59745 .37078 .60129 .37667 .60857 .37537 .60473 .3693 Mtetra
.649 .572 .755 r
.60473 .3693 .60857 .37537 .61587 .37395 .61203 .3677 Mtetra
.651 .57 .75 r
.61203 .3677 .61587 .37395 .62318 .37241 .61933 .366 Mtetra
.653 .568 .746 r
.61933 .366 .62318 .37241 .63051 .37076 .62665 .3642 Mtetra
.656 .566 .742 r
.62665 .3642 .63051 .37076 .63784 .36899 .63398 .3623 Mtetra
.658 .565 .738 r
.63398 .3623 .63784 .36899 .64519 .36709 .64131 .36029 Mtetra
.662 .565 .735 r
.64131 .36029 .64519 .36709 .65254 .36503 .64866 .35813 Mtetra
.632 .546 .74 r
.64866 .35813 .65254 .36503 .65995 .36371 .65607 .35681 Mtetra
.599 .528 .745 r
.65607 .35681 .65995 .36371 .66743 .36313 .66355 .3563 Mtetra
.605 .533 .747 r
.66355 .3563 .66743 .36313 .67493 .3624 .67105 .35566 Mtetra
.61 .538 .748 r
.67105 .35566 .67493 .3624 .68244 .36153 .67857 .35491 Mtetra
.615 .543 .751 r
.67857 .35491 .68244 .36153 .68996 .36054 .6861 .35406 Mtetra
.619 .549 .753 r
.6861 .35406 .68996 .36054 .6975 .35945 .69365 .3531 Mtetra
.624 .555 .757 r
.69365 .3531 .6975 .35945 .70505 .35824 .70121 .35205 Mtetra
.63 .562 .76 r
.70121 .35205 .70505 .35824 .71261 .3569 .70879 .35088 Mtetra
.636 .57 .763 r
.70879 .35088 .71261 .3569 .72018 .35544 .71637 .34958 Mtetra
.643 .578 .767 r
.71637 .34958 .72018 .35544 .72775 .35384 .72396 .34814 Mtetra
.65 .586 .77 r
.72396 .34814 .72775 .35384 .73533 .35209 .73156 .34655 Mtetra
.658 .595 .773 r
.73156 .34655 .73533 .35209 .74291 .35019 .73917 .34481 Mtetra
.666 .604 .776 r
.73917 .34481 .74291 .35019 .75049 .34813 .74677 .34291 Mtetra
.674 .613 .779 r
.74677 .34291 .75049 .34813 .75807 .34592 .75437 .34084 Mtetra
.683 .622 .782 r
.75437 .34084 .75807 .34592 .76565 .34355 .76197 .33861 Mtetra
.691 .631 .784 r
.76197 .33861 .76565 .34355 .77322 .34102 .76956 .33622 Mtetra
.7 .64 .786 r
.76956 .33622 .77322 .34102 .78078 .33834 .77715 .33367 Mtetra
.708 .649 .788 r
.77715 .33367 .78078 .33834 .78834 .33552 .78473 .33096 Mtetra
.716 .657 .79 r
.78473 .33096 .78834 .33552 .79589 .33254 .79231 .3281 Mtetra
.724 .666 .792 r
.79231 .3281 .79589 .33254 .80343 .32943 .79987 .3251 Mtetra
.732 .673 .793 r
.79987 .3251 .80343 .32943 .81096 .32618 .80743 .32196 Mtetra
.739 .681 .795 r
.80743 .32196 .81096 .32618 .81847 .32281 .81497 .31869 Mtetra
.746 .689 .796 r
.81497 .31869 .81847 .32281 .82598 .31932 .8225 .3153 Mtetra
.753 .696 .797 r
.8225 .3153 .82598 .31932 .83347 .31571 .83003 .31178 Mtetra
.759 .703 .799 r
.83003 .31178 .83347 .31571 .84096 .312 .83754 .30816 Mtetra
.765 .71 .8 r
.83754 .30816 .84096 .312 .84843 .30818 .84504 .30443 Mtetra
.771 .716 .801 r
.84504 .30443 .84843 .30818 .85589 .30428 .85252 .30061 Mtetra
.777 .722 .802 r
.85252 .30061 .85589 .30428 .86333 .30029 .86 .2967 Mtetra
.782 .729 .803 r
.86 .2967 .86333 .30029 .87077 .29622 .86746 .2927 Mtetra
.787 .735 .804 r
.86746 .2927 .87077 .29622 .87819 .29207 .87491 .28863 Mtetra
.792 .741 .805 r
.87491 .28863 .87819 .29207 .8856 .28787 .88236 .2845 Mtetra
.797 .746 .806 r
.88236 .2845 .8856 .28787 .893 .2836 .88979 .2803 Mtetra
.801 .752 .808 r
.88979 .2803 .893 .2836 .90039 .27929 .89721 .27605 Mtetra
.805 .758 .809 r
.89721 .27605 .90039 .27929 .90778 .27492 .90462 .27176 Mtetra
.809 .763 .811 r
.90462 .27176 .90778 .27492 .91515 .27052 .91203 .26742 Mtetra
.812 .769 .812 r
.91203 .26742 .91515 .27052 .92251 .26609 .91942 .26305 Mtetra
.816 .774 .814 r
.91942 .26305 .92251 .26609 .92987 .26163 .92681 .25866 Mtetra
.819 .779 .816 r
.92681 .25866 .92987 .26163 .93722 .25715 .9342 .25424 Mtetra
.821 .785 .818 r
.9342 .25424 .93722 .25715 .94457 .25266 .94157 .24981 Mtetra
.824 .79 .82 r
.94157 .24981 .94457 .25266 .95191 .24816 .94895 .24537 Mtetra
.162 .515 .915 r
.37398 .3512 .37796 .35349 .38431 .35504 .38034 .35268 Mtetra
.18 .519 .917 r
.38034 .35268 .38431 .35504 .3907 .35659 .38674 .35417 Mtetra
.198 .522 .918 r
.38674 .35417 .3907 .35659 .39711 .35814 .39316 .35564 Mtetra
.217 .527 .92 r
.39316 .35564 .39711 .35814 .40357 .35967 .39963 .3571 Mtetra
.237 .532 .92 r
.39963 .3571 .40357 .35967 .41005 .36119 .40612 .35854 Mtetra
.258 .536 .92 r
.40612 .35854 .41005 .36119 .41658 .36268 .41265 .35996 Mtetra
.279 .541 .92 r
.41265 .35996 .41658 .36268 .42313 .36413 .41921 .36134 Mtetra
.3 .547 .919 r
.41921 .36134 .42313 .36413 .42973 .36555 .42581 .36269 Mtetra
.321 .552 .917 r
.42581 .36269 .42973 .36555 .43635 .36693 .43245 .36398 Mtetra
.342 .556 .914 r
.43245 .36398 .43635 .36693 .44302 .36825 .43912 .36523 Mtetra
.363 .561 .911 r
.43912 .36523 .44302 .36825 .44971 .36952 .44582 .36641 Mtetra
.384 .566 .908 r
.44582 .36641 .44971 .36952 .45645 .37072 .45256 .36753 Mtetra
.405 .57 .903 r
.45256 .36753 .45645 .37072 .46322 .37185 .45934 .36857 Mtetra
.425 .574 .898 r
.45934 .36857 .46322 .37185 .47002 .3729 .46615 .36953 Mtetra
.444 .578 .893 r
.46615 .36953 .47002 .3729 .47686 .37386 .47299 .37039 Mtetra
.463 .581 .887 r
.47299 .37039 .47686 .37386 .48373 .37473 .47987 .37116 Mtetra
.481 .584 .88 r
.47987 .37116 .48373 .37473 .49063 .3755 .48678 .37183 Mtetra
.499 .586 .873 r
.48678 .37183 .49063 .3755 .49757 .37616 .49372 .37238 Mtetra
.516 .588 .866 r
.49372 .37238 .49757 .37616 .50454 .37671 .50069 .37281 Mtetra
.531 .59 .858 r
.50069 .37281 .50454 .37671 .51154 .37713 .5077 .37312 Mtetra
.546 .591 .851 r
.5077 .37312 .51154 .37713 .51857 .37742 .51473 .37329 Mtetra
.56 .592 .843 r
.51473 .37329 .51857 .37742 .52562 .37757 .52179 .37331 Mtetra
.574 .593 .834 r
.52179 .37331 .52562 .37757 .53271 .37758 .52888 .37319 Mtetra
.586 .593 .826 r
.52888 .37319 .53271 .37758 .53982 .37745 .53599 .37291 Mtetra
.597 .593 .818 r
.53599 .37291 .53982 .37745 .54695 .37716 .54312 .37248 Mtetra
.608 .593 .81 r
.54312 .37248 .54695 .37716 .55411 .37671 .55028 .37188 Mtetra
.617 .592 .802 r
.55028 .37188 .55411 .37671 .56129 .37611 .55746 .37111 Mtetra
.626 .59 .794 r
.55746 .37111 .56129 .37611 .56849 .37534 .56466 .37019 Mtetra
.633 .589 .787 r
.56466 .37019 .56849 .37534 .5757 .37442 .57188 .36909 Mtetra
.64 .587 .779 r
.57188 .36909 .5757 .37442 .58294 .37335 .57911 .36784 Mtetra
.645 .585 .772 r
.57911 .36784 .58294 .37335 .59019 .37214 .58636 .36645 Mtetra
.649 .582 .766 r
.58636 .36645 .59019 .37214 .59745 .37078 .59362 .36491 Mtetra
.653 .579 .76 r
.59362 .36491 .59745 .37078 .60473 .3693 .60089 .36325 Mtetra
.655 .577 .754 r
.60089 .36325 .60473 .3693 .61203 .3677 .60818 .36148 Mtetra
.657 .574 .749 r
.60818 .36148 .61203 .3677 .61933 .366 .61548 .35961 Mtetra
.659 .571 .745 r
.61548 .35961 .61933 .366 .62665 .3642 .62279 .35766 Mtetra
.66 .569 .741 r
.62279 .35766 .62665 .3642 .63398 .3623 .63011 .35563 Mtetra
.662 .567 .738 r
.63011 .35563 .63398 .3623 .64131 .36029 .63744 .35351 Mtetra
.665 .567 .735 r
.63744 .35351 .64131 .36029 .64866 .35813 .64478 .35128 Mtetra
.632 .547 .741 r
.64478 .35128 .64866 .35813 .65607 .35681 .65218 .34994 Mtetra
.596 .527 .747 r
.65218 .34994 .65607 .35681 .66355 .3563 .65967 .3495 Mtetra
.601 .531 .748 r
.65967 .3495 .66355 .3563 .67105 .35566 .66717 .34895 Mtetra
.605 .536 .75 r
.66717 .34895 .67105 .35566 .67857 .35491 .67469 .3483 Mtetra
.609 .54 .752 r
.67469 .3483 .67857 .35491 .6861 .35406 .68223 .34758 Mtetra
.613 .546 .755 r
.68223 .34758 .6861 .35406 .69365 .3531 .68979 .34678 Mtetra
.617 .552 .759 r
.68979 .34678 .69365 .3531 .70121 .35205 .69737 .34588 Mtetra
.622 .559 .762 r
.69737 .34588 .70121 .35205 .70879 .35088 .70496 .34487 Mtetra
.628 .567 .766 r
.70496 .34487 .70879 .35088 .71637 .34958 .71256 .34374 Mtetra
.635 .575 .769 r
.71256 .34374 .71637 .34958 .72396 .34814 .72017 .34247 Mtetra
.643 .584 .773 r
.72017 .34247 .72396 .34814 .73156 .34655 .72779 .34104 Mtetra
.651 .593 .776 r
.72779 .34104 .73156 .34655 .73917 .34481 .73541 .33946 Mtetra
.66 .602 .779 r
.73541 .33946 .73917 .34481 .74677 .34291 .74304 .33771 Mtetra
.668 .612 .782 r
.74304 .33771 .74677 .34291 .75437 .34084 .75066 .33579 Mtetra
.677 .621 .785 r
.75066 .33579 .75437 .34084 .76197 .33861 .75828 .3337 Mtetra
.686 .63 .788 r
.75828 .3337 .76197 .33861 .76956 .33622 .7659 .33144 Mtetra
.695 .639 .79 r
.7659 .33144 .76956 .33622 .77715 .33367 .77351 .32901 Mtetra
.704 .648 .792 r
.77351 .32901 .77715 .33367 .78473 .33096 .78112 .32643 Mtetra
.712 .657 .793 r
.78112 .32643 .78473 .33096 .79231 .3281 .78872 .32369 Mtetra
.72 .665 .795 r
.78872 .32369 .79231 .3281 .79987 .3251 .79631 .3208 Mtetra
.728 .673 .797 r
.79631 .3208 .79987 .3251 .80743 .32196 .80389 .31776 Mtetra
.736 .681 .798 r
.80389 .31776 .80743 .32196 .81497 .31869 .81146 .31459 Mtetra
.743 .689 .799 r
.81146 .31459 .81497 .31869 .8225 .3153 .81902 .31129 Mtetra
.75 .696 .8 r
.81902 .31129 .8225 .3153 .83003 .31178 .82657 .30787 Mtetra
.756 .703 .801 r
.82657 .30787 .83003 .31178 .83754 .30816 .83411 .30433 Mtetra
.763 .71 .802 r
.83411 .30433 .83754 .30816 .84504 .30443 .84163 .30069 Mtetra
.769 .716 .804 r
.84163 .30069 .84504 .30443 .85252 .30061 .84915 .29695 Mtetra
.774 .723 .805 r
.84915 .29695 .85252 .30061 .86 .2967 .85665 .29311 Mtetra
.78 .729 .806 r
.85665 .29311 .86 .2967 .86746 .2927 .86415 .28919 Mtetra
.785 .735 .807 r
.86415 .28919 .86746 .2927 .87491 .28863 .87163 .2852 Mtetra
.79 .741 .808 r
.87163 .2852 .87491 .28863 .88236 .2845 .8791 .28113 Mtetra
.794 .747 .809 r
.8791 .28113 .88236 .2845 .88979 .2803 .88656 .277 Mtetra
.798 .752 .81 r
.88656 .277 .88979 .2803 .89721 .27605 .89401 .27282 Mtetra
.803 .758 .812 r
.89401 .27282 .89721 .27605 .90462 .27176 .90146 .26859 Mtetra
.806 .763 .813 r
.90146 .26859 .90462 .27176 .91203 .26742 .90889 .26432 Mtetra
.81 .768 .815 r
.90889 .26432 .91203 .26742 .91942 .26305 .91632 .26001 Mtetra
.813 .774 .816 r
.91632 .26001 .91942 .26305 .92681 .25866 .92374 .25567 Mtetra
.816 .779 .818 r
.92374 .25567 .92681 .25866 .9342 .25424 .93116 .25132 Mtetra
.819 .785 .82 r
.93116 .25132 .9342 .25424 .94157 .24981 .93857 .24695 Mtetra
.822 .79 .822 r
.93857 .24695 .94157 .24981 .94895 .24537 .94598 .24257 Mtetra
.182 .527 .921 r
.36999 .34891 .37398 .3512 .38034 .35268 .37636 .35032 Mtetra
.198 .53 .922 r
.37636 .35032 .38034 .35268 .38674 .35417 .38276 .35173 Mtetra
.216 .533 .923 r
.38276 .35173 .38674 .35417 .39316 .35564 .3892 .35314 Mtetra
.234 .537 .923 r
.3892 .35314 .39316 .35564 .39963 .3571 .39567 .35453 Mtetra
.253 .541 .924 r
.39567 .35453 .39963 .3571 .40612 .35854 .40217 .3559 Mtetra
.273 .546 .923 r
.40217 .3559 .40612 .35854 .41265 .35996 .40871 .35724 Mtetra
.293 .55 .922 r
.40871 .35724 .41265 .35996 .41921 .36134 .41528 .35855 Mtetra
.314 .555 .921 r
.41528 .35855 .41921 .36134 .42581 .36269 .42189 .35982 Mtetra
.334 .56 .919 r
.42189 .35982 .42581 .36269 .43245 .36398 .42853 .36104 Mtetra
.355 .564 .916 r
.42853 .36104 .43245 .36398 .43912 .36523 .43521 .36221 Mtetra
.376 .569 .913 r
.43521 .36221 .43912 .36523 .44582 .36641 .44192 .36331 Mtetra
.396 .573 .909 r
.44192 .36331 .44582 .36641 .45256 .36753 .44867 .36434 Mtetra
.416 .577 .904 r
.44867 .36434 .45256 .36753 .45934 .36857 .45545 .36529 Mtetra
.436 .581 .899 r
.45545 .36529 .45934 .36857 .46615 .36953 .46226 .36616 Mtetra
.455 .585 .894 r
.46226 .36616 .46615 .36953 .47299 .37039 .46911 .36694 Mtetra
.474 .588 .887 r
.46911 .36694 .47299 .37039 .47987 .37116 .47599 .36761 Mtetra
.492 .59 .881 r
.47599 .36761 .47987 .37116 .48678 .37183 .48291 .36817 Mtetra
.509 .593 .874 r
.48291 .36817 .48678 .37183 .49372 .37238 .48986 .36862 Mtetra
.525 .595 .866 r
.48986 .36862 .49372 .37238 .50069 .37281 .49684 .36894 Mtetra
.541 .597 .859 r
.49684 .36894 .50069 .37281 .5077 .37312 .50384 .36913 Mtetra
.556 .598 .851 r
.50384 .36913 .5077 .37312 .51473 .37329 .51088 .36918 Mtetra
.57 .599 .843 r
.51088 .36918 .51473 .37329 .52179 .37331 .51794 .36908 Mtetra
.583 .599 .834 r
.51794 .36908 .52179 .37331 .52888 .37319 .52503 .36882 Mtetra
.595 .599 .826 r
.52503 .36882 .52888 .37319 .53599 .37291 .53215 .36841 Mtetra
.606 .599 .818 r
.53215 .36841 .53599 .37291 .54312 .37248 .53929 .36783 Mtetra
.617 .598 .81 r
.53929 .36783 .54312 .37248 .55028 .37188 .54645 .36707 Mtetra
.626 .597 .801 r
.54645 .36707 .55028 .37188 .55746 .37111 .55363 .36615 Mtetra
.634 .596 .794 r
.55363 .36615 .55746 .37111 .56466 .37019 .56083 .36505 Mtetra
.642 .594 .786 r
.56083 .36505 .56466 .37019 .57188 .36909 .56804 .36379 Mtetra
.648 .592 .778 r
.56804 .36379 .57188 .36909 .57911 .36784 .57527 .36236 Mtetra
.653 .59 .771 r
.57527 .36236 .57911 .36784 .58636 .36645 .58252 .36078 Mtetra
.657 .587 .765 r
.58252 .36078 .58636 .36645 .59362 .36491 .58977 .35906 Mtetra
.66 .584 .759 r
.58977 .35906 .59362 .36491 .60089 .36325 .59704 .35722 Mtetra
.662 .581 .753 r
.59704 .35722 .60089 .36325 .60818 .36148 .60433 .35527 Mtetra
.663 .577 .748 r
.60433 .35527 .60818 .36148 .61548 .35961 .61162 .35324 Mtetra
.664 .574 .744 r
.61162 .35324 .61548 .35961 .62279 .35766 .61892 .35114 Mtetra
.664 .572 .741 r
.61892 .35114 .62279 .35766 .63011 .35563 .62624 .34898 Mtetra
.665 .57 .738 r
.62624 .34898 .63011 .35563 .63744 .35351 .63356 .34676 Mtetra
.667 .569 .735 r
.63356 .34676 .63744 .35351 .64478 .35128 .6409 .34446 Mtetra
.633 .548 .741 r
.6409 .34446 .64478 .35128 .65218 .34994 .6483 .34311 Mtetra
.594 .526 .748 r
.6483 .34311 .65218 .34994 .65967 .3495 .65578 .34272 Mtetra
.597 .53 .749 r
.65578 .34272 .65967 .3495 .66717 .34895 .66329 .34225 Mtetra
.6 .533 .751 r
.66329 .34225 .66717 .34895 .67469 .3483 .67082 .34171 Mtetra
.603 .537 .754 r
.67082 .34171 .67469 .3483 .68223 .34758 .67837 .34112 Mtetra
.606 .542 .757 r
.67837 .34112 .68223 .34758 .68979 .34678 .68594 .34047 Mtetra
.61 .548 .761 r
.68594 .34047 .68979 .34678 .69737 .34588 .69352 .33973 Mtetra
.615 .555 .764 r
.69352 .33973 .69737 .34588 .70496 .34487 .70113 .33889 Mtetra
.621 .563 .768 r
.70113 .33889 .70496 .34487 .71256 .34374 .70875 .33793 Mtetra
.628 .572 .772 r
.70875 .33793 .71256 .34374 .72017 .34247 .71638 .33682 Mtetra
.636 .581 .776 r
.71638 .33682 .72017 .34247 .72779 .34104 .72401 .33556 Mtetra
.644 .59 .779 r
.72401 .33556 .72779 .34104 .73541 .33946 .73166 .33413 Mtetra
.653 .6 .783 r
.73166 .33413 .73541 .33946 .74304 .33771 .7393 .33254 Mtetra
.662 .61 .786 r
.7393 .33254 .74304 .33771 .75066 .33579 .74695 .33076 Mtetra
.672 .62 .788 r
.74695 .33076 .75066 .33579 .75828 .3337 .75459 .32881 Mtetra
.681 .629 .791 r
.75459 .32881 .75828 .3337 .7659 .33144 .76223 .32669 Mtetra
.69 .639 .793 r
.76223 .32669 .7659 .33144 .77351 .32901 .76987 .32439 Mtetra
.699 .648 .795 r
.76987 .32439 .77351 .32901 .78112 .32643 .7775 .32192 Mtetra
.708 .656 .797 r
.7775 .32192 .78112 .32643 .78872 .32369 .78512 .31929 Mtetra
.716 .665 .798 r
.78512 .31929 .78872 .32369 .79631 .3208 .79274 .31651 Mtetra
.724 .673 .8 r
.79274 .31651 .79631 .3208 .80389 .31776 .80034 .31358 Mtetra
.732 .681 .801 r
.80034 .31358 .80389 .31776 .81146 .31459 .80794 .31051 Mtetra
.739 .689 .802 r
.80794 .31051 .81146 .31459 .81902 .31129 .81553 .3073 Mtetra
.747 .696 .803 r
.81553 .3073 .81902 .31129 .82657 .30787 .8231 .30397 Mtetra
.753 .703 .804 r
.8231 .30397 .82657 .30787 .83411 .30433 .83067 .30052 Mtetra
.76 .71 .805 r
.83067 .30052 .83411 .30433 .84163 .30069 .83822 .29695 Mtetra
.766 .717 .806 r
.83822 .29695 .84163 .30069 .84915 .29695 .84577 .29329 Mtetra
.772 .723 .807 r
.84577 .29329 .84915 .29695 .85665 .29311 .8533 .28953 Mtetra
.777 .729 .808 r
.8533 .28953 .85665 .29311 .86415 .28919 .86082 .28569 Mtetra
.782 .735 .809 r
.86082 .28569 .86415 .28919 .87163 .2852 .86833 .28176 Mtetra
.787 .741 .81 r
.86833 .28176 .87163 .2852 .8791 .28113 .87583 .27776 Mtetra
.792 .747 .811 r
.87583 .27776 .8791 .28113 .88656 .277 .88332 .2737 Mtetra
.796 .752 .813 r
.88332 .2737 .88656 .277 .89401 .27282 .8908 .26958 Mtetra
.8 .758 .814 r
.8908 .26958 .89401 .27282 .90146 .26859 .89828 .26542 Mtetra
.804 .763 .815 r
.89828 .26542 .90146 .26859 .90889 .26432 .90574 .26121 Mtetra
.807 .768 .817 r
.90574 .26121 .90889 .26432 .91632 .26001 .9132 .25696 Mtetra
.811 .774 .818 r
.9132 .25696 .91632 .26001 .92374 .25567 .92066 .25268 Mtetra
.814 .779 .82 r
.92066 .25268 .92374 .25567 .93116 .25132 .9281 .24839 Mtetra
.817 .784 .822 r
.9281 .24839 .93116 .25132 .93857 .24695 .93555 .24408 Mtetra
.819 .789 .825 r
.93555 .24408 .93857 .24695 .94598 .24257 .94299 .23976 Mtetra
.2 .538 .926 r
.36598 .3466 .36999 .34891 .37636 .35032 .37236 .34795 Mtetra
.216 .54 .926 r
.37236 .34795 .37636 .35032 .38276 .35173 .37877 .34929 Mtetra
.233 .543 .927 r
.37877 .34929 .38276 .35173 .3892 .35314 .38521 .35063 Mtetra
.25 .547 .927 r
.38521 .35063 .3892 .35314 .39567 .35453 .39169 .35195 Mtetra
.268 .55 .927 r
.39169 .35195 .39567 .35453 .40217 .3559 .3982 .35325 Mtetra
.287 .555 .926 r
.3982 .35325 .40217 .3559 .40871 .35724 .40475 .35453 Mtetra
.307 .559 .925 r
.40475 .35453 .40871 .35724 .41528 .35855 .41133 .35576 Mtetra
.327 .563 .923 r
.41133 .35576 .41528 .35855 .42189 .35982 .41794 .35696 Mtetra
.347 .568 .921 r
.41794 .35696 .42189 .35982 .42853 .36104 .42459 .3581 Mtetra
.367 .572 .918 r
.42459 .3581 .42853 .36104 .43521 .36221 .43128 .35919 Mtetra
.387 .576 .914 r
.43128 .35919 .43521 .36221 .44192 .36331 .438 .36021 Mtetra
.407 .581 .91 r
.438 .36021 .44192 .36331 .44867 .36434 .44475 .36116 Mtetra
.427 .584 .906 r
.44475 .36116 .44867 .36434 .45545 .36529 .45154 .36203 Mtetra
.446 .588 .9 r
.45154 .36203 .45545 .36529 .46226 .36616 .45836 .36281 Mtetra
.465 .591 .895 r
.45836 .36281 .46226 .36616 .46911 .36694 .46522 .36349 Mtetra
.484 .594 .888 r
.46522 .36349 .46911 .36694 .47599 .36761 .47211 .36407 Mtetra
.501 .597 .881 r
.47211 .36407 .47599 .36761 .48291 .36817 .47903 .36453 Mtetra
.518 .599 .874 r
.47903 .36453 .48291 .36817 .48986 .36862 .48598 .36488 Mtetra
.535 .601 .867 r
.48598 .36488 .48986 .36862 .49684 .36894 .49296 .36509 Mtetra
.55 .603 .859 r
.49296 .36509 .49684 .36894 .50384 .36913 .49998 .36517 Mtetra
.565 .604 .851 r
.49998 .36517 .50384 .36913 .51088 .36918 .50702 .36509 Mtetra
.579 .605 .843 r
.50702 .36509 .51088 .36918 .51794 .36908 .51409 .36487 Mtetra
.592 .605 .834 r
.51409 .36487 .51794 .36908 .52503 .36882 .52118 .36448 Mtetra
.604 .605 .826 r
.52118 .36448 .52503 .36882 .53215 .36841 .5283 .36393 Mtetra
.615 .605 .817 r
.5283 .36393 .53215 .36841 .53929 .36783 .53544 .3632 Mtetra
.625 .604 .809 r
.53544 .3632 .53929 .36783 .54645 .36707 .5426 .3623 Mtetra
.634 .603 .801 r
.5426 .3623 .54645 .36707 .55363 .36615 .54979 .36122 Mtetra
.643 .602 .793 r
.54979 .36122 .55363 .36615 .56083 .36505 .55699 .35995 Mtetra
.65 .6 .785 r
.55699 .35995 .56083 .36505 .56804 .36379 .5642 .35852 Mtetra
.656 .598 .777 r
.5642 .35852 .56804 .36379 .57527 .36236 .57143 .35691 Mtetra
.661 .595 .77 r
.57143 .35691 .57527 .36236 .58252 .36078 .57867 .35514 Mtetra
.665 .592 .764 r
.57867 .35514 .58252 .36078 .58977 .35906 .58593 .35323 Mtetra
.667 .589 .758 r
.58593 .35323 .58977 .35906 .59704 .35722 .59319 .3512 Mtetra
.669 .585 .752 r
.59319 .3512 .59704 .35722 .60433 .35527 .60047 .34907 Mtetra
.669 .581 .747 r
.60047 .34907 .60433 .35527 .61162 .35324 .60776 .34687 Mtetra
.669 .577 .743 r
.60776 .34687 .61162 .35324 .61892 .35114 .61505 .34462 Mtetra
.669 .574 .74 r
.61505 .34462 .61892 .35114 .62624 .34898 .62236 .34234 Mtetra
.668 .571 .737 r
.62236 .34234 .62624 .34898 .63356 .34676 .62968 .34002 Mtetra
.669 .57 .735 r
.62968 .34002 .63356 .34676 .6409 .34446 .63702 .33766 Mtetra
.633 .549 .742 r
.63702 .33766 .6409 .34446 .6483 .34311 .64442 .3363 Mtetra
.591 .525 .749 r
.64442 .3363 .6483 .34311 .65578 .34272 .6519 .33595 Mtetra
.593 .528 .75 r
.6519 .33595 .65578 .34272 .66329 .34225 .65941 .33555 Mtetra
.595 .53 .752 r
.65941 .33555 .66329 .34225 .67082 .34171 .66694 .33513 Mtetra
.596 .534 .755 r
.66694 .33513 .67082 .34171 .67837 .34112 .67449 .33467 Mtetra
.598 .538 .759 r
.67449 .33467 .67837 .34112 .68594 .34047 .68207 .33417 Mtetra
.602 .544 .763 r
.68207 .33417 .68594 .34047 .69352 .33973 .68968 .3336 Mtetra
.606 .551 .767 r
.68968 .3336 .69352 .33973 .70113 .33889 .6973 .33293 Mtetra
.612 .559 .771 r
.6973 .33293 .70113 .33889 .70875 .33793 .70493 .33214 Mtetra
.62 .568 .775 r
.70493 .33214 .70875 .33793 .71638 .33682 .71258 .3312 Mtetra
.628 .578 .779 r
.71258 .3312 .71638 .33682 .72401 .33556 .72023 .33011 Mtetra
.637 .588 .783 r
.72023 .33011 .72401 .33556 .73166 .33413 .72789 .32884 Mtetra
.646 .598 .786 r
.72789 .32884 .73166 .33413 .7393 .33254 .73556 .3274 Mtetra
.656 .608 .789 r
.73556 .3274 .7393 .33254 .74695 .33076 .74323 .32577 Mtetra
.665 .618 .792 r
.74323 .32577 .74695 .33076 .75459 .32881 .75089 .32395 Mtetra
.675 .628 .794 r
.75089 .32395 .75459 .32881 .76223 .32669 .75856 .32196 Mtetra
.685 .638 .797 r
.75856 .32196 .76223 .32669 .76987 .32439 .76622 .31979 Mtetra
.694 .647 .799 r
.76622 .31979 .76987 .32439 .7775 .32192 .77387 .31744 Mtetra
.703 .656 .8 r
.77387 .31744 .7775 .32192 .78512 .31929 .78152 .31492 Mtetra
.712 .665 .802 r
.78152 .31492 .78512 .31929 .79274 .31651 .78916 .31225 Mtetra
.72 .673 .803 r
.78916 .31225 .79274 .31651 .80034 .31358 .79679 .30942 Mtetra
.729 .681 .804 r
.79679 .30942 .80034 .31358 .80794 .31051 .80441 .30644 Mtetra
.736 .689 .805 r
.80441 .30644 .80794 .31051 .81553 .3073 .81203 .30333 Mtetra
.744 .696 .806 r
.81203 .30333 .81553 .3073 .8231 .30397 .81963 .30008 Mtetra
.75 .703 .807 r
.81963 .30008 .8231 .30397 .83067 .30052 .82722 .29671 Mtetra
.757 .71 .808 r
.82722 .29671 .83067 .30052 .83822 .29695 .8348 .29323 Mtetra
.763 .717 .809 r
.8348 .29323 .83822 .29695 .84577 .29329 .84237 .28964 Mtetra
.769 .723 .81 r
.84237 .28964 .84577 .29329 .8533 .28953 .84993 .28596 Mtetra
.775 .729 .811 r
.84993 .28596 .8533 .28953 .86082 .28569 .85748 .28219 Mtetra
.78 .735 .812 r
.85748 .28219 .86082 .28569 .86833 .28176 .86502 .27833 Mtetra
.785 .741 .813 r
.86502 .27833 .86833 .28176 .87583 .27776 .87255 .2744 Mtetra
.79 .747 .814 r
.87255 .2744 .87583 .27776 .88332 .2737 .88007 .2704 Mtetra
.794 .752 .815 r
.88007 .2704 .88332 .2737 .8908 .26958 .88758 .26635 Mtetra
.798 .758 .816 r
.88758 .26635 .8908 .26958 .89828 .26542 .89509 .26224 Mtetra
.802 .763 .818 r
.89509 .26224 .89828 .26542 .90574 .26121 .90258 .25809 Mtetra
.805 .768 .819 r
.90258 .25809 .90574 .26121 .9132 .25696 .91007 .2539 Mtetra
.808 .774 .821 r
.91007 .2539 .9132 .25696 .92066 .25268 .91756 .24968 Mtetra
.811 .779 .822 r
.91756 .24968 .92066 .25268 .9281 .24839 .92504 .24545 Mtetra
.814 .784 .824 r
.92504 .24545 .9281 .24839 .93555 .24408 .93251 .24119 Mtetra
.816 .789 .827 r
.93251 .24119 .93555 .24408 .94299 .23976 .93999 .23693 Mtetra
.218 .548 .93 r
.36195 .34428 .36598 .3466 .37236 .34795 .36834 .34556 Mtetra
.233 .55 .93 r
.36834 .34556 .37236 .34795 .37877 .34929 .37476 .34684 Mtetra
.249 .553 .93 r
.37476 .34684 .37877 .34929 .38521 .35063 .38121 .34812 Mtetra
.265 .556 .93 r
.38121 .34812 .38521 .35063 .39169 .35195 .3877 .34937 Mtetra
.283 .559 .93 r
.3877 .34937 .39169 .35195 .3982 .35325 .39422 .3506 Mtetra
.301 .563 .929 r
.39422 .3506 .3982 .35325 .40475 .35453 .40077 .35181 Mtetra
.32 .567 .927 r
.40077 .35181 .40475 .35453 .41133 .35576 .40736 .35298 Mtetra
.34 .571 .925 r
.40736 .35298 .41133 .35576 .41794 .35696 .41398 .3541 Mtetra
.359 .575 .923 r
.41398 .3541 .41794 .35696 .42459 .3581 .42064 .35517 Mtetra
.379 .579 .92 r
.42064 .35517 .42459 .3581 .43128 .35919 .42733 .35618 Mtetra
.399 .584 .916 r
.42733 .35618 .43128 .35919 .438 .36021 .43406 .35712 Mtetra
.418 .588 .912 r
.43406 .35712 .438 .36021 .44475 .36116 .44082 .35799 Mtetra
.438 .591 .907 r
.44082 .35799 .44475 .36116 .45154 .36203 .44761 .35878 Mtetra
.457 .595 .901 r
.44761 .35878 .45154 .36203 .45836 .36281 .45444 .35947 Mtetra
.475 .598 .895 r
.45444 .35947 .45836 .36281 .46522 .36349 .46131 .36006 Mtetra
.493 .601 .889 r
.46131 .36006 .46522 .36349 .47211 .36407 .4682 .36055 Mtetra
.511 .603 .882 r
.4682 .36055 .47211 .36407 .47903 .36453 .47513 .36091 Mtetra
.528 .606 .875 r
.47513 .36091 .47903 .36453 .48598 .36488 .48209 .36115 Mtetra
.544 .607 .867 r
.48209 .36115 .48598 .36488 .49296 .36509 .48908 .36126 Mtetra
.559 .609 .859 r
.48908 .36126 .49296 .36509 .49998 .36517 .4961 .36122 Mtetra
.574 .61 .851 r
.4961 .36122 .49998 .36517 .50702 .36509 .50314 .36104 Mtetra
.587 .611 .843 r
.50314 .36104 .50702 .36509 .51409 .36487 .51022 .36069 Mtetra
.6 .611 .834 r
.51022 .36069 .51409 .36487 .52118 .36448 .51732 .36017 Mtetra
.612 .611 .826 r
.51732 .36017 .52118 .36448 .5283 .36393 .52444 .35948 Mtetra
.623 .611 .817 r
.52444 .35948 .5283 .36393 .53544 .3632 .53159 .35861 Mtetra
.634 .61 .809 r
.53159 .35861 .53544 .3632 .5426 .3623 .53875 .35756 Mtetra
.643 .609 .8 r
.53875 .35756 .5426 .3623 .54979 .36122 .54594 .35632 Mtetra
.651 .607 .792 r
.54594 .35632 .54979 .36122 .55699 .35995 .55314 .35489 Mtetra
.658 .605 .784 r
.55314 .35489 .55699 .35995 .5642 .35852 .56035 .35327 Mtetra
.664 .603 .776 r
.56035 .35327 .5642 .35852 .57143 .35691 .56758 .35148 Mtetra
.669 .6 .769 r
.56758 .35148 .57143 .35691 .57867 .35514 .57482 .34952 Mtetra
.672 .597 .762 r
.57482 .34952 .57867 .35514 .58593 .35323 .58207 .34742 Mtetra
.675 .593 .756 r
.58207 .34742 .58593 .35323 .59319 .3512 .58934 .3452 Mtetra
.676 .589 .751 r
.58934 .3452 .59319 .3512 .60047 .34907 .59661 .34288 Mtetra
.675 .585 .746 r
.59661 .34288 .60047 .34907 .60776 .34687 .60389 .3405 Mtetra
.674 .58 .742 r
.60389 .3405 .60776 .34687 .61505 .34462 .61118 .3381 Mtetra
.673 .576 .739 r
.61118 .3381 .61505 .34462 .62236 .34234 .61849 .33569 Mtetra
.671 .573 .736 r
.61849 .33569 .62236 .34234 .62968 .34002 .6258 .33329 Mtetra
.67 .571 .735 r
.6258 .33329 .62968 .34002 .63702 .33766 .63313 .33088 Mtetra
.633 .55 .743 r
.63313 .33088 .63702 .33766 .64442 .3363 .64053 .32951 Mtetra
.589 .525 .75 r
.64053 .32951 .64442 .3363 .6519 .33595 .64801 .32919 Mtetra
.59 .526 .751 r
.64801 .32919 .6519 .33595 .65941 .33555 .65552 .32886 Mtetra
.589 .528 .753 r
.65552 .32886 .65941 .33555 .66694 .33513 .66306 .32854 Mtetra
.589 .53 .756 r
.66306 .32854 .66694 .33513 .67449 .33467 .67062 .32822 Mtetra
.59 .534 .76 r
.67062 .32822 .67449 .33467 .68207 .33417 .67821 .32788 Mtetra
.593 .54 .764 r
.67821 .32788 .68207 .33417 .68968 .3336 .68582 .32748 Mtetra
.598 .547 .769 r
.68582 .32748 .68968 .3336 .6973 .33293 .69346 .32698 Mtetra
.604 .555 .773 r
.69346 .32698 .6973 .33293 .70493 .33214 .70111 .32637 Mtetra
.611 .565 .778 r
.70111 .32637 .70493 .33214 .71258 .3312 .70877 .32561 Mtetra
.62 .575 .782 r
.70877 .32561 .71258 .3312 .72023 .33011 .71645 .32468 Mtetra
.629 .585 .786 r
.71645 .32468 .72023 .33011 .72789 .32884 .72413 .32358 Mtetra
.639 .596 .79 r
.72413 .32358 .72789 .32884 .73556 .3274 .73182 .32229 Mtetra
.649 .606 .793 r
.73182 .32229 .73556 .3274 .74323 .32577 .7395 .3208 Mtetra
.659 .617 .796 r
.7395 .3208 .74323 .32577 .75089 .32395 .74719 .31913 Mtetra
.669 .627 .798 r
.74719 .31913 .75089 .32395 .75856 .32196 .75488 .31726 Mtetra
.68 .637 .8 r
.75488 .31726 .75856 .32196 .76622 .31979 .76256 .31521 Mtetra
.689 .647 .802 r
.76256 .31521 .76622 .31979 .77387 .31744 .77024 .31298 Mtetra
.699 .656 .804 r
.77024 .31298 .77387 .31744 .78152 .31492 .77791 .31058 Mtetra
.708 .665 .805 r
.77791 .31058 .78152 .31492 .78916 .31225 .78557 .30801 Mtetra
.717 .673 .806 r
.78557 .30801 .78916 .31225 .79679 .30942 .79323 .30528 Mtetra
.725 .681 .808 r
.79323 .30528 .79679 .30942 .80441 .30644 .80088 .30239 Mtetra
.733 .689 .809 r
.80088 .30239 .80441 .30644 .81203 .30333 .80852 .29937 Mtetra
.74 .697 .809 r
.80852 .29937 .81203 .30333 .81963 .30008 .81614 .29621 Mtetra
.748 .704 .81 r
.81614 .29621 .81963 .30008 .82722 .29671 .82376 .29292 Mtetra
.754 .711 .811 r
.82376 .29292 .82722 .29671 .8348 .29323 .83137 .28952 Mtetra
.761 .717 .812 r
.83137 .28952 .8348 .29323 .84237 .28964 .83897 .28601 Mtetra
.767 .724 .813 r
.83897 .28601 .84237 .28964 .84993 .28596 .84656 .2824 Mtetra
.772 .73 .813 r
.84656 .2824 .84993 .28596 .85748 .28219 .85413 .27869 Mtetra
.778 .736 .814 r
.85413 .27869 .85748 .28219 .86502 .27833 .8617 .2749 Mtetra
.783 .742 .815 r
.8617 .2749 .86502 .27833 .87255 .2744 .86926 .27103 Mtetra
.787 .747 .816 r
.86926 .27103 .87255 .2744 .88007 .2704 .87681 .2671 Mtetra
.792 .753 .817 r
.87681 .2671 .88007 .2704 .88758 .26635 .88435 .26311 Mtetra
.796 .758 .818 r
.88435 .26311 .88758 .26635 .89509 .26224 .89188 .25906 Mtetra
.799 .763 .82 r
.89188 .25906 .89509 .26224 .90258 .25809 .89941 .25497 Mtetra
.803 .768 .821 r
.89941 .25497 .90258 .25809 .91007 .2539 .90693 .25084 Mtetra
.806 .773 .823 r
.90693 .25084 .91007 .2539 .91756 .24968 .91444 .24668 Mtetra
.809 .778 .825 r
.91444 .24668 .91756 .24968 .92504 .24545 .92196 .24249 Mtetra
.812 .783 .827 r
.92196 .24249 .92504 .24545 .93251 .24119 .92946 .23829 Mtetra
.814 .788 .829 r
.92946 .23829 .93251 .24119 .93999 .23693 .93697 .23409 Mtetra
.236 .558 .934 r
.3579 .34196 .36195 .34428 .36834 .34556 .3643 .34317 Mtetra
.249 .559 .934 r
.3643 .34317 .36834 .34556 .37476 .34684 .37073 .34439 Mtetra
.264 .561 .934 r
.37073 .34439 .37476 .34684 .38121 .34812 .37719 .3456 Mtetra
.28 .564 .933 r
.37719 .3456 .38121 .34812 .3877 .34937 .38369 .34679 Mtetra
.297 .567 .932 r
.38369 .34679 .3877 .34937 .39422 .3506 .39021 .34795 Mtetra
.315 .571 .931 r
.39021 .34795 .39422 .3506 .40077 .35181 .39678 .34909 Mtetra
.333 .575 .929 r
.39678 .34909 .40077 .35181 .40736 .35298 .40337 .35019 Mtetra
.352 .578 .927 r
.40337 .35019 .40736 .35298 .41398 .3541 .41 .35124 Mtetra
.371 .582 .924 r
.41 .35124 .41398 .3541 .42064 .35517 .41667 .35224 Mtetra
.39 .586 .921 r
.41667 .35224 .42064 .35517 .42733 .35618 .42337 .35317 Mtetra
.409 .59 .917 r
.42337 .35317 .42733 .35618 .43406 .35712 .4301 .35404 Mtetra
.429 .594 .913 r
.4301 .35404 .43406 .35712 .44082 .35799 .43687 .35483 Mtetra
.448 .598 .908 r
.43687 .35483 .44082 .35799 .44761 .35878 .44367 .35553 Mtetra
.466 .601 .902 r
.44367 .35553 .44761 .35878 .45444 .35947 .45051 .35614 Mtetra
.485 .604 .896 r
.45051 .35614 .45444 .35947 .46131 .36006 .45738 .35665 Mtetra
.503 .607 .89 r
.45738 .35665 .46131 .36006 .4682 .36055 .46428 .35704 Mtetra
.52 .61 .883 r
.46428 .35704 .4682 .36055 .47513 .36091 .47122 .35731 Mtetra
.537 .612 .875 r
.47122 .35731 .47513 .36091 .48209 .36115 .47818 .35745 Mtetra
.553 .614 .867 r
.47818 .35745 .48209 .36115 .48908 .36126 .48518 .35745 Mtetra
.568 .615 .859 r
.48518 .35745 .48908 .36126 .4961 .36122 .49221 .35731 Mtetra
.582 .616 .851 r
.49221 .35731 .4961 .36122 .50314 .36104 .49926 .35701 Mtetra
.596 .617 .843 r
.49926 .35701 .50314 .36104 .51022 .36069 .50634 .35654 Mtetra
.609 .617 .834 r
.50634 .35654 .51022 .36069 .51732 .36017 .51344 .35589 Mtetra
.621 .617 .825 r
.51344 .35589 .51732 .36017 .52444 .35948 .52057 .35507 Mtetra
.632 .616 .817 r
.52057 .35507 .52444 .35948 .53159 .35861 .52772 .35406 Mtetra
.642 .616 .808 r
.52772 .35406 .53159 .35861 .53875 .35756 .53489 .35285 Mtetra
.651 .614 .8 r
.53489 .35285 .53875 .35756 .54594 .35632 .54208 .35145 Mtetra
.659 .613 .791 r
.54208 .35145 .54594 .35632 .55314 .35489 .54928 .34985 Mtetra
.666 .611 .783 r
.54928 .34985 .55314 .35489 .56035 .35327 .5565 .34806 Mtetra
.672 .608 .775 r
.5565 .34806 .56035 .35327 .56758 .35148 .56373 .34608 Mtetra
.677 .605 .768 r
.56373 .34608 .56758 .35148 .57482 .34952 .57097 .34393 Mtetra
.68 .601 .761 r
.57097 .34393 .57482 .34952 .58207 .34742 .57822 .34163 Mtetra
.682 .597 .755 r
.57822 .34163 .58207 .34742 .58934 .3452 .58547 .33921 Mtetra
.682 .593 .749 r
.58547 .33921 .58934 .3452 .59661 .34288 .59274 .3367 Mtetra
.682 .588 .744 r
.59274 .3367 .59661 .34288 .60389 .3405 .60002 .33414 Mtetra
.679 .583 .741 r
.60002 .33414 .60389 .3405 .61118 .3381 .60731 .33157 Mtetra
.677 .578 .738 r
.60731 .33157 .61118 .3381 .61849 .33569 .61461 .32904 Mtetra
.674 .574 .736 r
.61461 .32904 .61849 .33569 .6258 .33329 .62192 .32655 Mtetra
.671 .572 .734 r
.62192 .32655 .6258 .33329 .63313 .33088 .62925 .32411 Mtetra
.633 .55 .743 r
.62925 .32411 .63313 .33088 .64053 .32951 .63664 .32273 Mtetra
.588 .524 .751 r
.63664 .32273 .64053 .32951 .64801 .32919 .64412 .32243 Mtetra
.586 .524 .752 r
.64412 .32243 .64801 .32919 .65552 .32886 .65163 .32216 Mtetra
.584 .524 .754 r
.65163 .32216 .65552 .32886 .66306 .32854 .65917 .32195 Mtetra
.582 .526 .757 r
.65917 .32195 .66306 .32854 .67062 .32822 .66674 .32178 Mtetra
.582 .53 .762 r
.66674 .32178 .67062 .32822 .67821 .32788 .67434 .3216 Mtetra
.584 .535 .766 r
.67434 .3216 .67821 .32788 .68582 .32748 .68197 .32137 Mtetra
.588 .542 .771 r
.68197 .32137 .68582 .32748 .69346 .32698 .68962 .32106 Mtetra
.594 .551 .776 r
.68962 .32106 .69346 .32698 .70111 .32637 .69728 .32063 Mtetra
.602 .561 .781 r
.69728 .32063 .70111 .32637 .70877 .32561 .70496 .32005 Mtetra
.611 .571 .785 r
.70496 .32005 .70877 .32561 .71645 .32468 .71266 .31929 Mtetra
.621 .582 .789 r
.71266 .31929 .71645 .32468 .72413 .32358 .72036 .31835 Mtetra
.631 .593 .793 r
.72036 .31835 .72413 .32358 .73182 .32229 .72806 .31721 Mtetra
.642 .604 .796 r
.72806 .31721 .73182 .32229 .7395 .3208 .73577 .31587 Mtetra
.653 .615 .799 r
.73577 .31587 .7395 .3208 .74719 .31913 .74348 .31434 Mtetra
.663 .626 .802 r
.74348 .31434 .74719 .31913 .75488 .31726 .75119 .3126 Mtetra
.674 .636 .804 r
.75119 .3126 .75488 .31726 .76256 .31521 .7589 .31067 Mtetra
.684 .646 .806 r
.7589 .31067 .76256 .31521 .77024 .31298 .7666 .30856 Mtetra
.694 .656 .807 r
.7666 .30856 .77024 .31298 .77791 .31058 .77429 .30626 Mtetra
.704 .665 .809 r
.77429 .30626 .77791 .31058 .78557 .30801 .78198 .30379 Mtetra
.713 .673 .81 r
.78198 .30379 .78557 .30801 .79323 .30528 .78966 .30116 Mtetra
.721 .682 .811 r
.78966 .30116 .79323 .30528 .80088 .30239 .79733 .29837 Mtetra
.73 .689 .812 r
.79733 .29837 .80088 .30239 .80852 .29937 .805 .29543 Mtetra
.737 .697 .813 r
.805 .29543 .80852 .29937 .81614 .29621 .81265 .29235 Mtetra
.745 .704 .813 r
.81265 .29235 .81614 .29621 .82376 .29292 .82029 .28915 Mtetra
.752 .711 .814 r
.82029 .28915 .82376 .29292 .83137 .28952 .82793 .28582 Mtetra
.758 .718 .815 r
.82793 .28582 .83137 .28952 .83897 .28601 .83555 .28238 Mtetra
.764 .724 .815 r
.83555 .28238 .83897 .28601 .84656 .2824 .84317 .27884 Mtetra
.77 .73 .816 r
.84317 .27884 .84656 .2824 .85413 .27869 .85077 .2752 Mtetra
.775 .736 .817 r
.85077 .2752 .85413 .27869 .8617 .2749 .85837 .27148 Mtetra
.78 .742 .818 r
.85837 .27148 .8617 .2749 .86926 .27103 .86596 .26767 Mtetra
.785 .747 .819 r
.86596 .26767 .86926 .27103 .87681 .2671 .87353 .2638 Mtetra
.789 .753 .82 r
.87353 .2638 .87681 .2671 .88435 .26311 .8811 .25986 Mtetra
.793 .758 .821 r
.8811 .25986 .88435 .26311 .89188 .25906 .88867 .25587 Mtetra
.797 .763 .822 r
.88867 .25587 .89188 .25906 .89941 .25497 .89622 .25184 Mtetra
.801 .768 .823 r
.89622 .25184 .89941 .25497 .90693 .25084 .90377 .24776 Mtetra
.804 .773 .825 r
.90377 .24776 .90693 .25084 .91444 .24668 .91132 .24366 Mtetra
.807 .778 .827 r
.91132 .24366 .91444 .24668 .92196 .24249 .91886 .23953 Mtetra
.809 .783 .829 r
.91886 .23953 .92196 .24249 .92946 .23829 .9264 .23538 Mtetra
.811 .788 .831 r
.9264 .23538 .92946 .23829 .93697 .23409 .93394 .23123 Mtetra
.252 .567 .938 r
.35384 .33962 .3579 .34196 .3643 .34317 .36024 .34077 Mtetra
.265 .568 .937 r
.36024 .34077 .3643 .34317 .37073 .34439 .36668 .34193 Mtetra
.279 .57 .936 r
.36668 .34193 .37073 .34439 .37719 .3456 .37315 .34307 Mtetra
.294 .572 .935 r
.37315 .34307 .37719 .3456 .38369 .34679 .37966 .3442 Mtetra
.31 .575 .934 r
.37966 .3442 .38369 .34679 .39021 .34795 .38619 .3453 Mtetra
.327 .578 .933 r
.38619 .3453 .39021 .34795 .39678 .34909 .39276 .34637 Mtetra
.345 .582 .931 r
.39276 .34637 .39678 .34909 .40337 .35019 .39937 .3474 Mtetra
.363 .586 .928 r
.39937 .3474 .40337 .35019 .41 .35124 .40601 .34838 Mtetra
.382 .589 .926 r
.40601 .34838 .41 .35124 .41667 .35224 .41268 .34931 Mtetra
.401 .593 .922 r
.41268 .34931 .41667 .35224 .42337 .35317 .41939 .35018 Mtetra
.42 .597 .918 r
.41939 .35018 .42337 .35317 .4301 .35404 .42613 .35097 Mtetra
.438 .601 .914 r
.42613 .35097 .4301 .35404 .43687 .35483 .43291 .35168 Mtetra
.457 .604 .909 r
.43291 .35168 .43687 .35483 .44367 .35553 .43972 .3523 Mtetra
.476 .607 .903 r
.43972 .3523 .44367 .35553 .45051 .35614 .44656 .35283 Mtetra
.494 .611 .897 r
.44656 .35283 .45051 .35614 .45738 .35665 .45344 .35325 Mtetra
.511 .613 .89 r
.45344 .35325 .45738 .35665 .46428 .35704 .46035 .35355 Mtetra
.529 .616 .883 r
.46035 .35355 .46428 .35704 .47122 .35731 .46729 .35373 Mtetra
.545 .618 .876 r
.46729 .35373 .47122 .35731 .47818 .35745 .47426 .35377 Mtetra
.561 .619 .868 r
.47426 .35377 .47818 .35745 .48518 .35745 .48127 .35367 Mtetra
.576 .621 .86 r
.48127 .35367 .48518 .35745 .49221 .35731 .4883 .35342 Mtetra
.591 .622 .851 r
.4883 .35342 .49221 .35731 .49926 .35701 .49536 .353 Mtetra
.604 .622 .843 r
.49536 .353 .49926 .35701 .50634 .35654 .50244 .35241 Mtetra
.617 .623 .834 r
.50244 .35241 .50634 .35654 .51344 .35589 .50955 .35165 Mtetra
.629 .623 .825 r
.50955 .35165 .51344 .35589 .52057 .35507 .51669 .35069 Mtetra
.64 .622 .816 r
.51669 .35069 .52057 .35507 .52772 .35406 .52384 .34953 Mtetra
.65 .621 .808 r
.52384 .34953 .52772 .35406 .53489 .35285 .53102 .34818 Mtetra
.659 .62 .799 r
.53102 .34818 .53489 .35285 .54208 .35145 .53821 .34662 Mtetra
.667 .618 .79 r
.53821 .34662 .54208 .35145 .54928 .34985 .54541 .34485 Mtetra
.674 .616 .782 r
.54541 .34485 .54928 .34985 .5565 .34806 .55263 .34288 Mtetra
.68 .613 .774 r
.55263 .34288 .5565 .34806 .56373 .34608 .55986 .34072 Mtetra
.685 .61 .767 r
.55986 .34072 .56373 .34608 .57097 .34393 .5671 .33837 Mtetra
.688 .606 .759 r
.5671 .33837 .57097 .34393 .57822 .34163 .57435 .33586 Mtetra
.689 .602 .753 r
.57435 .33586 .57822 .34163 .58547 .33921 .58161 .33323 Mtetra
.689 .597 .747 r
.58161 .33323 .58547 .33921 .59274 .3367 .58887 .33052 Mtetra
.688 .592 .743 r
.58887 .33052 .59274 .3367 .60002 .33414 .59614 .32777 Mtetra
.685 .586 .739 r
.59614 .32777 .60002 .33414 .60731 .33157 .60343 .32503 Mtetra
.681 .58 .736 r
.60343 .32503 .60731 .33157 .61461 .32904 .61072 .32237 Mtetra
.676 .575 .735 r
.61072 .32237 .61461 .32904 .62192 .32655 .61803 .3198 Mtetra
.672 .572 .734 r
.61803 .3198 .62192 .32655 .62925 .32411 .62536 .31733 Mtetra
.633 .55 .743 r
.62536 .31733 .62925 .32411 .63664 .32273 .63275 .31594 Mtetra
.587 .524 .751 r
.63275 .31594 .63664 .32273 .64412 .32243 .64023 .31565 Mtetra
.583 .522 .752 r
.64023 .31565 .64412 .32243 .65163 .32216 .64774 .31545 Mtetra
.578 .521 .754 r
.64774 .31545 .65163 .32216 .65917 .32195 .65528 .31535 Mtetra
.574 .521 .758 r
.65528 .31535 .65917 .32195 .66674 .32178 .66286 .31532 Mtetra
.573 .524 .763 r
.66286 .31532 .66674 .32178 .67434 .3216 .67047 .31531 Mtetra
.574 .53 .768 r
.67047 .31531 .67434 .3216 .68197 .32137 .67811 .31528 Mtetra
.578 .537 .773 r
.67811 .31528 .68197 .32137 .68962 .32106 .68577 .31516 Mtetra
.584 .546 .779 r
.68577 .31516 .68962 .32106 .69728 .32063 .69345 .31492 Mtetra
.592 .557 .784 r
.69345 .31492 .69728 .32063 .70496 .32005 .70115 .31452 Mtetra
.601 .568 .788 r
.70115 .31452 .70496 .32005 .71266 .31929 .70886 .31394 Mtetra
.612 .579 .793 r
.70886 .31394 .71266 .31929 .72036 .31835 .71658 .31316 Mtetra
.623 .591 .797 r
.71658 .31316 .72036 .31835 .72806 .31721 .72431 .31217 Mtetra
.634 .602 .8 r
.72431 .31217 .72806 .31721 .73577 .31587 .73204 .31098 Mtetra
.646 .614 .803 r
.73204 .31098 .73577 .31587 .74348 .31434 .73977 .30958 Mtetra
.657 .625 .806 r
.73977 .30958 .74348 .31434 .75119 .3126 .7475 .30797 Mtetra
.668 .635 .808 r
.7475 .30797 .75119 .3126 .7589 .31067 .75523 .30616 Mtetra
.679 .646 .809 r
.75523 .30616 .7589 .31067 .7666 .30856 .76295 .30416 Mtetra
.69 .655 .811 r
.76295 .30416 .7666 .30856 .77429 .30626 .77067 .30197 Mtetra
.699 .665 .812 r
.77067 .30197 .77429 .30626 .78198 .30379 .77838 .2996 Mtetra
.709 .673 .813 r
.77838 .2996 .78198 .30379 .78966 .30116 .78608 .29706 Mtetra
.718 .682 .814 r
.78608 .29706 .78966 .30116 .79733 .29837 .79378 .29436 Mtetra
.726 .69 .815 r
.79378 .29436 .79733 .29837 .805 .29543 .80147 .29151 Mtetra
.734 .697 .816 r
.80147 .29151 .805 .29543 .81265 .29235 .80915 .28851 Mtetra
.742 .705 .816 r
.80915 .28851 .81265 .29235 .82029 .28915 .81682 .28538 Mtetra
.749 .712 .817 r
.81682 .28538 .82029 .28915 .82793 .28582 .82448 .28213 Mtetra
.755 .718 .818 r
.82448 .28213 .82793 .28582 .83555 .28238 .83213 .27876 Mtetra
.762 .725 .818 r
.83213 .27876 .83555 .28238 .84317 .27884 .83977 .27529 Mtetra
.767 .731 .819 r
.83977 .27529 .84317 .27884 .85077 .2752 .8474 .27172 Mtetra
.773 .737 .819 r
.8474 .27172 .85077 .2752 .85837 .27148 .85503 .26805 Mtetra
.778 .742 .82 r
.85503 .26805 .85837 .27148 .86596 .26767 .86264 .26431 Mtetra
.783 .748 .821 r
.86264 .26431 .86596 .26767 .87353 .2638 .87025 .2605 Mtetra
.787 .753 .822 r
.87025 .2605 .87353 .2638 .8811 .25986 .87784 .25662 Mtetra
.791 .758 .823 r
.87784 .25662 .8811 .25986 .88867 .25587 .88544 .25269 Mtetra
.795 .763 .824 r
.88544 .25269 .88867 .25587 .89622 .25184 .89302 .24871 Mtetra
.798 .768 .825 r
.89302 .24871 .89622 .25184 .90377 .24776 .9006 .24468 Mtetra
.801 .773 .827 r
.9006 .24468 .90377 .24776 .91132 .24366 .90818 .24063 Mtetra
.804 .778 .829 r
.90818 .24063 .91132 .24366 .91886 .23953 .91575 .23655 Mtetra
.807 .783 .831 r
.91575 .23655 .91886 .23953 .9264 .23538 .92332 .23246 Mtetra
.809 .788 .833 r
.92332 .23246 .9264 .23538 .93394 .23123 .93089 .22836 Mtetra
.268 .576 .941 r
.34975 .33727 .35384 .33962 .36024 .34077 .35617 .33837 Mtetra
.279 .576 .94 r
.35617 .33837 .36024 .34077 .36668 .34193 .36262 .33946 Mtetra
.293 .578 .939 r
.36262 .33946 .36668 .34193 .37315 .34307 .3691 .34054 Mtetra
.307 .58 .938 r
.3691 .34054 .37315 .34307 .37966 .3442 .37561 .3416 Mtetra
.323 .582 .936 r
.37561 .3416 .37966 .3442 .38619 .3453 .38215 .34264 Mtetra
.339 .585 .935 r
.38215 .34264 .38619 .3453 .39276 .34637 .38873 .34365 Mtetra
.356 .589 .932 r
.38873 .34365 .39276 .34637 .39937 .3474 .39535 .34461 Mtetra
.374 .592 .93 r
.39535 .34461 .39937 .3474 .40601 .34838 .40199 .34553 Mtetra
.392 .596 .927 r
.40199 .34553 .40601 .34838 .41268 .34931 .40867 .34639 Mtetra
.411 .6 .923 r
.40867 .34639 .41268 .34931 .41939 .35018 .41539 .34718 Mtetra
.429 .603 .919 r
.41539 .34718 .41939 .35018 .42613 .35097 .42214 .3479 Mtetra
.448 .607 .915 r
.42214 .3479 .42613 .35097 .43291 .35168 .42893 .34854 Mtetra
.466 .61 .909 r
.42893 .34854 .43291 .35168 .43972 .3523 .43574 .34909 Mtetra
.485 .614 .904 r
.43574 .34909 .43972 .3523 .44656 .35283 .4426 .34953 Mtetra
.502 .616 .898 r
.4426 .34953 .44656 .35283 .45344 .35325 .44948 .34987 Mtetra
.52 .619 .891 r
.44948 .34987 .45344 .35325 .46035 .35355 .4564 .35008 Mtetra
.537 .622 .884 r
.4564 .35008 .46035 .35355 .46729 .35373 .46335 .35017 Mtetra
.553 .624 .876 r
.46335 .35017 .46729 .35373 .47426 .35377 .47033 .35012 Mtetra
.569 .625 .868 r
.47033 .35012 .47426 .35377 .48127 .35367 .47734 .34991 Mtetra
.584 .627 .86 r
.47734 .34991 .48127 .35367 .4883 .35342 .48438 .34956 Mtetra
.598 .628 .851 r
.48438 .34956 .4883 .35342 .49536 .353 .49144 .34903 Mtetra
.612 .628 .843 r
.49144 .34903 .49536 .353 .50244 .35241 .49854 .34832 Mtetra
.625 .628 .834 r
.49854 .34832 .50244 .35241 .50955 .35165 .50565 .34743 Mtetra
.637 .628 .825 r
.50565 .34743 .50955 .35165 .51669 .35069 .51279 .34634 Mtetra
.648 .628 .816 r
.51279 .34634 .51669 .35069 .52384 .34953 .51995 .34505 Mtetra
.658 .627 .807 r
.51995 .34505 .52384 .34953 .53102 .34818 .52713 .34355 Mtetra
.667 .625 .798 r
.52713 .34355 .53102 .34818 .53821 .34662 .53433 .34183 Mtetra
.675 .624 .79 r
.53433 .34183 .53821 .34662 .54541 .34485 .54154 .33989 Mtetra
.682 .621 .781 r
.54154 .33989 .54541 .34485 .55263 .34288 .54876 .33774 Mtetra
.688 .619 .773 r
.54876 .33774 .55263 .34288 .55986 .34072 .55599 .33538 Mtetra
.693 .615 .765 r
.55599 .33538 .55986 .34072 .5671 .33837 .56323 .33283 Mtetra
.696 .611 .758 r
.56323 .33283 .5671 .33837 .57435 .33586 .57048 .33012 Mtetra
.697 .607 .751 r
.57048 .33012 .57435 .33586 .58161 .33323 .57774 .32727 Mtetra
.697 .601 .746 r
.57774 .32727 .58161 .33323 .58887 .33052 .585 .32434 Mtetra
.694 .595 .741 r
.585 .32434 .58887 .33052 .59614 .32777 .59227 .32138 Mtetra
.69 .589 .737 r
.59227 .32138 .59614 .32777 .60343 .32503 .59954 .31847 Mtetra
.685 .582 .735 r
.59954 .31847 .60343 .32503 .61072 .32237 .60683 .31566 Mtetra
.678 .576 .733 r
.60683 .31566 .61072 .32237 .61803 .3198 .61414 .31302 Mtetra
.672 .571 .733 r
.61414 .31302 .61803 .3198 .62536 .31733 .62147 .31053 Mtetra
.633 .55 .743 r
.62147 .31053 .62536 .31733 .63275 .31594 .62886 .30914 Mtetra
.587 .523 .75 r
.62886 .30914 .63275 .31594 .64023 .31565 .63633 .30883 Mtetra
.579 .519 .752 r
.63633 .30883 .64023 .31565 .64774 .31545 .64384 .30869 Mtetra
.572 .516 .755 r
.64384 .30869 .64774 .31545 .65528 .31535 .65139 .30872 Mtetra
.566 .516 .759 r
.65139 .30872 .65528 .31535 .66286 .31532 .65897 .30885 Mtetra
.563 .518 .764 r
.65897 .30885 .66286 .31532 .67047 .31531 .66659 .30903 Mtetra
.563 .524 .769 r
.66659 .30903 .67047 .31531 .67811 .31528 .67424 .3092 Mtetra
.566 .531 .775 r
.67424 .3092 .67811 .31528 .68577 .31516 .68192 .30928 Mtetra
.572 .541 .781 r
.68192 .30928 .68577 .31516 .69345 .31492 .68962 .30923 Mtetra
.581 .552 .787 r
.68962 .30923 .69345 .31492 .70115 .31452 .69734 .30902 Mtetra
.591 .564 .792 r
.69734 .30902 .70115 .31452 .70886 .31394 .70507 .30861 Mtetra
.602 .576 .796 r
.70507 .30861 .70886 .31394 .71658 .31316 .7128 .308 Mtetra
.614 .588 .8 r
.7128 .308 .71658 .31316 .72431 .31217 .72055 .30717 Mtetra
.627 .6 .804 r
.72055 .30717 .72431 .31217 .73204 .31098 .7283 .30612 Mtetra
.639 .612 .807 r
.7283 .30612 .73204 .31098 .73977 .30958 .73605 .30486 Mtetra
.651 .624 .809 r
.73605 .30486 .73977 .30958 .7475 .30797 .7438 .30337 Mtetra
.663 .635 .812 r
.7438 .30337 .7475 .30797 .75523 .30616 .75155 .30168 Mtetra
.674 .645 .813 r
.75155 .30168 .75523 .30616 .76295 .30416 .7593 .29979 Mtetra
.685 .655 .815 r
.7593 .29979 .76295 .30416 .77067 .30197 .76704 .2977 Mtetra
.695 .665 .816 r
.76704 .2977 .77067 .30197 .77838 .2996 .77477 .29543 Mtetra
.705 .674 .817 r
.77477 .29543 .77838 .2996 .78608 .29706 .7825 .29299 Mtetra
.714 .682 .818 r
.7825 .29299 .78608 .29706 .79378 .29436 .79022 .29037 Mtetra
.723 .69 .818 r
.79022 .29037 .79378 .29436 .80147 .29151 .79793 .28761 Mtetra
.731 .698 .819 r
.79793 .28761 .80147 .29151 .80915 .28851 .80564 .28469 Mtetra
.739 .705 .819 r
.80564 .28469 .80915 .28851 .81682 .28538 .81333 .28164 Mtetra
.746 .712 .82 r
.81333 .28164 .81682 .28538 .82448 .28213 .82102 .27846 Mtetra
.753 .719 .82 r
.82102 .27846 .82448 .28213 .83213 .27876 .82869 .27516 Mtetra
.759 .725 .821 r
.82869 .27516 .83213 .27876 .83977 .27529 .83636 .27175 Mtetra
.765 .731 .821 r
.83636 .27175 .83977 .27529 .8474 .27172 .84402 .26824 Mtetra
.771 .737 .822 r
.84402 .26824 .8474 .27172 .85503 .26805 .85167 .26464 Mtetra
.776 .743 .823 r
.85167 .26464 .85503 .26805 .86264 .26431 .85931 .26095 Mtetra
.781 .748 .823 r
.85931 .26095 .86264 .26431 .87025 .2605 .86695 .2572 Mtetra
.785 .753 .824 r
.86695 .2572 .87025 .2605 .87784 .25662 .87457 .25338 Mtetra
.789 .758 .825 r
.87457 .25338 .87784 .25662 .88544 .25269 .88219 .2495 Mtetra
.793 .763 .826 r
.88219 .2495 .88544 .25269 .89302 .24871 .88981 .24557 Mtetra
.796 .768 .828 r
.88981 .24557 .89302 .24871 .9006 .24468 .89742 .2416 Mtetra
.799 .773 .829 r
.89742 .2416 .9006 .24468 .90818 .24063 .90502 .2376 Mtetra
.802 .778 .831 r
.90502 .2376 .90818 .24063 .91575 .23655 .91262 .23357 Mtetra
.804 .782 .832 r
.91262 .23357 .91575 .23655 .92332 .23246 .92023 .22953 Mtetra
.807 .787 .835 r
.92023 .22953 .92332 .23246 .93089 .22836 .92783 .22547 Mtetra
.282 .584 .943 r
.34565 .33491 .34975 .33727 .35617 .33837 .35207 .33595 Mtetra
.293 .584 .942 r
.35207 .33595 .35617 .33837 .36262 .33946 .35853 .33698 Mtetra
.306 .585 .941 r
.35853 .33698 .36262 .33946 .3691 .34054 .36502 .338 Mtetra
.32 .587 .94 r
.36502 .338 .3691 .34054 .37561 .3416 .37154 .33901 Mtetra
.335 .589 .938 r
.37154 .33901 .37561 .3416 .38215 .34264 .3781 .33998 Mtetra
.351 .592 .936 r
.3781 .33998 .38215 .34264 .38873 .34365 .38468 .34093 Mtetra
.367 .595 .934 r
.38468 .34093 .38873 .34365 .39535 .34461 .39131 .34183 Mtetra
.385 .599 .931 r
.39131 .34183 .39535 .34461 .40199 .34553 .39796 .34268 Mtetra
.402 .602 .928 r
.39796 .34268 .40199 .34553 .40867 .34639 .40465 .34347 Mtetra
.42 .606 .924 r
.40465 .34347 .40867 .34639 .41539 .34718 .41138 .3442 Mtetra
.439 .609 .92 r
.41138 .3442 .41539 .34718 .42214 .3479 .41813 .34485 Mtetra
.457 .613 .916 r
.41813 .34485 .42214 .3479 .42893 .34854 .42493 .34541 Mtetra
.475 .616 .91 r
.42493 .34541 .42893 .34854 .43574 .34909 .43175 .34588 Mtetra
.493 .619 .904 r
.43175 .34588 .43574 .34909 .4426 .34953 .43861 .34625 Mtetra
.511 .622 .898 r
.43861 .34625 .4426 .34953 .44948 .34987 .44551 .3465 Mtetra
.528 .625 .891 r
.44551 .3465 .44948 .34987 .4564 .35008 .45243 .34663 Mtetra
.545 .627 .884 r
.45243 .34663 .4564 .35008 .46335 .35017 .45939 .34663 Mtetra
.561 .629 .877 r
.45939 .34663 .46335 .35017 .47033 .35012 .46638 .34648 Mtetra
.577 .631 .869 r
.46638 .34648 .47033 .35012 .47734 .34991 .4734 .34618 Mtetra
.592 .632 .86 r
.4734 .34618 .47734 .34991 .48438 .34956 .48044 .34572 Mtetra
.606 .633 .852 r
.48044 .34572 .48438 .34956 .49144 .34903 .48752 .34509 Mtetra
.62 .634 .843 r
.48752 .34509 .49144 .34903 .49854 .34832 .49462 .34427 Mtetra
.632 .634 .834 r
.49462 .34427 .49854 .34832 .50565 .34743 .50174 .34325 Mtetra
.644 .634 .825 r
.50174 .34325 .50565 .34743 .51279 .34634 .50889 .34203 Mtetra
.655 .633 .816 r
.50889 .34203 .51279 .34634 .51995 .34505 .51605 .3406 Mtetra
.666 .632 .807 r
.51605 .3406 .51995 .34505 .52713 .34355 .52324 .33895 Mtetra
.675 .631 .798 r
.52324 .33895 .52713 .34355 .53433 .34183 .53044 .33708 Mtetra
.683 .629 .789 r
.53044 .33708 .53433 .34183 .54154 .33989 .53765 .33497 Mtetra
.69 .627 .78 r
.53765 .33497 .54154 .33989 .54876 .33774 .54488 .33264 Mtetra
.696 .624 .772 r
.54488 .33264 .54876 .33774 .55599 .33538 .55211 .33009 Mtetra
.701 .62 .764 r
.55211 .33009 .55599 .33538 .56323 .33283 .55936 .32733 Mtetra
.704 .616 .756 r
.55936 .32733 .56323 .33283 .57048 .33012 .56661 .32439 Mtetra
.705 .611 .749 r
.56661 .32439 .57048 .33012 .57774 .32727 .57386 .32131 Mtetra
.704 .605 .743 r
.57386 .32131 .57774 .32727 .585 .32434 .58112 .31815 Mtetra
.701 .599 .739 r
.58112 .31815 .585 .32434 .59227 .32138 .58838 .31498 Mtetra
.696 .591 .735 r
.58838 .31498 .59227 .32138 .59954 .31847 .59566 .31187 Mtetra
.689 .584 .733 r
.59566 .31187 .59954 .31847 .60683 .31566 .60294 .30892 Mtetra
.68 .576 .732 r
.60294 .30892 .60683 .31566 .61414 .31302 .61024 .30618 Mtetra
.671 .57 .733 r
.61024 .30618 .61414 .31302 .62147 .31053 .61757 .3037 Mtetra
.633 .549 .742 r
.61757 .3037 .62147 .31053 .62886 .30914 .62496 .30229 Mtetra
.587 .523 .75 r
.62496 .30229 .62886 .30914 .63633 .30883 .63243 .30197 Mtetra
.576 .516 .751 r
.63243 .30197 .63633 .30883 .64384 .30869 .63993 .3019 Mtetra
.565 .511 .754 r
.63993 .3019 .64384 .30869 .65139 .30872 .64748 .30205 Mtetra
.556 .51 .759 r
.64748 .30205 .65139 .30872 .65897 .30885 .65508 .30236 Mtetra
.551 .512 .765 r
.65508 .30236 .65897 .30885 .66659 .30903 .66271 .30275 Mtetra
.55 .517 .771 r
.66271 .30275 .66659 .30903 .67424 .3092 .67037 .30312 Mtetra
.554 .525 .777 r
.67037 .30312 .67424 .3092 .68192 .30928 .67807 .30342 Mtetra
.56 .535 .784 r
.67807 .30342 .68192 .30928 .68962 .30923 .68578 .30358 Mtetra
.569 .547 .79 r
.68578 .30358 .68962 .30923 .69734 .30902 .69351 .30356 Mtetra
.58 .559 .795 r
.69351 .30356 .69734 .30902 .70507 .30861 .70126 .30333 Mtetra
.593 .572 .8 r
.70126 .30333 .70507 .30861 .7128 .308 .70902 .30289 Mtetra
.605 .585 .804 r
.70902 .30289 .7128 .308 .72055 .30717 .71678 .30221 Mtetra
.619 .598 .808 r
.71678 .30221 .72055 .30717 .7283 .30612 .72455 .30131 Mtetra
.632 .611 .811 r
.72455 .30131 .7283 .30612 .73605 .30486 .73232 .30017 Mtetra
.644 .623 .813 r
.73232 .30017 .73605 .30486 .7438 .30337 .7401 .29882 Mtetra
.657 .634 .816 r
.7401 .29882 .7438 .30337 .75155 .30168 .74787 .29724 Mtetra
.669 .645 .817 r
.74787 .29724 .75155 .30168 .7593 .29979 .75563 .29546 Mtetra
.68 .655 .819 r
.75563 .29546 .7593 .29979 .76704 .2977 .7634 .29347 Mtetra
.691 .665 .82 r
.7634 .29347 .76704 .2977 .77477 .29543 .77115 .2913 Mtetra
.701 .674 .821 r
.77115 .2913 .77477 .29543 .7825 .29299 .77891 .28894 Mtetra
.711 .683 .821 r
.77891 .28894 .7825 .29299 .79022 .29037 .78665 .28641 Mtetra
.72 .691 .822 r
.78665 .28641 .79022 .29037 .79793 .28761 .79439 .28372 Mtetra
.728 .698 .822 r
.79439 .28372 .79793 .28761 .80564 .28469 .80212 .28089 Mtetra
.736 .706 .823 r
.80212 .28089 .80564 .28469 .81333 .28164 .80984 .27791 Mtetra
.743 .713 .823 r
.80984 .27791 .81333 .28164 .82102 .27846 .81755 .27479 Mtetra
.75 .719 .823 r
.81755 .27479 .82102 .27846 .82869 .27516 .82525 .27156 Mtetra
.757 .726 .824 r
.82525 .27156 .82869 .27516 .83636 .27175 .83294 .26822 Mtetra
.763 .732 .824 r
.83294 .26822 .83636 .27175 .84402 .26824 .84063 .26477 Mtetra
.768 .738 .825 r
.84063 .26477 .84402 .26824 .85167 .26464 .8483 .26123 Mtetra
.774 .743 .825 r
.8483 .26123 .85167 .26464 .85931 .26095 .85597 .2576 Mtetra
.778 .748 .826 r
.85597 .2576 .85931 .26095 .86695 .2572 .86363 .2539 Mtetra
.783 .754 .827 r
.86363 .2539 .86695 .2572 .87457 .25338 .87129 .25013 Mtetra
.787 .759 .827 r
.87129 .25013 .87457 .25338 .88219 .2495 .87894 .2463 Mtetra
.791 .764 .828 r
.87894 .2463 .88219 .2495 .88981 .24557 .88658 .24242 Mtetra
.794 .768 .83 r
.88658 .24242 .88981 .24557 .89742 .2416 .89422 .2385 Mtetra
.797 .773 .831 r
.89422 .2385 .89742 .2416 .90502 .2376 .90185 .23455 Mtetra
.8 .778 .833 r
.90185 .23455 .90502 .2376 .91262 .23357 .90948 .23057 Mtetra
.802 .782 .834 r
.90948 .23057 .91262 .23357 .92023 .22953 .91712 .22658 Mtetra
.804 .787 .836 r
.91712 .22658 .92023 .22953 .92783 .22547 .92475 .22257 Mtetra
.296 .591 .945 r
.34153 .33254 .34565 .33491 .35207 .33595 .34796 .33352 Mtetra
.307 .591 .944 r
.34796 .33352 .35207 .33595 .35853 .33698 .35443 .3345 Mtetra
.319 .592 .943 r
.35443 .3345 .35853 .33698 .36502 .338 .36093 .33546 Mtetra
.332 .594 .941 r
.36093 .33546 .36502 .338 .37154 .33901 .36746 .33641 Mtetra
.346 .596 .94 r
.36746 .33641 .37154 .33901 .3781 .33998 .37402 .33732 Mtetra
.361 .599 .937 r
.37402 .33732 .3781 .33998 .38468 .34093 .38062 .33821 Mtetra
.378 .602 .935 r
.38062 .33821 .38468 .34093 .39131 .34183 .38725 .33905 Mtetra
.394 .605 .932 r
.38725 .33905 .39131 .34183 .39796 .34268 .39391 .33983 Mtetra
.412 .608 .929 r
.39391 .33983 .39796 .34268 .40465 .34347 .40061 .34056 Mtetra
.429 .612 .925 r
.40061 .34056 .40465 .34347 .41138 .3442 .40734 .34122 Mtetra
.447 .615 .921 r
.40734 .34122 .41138 .3442 .41813 .34485 .41411 .3418 Mtetra
.465 .619 .916 r
.41411 .3418 .41813 .34485 .42493 .34541 .42091 .34229 Mtetra
.483 .622 .911 r
.42091 .34229 .42493 .34541 .43175 .34588 .42775 .34269 Mtetra
.501 .625 .905 r
.42775 .34269 .43175 .34588 .43861 .34625 .43462 .34298 Mtetra
.519 .628 .899 r
.43462 .34298 .43861 .34625 .44551 .3465 .44152 .34315 Mtetra
.536 .631 .892 r
.44152 .34315 .44551 .3465 .45243 .34663 .44845 .3432 Mtetra
.553 .633 .885 r
.44845 .3432 .45243 .34663 .45939 .34663 .45542 .34311 Mtetra
.569 .635 .877 r
.45542 .34311 .45939 .34663 .46638 .34648 .46241 .34287 Mtetra
.584 .636 .869 r
.46241 .34287 .46638 .34648 .4734 .34618 .46944 .34248 Mtetra
.599 .638 .86 r
.46944 .34248 .4734 .34618 .48044 .34572 .47649 .34192 Mtetra
.614 .639 .852 r
.47649 .34192 .48044 .34572 .48752 .34509 .48358 .34117 Mtetra
.627 .639 .843 r
.48358 .34117 .48752 .34509 .49462 .34427 .49068 .34024 Mtetra
.64 .639 .834 r
.49068 .34024 .49462 .34427 .50174 .34325 .49782 .33911 Mtetra
.652 .639 .825 r
.49782 .33911 .50174 .34325 .50889 .34203 .50497 .33776 Mtetra
.663 .639 .815 r
.50497 .33776 .50889 .34203 .51605 .3406 .51214 .3362 Mtetra
.673 .638 .806 r
.51214 .3362 .51605 .3406 .52324 .33895 .51933 .3344 Mtetra
.683 .636 .797 r
.51933 .3344 .52324 .33895 .53044 .33708 .52654 .33237 Mtetra
.691 .634 .788 r
.52654 .33237 .53044 .33708 .53765 .33497 .53376 .33009 Mtetra
.698 .632 .779 r
.53376 .33009 .53765 .33497 .54488 .33264 .54099 .32758 Mtetra
.704 .629 .77 r
.54099 .32758 .54488 .33264 .55211 .33009 .54823 .32483 Mtetra
.709 .625 .762 r
.54823 .32483 .55211 .33009 .55936 .32733 .55547 .32186 Mtetra
.712 .621 .754 r
.55547 .32186 .55936 .32733 .56661 .32439 .56272 .31869 Mtetra
.713 .616 .747 r
.56272 .31869 .56661 .32439 .57386 .32131 .56998 .31537 Mtetra
.712 .61 .741 r
.56998 .31537 .57386 .32131 .58112 .31815 .57723 .31196 Mtetra
.708 .602 .736 r
.57723 .31196 .58112 .31815 .58838 .31498 .58449 .30855 Mtetra
.702 .594 .732 r
.58449 .30855 .58838 .31498 .59566 .31187 .59176 .30522 Mtetra
.693 .585 .73 r
.59176 .30522 .59566 .31187 .60294 .30892 .59904 .3021 Mtetra
.682 .576 .73 r
.59904 .3021 .60294 .30892 .61024 .30618 .60634 .29928 Mtetra
.67 .568 .731 r
.60634 .29928 .61024 .30618 .61757 .3037 .61367 .2968 Mtetra
.632 .547 .741 r
.61367 .2968 .61757 .3037 .62496 .30229 .62105 .29538 Mtetra
.588 .522 .748 r
.62105 .29538 .62496 .30229 .63243 .30197 .62852 .29504 Mtetra
.572 .512 .75 r
.62852 .29504 .63243 .30197 .63993 .3019 .63602 .29504 Mtetra
.557 .505 .754 r
.63602 .29504 .63993 .3019 .64748 .30205 .64358 .29534 Mtetra
.545 .502 .759 r
.64358 .29534 .64748 .30205 .65508 .30236 .65118 .29585 Mtetra
.538 .504 .765 r
.65118 .29585 .65508 .30236 .66271 .30275 .65882 .29646 Mtetra
.537 .509 .772 r
.65882 .29646 .66271 .30275 .67037 .30312 .6665 .29706 Mtetra
.54 .517 .78 r
.6665 .29706 .67037 .30312 .67807 .30342 .67421 .29759 Mtetra
.547 .528 .786 r
.67421 .29759 .67807 .30342 .68578 .30358 .68194 .29796 Mtetra
.557 .541 .793 r
.68194 .29796 .68578 .30358 .69351 .30356 .68969 .29814 Mtetra
.569 .555 .799 r
.68969 .29814 .69351 .30356 .70126 .30333 .69745 .29809 Mtetra
.582 .569 .804 r
.69745 .29809 .70126 .30333 .70902 .30289 .70523 .29782 Mtetra
.596 .583 .808 r
.70523 .29782 .70902 .30289 .71678 .30221 .71301 .2973 Mtetra
.61 .596 .812 r
.71301 .2973 .71678 .30221 .72455 .30131 .7208 .29653 Mtetra
.624 .609 .815 r
.7208 .29653 .72455 .30131 .73232 .30017 .72859 .29553 Mtetra
.638 .622 .818 r
.72859 .29553 .73232 .30017 .7401 .29882 .73639 .2943 Mtetra
.651 .633 .82 r
.73639 .2943 .7401 .29882 .74787 .29724 .74418 .29283 Mtetra
.663 .645 .821 r
.74418 .29283 .74787 .29724 .75563 .29546 .75197 .29116 Mtetra
.675 .655 .822 r
.75197 .29116 .75563 .29546 .7634 .29347 .75975 .28927 Mtetra
.686 .665 .823 r
.75975 .28927 .7634 .29347 .77115 .2913 .76753 .28719 Mtetra
.697 .674 .824 r
.76753 .28719 .77115 .2913 .77891 .28894 .7753 .28492 Mtetra
.707 .683 .825 r
.7753 .28492 .77891 .28894 .78665 .28641 .78307 .28248 Mtetra
.716 .691 .825 r
.78307 .28248 .78665 .28641 .79439 .28372 .79083 .27987 Mtetra
.725 .699 .825 r
.79083 .27987 .79439 .28372 .80212 .28089 .79859 .2771 Mtetra
.733 .707 .826 r
.79859 .2771 .80212 .28089 .80984 .27791 .80633 .27419 Mtetra
.741 .713 .826 r
.80633 .27419 .80984 .27791 .81755 .27479 .81407 .27115 Mtetra
.748 .72 .826 r
.81407 .27115 .81755 .27479 .82525 .27156 .82179 .26798 Mtetra
.754 .726 .826 r
.82179 .26798 .82525 .27156 .83294 .26822 .82951 .26469 Mtetra
.761 .732 .827 r
.82951 .26469 .83294 .26822 .84063 .26477 .83722 .2613 Mtetra
.766 .738 .827 r
.83722 .2613 .84063 .26477 .8483 .26123 .84493 .25782 Mtetra
.771 .744 .828 r
.84493 .25782 .8483 .26123 .85597 .2576 .85262 .25425 Mtetra
.776 .749 .828 r
.85262 .25425 .85597 .2576 .86363 .2539 .86031 .2506 Mtetra
.781 .754 .829 r
.86031 .2506 .86363 .2539 .87129 .25013 .86799 .24688 Mtetra
.785 .759 .83 r
.86799 .24688 .87129 .25013 .87894 .2463 .87567 .2431 Mtetra
.789 .764 .831 r
.87567 .2431 .87894 .2463 .88658 .24242 .88334 .23928 Mtetra
.792 .768 .832 r
.88334 .23928 .88658 .24242 .89422 .2385 .891 .2354 Mtetra
.795 .773 .833 r
.891 .2354 .89422 .2385 .90185 .23455 .89867 .2315 Mtetra
.798 .777 .834 r
.89867 .2315 .90185 .23455 .90948 .23057 .90633 .22757 Mtetra
.8 .782 .836 r
.90633 .22757 .90948 .23057 .91712 .22658 .91399 .22362 Mtetra
.802 .786 .838 r
.91399 .22362 .91712 .22658 .92475 .22257 .92165 .21966 Mtetra
.309 .598 .947 r
.33738 .33016 .34153 .33254 .34796 .33352 .34383 .33108 Mtetra
.319 .598 .946 r
.34383 .33108 .34796 .33352 .35443 .3345 .35031 .332 Mtetra
.331 .599 .944 r
.35031 .332 .35443 .3345 .36093 .33546 .35681 .33291 Mtetra
.343 .6 .943 r
.35681 .33291 .36093 .33546 .36746 .33641 .36335 .3338 Mtetra
.357 .602 .941 r
.36335 .3338 .36746 .33641 .37402 .33732 .36993 .33466 Mtetra
.372 .605 .939 r
.36993 .33466 .37402 .33732 .38062 .33821 .37653 .33549 Mtetra
.387 .608 .936 r
.37653 .33549 .38062 .33821 .38725 .33905 .38317 .33627 Mtetra
.404 .611 .933 r
.38317 .33627 .38725 .33905 .39391 .33983 .38984 .33699 Mtetra
.421 .614 .93 r
.38984 .33699 .39391 .33983 .40061 .34056 .39655 .33766 Mtetra
.438 .617 .926 r
.39655 .33766 .40061 .34056 .40734 .34122 .40329 .33825 Mtetra
.456 .621 .922 r
.40329 .33825 .40734 .34122 .41411 .3418 .41007 .33876 Mtetra
.473 .624 .917 r
.41007 .33876 .41411 .3418 .42091 .34229 .41688 .33919 Mtetra
.491 .627 .912 r
.41688 .33919 .42091 .34229 .42775 .34269 .42372 .33951 Mtetra
.509 .631 .906 r
.42372 .33951 .42775 .34269 .43462 .34298 .4306 .33973 Mtetra
.526 .633 .899 r
.4306 .33973 .43462 .34298 .44152 .34315 .43751 .33982 Mtetra
.543 .636 .893 r
.43751 .33982 .44152 .34315 .44845 .3432 .44445 .33979 Mtetra
.56 .638 .885 r
.44445 .33979 .44845 .3432 .45542 .34311 .45143 .33962 Mtetra
.576 .64 .877 r
.45143 .33962 .45542 .34311 .46241 .34287 .45843 .33929 Mtetra
.592 .642 .869 r
.45843 .33929 .46241 .34287 .46944 .34248 .46547 .3388 Mtetra
.606 .643 .861 r
.46547 .3388 .46944 .34248 .47649 .34192 .47253 .33814 Mtetra
.621 .644 .852 r
.47253 .33814 .47649 .34192 .48358 .34117 .47962 .3373 Mtetra
.634 .645 .843 r
.47962 .3373 .48358 .34117 .49068 .34024 .48674 .33625 Mtetra
.647 .645 .834 r
.48674 .33625 .49068 .34024 .49782 .33911 .49388 .335 Mtetra
.659 .645 .825 r
.49388 .335 .49782 .33911 .50497 .33776 .50104 .33353 Mtetra
.67 .644 .815 r
.50104 .33353 .50497 .33776 .51214 .3362 .50822 .33183 Mtetra
.681 .643 .806 r
.50822 .33183 .51214 .3362 .51933 .3344 .51542 .3299 Mtetra
.69 .642 .796 r
.51542 .3299 .51933 .3344 .52654 .33237 .52263 .32771 Mtetra
.699 .64 .787 r
.52263 .32771 .52654 .33237 .53376 .33009 .52986 .32526 Mtetra
.706 .637 .778 r
.52986 .32526 .53376 .33009 .54099 .32758 .53709 .32257 Mtetra
.712 .634 .769 r
.53709 .32257 .54099 .32758 .54823 .32483 .54434 .31961 Mtetra
.717 .631 .76 r
.54434 .31961 .54823 .32483 .55547 .32186 .55158 .31642 Mtetra
.72 .626 .752 r
.55158 .31642 .55547 .32186 .56272 .31869 .55884 .31302 Mtetra
.721 .621 .745 r
.55884 .31302 .56272 .31869 .56998 .31537 .56609 .30944 Mtetra
.72 .614 .739 r
.56609 .30944 .56998 .31537 .57723 .31196 .57334 .30577 Mtetra
.716 .606 .733 r
.57334 .30577 .57723 .31196 .58449 .30855 .5806 .30209 Mtetra
.708 .597 .73 r
.5806 .30209 .58449 .30855 .59176 .30522 .58786 .29852 Mtetra
.698 .587 .728 r
.58786 .29852 .59176 .30522 .59904 .3021 .59514 .29521 Mtetra
.684 .576 .728 r
.59514 .29521 .59904 .3021 .60634 .29928 .60244 .29228 Mtetra
.668 .566 .73 r
.60244 .29228 .60634 .29928 .61367 .2968 .60976 .28981 Mtetra
.632 .545 .739 r
.60976 .28981 .61367 .2968 .62105 .29538 .61714 .28839 Mtetra
.588 .521 .746 r
.61714 .28839 .62105 .29538 .62852 .29504 .6246 .28801 Mtetra
.567 .508 .748 r
.6246 .28801 .62852 .29504 .63602 .29504 .63211 .2881 Mtetra
.548 .498 .753 r
.63211 .2881 .63602 .29504 .64358 .29534 .63967 .28857 Mtetra
.533 .494 .759 r
.63967 .28857 .64358 .29534 .65118 .29585 .64728 .2893 Mtetra
.524 .494 .766 r
.64728 .2893 .65118 .29585 .65882 .29646 .65493 .29016 Mtetra
.521 .5 .774 r
.65493 .29016 .65882 .29646 .6665 .29706 .66262 .29102 Mtetra
.524 .509 .782 r
.66262 .29102 .6665 .29706 .67421 .29759 .67034 .29178 Mtetra
.532 .521 .789 r
.67034 .29178 .67421 .29759 .68194 .29796 .67809 .29237 Mtetra
.543 .535 .796 r
.67809 .29237 .68194 .29796 .68969 .29814 .68586 .29276 Mtetra
.556 .55 .803 r
.68586 .29276 .68969 .29814 .69745 .29809 .69364 .2929 Mtetra
.571 .565 .808 r
.69364 .2929 .69745 .29809 .70523 .29782 .70144 .29279 Mtetra
.586 .58 .813 r
.70144 .29279 .70523 .29782 .71301 .2973 .70924 .29243 Mtetra
.601 .594 .816 r
.70924 .29243 .71301 .2973 .7208 .29653 .71705 .29181 Mtetra
.616 .608 .819 r
.71705 .29181 .7208 .29653 .72859 .29553 .72486 .29093 Mtetra
.631 .621 .822 r
.72486 .29093 .72859 .29553 .73639 .2943 .73267 .28982 Mtetra
.645 .633 .824 r
.73267 .28982 .73639 .2943 .74418 .29283 .74048 .28847 Mtetra
.658 .644 .825 r
.74048 .28847 .74418 .29283 .75197 .29116 .74829 .28689 Mtetra
.67 .655 .826 r
.74829 .28689 .75197 .29116 .75975 .28927 .7561 .2851 Mtetra
.682 .665 .827 r
.7561 .2851 .75975 .28927 .76753 .28719 .7639 .28311 Mtetra
.693 .675 .828 r
.7639 .28311 .76753 .28719 .7753 .28492 .77169 .28093 Mtetra
.703 .684 .828 r
.77169 .28093 .7753 .28492 .78307 .28248 .77949 .27856 Mtetra
.713 .692 .829 r
.77949 .27856 .78307 .28248 .79083 .27987 .78727 .27603 Mtetra
.722 .7 .829 r
.78727 .27603 .79083 .27987 .79859 .2771 .79504 .27333 Mtetra
.73 .707 .829 r
.79504 .27333 .79859 .2771 .80633 .27419 .80281 .27049 Mtetra
.738 .714 .829 r
.80281 .27049 .80633 .27419 .81407 .27115 .81057 .26751 Mtetra
.745 .721 .829 r
.81057 .26751 .81407 .27115 .82179 .26798 .81833 .26441 Mtetra
.752 .727 .829 r
.81833 .26441 .82179 .26798 .82951 .26469 .82607 .26118 Mtetra
.758 .733 .829 r
.82607 .26118 .82951 .26469 .83722 .2613 .83381 .25785 Mtetra
.764 .739 .83 r
.83381 .25785 .83722 .2613 .84493 .25782 .84154 .25442 Mtetra
.769 .744 .83 r
.84154 .25442 .84493 .25782 .85262 .25425 .84926 .2509 Mtetra
.774 .749 .83 r
.84926 .2509 .85262 .25425 .86031 .2506 .85697 .2473 Mtetra
.779 .754 .831 r
.85697 .2473 .86031 .2506 .86799 .24688 .86468 .24363 Mtetra
.783 .759 .832 r
.86468 .24363 .86799 .24688 .87567 .2431 .87238 .2399 Mtetra
.786 .764 .833 r
.87238 .2399 .87567 .2431 .88334 .23928 .88008 .23612 Mtetra
.79 .768 .834 r
.88008 .23612 .88334 .23928 .891 .2354 .88778 .2323 Mtetra
.793 .773 .835 r
.88778 .2323 .891 .2354 .89867 .2315 .89547 .22844 Mtetra
.795 .777 .836 r
.89547 .22844 .89867 .2315 .90633 .22757 .90316 .22455 Mtetra
.798 .781 .838 r
.90316 .22455 .90633 .22757 .91399 .22362 .91085 .22064 Mtetra
.8 .786 .84 r
.91085 .22064 .91399 .22362 .92165 .21966 .91854 .21673 Mtetra
.322 .605 .949 r
.33322 .32777 .33738 .33016 .34383 .33108 .33968 .32864 Mtetra
.331 .604 .947 r
.33968 .32864 .34383 .33108 .35031 .332 .34616 .32951 Mtetra
.342 .605 .946 r
.34616 .32951 .35031 .332 .35681 .33291 .35268 .33036 Mtetra
.354 .606 .944 r
.35268 .33036 .35681 .33291 .36335 .3338 .35923 .33119 Mtetra
.367 .608 .942 r
.35923 .33119 .36335 .3338 .36993 .33466 .36581 .332 Mtetra
.381 .61 .94 r
.36581 .332 .36993 .33466 .37653 .33549 .37243 .33276 Mtetra
.397 .613 .937 r
.37243 .33276 .37653 .33549 .38317 .33627 .37907 .33349 Mtetra
.413 .616 .934 r
.37907 .33349 .38317 .33627 .38984 .33699 .38576 .33415 Mtetra
.429 .619 .931 r
.38576 .33415 .38984 .33699 .39655 .33766 .39247 .33476 Mtetra
.446 .623 .927 r
.39247 .33476 .39655 .33766 .40329 .33825 .39922 .33529 Mtetra
.463 .626 .923 r
.39922 .33529 .40329 .33825 .41007 .33876 .40601 .33574 Mtetra
.481 .63 .918 r
.40601 .33574 .41007 .33876 .41688 .33919 .41283 .33609 Mtetra
.499 .633 .913 r
.41283 .33609 .41688 .33919 .42372 .33951 .41968 .33635 Mtetra
.516 .636 .907 r
.41968 .33635 .42372 .33951 .4306 .33973 .42657 .33649 Mtetra
.533 .639 .9 r
.42657 .33649 .4306 .33973 .43751 .33982 .43349 .33651 Mtetra
.55 .641 .893 r
.43349 .33651 .43751 .33982 .44445 .33979 .44044 .3364 Mtetra
.567 .644 .886 r
.44044 .3364 .44445 .33979 .45143 .33962 .44742 .33615 Mtetra
.583 .646 .878 r
.44742 .33615 .45143 .33962 .45843 .33929 .45444 .33574 Mtetra
.598 .647 .87 r
.45444 .33574 .45843 .33929 .46547 .3388 .46148 .33516 Mtetra
.613 .649 .861 r
.46148 .33516 .46547 .3388 .47253 .33814 .46855 .3344 Mtetra
.628 .65 .852 r
.46855 .3344 .47253 .33814 .47962 .3373 .47565 .33345 Mtetra
.641 .65 .843 r
.47565 .33345 .47962 .3373 .48674 .33625 .48277 .33231 Mtetra
.654 .65 .834 r
.48277 .33231 .48674 .33625 .49388 .335 .48992 .33094 Mtetra
.666 .65 .825 r
.48992 .33094 .49388 .335 .50104 .33353 .49709 .32935 Mtetra
.677 .65 .815 r
.49709 .32935 .50104 .33353 .50822 .33183 .50428 .32752 Mtetra
.688 .649 .805 r
.50428 .32752 .50822 .33183 .51542 .3299 .51149 .32544 Mtetra
.698 .647 .796 r
.51149 .32544 .51542 .3299 .52263 .32771 .51871 .3231 Mtetra
.706 .645 .786 r
.51871 .3231 .52263 .32771 .52986 .32526 .52594 .32049 Mtetra
.714 .643 .777 r
.52594 .32049 .52986 .32526 .53709 .32257 .53318 .3176 Mtetra
.72 .64 .768 r
.53318 .3176 .53709 .32257 .54434 .31961 .54043 .31445 Mtetra
.725 .636 .759 r
.54043 .31445 .54434 .31961 .55158 .31642 .54769 .31103 Mtetra
.728 .631 .75 r
.54769 .31103 .55158 .31642 .55884 .31302 .55494 .30738 Mtetra
.73 .626 .742 r
.55494 .30738 .55884 .31302 .56609 .30944 .56219 .30353 Mtetra
.728 .619 .736 r
.56219 .30353 .56609 .30944 .57334 .30577 .56945 .29956 Mtetra
.724 .61 .73 r
.56945 .29956 .57334 .30577 .5806 .30209 .5767 .29559 Mtetra
.716 .6 .726 r
.5767 .29559 .5806 .30209 .58786 .29852 .58396 .29175 Mtetra
.703 .588 .724 r
.58396 .29175 .58786 .29852 .59514 .29521 .59123 .28822 Mtetra
.686 .575 .725 r
.59123 .28822 .59514 .29521 .60244 .29228 .59852 .28517 Mtetra
.667 .562 .728 r
.59852 .28517 .60244 .29228 .60976 .28981 .60585 .28271 Mtetra
.631 .543 .736 r
.60585 .28271 .60976 .28981 .61714 .28839 .61323 .28128 Mtetra
.589 .519 .743 r
.61323 .28128 .61714 .28839 .6246 .28801 .62067 .28087 Mtetra
.562 .502 .746 r
.62067 .28087 .6246 .28801 .63211 .2881 .62818 .28106 Mtetra
.537 .49 .751 r
.62818 .28106 .63211 .2881 .63967 .28857 .63575 .28173 Mtetra
.518 .484 .758 r
.63575 .28173 .63967 .28857 .64728 .2893 .64337 .28272 Mtetra
.507 .484 .766 r
.64337 .28272 .64728 .2893 .65493 .29016 .65103 .28386 Mtetra
.503 .489 .775 r
.65103 .28386 .65493 .29016 .66262 .29102 .65874 .28499 Mtetra
.506 .5 .783 r
.65874 .28499 .66262 .29102 .67034 .29178 .66648 .286 Mtetra
.515 .513 .792 r
.66648 .286 .67034 .29178 .67809 .29237 .67424 .28683 Mtetra
.528 .528 .8 r
.67424 .28683 .67809 .29237 .68586 .29276 .68203 .28743 Mtetra
.543 .545 .806 r
.68203 .28743 .68586 .29276 .69364 .2929 .68983 .28776 Mtetra
.559 .561 .812 r
.68983 .28776 .69364 .2929 .70144 .29279 .69764 .28782 Mtetra
.575 .577 .817 r
.69764 .28782 .70144 .29279 .70924 .29243 .70546 .28761 Mtetra
.592 .592 .821 r
.70546 .28761 .70924 .29243 .71705 .29181 .71328 .28713 Mtetra
.608 .606 .824 r
.71328 .28713 .71705 .29181 .72486 .29093 .72111 .28638 Mtetra
.623 .62 .826 r
.72111 .28638 .72486 .29093 .73267 .28982 .72895 .28538 Mtetra
.638 .632 .828 r
.72895 .28538 .73267 .28982 .74048 .28847 .73678 .28414 Mtetra
.652 .644 .83 r
.73678 .28414 .74048 .28847 .74829 .28689 .74461 .28266 Mtetra
.665 .655 .831 r
.74461 .28266 .74829 .28689 .7561 .2851 .75243 .28097 Mtetra
.677 .666 .831 r
.75243 .28097 .7561 .2851 .7639 .28311 .76026 .27906 Mtetra
.689 .675 .832 r
.76026 .27906 .7639 .28311 .77169 .28093 .76808 .27696 Mtetra
.7 .684 .832 r
.76808 .27696 .77169 .28093 .77949 .27856 .77589 .27468 Mtetra
.71 .693 .832 r
.77589 .27468 .77949 .27856 .78727 .27603 .7837 .27221 Mtetra
.719 .701 .832 r
.7837 .27221 .78727 .27603 .79504 .27333 .7915 .26959 Mtetra
.727 .708 .832 r
.7915 .26959 .79504 .27333 .80281 .27049 .79929 .26681 Mtetra
.735 .715 .832 r
.79929 .26681 .80281 .27049 .81057 .26751 .80707 .2639 Mtetra
.743 .722 .832 r
.80707 .2639 .81057 .26751 .81833 .26441 .81485 .26085 Mtetra
.75 .728 .832 r
.81485 .26085 .81833 .26441 .82607 .26118 .82262 .25768 Mtetra
.756 .734 .832 r
.82262 .25768 .82607 .26118 .83381 .25785 .83038 .2544 Mtetra
.762 .739 .832 r
.83038 .2544 .83381 .25785 .84154 .25442 .83813 .25102 Mtetra
.767 .745 .832 r
.83813 .25102 .84154 .25442 .84926 .2509 .84588 .24756 Mtetra
.772 .75 .833 r
.84588 .24756 .84926 .2509 .85697 .2473 .85362 .24401 Mtetra
.777 .755 .833 r
.85362 .24401 .85697 .2473 .86468 .24363 .86136 .24038 Mtetra
.781 .76 .834 r
.86136 .24038 .86468 .24363 .87238 .2399 .86909 .2367 Mtetra
.785 .764 .835 r
.86909 .2367 .87238 .2399 .88008 .23612 .87681 .23296 Mtetra
.788 .769 .836 r
.87681 .23296 .88008 .23612 .88778 .2323 .88454 .22918 Mtetra
.791 .773 .837 r
.88454 .22918 .88778 .2323 .89547 .22844 .89226 .22536 Mtetra
.793 .777 .838 r
.89226 .22536 .89547 .22844 .90316 .22455 .89998 .22152 Mtetra
.796 .781 .84 r
.89998 .22152 .90316 .22455 .91085 .22064 .9077 .21766 Mtetra
.797 .785 .841 r
.9077 .21766 .91085 .22064 .91854 .21673 .91542 .21378 Mtetra
.334 .611 .95 r
.32904 .32537 .33322 .32777 .33968 .32864 .33551 .32619 Mtetra
.342 .61 .949 r
.33551 .32619 .33968 .32864 .34616 .32951 .342 .327 Mtetra
.352 .611 .947 r
.342 .327 .34616 .32951 .35268 .33036 .34853 .3278 Mtetra
.364 .612 .945 r
.34853 .3278 .35268 .33036 .35923 .33119 .35509 .32858 Mtetra
.377 .614 .943 r
.35509 .32858 .35923 .33119 .36581 .332 .36168 .32933 Mtetra
.39 .616 .941 r
.36168 .32933 .36581 .332 .37243 .33276 .3683 .33004 Mtetra
.405 .618 .938 r
.3683 .33004 .37243 .33276 .37907 .33349 .37496 .33071 Mtetra
.421 .621 .935 r
.37496 .33071 .37907 .33349 .38576 .33415 .38165 .33132 Mtetra
.437 .625 .932 r
.38165 .33132 .38576 .33415 .39247 .33476 .38838 .33186 Mtetra
.454 .628 .928 r
.38838 .33186 .39247 .33476 .39922 .33529 .39514 .33234 Mtetra
.471 .631 .924 r
.39514 .33234 .39922 .33529 .40601 .33574 .40193 .33272 Mtetra
.488 .635 .919 r
.40193 .33272 .40601 .33574 .41283 .33609 .40876 .33301 Mtetra
.506 .638 .913 r
.40876 .33301 .41283 .33609 .41968 .33635 .41562 .3332 Mtetra
.523 .641 .907 r
.41562 .3332 .41968 .33635 .42657 .33649 .42252 .33328 Mtetra
.54 .644 .901 r
.42252 .33328 .42657 .33649 .43349 .33651 .42945 .33323 Mtetra
.557 .646 .894 r
.42945 .33323 .43349 .33651 .44044 .3364 .43641 .33304 Mtetra
.573 .649 .886 r
.43641 .33304 .44044 .3364 .44742 .33615 .4434 .3327 Mtetra
.59 .651 .879 r
.4434 .3327 .44742 .33615 .45444 .33574 .45042 .33221 Mtetra
.605 .652 .87 r
.45042 .33221 .45444 .33574 .46148 .33516 .45747 .33154 Mtetra
.62 .654 .862 r
.45747 .33154 .46148 .33516 .46855 .3344 .46456 .33069 Mtetra
.634 .655 .853 r
.46456 .33069 .46855 .3344 .47565 .33345 .47166 .32965 Mtetra
.648 .655 .844 r
.47166 .32965 .47565 .33345 .48277 .33231 .4788 .3284 Mtetra
.661 .656 .834 r
.4788 .3284 .48277 .33231 .48992 .33094 .48596 .32692 Mtetra
.673 .656 .825 r
.48596 .32692 .48992 .33094 .49709 .32935 .49313 .32521 Mtetra
.684 .655 .815 r
.49313 .32521 .49709 .32935 .50428 .32752 .50033 .32325 Mtetra
.695 .654 .805 r
.50033 .32325 .50428 .32752 .51149 .32544 .50755 .32103 Mtetra
.705 .653 .795 r
.50755 .32103 .51149 .32544 .51871 .3231 .51478 .31854 Mtetra
.714 .651 .786 r
.51478 .31854 .51871 .3231 .52594 .32049 .52202 .31576 Mtetra
.721 .648 .776 r
.52202 .31576 .52594 .32049 .53318 .3176 .52927 .31269 Mtetra
.728 .645 .766 r
.52927 .31269 .53318 .3176 .54043 .31445 .53652 .30933 Mtetra
.733 .642 .757 r
.53652 .30933 .54043 .31445 .54769 .31103 .54378 .30569 Mtetra
.737 .637 .748 r
.54378 .30569 .54769 .31103 .55494 .30738 .55104 .30177 Mtetra
.738 .631 .74 r
.55104 .30177 .55494 .30738 .56219 .30353 .55829 .29764 Mtetra
.737 .624 .733 r
.55829 .29764 .56219 .30353 .56945 .29956 .56555 .29336 Mtetra
.732 .615 .727 r
.56555 .29336 .56945 .29956 .5767 .29559 .5728 .28905 Mtetra
.723 .604 .723 r
.5728 .28905 .5767 .29559 .58396 .29175 .58005 .28489 Mtetra
.709 .59 .721 r
.58005 .28489 .58396 .29175 .59123 .28822 .58731 .2811 Mtetra
.689 .575 .721 r
.58731 .2811 .59123 .28822 .59852 .28517 .5946 .27789 Mtetra
.664 .558 .725 r
.5946 .27789 .59852 .28517 .60585 .28271 .60192 .27545 Mtetra
.63 .539 .733 r
.60192 .27545 .60585 .28271 .61323 .28128 .6093 .274 Mtetra
.59 .516 .739 r
.6093 .274 .61323 .28128 .62067 .28087 .61674 .27356 Mtetra
.555 .495 .743 r
.61674 .27356 .62067 .28087 .62818 .28106 .62425 .27389 Mtetra
.524 .479 .749 r
.62425 .27389 .62818 .28106 .63575 .28173 .63182 .27481 Mtetra
.5 .471 .756 r
.63182 .27481 .63575 .28173 .64337 .28272 .63945 .2761 Mtetra
.487 .471 .766 r
.63945 .2761 .64337 .28272 .65103 .28386 .64713 .27755 Mtetra
.482 .477 .775 r
.64713 .27755 .65103 .28386 .65874 .28499 .65485 .27898 Mtetra
.487 .489 .785 r
.65485 .27898 .65874 .28499 .66648 .286 .66261 .28027 Mtetra
.497 .504 .795 r
.66261 .28027 .66648 .286 .67424 .28683 .67039 .28134 Mtetra
.511 .521 .803 r
.67039 .28134 .67424 .28683 .68203 .28743 .67819 .28215 Mtetra
.528 .539 .81 r
.67819 .28215 .68203 .28743 .68983 .28776 .68601 .28267 Mtetra
.546 .557 .816 r
.68601 .28267 .68983 .28776 .69764 .28782 .69383 .2829 Mtetra
.564 .574 .821 r
.69383 .2829 .69764 .28782 .70546 .28761 .70167 .28284 Mtetra
.582 .59 .825 r
.70167 .28284 .70546 .28761 .71328 .28713 .70952 .2825 Mtetra
.6 .605 .828 r
.70952 .2825 .71328 .28713 .72111 .28638 .71737 .28187 Mtetra
.616 .619 .831 r
.71737 .28187 .72111 .28638 .72895 .28538 .72522 .28099 Mtetra
.632 .632 .833 r
.72522 .28099 .72895 .28538 .73678 .28414 .73307 .27985 Mtetra
.646 .644 .834 r
.73307 .27985 .73678 .28414 .74461 .28266 .74092 .27848 Mtetra
.66 .656 .835 r
.74092 .27848 .74461 .28266 .75243 .28097 .74877 .27687 Mtetra
.673 .666 .835 r
.74877 .27687 .75243 .28097 .76026 .27906 .75661 .27505 Mtetra
.685 .676 .836 r
.75661 .27505 .76026 .27906 .76808 .27696 .76445 .27303 Mtetra
.696 .685 .836 r
.76445 .27303 .76808 .27696 .77589 .27468 .77228 .27082 Mtetra
.706 .694 .836 r
.77228 .27082 .77589 .27468 .7837 .27221 .78011 .26842 Mtetra
.716 .702 .835 r
.78011 .26842 .7837 .27221 .7915 .26959 .78794 .26587 Mtetra
.725 .709 .835 r
.78794 .26587 .7915 .26959 .79929 .26681 .79575 .26315 Mtetra
.733 .716 .835 r
.79575 .26315 .79929 .26681 .80707 .2639 .80356 .2603 Mtetra
.741 .723 .835 r
.80356 .2603 .80707 .2639 .81485 .26085 .81136 .2573 Mtetra
.748 .729 .835 r
.81136 .2573 .81485 .26085 .82262 .25768 .81915 .25419 Mtetra
.754 .735 .835 r
.81915 .25419 .82262 .25768 .83038 .2544 .82694 .25096 Mtetra
.76 .74 .835 r
.82694 .25096 .83038 .2544 .83813 .25102 .83472 .24764 Mtetra
.765 .745 .835 r
.83472 .24764 .83813 .25102 .84588 .24756 .84249 .24421 Mtetra
.77 .75 .835 r
.84249 .24421 .84588 .24756 .85362 .24401 .85026 .24071 Mtetra
.775 .755 .835 r
.85026 .24071 .85362 .24401 .86136 .24038 .85802 .23714 Mtetra
.779 .76 .836 r
.85802 .23714 .86136 .24038 .86909 .2367 .86578 .2335 Mtetra
.783 .764 .837 r
.86578 .2335 .86909 .2367 .87681 .23296 .87353 .2298 Mtetra
.786 .769 .837 r
.87353 .2298 .87681 .23296 .88454 .22918 .88128 .22606 Mtetra
.789 .773 .839 r
.88128 .22606 .88454 .22918 .89226 .22536 .88903 .22228 Mtetra
.791 .777 .84 r
.88903 .22228 .89226 .22536 .89998 .22152 .89678 .21848 Mtetra
.793 .781 .841 r
.89678 .21848 .89998 .22152 .9077 .21766 .90452 .21466 Mtetra
.795 .785 .843 r
.90452 .21466 .9077 .21766 .91542 .21378 .91228 .21082 Mtetra
.345 .616 .951 r
.32484 .32295 .32904 .32537 .33551 .32619 .33132 .32372 Mtetra
.353 .616 .95 r
.33132 .32372 .33551 .32619 .342 .327 .33782 .32448 Mtetra
.362 .616 .948 r
.33782 .32448 .342 .327 .34853 .3278 .34436 .32524 Mtetra
.373 .617 .946 r
.34436 .32524 .34853 .3278 .35509 .32858 .35093 .32596 Mtetra
.386 .619 .944 r
.35093 .32596 .35509 .32858 .36168 .32933 .35753 .32666 Mtetra
.399 .621 .942 r
.35753 .32666 .36168 .32933 .3683 .33004 .36416 .32732 Mtetra
.413 .624 .939 r
.36416 .32732 .3683 .33004 .37496 .33071 .37083 .32794 Mtetra
.429 .626 .936 r
.37083 .32794 .37496 .33071 .38165 .33132 .37753 .32849 Mtetra
.445 .63 .933 r
.37753 .32849 .38165 .33132 .38838 .33186 .38426 .32898 Mtetra
.461 .633 .929 r
.38426 .32898 .38838 .33186 .39514 .33234 .39103 .32939 Mtetra
.478 .636 .924 r
.39103 .32939 .39514 .33234 .40193 .33272 .39783 .32972 Mtetra
.495 .64 .919 r
.39783 .32972 .40193 .33272 .40876 .33301 .40467 .32995 Mtetra
.512 .643 .914 r
.40467 .32995 .40876 .33301 .41562 .3332 .41154 .33007 Mtetra
.529 .646 .908 r
.41154 .33007 .41562 .3332 .42252 .33328 .41845 .33008 Mtetra
.547 .649 .902 r
.41845 .33008 .42252 .33328 .42945 .33323 .42539 .32996 Mtetra
.563 .651 .895 r
.42539 .32996 .42945 .33323 .43641 .33304 .43236 .3297 Mtetra
.58 .654 .887 r
.43236 .3297 .43641 .33304 .4434 .3327 .43936 .32928 Mtetra
.596 .656 .879 r
.43936 .32928 .4434 .3327 .45042 .33221 .44639 .32871 Mtetra
.611 .658 .871 r
.44639 .32871 .45042 .33221 .45747 .33154 .45345 .32796 Mtetra
.626 .659 .862 r
.45345 .32796 .45747 .33154 .46456 .33069 .46054 .32702 Mtetra
.641 .66 .853 r
.46054 .32702 .46456 .33069 .47166 .32965 .46766 .32588 Mtetra
.654 .661 .844 r
.46766 .32588 .47166 .32965 .4788 .3284 .47481 .32453 Mtetra
.667 .661 .834 r
.47481 .32453 .4788 .3284 .48596 .32692 .48197 .32294 Mtetra
.68 .661 .825 r
.48197 .32294 .48596 .32692 .49313 .32521 .48916 .32112 Mtetra
.691 .66 .815 r
.48916 .32112 .49313 .32521 .50033 .32325 .49637 .31903 Mtetra
.702 .659 .805 r
.49637 .31903 .50033 .32325 .50755 .32103 .50359 .31668 Mtetra
.712 .658 .795 r
.50359 .31668 .50755 .32103 .51478 .31854 .51083 .31404 Mtetra
.721 .656 .785 r
.51083 .31404 .51478 .31854 .52202 .31576 .51808 .3111 Mtetra
.729 .654 .775 r
.51808 .3111 .52202 .31576 .52927 .31269 .52534 .30785 Mtetra
.736 .651 .765 r
.52534 .30785 .52927 .31269 .53652 .30933 .5326 .30428 Mtetra
.742 .647 .755 r
.5326 .30428 .53652 .30933 .54378 .30569 .53987 .3004 Mtetra
.746 .642 .746 r
.53987 .3004 .54378 .30569 .55104 .30177 .54713 .29622 Mtetra
.747 .636 .737 r
.54713 .29622 .55104 .30177 .55829 .29764 .55439 .29178 Mtetra
.746 .629 .729 r
.55439 .29178 .55829 .29764 .56555 .29336 .56164 .28715 Mtetra
.742 .619 .723 r
.56164 .28715 .56555 .29336 .5728 .28905 .56889 .28247 Mtetra
.732 .607 .718 r
.56889 .28247 .5728 .28905 .58005 .28489 .57614 .27794 Mtetra
.716 .592 .716 r
.57614 .27794 .58005 .28489 .58731 .2811 .58339 .27383 Mtetra
.508 .466 .746 r
.62031 .26657 .62425 .27389 .63182 .27481 .62788 .26779 Mtetra
.479 .456 .754 r
.62788 .26779 .63182 .27481 .63945 .2761 .63553 .26944 Mtetra
.463 .456 .765 r
.63553 .26944 .63945 .2761 .64713 .27755 .64322 .27124 Mtetra
.459 .463 .776 r
.64322 .27124 .64713 .27755 .65485 .27898 .65096 .273 Mtetra
.464 .477 .787 r
.65096 .273 .65485 .27898 .66261 .28027 .65873 .27458 Mtetra
.476 .494 .797 r
.65873 .27458 .66261 .28027 .67039 .28134 .66653 .2759 Mtetra
.493 .513 .807 r
.66653 .2759 .67039 .28134 .67819 .28215 .67435 .27693 Mtetra
.512 .533 .814 r
.67435 .27693 .67819 .28215 .68601 .28267 .68218 .27764 Mtetra
.532 .552 .821 r
.68218 .27764 .68601 .28267 .69383 .2829 .69003 .27804 Mtetra
.553 .57 .826 r
.69003 .27804 .69383 .2829 .70167 .28284 .69788 .27813 Mtetra
.572 .587 .83 r
.69788 .27813 .70167 .28284 .70952 .2825 .70574 .27792 Mtetra
.591 .603 .833 r
.70574 .27792 .70952 .2825 .71737 .28187 .71361 .27742 Mtetra
.609 .618 .835 r
.71361 .27742 .71737 .28187 .72522 .28099 .72148 .27665 Mtetra
.625 .632 .837 r
.72148 .27665 .72522 .28099 .73307 .27985 .72935 .27561 Mtetra
.641 .644 .838 r
.72935 .27561 .73307 .27985 .74092 .27848 .73722 .27433 Mtetra
.655 .656 .839 r
.73722 .27433 .74092 .27848 .74877 .27687 .74509 .27281 Mtetra
.668 .667 .839 r
.74509 .27281 .74877 .27687 .75661 .27505 .75295 .27107 Mtetra
.681 .677 .839 r
.75295 .27107 .75661 .27505 .76445 .27303 .76081 .26913 Mtetra
.692 .686 .839 r
.76081 .26913 .76445 .27303 .77228 .27082 .76867 .26698 Mtetra
.703 .695 .839 r
.76867 .26698 .77228 .27082 .78011 .26842 .77652 .26466 Mtetra
.713 .703 .839 r
.77652 .26466 .78011 .26842 .78794 .26587 .78437 .26217 Mtetra
.722 .71 .838 r
.78437 .26217 .78794 .26587 .79575 .26315 .7922 .25951 Mtetra
.73 .717 .838 r
.7922 .25951 .79575 .26315 .80356 .2603 .80004 .25671 Mtetra
.738 .724 .838 r
.80004 .25671 .80356 .2603 .81136 .2573 .80786 .25377 Mtetra
.745 .73 .837 r
.80786 .25377 .81136 .2573 .81915 .25419 .81568 .25071 Mtetra
.752 .736 .837 r
.81568 .25071 .81915 .25419 .82694 .25096 .82349 .24754 Mtetra
.758 .741 .837 r
.82349 .24754 .82694 .25096 .83472 .24764 .83129 .24425 Mtetra
.763 .746 .837 r
.83129 .24425 .83472 .24764 .84249 .24421 .83909 .24088 Mtetra
.768 .751 .837 r
.83909 .24088 .84249 .24421 .85026 .24071 .84688 .23742 Mtetra
.773 .756 .837 r
.84688 .23742 .85026 .24071 .85802 .23714 .85467 .23389 Mtetra
.777 .76 .838 r
.85467 .23389 .85802 .23714 .86578 .2335 .86245 .23029 Mtetra
.781 .765 .838 r
.86245 .23029 .86578 .2335 .87353 .2298 .87023 .22663 Mtetra
.784 .769 .839 r
.87023 .22663 .87353 .2298 .88128 .22606 .87801 .22293 Mtetra
.787 .773 .84 r
.87801 .22293 .88128 .22606 .88903 .22228 .88579 .21919 Mtetra
.789 .777 .841 r
.88579 .21919 .88903 .22228 .89678 .21848 .89356 .21543 Mtetra
.791 .781 .843 r
.89356 .21543 .89678 .21848 .90452 .21466 .90134 .21164 Mtetra
.793 .784 .845 r
.90134 .21164 .90452 .21466 .91228 .21082 .90912 .20785 Mtetra
.355 .621 .952 r
.32063 .32053 .32484 .32295 .33132 .32372 .32711 .32125 Mtetra
.363 .621 .951 r
.32711 .32125 .33132 .32372 .33782 .32448 .33362 .32196 Mtetra
.372 .621 .949 r
.33362 .32196 .33782 .32448 .34436 .32524 .34017 .32267 Mtetra
.382 .622 .947 r
.34017 .32267 .34436 .32524 .35093 .32596 .34675 .32335 Mtetra
.394 .624 .945 r
.34675 .32335 .35093 .32596 .35753 .32666 .35336 .32399 Mtetra
.407 .626 .942 r
.35336 .32399 .35753 .32666 .36416 .32732 .36 .3246 Mtetra
.421 .628 .94 r
.36 .3246 .36416 .32732 .37083 .32794 .36667 .32516 Mtetra
.436 .631 .937 r
.36667 .32516 .37083 .32794 .37753 .32849 .37338 .32567 Mtetra
.452 .634 .933 r
.37338 .32567 .37753 .32849 .38426 .32898 .38013 .3261 Mtetra
.468 .638 .929 r
.38013 .3261 .38426 .32898 .39103 .32939 .38691 .32646 Mtetra
.485 .641 .925 r
.38691 .32646 .39103 .32939 .39783 .32972 .39372 .32672 Mtetra
.501 .644 .92 r
.39372 .32672 .39783 .32972 .40467 .32995 .40057 .32689 Mtetra
.519 .648 .915 r
.40057 .32689 .40467 .32995 .41154 .33007 .40745 .32696 Mtetra
.536 .651 .909 r
.40745 .32696 .41154 .33007 .41845 .33008 .41436 .3269 Mtetra
.553 .654 .902 r
.41436 .3269 .41845 .33008 .42539 .32996 .42131 .32671 Mtetra
.569 .656 .895 r
.42131 .32671 .42539 .32996 .43236 .3297 .42829 .32638 Mtetra
.586 .659 .888 r
.42829 .32638 .43236 .3297 .43936 .32928 .4353 .32589 Mtetra
.602 .661 .88 r
.4353 .32589 .43936 .32928 .44639 .32871 .44234 .32524 Mtetra
.617 .663 .872 r
.44234 .32524 .44639 .32871 .45345 .32796 .44942 .32441 Mtetra
.632 .664 .863 r
.44942 .32441 .45345 .32796 .46054 .32702 .45652 .32338 Mtetra
.647 .665 .854 r
.45652 .32338 .46054 .32702 .46766 .32588 .46365 .32215 Mtetra
.661 .666 .844 r
.46365 .32215 .46766 .32588 .47481 .32453 .4708 .3207 Mtetra
.674 .666 .835 r
.4708 .3207 .47481 .32453 .48197 .32294 .47798 .31901 Mtetra
.686 .666 .825 r
.47798 .31901 .48197 .32294 .48916 .32112 .48517 .31707 Mtetra
.698 .666 .815 r
.48517 .31707 .48916 .32112 .49637 .31903 .49239 .31487 Mtetra
.709 .665 .805 r
.49239 .31487 .49637 .31903 .50359 .31668 .49963 .31238 Mtetra
.719 .664 .795 r
.49963 .31238 .50359 .31668 .51083 .31404 .50688 .30959 Mtetra
.728 .662 .784 r
.50688 .30959 .51083 .31404 .51808 .3111 .51414 .30649 Mtetra
.736 .659 .774 r
.51414 .30649 .51808 .3111 .52534 .30785 .5214 .30306 Mtetra
.744 .657 .764 r
.5214 .30306 .52534 .30785 .5326 .30428 .52867 .29929 Mtetra
.75 .653 .754 r
.52867 .29929 .5326 .30428 .53987 .3004 .53595 .29517 Mtetra
.754 .648 .744 r
.53595 .29517 .53987 .3004 .54713 .29622 .54322 .29071 Mtetra
.757 .642 .734 r
.54322 .29071 .54713 .29622 .55439 .29178 .55048 .28595 Mtetra
.756 .634 .726 r
.55048 .28595 .55439 .29178 .56164 .28715 .55773 .28095 Mtetra
.752 .624 .719 r
.55773 .28095 .56164 .28715 .56889 .28247 .56498 .27585 Mtetra
.742 .612 .713 r
.56498 .27585 .56889 .28247 .57614 .27794 .57222 .27089 Mtetra
.454 .438 .752 r
.62394 .26067 .62788 .26779 .63553 .26944 .6316 .26273 Mtetra
.435 .438 .763 r
.6316 .26273 .63553 .26944 .64322 .27124 .63931 .26494 Mtetra
.431 .447 .776 r
.63931 .26494 .64322 .27124 .65096 .273 .64707 .26705 Mtetra
.438 .463 .788 r
.64707 .26705 .65096 .273 .65873 .27458 .65485 .26894 Mtetra
.453 .483 .8 r
.65485 .26894 .65873 .27458 .66653 .2759 .66267 .27053 Mtetra
.473 .505 .81 r
.66267 .27053 .66653 .2759 .67435 .27693 .6705 .27178 Mtetra
.495 .527 .819 r
.6705 .27178 .67435 .27693 .68218 .27764 .67835 .27268 Mtetra
.518 .547 .825 r
.67835 .27268 .68218 .27764 .69003 .27804 .68621 .27325 Mtetra
.54 .567 .831 r
.68621 .27325 .69003 .27804 .69788 .27813 .69408 .27348 Mtetra
.562 .585 .835 r
.69408 .27348 .69788 .27813 .70574 .27792 .70196 .2734 Mtetra
.582 .602 .838 r
.70196 .2734 .70574 .27792 .71361 .27742 .70985 .27302 Mtetra
.601 .618 .84 r
.70985 .27302 .71361 .27742 .72148 .27665 .71774 .27235 Mtetra
.618 .632 .842 r
.71774 .27235 .72148 .27665 .72935 .27561 .72562 .27141 Mtetra
.635 .645 .843 r
.72562 .27141 .72935 .27561 .73722 .27433 .73351 .27022 Mtetra
.65 .657 .843 r
.73351 .27022 .73722 .27433 .74509 .27281 .7414 .26879 Mtetra
.664 .668 .843 r
.7414 .26879 .74509 .27281 .75295 .27107 .74929 .26713 Mtetra
.677 .678 .843 r
.74929 .26713 .75295 .27107 .76081 .26913 .75717 .26525 Mtetra
.689 .687 .843 r
.75717 .26525 .76081 .26913 .76867 .26698 .76505 .26318 Mtetra
.7 .696 .843 r
.76505 .26318 .76867 .26698 .77652 .26466 .77292 .26092 Mtetra
.71 .704 .842 r
.77292 .26092 .77652 .26466 .78437 .26217 .78079 .25849 Mtetra
.719 .711 .842 r
.78079 .25849 .78437 .26217 .7922 .25951 .78865 .25589 Mtetra
.728 .718 .841 r
.78865 .25589 .7922 .25951 .80004 .25671 .7965 .25314 Mtetra
.736 .725 .841 r
.7965 .25314 .80004 .25671 .80786 .25377 .80435 .25026 Mtetra
.743 .731 .84 r
.80435 .25026 .80786 .25377 .81568 .25071 .81219 .24725 Mtetra
.75 .736 .84 r
.81219 .24725 .81568 .25071 .82349 .24754 .82003 .24412 Mtetra
.756 .742 .84 r
.82003 .24412 .82349 .24754 .83129 .24425 .82785 .24088 Mtetra
.762 .747 .839 r
.82785 .24088 .83129 .24425 .83909 .24088 .83568 .23755 Mtetra
.767 .752 .839 r
.83568 .23755 .83909 .24088 .84688 .23742 .84349 .23413 Mtetra
.771 .756 .84 r
.84349 .23413 .84688 .23742 .85467 .23389 .85131 .23064 Mtetra
.775 .761 .84 r
.85131 .23064 .85467 .23389 .86245 .23029 .85912 .22708 Mtetra
.779 .765 .84 r
.85912 .22708 .86245 .23029 .87023 .22663 .86692 .22346 Mtetra
.782 .769 .841 r
.86692 .22346 .87023 .22663 .87801 .22293 .87473 .2198 Mtetra
.785 .773 .842 r
.87473 .2198 .87801 .22293 .88579 .21919 .88253 .2161 Mtetra
.787 .777 .843 r
.88253 .2161 .88579 .21919 .89356 .21543 .89033 .21237 Mtetra
.789 .78 .844 r
.89033 .21237 .89356 .21543 .90134 .21164 .89813 .20862 Mtetra
.791 .784 .846 r
.89813 .20862 .90134 .21164 .90912 .20785 .90594 .20486 Mtetra
.365 .626 .953 r
.31639 .31809 .32063 .32053 .32711 .32125 .32288 .31877 Mtetra
.372 .626 .951 r
.32288 .31877 .32711 .32125 .33362 .32196 .32941 .31943 Mtetra
.38 .626 .949 r
.32941 .31943 .33362 .32196 .34017 .32267 .33596 .32009 Mtetra
.39 .627 .948 r
.33596 .32009 .34017 .32267 .34675 .32335 .34255 .32072 Mtetra
.402 .628 .945 r
.34255 .32072 .34675 .32335 .35336 .32399 .34917 .32132 Mtetra
.414 .63 .943 r
.34917 .32132 .35336 .32399 .36 .3246 .35582 .32189 Mtetra
.428 .633 .94 r
.35582 .32189 .36 .3246 .36667 .32516 .3625 .3224 Mtetra
.443 .636 .937 r
.3625 .3224 .36667 .32516 .37338 .32567 .36922 .32285 Mtetra
.458 .639 .934 r
.36922 .32285 .37338 .32567 .38013 .3261 .37597 .32323 Mtetra
.474 .642 .93 r
.37597 .32323 .38013 .3261 .38691 .32646 .38276 .32353 Mtetra
.491 .646 .926 r
.38276 .32353 .38691 .32646 .39372 .32672 .38958 .32374 Mtetra
.508 .649 .921 r
.38958 .32374 .39372 .32672 .40057 .32689 .39644 .32386 Mtetra
.524 .652 .916 r
.39644 .32386 .40057 .32689 .40745 .32696 .40333 .32386 Mtetra
.541 .655 .91 r
.40333 .32386 .40745 .32696 .41436 .3269 .41025 .32374 Mtetra
.558 .658 .903 r
.41025 .32374 .41436 .3269 .42131 .32671 .41721 .32349 Mtetra
.575 .661 .896 r
.41721 .32349 .42131 .32671 .42829 .32638 .4242 .32309 Mtetra
.592 .664 .889 r
.4242 .32309 .42829 .32638 .4353 .32589 .43122 .32253 Mtetra
.608 .666 .881 r
.43122 .32253 .4353 .32589 .44234 .32524 .43828 .3218 Mtetra
.623 .668 .872 r
.43828 .3218 .44234 .32524 .44942 .32441 .44536 .32089 Mtetra
.638 .669 .863 r
.44536 .32089 .44942 .32441 .45652 .32338 .45247 .31978 Mtetra
.653 .67 .854 r
.45247 .31978 .45652 .32338 .46365 .32215 .45961 .31846 Mtetra
.666 .671 .845 r
.45961 .31846 .46365 .32215 .4708 .3207 .46678 .31692 Mtetra
.68 .671 .835 r
.46678 .31692 .4708 .3207 .47798 .31901 .47396 .31513 Mtetra
.692 .671 .825 r
.47396 .31513 .47798 .31901 .48517 .31707 .48117 .31308 Mtetra
.704 .671 .815 r
.48117 .31308 .48517 .31707 .49239 .31487 .4884 .31076 Mtetra
.715 .67 .805 r
.4884 .31076 .49239 .31487 .49963 .31238 .49565 .30814 Mtetra
.725 .669 .794 r
.49565 .30814 .49963 .31238 .50688 .30959 .50291 .30522 Mtetra
.735 .667 .784 r
.50291 .30522 .50688 .30959 .51414 .30649 .51018 .30196 Mtetra
.744 .665 .773 r
.51018 .30196 .51414 .30649 .5214 .30306 .51745 .29835 Mtetra
.751 .662 .763 r
.51745 .29835 .5214 .30306 .52867 .29929 .52474 .29438 Mtetra
.758 .659 .752 r
.52474 .29438 .52867 .29929 .53595 .29517 .53202 .29002 Mtetra
.763 .654 .741 r
.53202 .29002 .53595 .29517 .54322 .29071 .53929 .28528 Mtetra
.766 .648 .731 r
.53929 .28528 .54322 .29071 .55048 .28595 .54656 .28017 Mtetra
.766 .64 .722 r
.54656 .28017 .55048 .28595 .55773 .28095 .55382 .27477 Mtetra
.398 .428 .775 r
.6354 .25865 .63931 .26494 .64707 .26705 .64317 .26116 Mtetra
.408 .447 .789 r
.64317 .26116 .64707 .26705 .65485 .26894 .65097 .26337 Mtetra
.428 .471 .802 r
.65097 .26337 .65485 .26894 .66267 .27053 .6588 .26522 Mtetra
.451 .496 .814 r
.6588 .26522 .66267 .27053 .6705 .27178 .66665 .2667 Mtetra
.477 .52 .823 r
.66665 .2667 .6705 .27178 .67835 .27268 .67452 .26779 Mtetra
.503 .543 .83 r
.67452 .26779 .67835 .27268 .68621 .27325 .68239 .26852 Mtetra
.527 .564 .836 r
.68239 .26852 .68621 .27325 .69408 .27348 .69028 .2689 Mtetra
.551 .583 .84 r
.69028 .2689 .69408 .27348 .70196 .2734 .69818 .26894 Mtetra
.573 .601 .843 r
.69818 .26894 .70196 .2734 .70985 .27302 .70608 .26867 Mtetra
.593 .617 .845 r
.70608 .26867 .70985 .27302 .71774 .27235 .71399 .26811 Mtetra
.612 .632 .847 r
.71399 .26811 .71774 .27235 .72562 .27141 .72189 .26727 Mtetra
.629 .645 .847 r
.72189 .26727 .72562 .27141 .73351 .27022 .7298 .26616 Mtetra
.645 .657 .848 r
.7298 .26616 .73351 .27022 .7414 .26879 .73771 .26481 Mtetra
.66 .669 .848 r
.73771 .26481 .7414 .26879 .74929 .26713 .74561 .26322 Mtetra
.673 .679 .847 r
.74561 .26322 .74929 .26713 .75717 .26525 .75351 .26142 Mtetra
.685 .688 .847 r
.75351 .26142 .75717 .26525 .76505 .26318 .76141 .25941 Mtetra
.697 .697 .846 r
.76141 .25941 .76505 .26318 .77292 .26092 .76931 .25721 Mtetra
.707 .705 .846 r
.76931 .25721 .77292 .26092 .78079 .25849 .7772 .25483 Mtetra
.717 .713 .845 r
.7772 .25483 .78079 .25849 .78865 .25589 .78508 .25229 Mtetra
.726 .719 .844 r
.78508 .25229 .78865 .25589 .7965 .25314 .79296 .2496 Mtetra
.734 .726 .844 r
.79296 .2496 .7965 .25314 .80435 .25026 .80083 .24676 Mtetra
.741 .732 .843 r
.80083 .24676 .80435 .25026 .81219 .24725 .80869 .24379 Mtetra
.748 .737 .842 r
.80869 .24379 .81219 .24725 .82003 .24412 .81655 .24071 Mtetra
.754 .743 .842 r
.81655 .24071 .82003 .24412 .82785 .24088 .8244 .23751 Mtetra
.76 .748 .842 r
.8244 .23751 .82785 .24088 .83568 .23755 .83225 .23422 Mtetra
.765 .752 .842 r
.83225 .23422 .83568 .23755 .84349 .23413 .84009 .23084 Mtetra
.769 .757 .842 r
.84009 .23084 .84349 .23413 .85131 .23064 .84793 .22739 Mtetra
.774 .761 .842 r
.84793 .22739 .85131 .23064 .85912 .22708 .85576 .22386 Mtetra
.777 .765 .842 r
.85576 .22386 .85912 .22708 .86692 .22346 .8636 .22028 Mtetra
.78 .769 .843 r
.8636 .22028 .86692 .22346 .87473 .2198 .87143 .21666 Mtetra
.783 .773 .844 r
.87143 .21666 .87473 .2198 .88253 .2161 .87925 .21299 Mtetra
.786 .777 .845 r
.87925 .21299 .88253 .2161 .89033 .21237 .88708 .20929 Mtetra
.788 .78 .846 r
.88708 .20929 .89033 .21237 .89813 .20862 .89492 .20558 Mtetra
.789 .784 .847 r
.89492 .20558 .89813 .20862 .90594 .20486 .90275 .20185 Mtetra
.374 .631 .954 r
.31213 .31564 .31639 .31809 .32288 .31877 .31863 .31627 Mtetra
.38 .63 .952 r
.31863 .31627 .32288 .31877 .32941 .31943 .32517 .3169 Mtetra
.388 .63 .95 r
.32517 .3169 .32941 .31943 .33596 .32009 .33173 .31751 Mtetra
.398 .631 .948 r
.33173 .31751 .33596 .32009 .34255 .32072 .33833 .3181 Mtetra
.409 .632 .946 r
.33833 .3181 .34255 .32072 .34917 .32132 .34495 .31865 Mtetra
.421 .635 .944 r
.34495 .31865 .34917 .32132 .35582 .32189 .35162 .31917 Mtetra
.435 .637 .941 r
.35162 .31917 .35582 .32189 .3625 .3224 .35831 .31963 Mtetra
.449 .64 .938 r
.35831 .31963 .3625 .3224 .36922 .32285 .36504 .32003 Mtetra
.464 .643 .935 r
.36504 .32003 .36922 .32285 .37597 .32323 .3718 .32036 Mtetra
.48 .647 .931 r
.3718 .32036 .37597 .32323 .38276 .32353 .3786 .32061 Mtetra
.496 .65 .927 r
.3786 .32061 .38276 .32353 .38958 .32374 .38543 .32077 Mtetra
.513 .653 .922 r
.38543 .32077 .38958 .32374 .39644 .32386 .3923 .32083 Mtetra
.53 .657 .916 r
.3923 .32083 .39644 .32386 .40333 .32386 .3992 .32078 Mtetra
.547 .66 .91 r
.3992 .32078 .40333 .32386 .41025 .32374 .40613 .3206 Mtetra
.564 .663 .904 r
.40613 .3206 .41025 .32374 .41721 .32349 .4131 .32028 Mtetra
.58 .666 .897 r
.4131 .32028 .41721 .32349 .4242 .32309 .4201 .31982 Mtetra
.597 .668 .889 r
.4201 .31982 .4242 .32309 .43122 .32253 .42713 .3192 Mtetra
.613 .671 .881 r
.42713 .3192 .43122 .32253 .43828 .3218 .43419 .3184 Mtetra
.629 .673 .873 r
.43419 .3184 .43828 .3218 .44536 .32089 .44129 .31741 Mtetra
.644 .674 .864 r
.44129 .31741 .44536 .32089 .45247 .31978 .44841 .31622 Mtetra
.658 .675 .855 r
.44841 .31622 .45247 .31978 .45961 .31846 .45556 .31482 Mtetra
.672 .676 .845 r
.45556 .31482 .45961 .31846 .46678 .31692 .46274 .31318 Mtetra
.685 .677 .836 r
.46274 .31318 .46678 .31692 .47396 .31513 .46993 .31129 Mtetra
.698 .677 .826 r
.46993 .31129 .47396 .31513 .48117 .31308 .47716 .30914 Mtetra
.71 .676 .815 r
.47716 .30914 .48117 .31308 .4884 .31076 .4844 .30671 Mtetra
.721 .676 .805 r
.4844 .30671 .4884 .31076 .49565 .30814 .49165 .30397 Mtetra
.732 .674 .794 r
.49165 .30397 .49565 .30814 .50291 .30522 .49892 .30091 Mtetra
.742 .673 .783 r
.49892 .30091 .50291 .30522 .51018 .30196 .50621 .2975 Mtetra
.751 .671 .773 r
.50621 .2975 .51018 .30196 .51745 .29835 .51349 .29372 Mtetra
.759 .668 .762 r
.51349 .29372 .51745 .29835 .52474 .29438 .52079 .28955 Mtetra
.766 .665 .75 r
.52079 .28955 .52474 .29438 .53202 .29002 .52808 .28495 Mtetra
.772 .66 .739 r
.52808 .28495 .53202 .29002 .53929 .28528 .53536 .27993 Mtetra
.776 .654 .728 r
.53536 .27993 .53929 .28528 .54656 .28017 .54264 .27447 Mtetra
.777 .647 .718 r
.54264 .27447 .54656 .28017 .55382 .27477 .5499 .26862 Mtetra
.359 .405 .773 r
.63148 .25241 .6354 .25865 .64317 .26116 .63927 .25533 Mtetra
.374 .429 .79 r
.63927 .25533 .64317 .26116 .65097 .26337 .64709 .25788 Mtetra
.399 .457 .805 r
.64709 .25788 .65097 .26337 .6588 .26522 .65493 .26001 Mtetra
.428 .486 .817 r
.65493 .26001 .6588 .26522 .66665 .2667 .6628 .2617 Mtetra
.457 .513 .827 r
.6628 .2617 .66665 .2667 .67452 .26779 .67068 .26298 Mtetra
.486 .538 .835 r
.67068 .26298 .67452 .26779 .68239 .26852 .67857 .26386 Mtetra
.514 .561 .841 r
.67857 .26386 .68239 .26852 .69028 .2689 .68648 .26438 Mtetra
.539 .581 .845 r
.68648 .26438 .69028 .2689 .69818 .26894 .69439 .26454 Mtetra
.563 .6 .848 r
.69439 .26454 .69818 .26894 .70608 .26867 .70231 .26439 Mtetra
.585 .617 .85 r
.70231 .26439 .70608 .26867 .71399 .26811 .71023 .26392 Mtetra
.605 .632 .851 r
.71023 .26392 .71399 .26811 .72189 .26727 .71815 .26317 Mtetra
.623 .646 .852 r
.71815 .26317 .72189 .26727 .7298 .26616 .72608 .26214 Mtetra
.64 .658 .852 r
.72608 .26214 .7298 .26616 .73771 .26481 .734 .26087 Mtetra
.655 .67 .852 r
.734 .26087 .73771 .26481 .74561 .26322 .74193 .25935 Mtetra
.669 .68 .851 r
.74193 .25935 .74561 .26322 .75351 .26142 .74985 .25761 Mtetra
.682 .69 .851 r
.74985 .25761 .75351 .26142 .76141 .25941 .75777 .25567 Mtetra
.694 .698 .85 r
.75777 .25567 .76141 .25941 .76931 .25721 .76568 .25353 Mtetra
.705 .706 .849 r
.76568 .25353 .76931 .25721 .7772 .25483 .77359 .2512 Mtetra
.714 .714 .848 r
.77359 .2512 .7772 .25483 .78508 .25229 .7815 .24871 Mtetra
.723 .721 .847 r
.7815 .24871 .78508 .25229 .79296 .2496 .7894 .24606 Mtetra
.732 .727 .846 r
.7894 .24606 .79296 .2496 .80083 .24676 .79729 .24327 Mtetra
.739 .733 .846 r
.79729 .24327 .80083 .24676 .80869 .24379 .80518 .24035 Mtetra
.746 .739 .845 r
.80518 .24035 .80869 .24379 .81655 .24071 .81306 .23731 Mtetra
.752 .744 .844 r
.81306 .23731 .81655 .24071 .8244 .23751 .82094 .23415 Mtetra
.758 .749 .844 r
.82094 .23415 .8244 .23751 .83225 .23422 .82881 .2309 Mtetra
.763 .753 .844 r
.82881 .2309 .83225 .23422 .84009 .23084 .83668 .22756 Mtetra
.768 .758 .844 r
.83668 .22756 .84009 .23084 .84793 .22739 .84454 .22414 Mtetra
.772 .762 .844 r
.84454 .22414 .84793 .22739 .85576 .22386 .8524 .22065 Mtetra
.776 .766 .844 r
.8524 .22065 .85576 .22386 .8636 .22028 .86026 .2171 Mtetra
.779 .769 .844 r
.86026 .2171 .8636 .22028 .87143 .21666 .86811 .21351 Mtetra
.782 .773 .845 r
.86811 .21351 .87143 .21666 .87925 .21299 .87597 .20987 Mtetra
.784 .777 .846 r
.87597 .20987 .87925 .21299 .88708 .20929 .88382 .20621 Mtetra
.786 .78 .847 r
.88382 .20621 .88708 .20929 .89492 .20558 .89168 .20252 Mtetra
.787 .783 .849 r
.89168 .20252 .89492 .20558 .90275 .20185 .89954 .19883 Mtetra
.382 .635 .954 r
.30785 .31318 .31213 .31564 .31863 .31627 .31436 .31377 Mtetra
.388 .634 .952 r
.31436 .31377 .31863 .31627 .32517 .3169 .32091 .31435 Mtetra
.396 .634 .951 r
.32091 .31435 .32517 .3169 .33173 .31751 .32748 .31492 Mtetra
.405 .635 .949 r
.32748 .31492 .33173 .31751 .33833 .3181 .33409 .31547 Mtetra
.416 .636 .947 r
.33409 .31547 .33833 .3181 .34495 .31865 .34072 .31598 Mtetra
.428 .639 .944 r
.34072 .31598 .34495 .31865 .35162 .31917 .34739 .31645 Mtetra
.441 .641 .942 r
.34739 .31645 .35162 .31917 .35831 .31963 .3541 .31687 Mtetra
.455 .644 .939 r
.3541 .31687 .35831 .31963 .36504 .32003 .36084 .31722 Mtetra
.47 .647 .935 r
.36084 .31722 .36504 .32003 .3718 .32036 .36761 .31751 Mtetra
.486 .651 .932 r
.36761 .31751 .3718 .32036 .3786 .32061 .37441 .31771 Mtetra
.502 .654 .927 r
.37441 .31771 .3786 .32061 .38543 .32077 .38126 .31782 Mtetra
.518 .658 .923 r
.38126 .31782 .38543 .32077 .3923 .32083 .38813 .31782 Mtetra
.535 .661 .917 r
.38813 .31782 .3923 .32083 .3992 .32078 .39504 .31771 Mtetra
.552 .664 .911 r
.39504 .31771 .3992 .32078 .40613 .3206 .40199 .31748 Mtetra
.569 .668 .905 r
.40199 .31748 .40613 .3206 .4131 .32028 .40896 .3171 Mtetra
.586 .671 .898 r
.40896 .3171 .4131 .32028 .4201 .31982 .41597 .31658 Mtetra
.602 .673 .89 r
.41597 .31658 .4201 .31982 .42713 .3192 .42302 .31589 Mtetra
.618 .675 .882 r
.42302 .31589 .42713 .3192 .43419 .3184 .43009 .31502 Mtetra
.634 .677 .874 r
.43009 .31502 .43419 .3184 .44129 .31741 .4372 .31396 Mtetra
.649 .679 .865 r
.4372 .31396 .44129 .31741 .44841 .31622 .44433 .3127 Mtetra
.664 .68 .856 r
.44433 .3127 .44841 .31622 .45556 .31482 .45149 .31121 Mtetra
.678 .681 .846 r
.45149 .31121 .45556 .31482 .46274 .31318 .45868 .30949 Mtetra
.691 .682 .836 r
.45868 .30949 .46274 .31318 .46993 .31129 .46589 .30751 Mtetra
.704 .682 .826 r
.46589 .30751 .46993 .31129 .47716 .30914 .47312 .30526 Mtetra
.716 .682 .816 r
.47312 .30526 .47716 .30914 .4844 .30671 .48037 .30272 Mtetra
.727 .681 .805 r
.48037 .30272 .4844 .30671 .49165 .30397 .48764 .29986 Mtetra
.738 .68 .794 r
.48764 .29986 .49165 .30397 .49892 .30091 .49493 .29667 Mtetra
.748 .679 .783 r
.49493 .29667 .49892 .30091 .50621 .2975 .50222 .29312 Mtetra
.758 .677 .772 r
.50222 .29312 .50621 .2975 .51349 .29372 .50952 .28917 Mtetra
.766 .674 .761 r
.50952 .28917 .51349 .29372 .52079 .28955 .51682 .28481 Mtetra
.774 .671 .749 r
.51682 .28481 .52079 .28955 .52808 .28495 .52413 .27998 Mtetra
.781 .667 .737 r
.52413 .27998 .52808 .28495 .53536 .27993 .53142 .27467 Mtetra
.786 .661 .725 r
.53142 .27467 .53536 .27993 .54264 .27447 .53871 .26885 Mtetra
.335 .409 .79 r
.63536 .2496 .63927 .25533 .64709 .25788 .6432 .2525 Mtetra
.367 .443 .807 r
.6432 .2525 .64709 .25788 .65493 .26001 .65106 .25489 Mtetra
.402 .475 .821 r
.65106 .25489 .65493 .26001 .6628 .2617 .65894 .2568 Mtetra
.436 .506 .832 r
.65894 .2568 .6628 .2617 .67068 .26298 .66684 .25826 Mtetra
.469 .533 .84 r
.66684 .25826 .67068 .26298 .67857 .26386 .67474 .25929 Mtetra
.5 .558 .846 r
.67474 .25929 .67857 .26386 .68648 .26438 .68266 .25993 Mtetra
.528 .579 .851 r
.68266 .25993 .68648 .26438 .69439 .26454 .69059 .26021 Mtetra
.553 .599 .854 r
.69059 .26021 .69439 .26454 .70231 .26439 .69852 .26016 Mtetra
.577 .617 .855 r
.69852 .26016 .70231 .26439 .71023 .26392 .70646 .25979 Mtetra
.598 .632 .856 r
.70646 .25979 .71023 .26392 .71815 .26317 .7144 .25912 Mtetra
.617 .647 .857 r
.7144 .25912 .71815 .26317 .72608 .26214 .72235 .25817 Mtetra
.635 .659 .857 r
.72235 .25817 .72608 .26214 .734 .26087 .73029 .25697 Mtetra
.651 .671 .856 r
.73029 .25697 .734 .26087 .74193 .25935 .73824 .25552 Mtetra
.665 .682 .856 r
.73824 .25552 .74193 .25935 .74985 .25761 .74618 .25384 Mtetra
.679 .691 .855 r
.74618 .25384 .74985 .25761 .75777 .25567 .75412 .25196 Mtetra
.691 .7 .854 r
.75412 .25196 .75777 .25567 .76568 .25353 .76205 .24987 Mtetra
.702 .708 .853 r
.76205 .24987 .76568 .25353 .77359 .2512 .76998 .2476 Mtetra
.712 .715 .851 r
.76998 .2476 .77359 .2512 .7815 .24871 .77791 .24515 Mtetra
.721 .722 .85 r
.77791 .24515 .7815 .24871 .7894 .24606 .78583 .24255 Mtetra
.73 .728 .849 r
.78583 .24255 .7894 .24606 .79729 .24327 .79375 .23981 Mtetra
.737 .734 .848 r
.79375 .23981 .79729 .24327 .80518 .24035 .80166 .23692 Mtetra
.744 .74 .847 r
.80166 .23692 .80518 .24035 .81306 .23731 .80956 .23392 Mtetra
.751 .745 .847 r
.80956 .23392 .81306 .23731 .82094 .23415 .81746 .2308 Mtetra
.756 .75 .846 r
.81746 .2308 .82094 .23415 .82881 .2309 .82536 .22758 Mtetra
.762 .754 .846 r
.82536 .22758 .82881 .2309 .83668 .22756 .83325 .22428 Mtetra
.766 .758 .846 r
.83325 .22428 .83668 .22756 .84454 .22414 .84113 .22089 Mtetra
.77 .762 .846 r
.84113 .22089 .84454 .22414 .8524 .22065 .84902 .21743 Mtetra
.774 .766 .846 r
.84902 .21743 .8524 .22065 .86026 .2171 .8569 .21392 Mtetra
.777 .77 .846 r
.8569 .21392 .86026 .2171 .86811 .21351 .86478 .21035 Mtetra
.78 .773 .847 r
.86478 .21035 .86811 .21351 .87597 .20987 .87266 .20675 Mtetra
.782 .776 .848 r
.87266 .20675 .87597 .20987 .88382 .20621 .88054 .20311 Mtetra
.784 .78 .849 r
.88054 .20311 .88382 .20621 .89168 .20252 .88843 .19946 Mtetra
.786 .783 .85 r
.88843 .19946 .89168 .20252 .89954 .19883 .89632 .19579 Mtetra
.39 .638 .955 r
.30355 .31071 .30785 .31318 .31436 .31377 .31008 .31126 Mtetra
.396 .638 .953 r
.31008 .31126 .31436 .31377 .32091 .31435 .31663 .3118 Mtetra
.403 .638 .951 r
.31663 .3118 .32091 .31435 .32748 .31492 .32321 .31233 Mtetra
.412 .639 .949 r
.32321 .31233 .32748 .31492 .33409 .31547 .32983 .31284 Mtetra
.422 .64 .947 r
.32983 .31284 .33409 .31547 .34072 .31598 .33647 .31331 Mtetra
.434 .642 .945 r
.33647 .31331 .34072 .31598 .34739 .31645 .34315 .31373 Mtetra
.447 .645 .942 r
.34315 .31373 .34739 .31645 .3541 .31687 .34987 .31411 Mtetra
.461 .648 .939 r
.34987 .31411 .3541 .31687 .36084 .31722 .35661 .31442 Mtetra
.475 .651 .936 r
.35661 .31442 .36084 .31722 .36761 .31751 .36339 .31466 Mtetra
.491 .655 .932 r
.36339 .31466 .36761 .31751 .37441 .31771 .37021 .31481 Mtetra
.507 .658 .928 r
.37021 .31481 .37441 .31771 .38126 .31782 .37706 .31488 Mtetra
.523 .662 .923 r
.37706 .31488 .38126 .31782 .38813 .31782 .38395 .31483 Mtetra
.54 .665 .918 r
.38395 .31483 .38813 .31782 .39504 .31771 .39087 .31467 Mtetra
.557 .669 .912 r
.39087 .31467 .39504 .31771 .40199 .31748 .39782 .31438 Mtetra
.574 .672 .906 r
.39782 .31438 .40199 .31748 .40896 .3171 .40481 .31395 Mtetra
.59 .675 .899 r
.40481 .31395 .40896 .3171 .41597 .31658 .41183 .31337 Mtetra
.607 .678 .891 r
.41183 .31337 .41597 .31658 .42302 .31589 .41889 .31261 Mtetra
.623 .68 .883 r
.41889 .31261 .42302 .31589 .43009 .31502 .42597 .31168 Mtetra
.639 .682 .875 r
.42597 .31168 .43009 .31502 .4372 .31396 .43309 .31056 Mtetra
.654 .684 .866 r
.43309 .31056 .4372 .31396 .44433 .3127 .44023 .30922 Mtetra
.669 .685 .857 r
.44023 .30922 .44433 .3127 .45149 .31121 .4474 .30766 Mtetra
.683 .686 .847 r
.4474 .30766 .45149 .31121 .45868 .30949 .4546 .30585 Mtetra
.696 .687 .837 r
.4546 .30585 .45868 .30949 .46589 .30751 .46183 .30378 Mtetra
.709 .687 .827 r
.46183 .30378 .46589 .30751 .47312 .30526 .46907 .30144 Mtetra
.722 .687 .816 r
.46907 .30144 .47312 .30526 .48037 .30272 .47634 .29879 Mtetra
.733 .686 .805 r
.47634 .29879 .48037 .30272 .48764 .29986 .48362 .29582 Mtetra
.744 .685 .795 r
.48362 .29582 .48764 .29986 .49493 .29667 .49091 .29251 Mtetra
.755 .684 .783 r
.49091 .29251 .49493 .29667 .50222 .29312 .49822 .28882 Mtetra
.764 .682 .772 r
.49822 .28882 .50222 .29312 .50952 .28917 .50553 .28472 Mtetra
.774 .68 .76 r
.50553 .28472 .50952 .28917 .51682 .28481 .51285 .28017 Mtetra
.782 .677 .748 r
.51285 .28017 .51682 .28481 .52413 .27998 .52017 .27512 Mtetra
.79 .673 .736 r
.52017 .27512 .52413 .27998 .53142 .27467 .52747 .26953 Mtetra
.331 .426 .809 r
.63931 .24722 .6432 .2525 .65106 .25489 .64719 .24988 Mtetra
.374 .464 .825 r
.64719 .24988 .65106 .25489 .65894 .2568 .65508 .252 Mtetra
.414 .498 .837 r
.65508 .252 .65894 .2568 .66684 .25826 .66299 .25362 Mtetra
.452 .528 .845 r
.66299 .25362 .66684 .25826 .67474 .25929 .67091 .2548 Mtetra
.485 .555 .852 r
.67091 .2548 .67474 .25929 .68266 .25993 .67884 .25556 Mtetra
.516 .578 .856 r
.67884 .25556 .68266 .25993 .69059 .26021 .68678 .25595 Mtetra
.543 .598 .859 r
.68678 .25595 .69059 .26021 .69852 .26016 .69473 .25599 Mtetra
.568 .617 .861 r
.69473 .25599 .69852 .26016 .70646 .25979 .70269 .25571 Mtetra
.591 .633 .862 r
.70269 .25571 .70646 .25979 .7144 .25912 .71065 .25512 Mtetra
.611 .647 .862 r
.71065 .25512 .7144 .25912 .72235 .25817 .71861 .25425 Mtetra
.63 .661 .861 r
.71861 .25425 .72235 .25817 .73029 .25697 .72657 .25311 Mtetra
.646 .672 .861 r
.72657 .25311 .73029 .25697 .73824 .25552 .73453 .25173 Mtetra
.662 .683 .86 r
.73453 .25173 .73824 .25552 .74618 .25384 .74249 .25011 Mtetra
.675 .693 .859 r
.74249 .25011 .74618 .25384 .75412 .25196 .75045 .24828 Mtetra
.688 .702 .857 r
.75045 .24828 .75412 .25196 .76205 .24987 .75841 .24624 Mtetra
.699 .71 .856 r
.75841 .24624 .76205 .24987 .76998 .2476 .76636 .24402 Mtetra
.71 .717 .855 r
.76636 .24402 .76998 .2476 .77791 .24515 .77431 .24162 Mtetra
.719 .724 .853 r
.77431 .24162 .77791 .24515 .78583 .24255 .78225 .23906 Mtetra
.728 .73 .852 r
.78225 .23906 .78583 .24255 .79375 .23981 .79019 .23635 Mtetra
.736 .736 .851 r
.79019 .23635 .79375 .23981 .80166 .23692 .79812 .23351 Mtetra
.743 .741 .85 r
.79812 .23351 .80166 .23692 .80956 .23392 .80605 .23054 Mtetra
.749 .746 .849 r
.80605 .23054 .80956 .23392 .81746 .2308 .81397 .22746 Mtetra
.755 .751 .848 r
.81397 .22746 .81746 .2308 .82536 .22758 .82189 .22427 Mtetra
.76 .755 .848 r
.82189 .22427 .82536 .22758 .83325 .22428 .8298 .221 Mtetra
.765 .759 .848 r
.8298 .221 .83325 .22428 .84113 .22089 .83772 .21764 Mtetra
.769 .763 .847 r
.83772 .21764 .84113 .22089 .84902 .21743 .84562 .21421 Mtetra
.773 .767 .847 r
.84562 .21421 .84902 .21743 .8569 .21392 .85353 .21073 Mtetra
.776 .77 .848 r
.85353 .21073 .8569 .21392 .86478 .21035 .86144 .20719 Mtetra
.778 .773 .848 r
.86144 .20719 .86478 .21035 .87266 .20675 .86934 .20361 Mtetra
.781 .776 .849 r
.86934 .20361 .87266 .20675 .88054 .20311 .87725 .2 Mtetra
.782 .78 .85 r
.87725 .2 .88054 .20311 .88843 .19946 .88516 .19638 Mtetra
.784 .782 .851 r
.88516 .19638 .88843 .19946 .89632 .19579 .89308 .19273 Mtetra
.397 .642 .955 r
.29923 .30823 .30355 .31071 .31008 .31126 .30577 .30874 Mtetra
.402 .641 .953 r
.30577 .30874 .31008 .31126 .31663 .3118 .31233 .30925 Mtetra
.409 .641 .951 r
.31233 .30925 .31663 .3118 .32321 .31233 .31892 .30974 Mtetra
.418 .642 .95 r
.31892 .30974 .32321 .31233 .32983 .31284 .32554 .3102 Mtetra
.428 .644 .948 r
.32554 .3102 .32983 .31284 .33647 .31331 .3322 .31063 Mtetra
.439 .646 .945 r
.3322 .31063 .33647 .31331 .34315 .31373 .33889 .31102 Mtetra
.452 .649 .943 r
.33889 .31102 .34315 .31373 .34987 .31411 .34561 .31135 Mtetra
.466 .652 .94 r
.34561 .31135 .34987 .31411 .35661 .31442 .35237 .31162 Mtetra
.48 .655 .937 r
.35237 .31162 .35661 .31442 .36339 .31466 .35916 .31182 Mtetra
.495 .658 .933 r
.35916 .31182 .36339 .31466 .37021 .31481 .36599 .31193 Mtetra
.511 .662 .929 r
.36599 .31193 .37021 .31481 .37706 .31488 .37285 .31195 Mtetra
.528 .666 .924 r
.37285 .31195 .37706 .31488 .38395 .31483 .37974 .31185 Mtetra
.544 .669 .919 r
.37974 .31185 .38395 .31483 .39087 .31467 .38667 .31164 Mtetra
.561 .673 .913 r
.38667 .31164 .39087 .31467 .39782 .31438 .39364 .3113 Mtetra
.578 .676 .907 r
.39364 .3113 .39782 .31438 .40481 .31395 .40064 .31082 Mtetra
.595 .679 .9 r
.40064 .31082 .40481 .31395 .41183 .31337 .40767 .31018 Mtetra
.611 .682 .892 r
.40767 .31018 .41183 .31337 .41889 .31261 .41473 .30937 Mtetra
.627 .685 .884 r
.41473 .30937 .41889 .31261 .42597 .31168 .42183 .30838 Mtetra
.643 .687 .876 r
.42183 .30838 .42597 .31168 .43309 .31056 .42896 .30718 Mtetra
.659 .689 .867 r
.42896 .30718 .43309 .31056 .44023 .30922 .43611 .30578 Mtetra
.673 .69 .858 r
.43611 .30578 .44023 .30922 .4474 .30766 .4433 .30414 Mtetra
.688 .691 .848 r
.4433 .30414 .4474 .30766 .4546 .30585 .45051 .30226 Mtetra
.701 .692 .838 r
.45051 .30226 .4546 .30585 .46183 .30378 .45775 .30011 Mtetra
.714 .692 .828 r
.45775 .30011 .46183 .30378 .46907 .30144 .465 .29767 Mtetra
.727 .692 .817 r
.465 .29767 .46907 .30144 .47634 .29879 .47228 .29493 Mtetra
.739 .692 .806 r
.47228 .29493 .47634 .29879 .48362 .29582 .47958 .29186 Mtetra
.75 .691 .795 r
.47958 .29186 .48362 .29582 .49091 .29251 .48689 .28843 Mtetra
.761 .69 .784 r
.48689 .28843 .49091 .29251 .49822 .28882 .49421 .28461 Mtetra
.771 .688 .772 r
.49421 .28461 .49822 .28882 .50553 .28472 .50154 .28036 Mtetra
.781 .686 .76 r
.50154 .28036 .50553 .28472 .51285 .28017 .50887 .27564 Mtetra
.79 .684 .747 r
.50887 .27564 .51285 .28017 .52017 .27512 .51619 .27039 Mtetra
.798 .68 .734 r
.51619 .27039 .52017 .27512 .52747 .26953 .52352 .26453 Mtetra
.292 .409 .81 r
.63542 .24209 .63931 .24722 .64719 .24988 .64331 .245 Mtetra
.344 .453 .828 r
.64331 .245 .64719 .24988 .65508 .252 .65122 .24731 Mtetra
.391 .491 .841 r
.65122 .24731 .65508 .252 .66299 .25362 .65914 .24909 Mtetra
.433 .524 .851 r
.65914 .24909 .66299 .25362 .67091 .2548 .66707 .25039 Mtetra
.471 .552 .857 r
.66707 .25039 .67091 .2548 .67884 .25556 .67502 .25127 Mtetra
.504 .576 .862 r
.67502 .25127 .67884 .25556 .68678 .25595 .68297 .25177 Mtetra
.533 .598 .864 r
.68297 .25177 .68678 .25595 .69473 .25599 .69094 .2519 Mtetra
.56 .617 .866 r
.69094 .2519 .69473 .25599 .70269 .25571 .69891 .25169 Mtetra
.584 .634 .867 r
.69891 .25169 .70269 .25571 .71065 .25512 .70688 .25118 Mtetra
.605 .649 .867 r
.70688 .25118 .71065 .25512 .71861 .25425 .71486 .25038 Mtetra
.625 .662 .866 r
.71486 .25038 .71861 .25425 .72657 .25311 .72284 .2493 Mtetra
.642 .674 .865 r
.72284 .2493 .72657 .25311 .73453 .25173 .73082 .24798 Mtetra
.658 .685 .864 r
.73082 .24798 .73453 .25173 .74249 .25011 .7388 .24641 Mtetra
.672 .694 .863 r
.7388 .24641 .74249 .25011 .75045 .24828 .74678 .24463 Mtetra
.685 .703 .861 r
.74678 .24463 .75045 .24828 .75841 .24624 .75475 .24264 Mtetra
.697 .711 .859 r
.75475 .24264 .75841 .24624 .76636 .24402 .76273 .24046 Mtetra
.708 .719 .858 r
.76273 .24046 .76636 .24402 .77431 .24162 .77069 .23811 Mtetra
.717 .725 .856 r
.77069 .23811 .77431 .24162 .78225 .23906 .77866 .23559 Mtetra
.726 .731 .855 r
.77866 .23559 .78225 .23906 .79019 .23635 .78662 .23292 Mtetra
.734 .737 .854 r
.78662 .23292 .79019 .23635 .79812 .23351 .79457 .23011 Mtetra
.741 .742 .852 r
.79457 .23011 .79812 .23351 .80605 .23054 .80252 .22717 Mtetra
.748 .747 .851 r
.80252 .22717 .80605 .23054 .81397 .22746 .81047 .22412 Mtetra
.754 .752 .851 r
.81047 .22412 .81397 .22746 .82189 .22427 .81841 .22097 Mtetra
.759 .756 .85 r
.81841 .22097 .82189 .22427 .8298 .221 .82635 .21772 Mtetra
.763 .76 .849 r
.82635 .21772 .8298 .221 .83772 .21764 .83428 .21439 Mtetra
.768 .764 .849 r
.83428 .21439 .83772 .21764 .84562 .21421 .84222 .21099 Mtetra
.771 .767 .849 r
.84222 .21099 .84562 .21421 .85353 .21073 .85015 .20753 Mtetra
.774 .77 .849 r
.85015 .20753 .85353 .21073 .86144 .20719 .85808 .20402 Mtetra
.777 .774 .85 r
.85808 .20402 .86144 .20719 .86934 .20361 .86601 .20047 Mtetra
.779 .777 .85 r
.86601 .20047 .86934 .20361 .87725 .2 .87394 .19689 Mtetra
.781 .779 .851 r
.87394 .19689 .87725 .2 .88516 .19638 .88188 .19328 Mtetra
.782 .782 .852 r
.88188 .19328 .88516 .19638 .89308 .19273 .88982 .18966 Mtetra
.404 .645 .955 r
.2949 .30573 .29923 .30823 .30577 .30874 .30144 .30621 Mtetra
.409 .644 .953 r
.30144 .30621 .30577 .30874 .31233 .30925 .30801 .30668 Mtetra
.415 .644 .952 r
.30801 .30668 .31233 .30925 .31892 .30974 .31461 .30713 Mtetra
.424 .645 .95 r
.31461 .30713 .31892 .30974 .32554 .3102 .32124 .30756 Mtetra
.433 .647 .948 r
.32124 .30756 .32554 .3102 .3322 .31063 .32791 .30796 Mtetra
.444 .649 .946 r
.32791 .30796 .3322 .31063 .33889 .31102 .33461 .30831 Mtetra
.457 .652 .944 r
.33461 .30831 .33889 .31102 .34561 .31135 .34134 .3086 Mtetra
.47 .655 .941 r
.34134 .3086 .34561 .31135 .35237 .31162 .3481 .30883 Mtetra
.485 .658 .938 r
.3481 .30883 .35237 .31162 .35916 .31182 .35491 .30899 Mtetra
.5 .662 .934 r
.35491 .30899 .35916 .31182 .36599 .31193 .36174 .30906 Mtetra
.516 .666 .93 r
.36174 .30906 .36599 .31193 .37285 .31195 .36861 .30903 Mtetra
.532 .67 .925 r
.36861 .30903 .37285 .31195 .37974 .31185 .37552 .30889 Mtetra
.548 .673 .92 r
.37552 .30889 .37974 .31185 .38667 .31164 .38246 .30864 Mtetra
.565 .677 .914 r
.38246 .30864 .38667 .31164 .39364 .3113 .38943 .30825 Mtetra
.582 .68 .908 r
.38943 .30825 .39364 .3113 .40064 .31082 .39644 .30772 Mtetra
.599 .684 .901 r
.39644 .30772 .40064 .31082 .40767 .31018 .40349 .30702 Mtetra
.615 .687 .894 r
.40349 .30702 .40767 .31018 .41473 .30937 .41056 .30616 Mtetra
.632 .689 .886 r
.41056 .30616 .41473 .30937 .42183 .30838 .41767 .30511 Mtetra
.648 .692 .877 r
.41767 .30511 .42183 .30838 .42896 .30718 .42481 .30385 Mtetra
.663 .694 .868 r
.42481 .30385 .42896 .30718 .43611 .30578 .43198 .30238 Mtetra
.678 .695 .859 r
.43198 .30238 .43611 .30578 .4433 .30414 .43918 .30068 Mtetra
.692 .696 .849 r
.43918 .30068 .4433 .30414 .45051 .30226 .4464 .29872 Mtetra
.706 .697 .839 r
.4464 .29872 .45051 .30226 .45775 .30011 .45365 .29649 Mtetra
.719 .698 .828 r
.45365 .29649 .45775 .30011 .465 .29767 .46092 .29397 Mtetra
.732 .698 .818 r
.46092 .29397 .465 .29767 .47228 .29493 .46821 .29114 Mtetra
.744 .697 .807 r
.46821 .29114 .47228 .29493 .47958 .29186 .47552 .28797 Mtetra
.756 .697 .795 r
.47552 .28797 .47958 .29186 .48689 .28843 .48284 .28443 Mtetra
.767 .696 .784 r
.48284 .28443 .48689 .28843 .49421 .28461 .49018 .28049 Mtetra
.777 .694 .772 r
.49018 .28049 .49421 .28461 .50154 .28036 .49752 .27611 Mtetra
.787 .692 .76 r
.49752 .27611 .50154 .28036 .50887 .27564 .50487 .27123 Mtetra
.797 .69 .747 r
.50487 .27123 .50887 .27564 .51619 .27039 .51221 .26579 Mtetra
.312 .441 .831 r
.63943 .24026 .64331 .245 .65122 .24731 .64735 .24274 Mtetra
.367 .484 .846 r
.64735 .24274 .65122 .24731 .65914 .24909 .65528 .24466 Mtetra
.414 .519 .856 r
.65528 .24466 .65914 .24909 .66707 .25039 .66323 .24608 Mtetra
.455 .549 .863 r
.66323 .24608 .66707 .25039 .67502 .25127 .67118 .24707 Mtetra
.491 .575 .867 r
.67118 .24707 .67502 .25127 .68297 .25177 .67915 .24765 Mtetra
.523 .598 .87 r
.67915 .24765 .68297 .25177 .69094 .2519 .68713 .24786 Mtetra
.552 .617 .872 r
.68713 .24786 .69094 .2519 .69891 .25169 .69512 .24774 Mtetra
.577 .635 .872 r
.69512 .24774 .69891 .25169 .70688 .25118 .70311 .24729 Mtetra
.599 .65 .872 r
.70311 .24729 .70688 .25118 .71486 .25038 .7111 .24656 Mtetra
.62 .664 .871 r
.7111 .24656 .71486 .25038 .72284 .2493 .7191 .24554 Mtetra
.638 .676 .87 r
.7191 .24554 .72284 .2493 .73082 .24798 .7271 .24427 Mtetra
.654 .687 .868 r
.7271 .24427 .73082 .24798 .7388 .24641 .7351 .24276 Mtetra
.669 .696 .866 r
.7351 .24276 .7388 .24641 .74678 .24463 .7431 .24102 Mtetra
.683 .705 .865 r
.7431 .24102 .74678 .24463 .75475 .24264 .75109 .23908 Mtetra
.695 .713 .863 r
.75109 .23908 .75475 .24264 .76273 .24046 .75908 .23694 Mtetra
.706 .72 .861 r
.75908 .23694 .76273 .24046 .77069 .23811 .76707 .23462 Mtetra
.715 .727 .859 r
.76707 .23462 .77069 .23811 .77866 .23559 .77505 .23214 Mtetra
.724 .733 .858 r
.77505 .23214 .77866 .23559 .78662 .23292 .78304 .2295 Mtetra
.732 .739 .856 r
.78304 .2295 .78662 .23292 .79457 .23011 .79101 .22672 Mtetra
.74 .744 .855 r
.79101 .22672 .79457 .23011 .80252 .22717 .79898 .22382 Mtetra
.746 .748 .854 r
.79898 .22382 .80252 .22717 .81047 .22412 .80695 .2208 Mtetra
.752 .753 .853 r
.80695 .2208 .81047 .22412 .81841 .22097 .81492 .21767 Mtetra
.757 .757 .852 r
.81492 .21767 .81841 .22097 .82635 .21772 .82288 .21445 Mtetra
.762 .761 .851 r
.82288 .21445 .82635 .21772 .83428 .21439 .83083 .21115 Mtetra
.766 .764 .851 r
.83083 .21115 .83428 .21439 .84222 .21099 .83879 .20777 Mtetra
.77 .768 .851 r
.83879 .20777 .84222 .21099 .85015 .20753 .84675 .20433 Mtetra
.773 .771 .851 r
.84675 .20433 .85015 .20753 .85808 .20402 .8547 .20085 Mtetra
.776 .774 .851 r
.8547 .20085 .85808 .20402 .86601 .20047 .86266 .19732 Mtetra
.778 .777 .852 r
.86266 .19732 .86601 .20047 .87394 .19689 .87061 .19376 Mtetra
.78 .779 .852 r
.87061 .19376 .87394 .19689 .88188 .19328 .87857 .19017 Mtetra
.781 .782 .853 r
.87857 .19017 .88188 .19328 .88982 .18966 .88654 .18658 Mtetra
.41 .648 .955 r
.29054 .30322 .2949 .30573 .30144 .30621 .29709 .30367 Mtetra
.414 .647 .954 r
.29709 .30367 .30144 .30621 .30801 .30668 .30367 .3041 Mtetra
.421 .647 .952 r
.30367 .3041 .30801 .30668 .31461 .30713 .31028 .30453 Mtetra
.429 .648 .95 r
.31028 .30453 .31461 .30713 .32124 .30756 .31692 .30492 Mtetra
.438 .65 .948 r
.31692 .30492 .32124 .30756 .32791 .30796 .32359 .30528 Mtetra
.449 .652 .946 r
.32359 .30528 .32791 .30796 .33461 .30831 .3303 .3056 Mtetra
.461 .655 .944 r
.3303 .3056 .33461 .30831 .34134 .3086 .33704 .30586 Mtetra
.474 .658 .941 r
.33704 .30586 .34134 .3086 .3481 .30883 .34382 .30605 Mtetra
.489 .662 .938 r
.34382 .30605 .3481 .30883 .35491 .30899 .35063 .30617 Mtetra
.504 .665 .935 r
.35063 .30617 .35491 .30899 .36174 .30906 .35747 .3062 Mtetra
.519 .669 .931 r
.35747 .3062 .36174 .30906 .36861 .30903 .36436 .30613 Mtetra
.536 .673 .926 r
.36436 .30613 .36861 .30903 .37552 .30889 .37127 .30595 Mtetra
.552 .677 .921 r
.37127 .30595 .37552 .30889 .38246 .30864 .37822 .30565 Mtetra
.569 .681 .916 r
.37822 .30565 .38246 .30864 .38943 .30825 .38521 .30522 Mtetra
.586 .685 .909 r
.38521 .30522 .38943 .30825 .39644 .30772 .39223 .30464 Mtetra
.603 .688 .902 r
.39223 .30464 .39644 .30772 .40349 .30702 .39928 .30389 Mtetra
.619 .691 .895 r
.39928 .30389 .40349 .30702 .41056 .30616 .40637 .30298 Mtetra
.636 .694 .887 r
.40637 .30298 .41056 .30616 .41767 .30511 .41349 .30187 Mtetra
.652 .696 .878 r
.41349 .30187 .41767 .30511 .42481 .30385 .42064 .30056 Mtetra
.667 .698 .869 r
.42064 .30056 .42481 .30385 .43198 .30238 .42782 .29903 Mtetra
.682 .7 .86 r
.42782 .29903 .43198 .30238 .43918 .30068 .43503 .29726 Mtetra
.697 .701 .85 r
.43503 .29726 .43918 .30068 .4464 .29872 .44227 .29523 Mtetra
.711 .702 .84 r
.44227 .29523 .4464 .29872 .45365 .29649 .44953 .29293 Mtetra
.724 .703 .83 r
.44953 .29293 .45365 .29649 .46092 .29397 .45682 .29033 Mtetra
.737 .703 .819 r
.45682 .29033 .46092 .29397 .46821 .29114 .46412 .28741 Mtetra
.749 .703 .808 r
.46412 .28741 .46821 .29114 .47552 .28797 .47145 .28415 Mtetra
.761 .702 .796 r
.47145 .28415 .47552 .28797 .48284 .28443 .47878 .28051 Mtetra
.772 .701 .785 r
.47878 .28051 .48284 .28443 .49018 .28049 .48613 .27647 Mtetra
.783 .7 .773 r
.48613 .27647 .49018 .28049 .49752 .27611 .49349 .27196 Mtetra
.793 .699 .76 r
.49349 .27196 .49752 .27611 .50487 .27123 .50085 .26695 Mtetra
.804 .697 .747 r
.50085 .26695 .50487 .27123 .51221 .26579 .50821 .26134 Mtetra
.279 .43 .834 r
.63555 .23567 .63943 .24026 .64735 .24274 .64347 .2383 Mtetra
.342 .477 .85 r
.64347 .2383 .64735 .24274 .65528 .24466 .65142 .24034 Mtetra
.395 .515 .861 r
.65142 .24034 .65528 .24466 .66323 .24608 .65937 .24187 Mtetra
.44 .547 .869 r
.65937 .24187 .66323 .24608 .67118 .24707 .66735 .24295 Mtetra
.479 .574 .873 r
.66735 .24295 .67118 .24707 .67915 .24765 .67533 .24361 Mtetra
.513 .598 .876 r
.67533 .24361 .67915 .24765 .68713 .24786 .68332 .2439 Mtetra
.543 .618 .877 r
.68332 .2439 .68713 .24786 .69512 .24774 .69132 .24385 Mtetra
.57 .636 .877 r
.69132 .24385 .69512 .24774 .70311 .24729 .69933 .24347 Mtetra
.594 .652 .877 r
.69933 .24347 .70311 .24729 .7111 .24656 .70734 .24279 Mtetra
.615 .665 .876 r
.70734 .24279 .7111 .24656 .7191 .24554 .71535 .24183 Mtetra
.634 .678 .874 r
.71535 .24183 .7191 .24554 .7271 .24427 .72337 .2406 Mtetra
.651 .689 .872 r
.72337 .2406 .7271 .24427 .7351 .24276 .73138 .23914 Mtetra
.666 .698 .87 r
.73138 .23914 .7351 .24276 .7431 .24102 .7394 .23744 Mtetra
.68 .707 .868 r
.7394 .23744 .7431 .24102 .75109 .23908 .74741 .23554 Mtetra
.692 .715 .866 r
.74741 .23554 .75109 .23908 .75908 .23694 .75542 .23344 Mtetra
.704 .722 .864 r
.75542 .23344 .75908 .23694 .76707 .23462 .76343 .23116 Mtetra
.714 .729 .862 r
.76343 .23116 .76707 .23462 .77505 .23214 .77144 .22871 Mtetra
.723 .735 .861 r
.77144 .22871 .77505 .23214 .78304 .2295 .77944 .2261 Mtetra
.731 .74 .859 r
.77944 .2261 .78304 .2295 .79101 .22672 .78744 .22335 Mtetra
.738 .745 .857 r
.78744 .22335 .79101 .22672 .79898 .22382 .79543 .22047 Mtetra
.745 .75 .856 r
.79543 .22047 .79898 .22382 .80695 .2208 .80342 .21748 Mtetra
.751 .754 .855 r
.80342 .21748 .80695 .2208 .81492 .21767 .81141 .21438 Mtetra
.756 .758 .854 r
.81141 .21438 .81492 .21767 .82288 .21445 .81939 .21118 Mtetra
.761 .762 .853 r
.81939 .21118 .82288 .21445 .83083 .21115 .82737 .2079 Mtetra
.765 .765 .852 r
.82737 .2079 .83083 .21115 .83879 .20777 .83535 .20455 Mtetra
.769 .768 .852 r
.83535 .20455 .83879 .20777 .84675 .20433 .84333 .20113 Mtetra
.772 .771 .852 r
.84333 .20113 .84675 .20433 .8547 .20085 .85131 .19766 Mtetra
.774 .774 .852 r
.85131 .19766 .8547 .20085 .86266 .19732 .85929 .19415 Mtetra
.777 .777 .853 r
.85929 .19415 .86266 .19732 .87061 .19376 .86727 .19061 Mtetra
.778 .779 .853 r
.86727 .19061 .87061 .19376 .87857 .19017 .87526 .18705 Mtetra
.779 .782 .854 r
.87526 .18705 .87857 .19017 .88654 .18658 .88325 .18347 Mtetra
.415 .65 .955 r
.28616 .3007 .29054 .30322 .29709 .30367 .29272 .30112 Mtetra
.419 .65 .954 r
.29272 .30112 .29709 .30367 .30367 .3041 .29931 .30152 Mtetra
.426 .65 .952 r
.29931 .30152 .30367 .3041 .31028 .30453 .30592 .30191 Mtetra
.433 .651 .951 r
.30592 .30191 .31028 .30453 .31692 .30492 .31258 .30228 Mtetra
.442 .653 .949 r
.31258 .30228 .31692 .30492 .32359 .30528 .31926 .3026 Mtetra
.453 .655 .947 r
.31926 .3026 .32359 .30528 .3303 .3056 .32598 .30289 Mtetra
.465 .658 .945 r
.32598 .30289 .3303 .3056 .33704 .30586 .33273 .30311 Mtetra
.478 .661 .942 r
.33273 .30311 .33704 .30586 .34382 .30605 .33951 .30327 Mtetra
.492 .665 .939 r
.33951 .30327 .34382 .30605 .35063 .30617 .34633 .30335 Mtetra
.507 .669 .936 r
.34633 .30335 .35063 .30617 .35747 .3062 .35319 .30335 Mtetra
.523 .673 .932 r
.35319 .30335 .35747 .3062 .36436 .30613 .36008 .30324 Mtetra
.539 .677 .927 r
.36008 .30324 .36436 .30613 .37127 .30595 .367 .30302 Mtetra
.555 .681 .922 r
.367 .30302 .37127 .30595 .37822 .30565 .37396 .30268 Mtetra
.572 .685 .917 r
.37396 .30268 .37822 .30565 .38521 .30522 .38096 .30221 Mtetra
.589 .688 .911 r
.38096 .30221 .38521 .30522 .39223 .30464 .38799 .30158 Mtetra
.606 .692 .904 r
.38799 .30158 .39223 .30464 .39928 .30389 .39506 .30079 Mtetra
.623 .695 .896 r
.39506 .30079 .39928 .30389 .40637 .30298 .40216 .29983 Mtetra
.639 .698 .888 r
.40216 .29983 .40637 .30298 .41349 .30187 .40929 .29867 Mtetra
.655 .701 .88 r
.40929 .29867 .41349 .30187 .42064 .30056 .41645 .29731 Mtetra
.671 .703 .871 r
.41645 .29731 .42064 .30056 .42782 .29903 .42365 .29572 Mtetra
.686 .705 .861 r
.42365 .29572 .42782 .29903 .43503 .29726 .43087 .29389 Mtetra
.701 .706 .852 r
.43087 .29389 .43503 .29726 .44227 .29523 .43812 .2918 Mtetra
.715 .707 .841 r
.43812 .2918 .44227 .29523 .44953 .29293 .44539 .28943 Mtetra
.729 .708 .831 r
.44539 .28943 .44953 .29293 .45682 .29033 .45269 .28676 Mtetra
.742 .708 .82 r
.45269 .28676 .45682 .29033 .46412 .28741 .46001 .28376 Mtetra
.754 .708 .809 r
.46001 .28376 .46412 .28741 .47145 .28415 .46735 .28041 Mtetra
.766 .708 .797 r
.46735 .28041 .47145 .28415 .47878 .28051 .47471 .27669 Mtetra
.777 .707 .786 r
.47471 .27669 .47878 .28051 .48613 .27647 .48207 .27254 Mtetra
.788 .706 .773 r
.48207 .27254 .48613 .27647 .49349 .27196 .48945 .26793 Mtetra
.799 .705 .761 r
.48945 .26793 .49349 .27196 .50085 .26695 .49682 .2628 Mtetra
.81 .704 .747 r
.49682 .2628 .50085 .26695 .50821 .26134 .5042 .25706 Mtetra
.246 .419 .837 r
.63166 .23124 .63555 .23567 .64347 .2383 .6396 .23399 Mtetra
.317 .47 .855 r
.6396 .23399 .64347 .2383 .65142 .24034 .64755 .23613 Mtetra
.376 .511 .867 r
.64755 .23613 .65142 .24034 .65937 .24187 .65552 .23775 Mtetra
.425 .545 .874 r
.65552 .23775 .65937 .24187 .66735 .24295 .6635 .23891 Mtetra
.467 .574 .879 r
.6635 .23891 .66735 .24295 .67533 .24361 .67149 .23965 Mtetra
.503 .598 .882 r
.67149 .23965 .67533 .24361 .68332 .2439 .6795 .24001 Mtetra
.535 .619 .883 r
.6795 .24001 .68332 .2439 .69132 .24385 .68751 .24002 Mtetra
.563 .637 .883 r
.68751 .24002 .69132 .24385 .69933 .24347 .69554 .2397 Mtetra
.588 .653 .882 r
.69554 .2397 .69933 .24347 .70734 .24279 .70356 .23907 Mtetra
.61 .668 .88 r
.70356 .23907 .70734 .24279 .71535 .24183 .71159 .23816 Mtetra
.63 .68 .879 r
.71159 .23816 .71535 .24183 .72337 .2406 .71963 .23698 Mtetra
.648 .691 .877 r
.71963 .23698 .72337 .2406 .73138 .23914 .72766 .23556 Mtetra
.663 .701 .874 r
.72766 .23556 .73138 .23914 .7394 .23744 .73569 .2339 Mtetra
.678 .71 .872 r
.73569 .2339 .7394 .23744 .74741 .23554 .74373 .23204 Mtetra
.69 .717 .87 r
.74373 .23204 .74741 .23554 .75542 .23344 .75176 .22997 Mtetra
.702 .724 .867 r
.75176 .22997 .75542 .23344 .76343 .23116 .75978 .22772 Mtetra
.712 .731 .865 r
.75978 .22772 .76343 .23116 .77144 .22871 .76781 .2253 Mtetra
.721 .737 .863 r
.76781 .2253 .77144 .22871 .77944 .2261 .77583 .22272 Mtetra
.73 .742 .861 r
.77583 .22272 .77944 .2261 .78744 .22335 .78385 .22 Mtetra
.737 .747 .86 r
.78385 .22 .78744 .22335 .79543 .22047 .79187 .21714 Mtetra
.744 .751 .858 r
.79187 .21714 .79543 .22047 .80342 .21748 .79988 .21417 Mtetra
.75 .755 .857 r
.79988 .21417 .80342 .21748 .81141 .21438 .80789 .21109 Mtetra
.755 .759 .856 r
.80789 .21109 .81141 .21438 .81939 .21118 .81589 .20792 Mtetra
.76 .763 .855 r
.81589 .20792 .81939 .21118 .82737 .2079 .8239 .20466 Mtetra
.764 .766 .854 r
.8239 .20466 .82737 .2079 .83535 .20455 .8319 .20132 Mtetra
.768 .769 .854 r
.8319 .20132 .83535 .20455 .84333 .20113 .8399 .19793 Mtetra
.771 .772 .853 r
.8399 .19793 .84333 .20113 .85131 .19766 .8479 .19448 Mtetra
.773 .774 .854 r
.8479 .19448 .85131 .19766 .85929 .19415 .85591 .19098 Mtetra
.775 .777 .854 r
.85591 .19098 .85929 .19415 .86727 .19061 .86391 .18746 Mtetra
.777 .779 .854 r
.86391 .18746 .86727 .19061 .87526 .18705 .87192 .18391 Mtetra
.778 .781 .855 r
.87192 .18391 .87526 .18705 .88325 .18347 .87994 .18035 Mtetra
.42 .652 .955 r
.28176 .29817 .28616 .3007 .29272 .30112 .28832 .29856 Mtetra
.424 .652 .954 r
.28832 .29856 .29272 .30112 .29931 .30152 .29492 .29893 Mtetra
.43 .652 .952 r
.29492 .29893 .29931 .30152 .30592 .30191 .30155 .29929 Mtetra
.437 .654 .951 r
.30155 .29929 .30592 .30191 .31258 .30228 .30821 .29963 Mtetra
.446 .655 .949 r
.30821 .29963 .31258 .30228 .31926 .3026 .3149 .29993 Mtetra
.457 .658 .947 r
.3149 .29993 .31926 .3026 .32598 .30289 .32163 .30018 Mtetra
.468 .661 .945 r
.32163 .30018 .32598 .30289 .33273 .30311 .32839 .30037 Mtetra
.481 .664 .943 r
.32839 .30037 .33273 .30311 .33951 .30327 .33518 .3005 Mtetra
.495 .668 .94 r
.33518 .3005 .33951 .30327 .34633 .30335 .34201 .30055 Mtetra
.51 .672 .937 r
.34201 .30055 .34633 .30335 .35319 .30335 .34888 .30051 Mtetra
.526 .676 .933 r
.34888 .30051 .35319 .30335 .36008 .30324 .35578 .30037 Mtetra
.542 .68 .928 r
.35578 .30037 .36008 .30324 .367 .30302 .36271 .30012 Mtetra
.558 .684 .924 r
.36271 .30012 .367 .30302 .37396 .30268 .36969 .29974 Mtetra
.575 .688 .918 r
.36969 .29974 .37396 .30268 .38096 .30221 .37669 .29922 Mtetra
.592 .692 .912 r
.37669 .29922 .38096 .30221 .38799 .30158 .38373 .29856 Mtetra
.609 .696 .905 r
.38373 .29856 .38799 .30158 .39506 .30079 .39081 .29772 Mtetra
.626 .699 .898 r
.39081 .29772 .39506 .30079 .40216 .29983 .39792 .29671 Mtetra
.643 .703 .89 r
.39792 .29671 .40216 .29983 .40929 .29867 .40507 .29551 Mtetra
.659 .705 .881 r
.40507 .29551 .40929 .29867 .41645 .29731 .41224 .2941 Mtetra
.675 .708 .872 r
.41224 .2941 .41645 .29731 .42365 .29572 .41945 .29245 Mtetra
.69 .71 .863 r
.41945 .29245 .42365 .29572 .43087 .29389 .42668 .29057 Mtetra
.705 .711 .853 r
.42668 .29057 .43087 .29389 .43812 .2918 .43395 .28842 Mtetra
.719 .712 .843 r
.43395 .28842 .43812 .2918 .44539 .28943 .44124 .28598 Mtetra
.733 .713 .832 r
.44124 .28598 .44539 .28943 .45269 .28676 .44855 .28325 Mtetra
.746 .713 .821 r
.44855 .28325 .45269 .28676 .46001 .28376 .45589 .28018 Mtetra
.759 .714 .81 r
.45589 .28018 .46001 .28376 .46735 .28041 .46324 .27676 Mtetra
.771 .713 .799 r
.46324 .27676 .46735 .28041 .47471 .27669 .47061 .27295 Mtetra
.782 .713 .787 r
.47061 .27295 .47471 .27669 .48207 .27254 .47799 .26872 Mtetra
.794 .712 .775 r
.47799 .26872 .48207 .27254 .48945 .26793 .48538 .26402 Mtetra
.805 .711 .762 r
.48538 .26402 .48945 .26793 .49682 .2628 .49278 .25879 Mtetra
.293 .465 .859 r
.63572 .22982 .6396 .23399 .64755 .23613 .64367 .23204 Mtetra
.356 .508 .872 r
.64367 .23204 .64755 .23613 .65552 .23775 .65165 .23374 Mtetra
.409 .544 .88 r
.65165 .23374 .65552 .23775 .6635 .23891 .65964 .23497 Mtetra
.454 .574 .885 r
.65964 .23497 .6635 .23891 .67149 .23965 .66765 .23577 Mtetra
.493 .599 .887 r
.66765 .23577 .67149 .23965 .6795 .24001 .67567 .23619 Mtetra
.527 .62 .888 r
.67567 .23619 .6795 .24001 .68751 .24002 .6837 .23626 Mtetra
.556 .639 .888 r
.6837 .23626 .68751 .24002 .69554 .2397 .69173 .23599 Mtetra
.582 .656 .887 r
.69173 .23599 .69554 .2397 .70356 .23907 .69978 .23541 Mtetra
.606 .67 .885 r
.69978 .23541 .70356 .23907 .71159 .23816 .70782 .23454 Mtetra
.626 .682 .883 r
.70782 .23454 .71159 .23816 .71963 .23698 .71587 .2334 Mtetra
.644 .693 .881 r
.71587 .2334 .71963 .23698 .72766 .23556 .72392 .23202 Mtetra
.661 .703 .878 r
.72392 .23202 .72766 .23556 .73569 .2339 .73197 .2304 Mtetra
.675 .712 .876 r
.73197 .2304 .73569 .2339 .74373 .23204 .74003 .22856 Mtetra
.688 .72 .873 r
.74003 .22856 .74373 .23204 .75176 .22997 .74808 .22653 Mtetra
.7 .727 .871 r
.74808 .22653 .75176 .22997 .75978 .22772 .75612 .2243 Mtetra
.711 .733 .868 r
.75612 .2243 .75978 .22772 .76781 .2253 .76417 .22191 Mtetra
.72 .739 .866 r
.76417 .22191 .76781 .2253 .77583 .22272 .77221 .21935 Mtetra
.729 .744 .864 r
.77221 .21935 .77583 .22272 .78385 .22 .78025 .21666 Mtetra
.736 .748 .862 r
.78025 .21666 .78385 .22 .79187 .21714 .78829 .21382 Mtetra
.743 .753 .86 r
.78829 .21382 .79187 .21714 .79988 .21417 .79632 .21087 Mtetra
.749 .757 .859 r
.79632 .21087 .79988 .21417 .80789 .21109 .80435 .20781 Mtetra
.754 .76 .857 r
.80435 .20781 .80789 .21109 .81589 .20792 .81238 .20465 Mtetra
.759 .764 .856 r
.81238 .20465 .81589 .20792 .8239 .20466 .8204 .20141 Mtetra
.763 .767 .856 r
.8204 .20141 .8239 .20466 .8319 .20132 .82843 .19809 Mtetra
.767 .769 .855 r
.82843 .19809 .8319 .20132 .8399 .19793 .83645 .19471 Mtetra
.77 .772 .855 r
.83645 .19471 .8399 .19793 .8479 .19448 .84448 .19128 Mtetra
.772 .775 .855 r
.84448 .19128 .8479 .19448 .85591 .19098 .85251 .1878 Mtetra
.774 .777 .855 r
.85251 .1878 .85591 .19098 .86391 .18746 .86054 .18429 Mtetra
.776 .779 .855 r
.86054 .18429 .86391 .18746 .87192 .18391 .86857 .18076 Mtetra
.777 .781 .856 r
.86857 .18076 .87192 .18391 .87994 .18035 .87661 .17722 Mtetra
.425 .654 .955 r
.27733 .29563 .28176 .29817 .28832 .29856 .28391 .29599 Mtetra
.428 .654 .954 r
.28391 .29599 .28832 .29856 .29492 .29893 .29052 .29634 Mtetra
.434 .655 .953 r
.29052 .29634 .29492 .29893 .30155 .29929 .29716 .29667 Mtetra
.441 .656 .951 r
.29716 .29667 .30155 .29929 .30821 .29963 .30382 .29698 Mtetra
.45 .658 .95 r
.30382 .29698 .30821 .29963 .3149 .29993 .31053 .29725 Mtetra
.46 .66 .948 r
.31053 .29725 .3149 .29993 .32163 .30018 .31726 .29747 Mtetra
.471 .663 .946 r
.31726 .29747 .32163 .30018 .32839 .30037 .32403 .29764 Mtetra
.484 .667 .944 r
.32403 .29764 .32839 .30037 .33518 .3005 .33083 .29773 Mtetra
.498 .671 .941 r
.33083 .29773 .33518 .3005 .34201 .30055 .33767 .29775 Mtetra
.513 .675 .938 r
.33767 .29775 .34201 .30055 .34888 .30051 .34455 .29768 Mtetra
.528 .679 .934 r
.34455 .29768 .34888 .30051 .35578 .30037 .35146 .29751 Mtetra
.544 .683 .93 r
.35146 .29751 .35578 .30037 .36271 .30012 .3584 .29722 Mtetra
.561 .688 .925 r
.3584 .29722 .36271 .30012 .36969 .29974 .36538 .29681 Mtetra
.578 .692 .919 r
.36538 .29681 .36969 .29974 .37669 .29922 .3724 .29626 Mtetra
.595 .696 .913 r
.3724 .29626 .37669 .29922 .38373 .29856 .37945 .29556 Mtetra
.612 .7 .907 r
.37945 .29556 .38373 .29856 .39081 .29772 .38654 .29469 Mtetra
.629 .704 .899 r
.38654 .29469 .39081 .29772 .39792 .29671 .39367 .29363 Mtetra
.646 .707 .892 r
.39367 .29363 .39792 .29671 .40507 .29551 .40082 .29239 Mtetra
.662 .71 .883 r
.40082 .29239 .40507 .29551 .41224 .2941 .40801 .29093 Mtetra
.678 .712 .874 r
.40801 .29093 .41224 .2941 .41945 .29245 .41523 .28924 Mtetra
.694 .714 .865 r
.41523 .28924 .41945 .29245 .42668 .29057 .42248 .2873 Mtetra
.709 .716 .855 r
.42248 .2873 .42668 .29057 .43395 .28842 .42976 .28509 Mtetra
.723 .717 .844 r
.42976 .28509 .43395 .28842 .44124 .28598 .43706 .2826 Mtetra
.737 .718 .834 r
.43706 .2826 .44124 .28598 .44855 .28325 .44439 .2798 Mtetra
.75 .719 .823 r
.44439 .2798 .44855 .28325 .45589 .28018 .45174 .27667 Mtetra
.763 .719 .811 r
.45174 .27667 .45589 .28018 .46324 .27676 .45911 .27318 Mtetra
.775 .719 .8 r
.45911 .27318 .46324 .27676 .47061 .27295 .46649 .2693 Mtetra
.787 .719 .788 r
.46649 .2693 .47061 .27295 .47799 .26872 .47389 .265 Mtetra
.798 .718 .776 r
.47389 .265 .47799 .26872 .48538 .26402 .4813 .26022 Mtetra
.81 .718 .764 r
.4813 .26022 .48538 .26402 .49278 .25879 .48871 .25492 Mtetra
.269 .46 .863 r
.63183 .22579 .63572 .22982 .64367 .23204 .63979 .22807 Mtetra
.338 .506 .877 r
.63979 .22807 .64367 .23204 .65165 .23374 .64778 .22983 Mtetra
.394 .543 .886 r
.64778 .22983 .65165 .23374 .65964 .23497 .65578 .23111 Mtetra
.442 .574 .891 r
.65578 .23111 .65964 .23497 .66765 .23577 .6638 .23198 Mtetra
.483 .6 .893 r
.6638 .23198 .66765 .23577 .67567 .23619 .67183 .23245 Mtetra
.519 .622 .894 r
.67183 .23245 .67567 .23619 .6837 .23626 .67987 .23256 Mtetra
.55 .641 .894 r
.67987 .23256 .6837 .23626 .69173 .23599 .68792 .23234 Mtetra
.577 .658 .892 r
.68792 .23234 .69173 .23599 .69978 .23541 .69598 .2318 Mtetra
.601 .672 .89 r
.69598 .2318 .69978 .23541 .70782 .23454 .70404 .23097 Mtetra
.622 .685 .888 r
.70404 .23097 .70782 .23454 .71587 .2334 .71211 .22987 Mtetra
.641 .696 .885 r
.71211 .22987 .71587 .2334 .72392 .23202 .72017 .22852 Mtetra
.658 .706 .882 r
.72017 .22852 .72392 .23202 .73197 .2304 .72824 .22693 Mtetra
.673 .714 .879 r
.72824 .22693 .73197 .2304 .74003 .22856 .73631 .22512 Mtetra
.687 .722 .877 r
.73631 .22512 .74003 .22856 .74808 .22653 .74438 .22311 Mtetra
.699 .729 .874 r
.74438 .22311 .74808 .22653 .75612 .2243 .75245 .22091 Mtetra
.709 .735 .871 r
.75245 .22091 .75612 .2243 .76417 .22191 .76051 .21854 Mtetra
.719 .741 .869 r
.76051 .21854 .76417 .22191 .77221 .21935 .76858 .21601 Mtetra
.728 .746 .866 r
.76858 .21601 .77221 .21935 .78025 .21666 .77664 .21333 Mtetra
.735 .75 .864 r
.77664 .21333 .78025 .21666 .78829 .21382 .78469 .21052 Mtetra
.742 .754 .862 r
.78469 .21052 .78829 .21382 .79632 .21087 .79275 .20758 Mtetra
.748 .758 .861 r
.79275 .20758 .79632 .21087 .80435 .20781 .8008 .20454 Mtetra
.754 .761 .859 r
.8008 .20454 .80435 .20781 .81238 .20465 .80885 .2014 Mtetra
.758 .765 .858 r
.80885 .2014 .81238 .20465 .8204 .20141 .8169 .19817 Mtetra
.762 .768 .857 r
.8169 .19817 .8204 .20141 .82843 .19809 .82494 .19487 Mtetra
.766 .77 .856 r
.82494 .19487 .82843 .19809 .83645 .19471 .83299 .1915 Mtetra
.769 .773 .856 r
.83299 .1915 .83645 .19471 .84448 .19128 .84104 .18808 Mtetra
.771 .775 .856 r
.84104 .18808 .84448 .19128 .85251 .1878 .84909 .18461 Mtetra
.773 .777 .856 r
.84909 .18461 .85251 .1878 .86054 .18429 .85714 .18112 Mtetra
.775 .779 .856 r
.85714 .18112 .86054 .18429 .86857 .18076 .8652 .1776 Mtetra
.776 .781 .857 r
.8652 .1776 .86857 .18076 .87661 .17722 .87326 .17406 Mtetra
.428 .656 .955 r
.27289 .29307 .27733 .29563 .28391 .29599 .27948 .29341 Mtetra
.432 .656 .954 r
.27948 .29341 .28391 .29599 .29052 .29634 .28609 .29373 Mtetra
.437 .657 .953 r
.28609 .29373 .29052 .29634 .29716 .29667 .29274 .29404 Mtetra
.444 .658 .952 r
.29274 .29404 .29716 .29667 .30382 .29698 .29942 .29432 Mtetra
.453 .66 .95 r
.29942 .29432 .30382 .29698 .31053 .29725 .30613 .29457 Mtetra
.463 .663 .948 r
.30613 .29457 .31053 .29725 .31726 .29747 .31287 .29477 Mtetra
.474 .666 .947 r
.31287 .29477 .31726 .29747 .32403 .29764 .31965 .29491 Mtetra
.487 .669 .944 r
.31965 .29491 .32403 .29764 .33083 .29773 .32646 .29498 Mtetra
.5 .673 .942 r
.32646 .29498 .33083 .29773 .33767 .29775 .33331 .29497 Mtetra
.515 .678 .939 r
.33331 .29497 .33767 .29775 .34455 .29768 .34019 .29487 Mtetra
.531 .682 .935 r
.34019 .29487 .34455 .29768 .35146 .29751 .34711 .29467 Mtetra
.547 .687 .931 r
.34711 .29467 .35146 .29751 .3584 .29722 .35407 .29435 Mtetra
.563 .691 .926 r
.35407 .29435 .3584 .29722 .36538 .29681 .36106 .29391 Mtetra
.58 .696 .921 r
.36106 .29391 .36538 .29681 .3724 .29626 .36809 .29332 Mtetra
.597 .7 .915 r
.36809 .29332 .3724 .29626 .37945 .29556 .37515 .29258 Mtetra
.614 .704 .908 r
.37515 .29258 .37945 .29556 .38654 .29469 .38225 .29168 Mtetra
.631 .708 .901 r
.38225 .29168 .38654 .29469 .39367 .29363 .38939 .29059 Mtetra
.648 .711 .893 r
.38939 .29059 .39367 .29363 .40082 .29239 .39655 .2893 Mtetra
.665 .714 .885 r
.39655 .2893 .40082 .29239 .40801 .29093 .40376 .2878 Mtetra
.681 .717 .876 r
.40376 .2878 .40801 .29093 .41523 .28924 .41099 .28606 Mtetra
.697 .719 .867 r
.41099 .28606 .41523 .28924 .42248 .2873 .41825 .28408 Mtetra
.712 .721 .857 r
.41825 .28408 .42248 .2873 .42976 .28509 .42554 .28183 Mtetra
.727 .722 .846 r
.42554 .28183 .42976 .28509 .43706 .2826 .43286 .27928 Mtetra
.741 .723 .835 r
.43286 .27928 .43706 .2826 .44439 .2798 .4402 .27643 Mtetra
.754 .724 .824 r
.4402 .27643 .44439 .2798 .45174 .27667 .44757 .27324 Mtetra
.767 .724 .813 r
.44757 .27324 .45174 .27667 .45911 .27318 .45496 .26969 Mtetra
.779 .725 .802 r
.45496 .26969 .45911 .27318 .46649 .2693 .46236 .26574 Mtetra
.791 .724 .79 r
.46236 .26574 .46649 .2693 .47389 .265 .46977 .26138 Mtetra
.803 .724 .778 r
.46977 .26138 .47389 .265 .4813 .26022 .4772 .25655 Mtetra
.814 .724 .766 r
.4772 .25655 .4813 .26022 .48871 .25492 .48463 .25119 Mtetra
.247 .457 .867 r
.62793 .22191 .63183 .22579 .63979 .22807 .6359 .22422 Mtetra
.32 .504 .882 r
.6359 .22422 .63979 .22807 .64778 .22983 .64389 .22602 Mtetra
.38 .542 .891 r
.64389 .22602 .64778 .22983 .65578 .23111 .65191 .22735 Mtetra
.43 .574 .896 r
.65191 .22735 .65578 .23111 .6638 .23198 .65994 .22826 Mtetra
.473 .601 .899 r
.65994 .22826 .6638 .23198 .67183 .23245 .66798 .22878 Mtetra
.511 .624 .9 r
.66798 .22878 .67183 .23245 .67987 .23256 .67603 .22893 Mtetra
.543 .644 .899 r
.67603 .22893 .67987 .23256 .68792 .23234 .6841 .22875 Mtetra
.572 .661 .897 r
.6841 .22875 .68792 .23234 .69598 .2318 .69217 .22825 Mtetra
.597 .675 .895 r
.69217 .22825 .69598 .2318 .70404 .23097 .70025 .22745 Mtetra
.619 .688 .892 r
.70025 .22745 .70404 .23097 .71211 .22987 .70833 .22639 Mtetra
.639 .699 .889 r
.70833 .22639 .71211 .22987 .72017 .22852 .71641 .22506 Mtetra
.656 .709 .886 r
.71641 .22506 .72017 .22852 .72824 .22693 .7245 .2235 Mtetra
.671 .717 .883 r
.7245 .2235 .72824 .22693 .73631 .22512 .73259 .22172 Mtetra
.685 .725 .88 r
.73259 .22172 .73631 .22512 .74438 .22311 .74068 .21973 Mtetra
.697 .731 .877 r
.74068 .21973 .74438 .22311 .75245 .22091 .74876 .21755 Mtetra
.708 .737 .874 r
.74876 .21755 .75245 .22091 .76051 .21854 .75685 .2152 Mtetra
.718 .743 .871 r
.75685 .2152 .76051 .21854 .76858 .21601 .76493 .21268 Mtetra
.727 .748 .869 r
.76493 .21268 .76858 .21601 .77664 .21333 .77301 .21002 Mtetra
.734 .752 .866 r
.77301 .21002 .77664 .21333 .78469 .21052 .78109 .20722 Mtetra
.741 .756 .864 r
.78109 .20722 .78469 .21052 .79275 .20758 .78916 .2043 Mtetra
.747 .759 .862 r
.78916 .2043 .79275 .20758 .8008 .20454 .79723 .20127 Mtetra
.753 .763 .861 r
.79723 .20127 .8008 .20454 .80885 .2014 .8053 .19814 Mtetra
.758 .766 .859 r
.8053 .19814 .80885 .2014 .8169 .19817 .81337 .19493 Mtetra
.762 .768 .858 r
.81337 .19493 .8169 .19817 .82494 .19487 .82144 .19164 Mtetra
.765 .771 .858 r
.82144 .19164 .82494 .19487 .83299 .1915 .82951 .18828 Mtetra
.768 .773 .857 r
.82951 .18828 .83299 .1915 .84104 .18808 .83758 .18487 Mtetra
.771 .775 .857 r
.83758 .18487 .84104 .18808 .84909 .18461 .84566 .18142 Mtetra
.773 .777 .857 r
.84566 .18142 .84909 .18461 .85714 .18112 .85373 .17793 Mtetra
.774 .779 .857 r
.85373 .17793 .85714 .18112 .8652 .1776 .86181 .17442 Mtetra
.775 .781 .858 r
.86181 .17442 .8652 .1776 .87326 .17406 .8699 .17089 Mtetra
.432 .658 .955 r
.26843 .2905 .27289 .29307 .27948 .29341 .27502 .29082 Mtetra
.435 .658 .954 r
.27502 .29082 .27948 .29341 .28609 .29373 .28164 .29112 Mtetra
.44 .658 .953 r
.28164 .29112 .28609 .29373 .29274 .29404 .2883 .29141 Mtetra
.447 .66 .952 r
.2883 .29141 .29274 .29404 .29942 .29432 .29498 .29167 Mtetra
.455 .662 .951 r
.29498 .29167 .29942 .29432 .30613 .29457 .3017 .29189 Mtetra
.465 .665 .949 r
.3017 .29189 .30613 .29457 .31287 .29477 .30846 .29206 Mtetra
.476 .668 .947 r
.30846 .29206 .31287 .29477 .31965 .29491 .31524 .29218 Mtetra
.489 .672 .945 r
.31524 .29218 .31965 .29491 .32646 .29498 .32206 .29223 Mtetra
.502 .676 .943 r
.32206 .29223 .32646 .29498 .33331 .29497 .32892 .29219 Mtetra
.517 .68 .94 r
.32892 .29219 .33331 .29497 .34019 .29487 .33581 .29207 Mtetra
.532 .685 .936 r
.33581 .29207 .34019 .29487 .34711 .29467 .34274 .29184 Mtetra
.548 .69 .932 r
.34274 .29184 .34711 .29467 .35407 .29435 .34971 .2915 Mtetra
.565 .694 .928 r
.34971 .2915 .35407 .29435 .36106 .29391 .35671 .29102 Mtetra
.582 .699 .922 r
.35671 .29102 .36106 .29391 .36809 .29332 .36375 .29041 Mtetra
.599 .703 .917 r
.36375 .29041 .36809 .29332 .37515 .29258 .37083 .28964 Mtetra
.616 .708 .91 r
.37083 .28964 .37515 .29258 .38225 .29168 .37794 .2887 Mtetra
.634 .712 .903 r
.37794 .2887 .38225 .29168 .38939 .29059 .38508 .28758 Mtetra
.651 .715 .895 r
.38508 .28758 .38939 .29059 .39655 .2893 .39227 .28625 Mtetra
.667 .719 .887 r
.39227 .28625 .39655 .2893 .40376 .2878 .39948 .28471 Mtetra
.684 .721 .878 r
.39948 .28471 .40376 .2878 .41099 .28606 .40672 .28294 Mtetra
.7 .724 .869 r
.40672 .28294 .41099 .28606 .41825 .28408 .414 .28091 Mtetra
.715 .726 .859 r
.414 .28091 .41825 .28408 .42554 .28183 .42131 .27862 Mtetra
.73 .728 .848 r
.42131 .27862 .42554 .28183 .43286 .27928 .42864 .27602 Mtetra
.744 .729 .837 r
.42864 .27602 .43286 .27928 .4402 .27643 .436 .27312 Mtetra
.758 .73 .826 r
.436 .27312 .4402 .27643 .44757 .27324 .44338 .26988 Mtetra
.771 .73 .815 r
.44338 .26988 .44757 .27324 .45496 .26969 .45078 .26627 Mtetra
.783 .73 .803 r
.45078 .26627 .45496 .26969 .46236 .26574 .4582 .26228 Mtetra
.795 .73 .792 r
.4582 .26228 .46236 .26574 .46977 .26138 .46564 .25786 Mtetra
.807 .73 .78 r
.46564 .25786 .46977 .26138 .4772 .25655 .47308 .25298 Mtetra
.818 .73 .768 r
.47308 .25298 .4772 .25655 .48463 .25119 .48053 .2476 Mtetra
.226 .455 .871 r
.62403 .21816 .62793 .22191 .6359 .22422 .632 .22048 Mtetra
.303 .503 .887 r
.632 .22048 .6359 .22422 .64389 .22602 .64 .22231 Mtetra
.365 .542 .896 r
.64 .22231 .64389 .22602 .65191 .22735 .64802 .22368 Mtetra
.418 .575 .902 r
.64802 .22368 .65191 .22735 .65994 .22826 .65606 .22463 Mtetra
.464 .603 .905 r
.65606 .22463 .65994 .22826 .66798 .22878 .66412 .22518 Mtetra
.503 .626 .905 r
.66412 .22518 .66798 .22878 .67603 .22893 .67219 .22537 Mtetra
.537 .646 .904 r
.67219 .22537 .67603 .22893 .6841 .22875 .68026 .22522 Mtetra
.567 .663 .903 r
.68026 .22522 .6841 .22875 .69217 .22825 .68835 .22475 Mtetra
.593 .678 .9 r
.68835 .22475 .69217 .22825 .70025 .22745 .69644 .22399 Mtetra
.616 .691 .897 r
.69644 .22399 .70025 .22745 .70833 .22639 .70454 .22295 Mtetra
.636 .702 .894 r
.70454 .22295 .70833 .22639 .71641 .22506 .71264 .22165 Mtetra
.654 .712 .89 r
.71264 .22165 .71641 .22506 .7245 .2235 .72075 .22011 Mtetra
.67 .72 .887 r
.72075 .22011 .7245 .2235 .73259 .22172 .72885 .21834 Mtetra
.684 .727 .883 r
.72885 .21834 .73259 .22172 .74068 .21973 .73696 .21638 Mtetra
.696 .734 .88 r
.73696 .21638 .74068 .21973 .74876 .21755 .74506 .21421 Mtetra
.707 .74 .877 r
.74506 .21421 .74876 .21755 .75685 .2152 .75316 .21188 Mtetra
.717 .745 .874 r
.75316 .21188 .75685 .2152 .76493 .21268 .76127 .20938 Mtetra
.726 .75 .871 r
.76127 .20938 .76493 .21268 .77301 .21002 .76937 .20673 Mtetra
.734 .754 .868 r
.76937 .20673 .77301 .21002 .78109 .20722 .77746 .20394 Mtetra
.741 .758 .866 r
.77746 .20394 .78109 .20722 .78916 .2043 .78556 .20103 Mtetra
.747 .761 .864 r
.78556 .20103 .78916 .2043 .79723 .20127 .79365 .19801 Mtetra
.752 .764 .862 r
.79365 .19801 .79723 .20127 .8053 .19814 .80174 .19489 Mtetra
.757 .767 .861 r
.80174 .19489 .8053 .19814 .81337 .19493 .80984 .19169 Mtetra
.761 .769 .86 r
.80984 .19169 .81337 .19493 .82144 .19164 .81793 .1884 Mtetra
.765 .772 .859 r
.81793 .1884 .82144 .19164 .82951 .18828 .82602 .18506 Mtetra
.768 .774 .858 r
.82602 .18506 .82951 .18828 .83758 .18487 .83411 .18165 Mtetra
.77 .776 .858 r
.83411 .18165 .83758 .18487 .84566 .18142 .84221 .17821 Mtetra
.772 .778 .858 r
.84221 .17821 .84566 .18142 .85373 .17793 .8503 .17473 Mtetra
.773 .779 .858 r
.8503 .17473 .85373 .17793 .86181 .17442 .85841 .17122 Mtetra
.774 .781 .858 r
.85841 .17122 .86181 .17442 .8699 .17089 .86652 .16771 Mtetra
.435 .659 .955 r
.26394 .28792 .26843 .2905 .27502 .29082 .27054 .28822 Mtetra
.438 .659 .954 r
.27054 .28822 .27502 .29082 .28164 .29112 .27718 .2885 Mtetra
.442 .66 .953 r
.27718 .2885 .28164 .29112 .2883 .29141 .28384 .28877 Mtetra
.449 .661 .952 r
.28384 .28877 .2883 .29141 .29498 .29167 .29053 .28901 Mtetra
.457 .664 .951 r
.29053 .28901 .29498 .29167 .3017 .29189 .29726 .28921 Mtetra
.467 .667 .95 r
.29726 .28921 .3017 .29189 .30846 .29206 .30402 .28936 Mtetra
.478 .67 .948 r
.30402 .28936 .30846 .29206 .31524 .29218 .31081 .28946 Mtetra
.49 .674 .946 r
.31081 .28946 .31524 .29218 .32206 .29223 .31765 .28948 Mtetra
.504 .678 .944 r
.31765 .28948 .32206 .29223 .32892 .29219 .32451 .28943 Mtetra
.518 .683 .941 r
.32451 .28943 .32892 .29219 .33581 .29207 .33141 .28928 Mtetra
.534 .688 .938 r
.33141 .28928 .33581 .29207 .34274 .29184 .33835 .28903 Mtetra
.55 .693 .934 r
.33835 .28903 .34274 .29184 .34971 .2915 .34533 .28866 Mtetra
.567 .697 .929 r
.34533 .28866 .34971 .2915 .35671 .29102 .35234 .28816 Mtetra
.584 .702 .924 r
.35234 .28816 .35671 .29102 .36375 .29041 .35939 .28752 Mtetra
.601 .707 .918 r
.35939 .28752 .36375 .29041 .37083 .28964 .36648 .28672 Mtetra
.618 .711 .912 r
.36648 .28672 .37083 .28964 .37794 .2887 .3736 .28575 Mtetra
.636 .716 .905 r
.3736 .28575 .37794 .2887 .38508 .28758 .38076 .2846 Mtetra
.653 .719 .897 r
.38076 .2846 .38508 .28758 .39227 .28625 .38795 .28325 Mtetra
.67 .723 .889 r
.38795 .28325 .39227 .28625 .39948 .28471 .39518 .28167 Mtetra
.686 .726 .88 r
.39518 .28167 .39948 .28471 .40672 .28294 .40244 .27986 Mtetra
.702 .729 .871 r
.40244 .27986 .40672 .28294 .414 .28091 .40973 .2778 Mtetra
.718 .731 .861 r
.40973 .2778 .414 .28091 .42131 .27862 .41705 .27546 Mtetra
.733 .733 .85 r
.41705 .27546 .42131 .27862 .42864 .27602 .4244 .27283 Mtetra
.748 .734 .84 r
.4244 .27283 .42864 .27602 .436 .27312 .43177 .26988 Mtetra
.761 .735 .828 r
.43177 .26988 .436 .27312 .44338 .26988 .43917 .2666 Mtetra
.774 .736 .817 r
.43917 .2666 .44338 .26988 .45078 .26627 .44659 .26294 Mtetra
.787 .736 .806 r
.44659 .26294 .45078 .26627 .4582 .26228 .45402 .2589 Mtetra
.799 .736 .794 r
.45402 .2589 .4582 .26228 .46564 .25786 .46148 .25444 Mtetra
.81 .736 .782 r
.46148 .25444 .46564 .25786 .47308 .25298 .46894 .24953 Mtetra
.822 .737 .771 r
.46894 .24953 .47308 .25298 .48053 .2476 .47641 .24414 Mtetra
.208 .454 .875 r
.62011 .21453 .62403 .21816 .632 .22048 .62809 .21686 Mtetra
.286 .503 .891 r
.62809 .21686 .632 .22048 .64 .22231 .6361 .2187 Mtetra
.352 .543 .901 r
.6361 .2187 .64 .22231 .64802 .22368 .64413 .2201 Mtetra
.407 .576 .907 r
.64413 .2201 .64802 .22368 .65606 .22463 .65218 .22108 Mtetra
.455 .605 .91 r
.65218 .22108 .65606 .22463 .66412 .22518 .66025 .22166 Mtetra
.496 .629 .911 r
.66025 .22166 .66412 .22518 .67219 .22537 .66833 .22188 Mtetra
.531 .649 .91 r
.66833 .22188 .67219 .22537 .68026 .22522 .67642 .22176 Mtetra
.562 .667 .908 r
.67642 .22176 .68026 .22522 .68835 .22475 .68452 .22131 Mtetra
.589 .682 .905 r
.68452 .22131 .68835 .22475 .69644 .22399 .69263 .22057 Mtetra
.613 .694 .901 r
.69263 .22057 .69644 .22399 .70454 .22295 .70074 .21955 Mtetra
.634 .705 .898 r
.70074 .21955 .70454 .22295 .71264 .22165 .70886 .21827 Mtetra
.652 .715 .894 r
.70886 .21827 .71264 .22165 .72075 .22011 .71698 .21675 Mtetra
.668 .723 .89 r
.71698 .21675 .72075 .22011 .72885 .21834 .7251 .21501 Mtetra
.683 .73 .886 r
.7251 .21501 .72885 .21834 .73696 .21638 .73322 .21305 Mtetra
.695 .737 .883 r
.73322 .21305 .73696 .21638 .74506 .21421 .74135 .2109 Mtetra
.707 .742 .879 r
.74135 .2109 .74506 .21421 .75316 .21188 .74947 .20858 Mtetra
.717 .747 .876 r
.74947 .20858 .75316 .21188 .76127 .20938 .75759 .20609 Mtetra
.725 .752 .873 r
.75759 .20609 .76127 .20938 .76937 .20673 .76571 .20345 Mtetra
.733 .756 .871 r
.76571 .20345 .76937 .20673 .77746 .20394 .77383 .20067 Mtetra
.74 .759 .868 r
.77383 .20067 .77746 .20394 .78556 .20103 .78194 .19777 Mtetra
.746 .763 .866 r
.78194 .19777 .78556 .20103 .79365 .19801 .79006 .19476 Mtetra
.752 .766 .864 r
.79006 .19476 .79365 .19801 .80174 .19489 .79817 .19165 Mtetra
.757 .768 .862 r
.79817 .19165 .80174 .19489 .80984 .19169 .80628 .18845 Mtetra
.761 .771 .861 r
.80628 .18845 .80984 .19169 .81793 .1884 .81439 .18517 Mtetra
.764 .773 .86 r
.81439 .18517 .81793 .1884 .82602 .18506 .82251 .18183 Mtetra
.767 .775 .859 r
.82251 .18183 .82602 .18506 .83411 .18165 .83062 .17843 Mtetra
.769 .776 .859 r
.83062 .17843 .83411 .18165 .84221 .17821 .83874 .17499 Mtetra
.771 .778 .858 r
.83874 .17499 .84221 .17821 .8503 .17473 .84686 .17151 Mtetra
.773 .779 .859 r
.84686 .17151 .8503 .17473 .85841 .17122 .85499 .16801 Mtetra
.773 .781 .859 r
.85499 .16801 .85841 .17122 .86652 .16771 .86312 .1645 Mtetra
.437 .66 .955 r
.25943 .28533 .26394 .28792 .27054 .28822 .26604 .28561 Mtetra
.44 .66 .954 r
.26604 .28561 .27054 .28822 .27718 .2885 .27268 .28587 Mtetra
.444 .661 .953 r
.27268 .28587 .27718 .2885 .28384 .28877 .27935 .28612 Mtetra
.451 .663 .952 r
.27935 .28612 .28384 .28877 .29053 .28901 .28606 .28634 Mtetra
.459 .665 .951 r
.28606 .28634 .29053 .28901 .29726 .28921 .29279 .28653 Mtetra
.468 .668 .95 r
.29279 .28653 .29726 .28921 .30402 .28936 .29956 .28666 Mtetra
.479 .672 .949 r
.29956 .28666 .30402 .28936 .31081 .28946 .30636 .28674 Mtetra
.491 .676 .947 r
.30636 .28674 .31081 .28946 .31765 .28948 .3132 .28675 Mtetra
.505 .68 .945 r
.3132 .28675 .31765 .28948 .32451 .28943 .32008 .28667 Mtetra
.519 .685 .942 r
.32008 .28667 .32451 .28943 .33141 .28928 .32699 .2865 Mtetra
.535 .69 .939 r
.32699 .2865 .33141 .28928 .33835 .28903 .33394 .28623 Mtetra
.551 .695 .935 r
.33394 .28623 .33835 .28903 .34533 .28866 .34093 .28584 Mtetra
.568 .7 .931 r
.34093 .28584 .34533 .28866 .35234 .28816 .34795 .28532 Mtetra
.585 .705 .926 r
.34795 .28532 .35234 .28816 .35939 .28752 .35501 .28466 Mtetra
.602 .71 .92 r
.35501 .28466 .35939 .28752 .36648 .28672 .36211 .28383 Mtetra
.62 .715 .914 r
.36211 .28383 .36648 .28672 .3736 .28575 .36924 .28284 Mtetra
.637 .719 .907 r
.36924 .28284 .3736 .28575 .38076 .2846 .37641 .28166 Mtetra
.655 .723 .899 r
.37641 .28166 .38076 .2846 .38795 .28325 .38362 .28028 Mtetra
.672 .727 .891 r
.38362 .28028 .38795 .28325 .39518 .28167 .39086 .27868 Mtetra
.689 .73 .882 r
.39086 .27868 .39518 .28167 .40244 .27986 .39813 .27683 Mtetra
.705 .733 .873 r
.39813 .27683 .40244 .27986 .40973 .2778 .40543 .27474 Mtetra
.721 .736 .863 r
.40543 .27474 .40973 .2778 .41705 .27546 .41277 .27237 Mtetra
.736 .738 .853 r
.41277 .27237 .41705 .27546 .4244 .27283 .42013 .2697 Mtetra
.751 .739 .842 r
.42013 .2697 .4244 .27283 .43177 .26988 .42752 .26671 Mtetra
.764 .74 .831 r
.42752 .26671 .43177 .26988 .43917 .2666 .43493 .26339 Mtetra
.778 .741 .819 r
.43493 .26339 .43917 .2666 .44659 .26294 .44237 .2597 Mtetra
.79 .742 .808 r
.44237 .2597 .44659 .26294 .45402 .2589 .44982 .25562 Mtetra
.802 .742 .796 r
.44982 .25562 .45402 .2589 .46148 .25444 .45729 .25112 Mtetra
.814 .742 .785 r
.45729 .25112 .46148 .25444 .46894 .24953 .46477 .24619 Mtetra
.271 .503 .895 r
.62417 .21335 .62809 .21686 .6361 .2187 .63219 .2152 Mtetra
.338 .544 .906 r
.63219 .2152 .6361 .2187 .64413 .2201 .64023 .21661 Mtetra
.396 .578 .913 r
.64023 .21661 .64413 .2201 .65218 .22108 .64828 .21761 Mtetra
.446 .607 .916 r
.64828 .21761 .65218 .22108 .66025 .22166 .65636 .21822 Mtetra
.488 .632 .916 r
.65636 .21822 .66025 .22166 .66833 .22188 .66445 .21846 Mtetra
.525 .653 .915 r
.66445 .21846 .66833 .22188 .67642 .22176 .67256 .21836 Mtetra
.558 .67 .913 r
.67256 .21836 .67642 .22176 .68452 .22131 .68067 .21793 Mtetra
.586 .685 .91 r
.68067 .21793 .68452 .22131 .69263 .22057 .6888 .21721 Mtetra
.61 .698 .906 r
.6888 .21721 .69263 .22057 .70074 .21955 .69693 .21621 Mtetra
.632 .709 .902 r
.69693 .21621 .70074 .21955 .70886 .21827 .70506 .21494 Mtetra
.65 .718 .898 r
.70506 .21494 .70886 .21827 .71698 .21675 .7132 .21344 Mtetra
.667 .726 .894 r
.7132 .21344 .71698 .21675 .7251 .21501 .72134 .2117 Mtetra
.682 .733 .89 r
.72134 .2117 .7251 .21501 .73322 .21305 .72948 .20976 Mtetra
.695 .74 .886 r
.72948 .20976 .73322 .21305 .74135 .2109 .73762 .20762 Mtetra
.706 .745 .882 r
.73762 .20762 .74135 .2109 .74947 .20858 .74576 .2053 Mtetra
.716 .75 .879 r
.74576 .2053 .74947 .20858 .75759 .20609 .7539 .20282 Mtetra
.725 .754 .875 r
.7539 .20282 .75759 .20609 .76571 .20345 .76204 .20019 Mtetra
.733 .758 .873 r
.76204 .20019 .76571 .20345 .77383 .20067 .77018 .19742 Mtetra
.74 .761 .87 r
.77018 .19742 .77383 .20067 .78194 .19777 .77831 .19452 Mtetra
.746 .764 .868 r
.77831 .19452 .78194 .19777 .79006 .19476 .78645 .19151 Mtetra
.752 .767 .865 r
.78645 .19151 .79006 .19476 .79817 .19165 .79458 .18841 Mtetra
.756 .769 .864 r
.79458 .18841 .79817 .19165 .80628 .18845 .80271 .18521 Mtetra
.76 .772 .862 r
.80271 .18521 .80628 .18845 .81439 .18517 .81085 .18194 Mtetra
.764 .774 .861 r
.81085 .18194 .81439 .18517 .82251 .18183 .81898 .1786 Mtetra
.767 .775 .86 r
.81898 .1786 .82251 .18183 .83062 .17843 .82712 .1752 Mtetra
.769 .777 .859 r
.82712 .1752 .83062 .17843 .83874 .17499 .83526 .17176 Mtetra
.771 .778 .859 r
.83526 .17176 .83874 .17499 .84686 .17151 .8434 .16829 Mtetra
.772 .78 .859 r
.8434 .16829 .84686 .17151 .85499 .16801 .85155 .16479 Mtetra
.773 .781 .859 r
.85155 .16479 .85499 .16801 .86312 .1645 .8597 .16128 Mtetra
.439 .661 .955 r
.25491 .28272 .25943 .28533 .26604 .28561 .26152 .28298 Mtetra
.442 .661 .954 r
.26152 .28298 .26604 .28561 .27268 .28587 .26817 .28324 Mtetra
.446 .662 .954 r
.26817 .28324 .27268 .28587 .27935 .28612 .27485 .28347 Mtetra
.452 .664 .953 r
.27485 .28347 .27935 .28612 .28606 .28634 .28156 .28368 Mtetra
.46 .667 .952 r
.28156 .28368 .28606 .28634 .29279 .28653 .2883 .28385 Mtetra
.469 .67 .951 r
.2883 .28385 .29279 .28653 .29956 .28666 .29508 .28397 Mtetra
.48 .673 .949 r
.29508 .28397 .29956 .28666 .30636 .28674 .30189 .28403 Mtetra
.492 .678 .948 r
.30189 .28403 .30636 .28674 .3132 .28675 .30874 .28402 Mtetra
.506 .682 .946 r
.30874 .28402 .3132 .28675 .32008 .28667 .31562 .28392 Mtetra
.52 .687 .943 r
.31562 .28392 .32008 .28667 .32699 .2865 .32254 .28374 Mtetra
.535 .693 .94 r
.32254 .28374 .32699 .2865 .33394 .28623 .3295 .28345 Mtetra
.552 .698 .937 r
.3295 .28345 .33394 .28623 .34093 .28584 .3365 .28304 Mtetra
.568 .703 .933 r
.3365 .28304 .34093 .28584 .34795 .28532 .34353 .2825 Mtetra
.586 .708 .928 r
.34353 .2825 .34795 .28532 .35501 .28466 .3506 .28182 Mtetra
.603 .714 .922 r
.3506 .28182 .35501 .28466 .36211 .28383 .35771 .28097 Mtetra
.621 .719 .916 r
.35771 .28097 .36211 .28383 .36924 .28284 .36486 .27996 Mtetra
.638 .723 .909 r
.36486 .27996 .36924 .28284 .37641 .28166 .37204 .27876 Mtetra
.656 .728 .902 r
.37204 .27876 .37641 .28166 .38362 .28028 .37926 .27735 Mtetra
.673 .731 .894 r
.37926 .27735 .38362 .28028 .39086 .27868 .38651 .27572 Mtetra
.69 .735 .885 r
.38651 .27572 .39086 .27868 .39813 .27683 .39379 .27386 Mtetra
.707 .738 .875 r
.39379 .27386 .39813 .27683 .40543 .27474 .40111 .27173 Mtetra
.723 .741 .866 r
.40111 .27173 .40543 .27474 .41277 .27237 .40846 .26933 Mtetra
.738 .743 .855 r
.40846 .26933 .41277 .27237 .42013 .2697 .41584 .26663 Mtetra
.753 .744 .844 r
.41584 .26663 .42013 .2697 .42752 .26671 .42325 .26362 Mtetra
.767 .746 .833 r
.42325 .26362 .42752 .26671 .43493 .26339 .43068 .26026 Mtetra
.781 .747 .822 r
.43068 .26026 .43493 .26339 .44237 .2597 .43813 .25653 Mtetra
.794 .747 .81 r
.43813 .25653 .44237 .2597 .44982 .25562 .4456 .25242 Mtetra
.806 .748 .799 r
.4456 .25242 .44982 .25562 .45729 .25112 .45309 .2479 Mtetra
.817 .748 .787 r
.45309 .2479 .45729 .25112 .46477 .24619 .46059 .24295 Mtetra
.257 .503 .899 r
.62024 .20993 .62417 .21335 .63219 .2152 .62826 .21178 Mtetra
.326 .545 .911 r
.62826 .21178 .63219 .2152 .64023 .21661 .63631 .21321 Mtetra
.385 .58 .918 r
.63631 .21321 .64023 .21661 .64828 .21761 .64438 .21422 Mtetra
.437 .61 .921 r
.64438 .21422 .64828 .21761 .65636 .21822 .65247 .21485 Mtetra
.482 .635 .922 r
.65247 .21485 .65636 .21822 .66445 .21846 .66057 .2151 Mtetra
.52 .656 .921 r
.66057 .2151 .66445 .21846 .67256 .21836 .66869 .21502 Mtetra
.554 .674 .918 r
.66869 .21502 .67256 .21836 .68067 .21793 .67682 .21461 Mtetra
.583 .689 .915 r
.67682 .21461 .68067 .21793 .6888 .21721 .68495 .2139 Mtetra
.608 .702 .91 r
.68495 .2139 .6888 .21721 .69693 .21621 .6931 .21291 Mtetra
.63 .713 .906 r
.6931 .21291 .69693 .21621 .70506 .21494 .70125 .21166 Mtetra
.649 .722 .902 r
.70125 .21166 .70506 .21494 .7132 .21344 .7094 .21016 Mtetra
.666 .73 .897 r
.7094 .21016 .7132 .21344 .72134 .2117 .71756 .20843 Mtetra
.681 .737 .893 r
.71756 .20843 .72134 .2117 .72948 .20976 .72572 .20649 Mtetra
.694 .743 .889 r
.72572 .20649 .72948 .20976 .73762 .20762 .73388 .20436 Mtetra
.706 .748 .885 r
.73388 .20436 .73762 .20762 .74576 .2053 .74204 .20205 Mtetra
.716 .752 .881 r
.74204 .20205 .74576 .2053 .7539 .20282 .75019 .19957 Mtetra
.725 .756 .878 r
.75019 .19957 .7539 .20282 .76204 .20019 .75835 .19694 Mtetra
.733 .76 .875 r
.75835 .19694 .76204 .20019 .77018 .19742 .76651 .19418 Mtetra
.74 .763 .872 r
.76651 .19418 .77018 .19742 .77831 .19452 .77466 .19128 Mtetra
.746 .766 .869 r
.77466 .19128 .77831 .19452 .78645 .19151 .78282 .18828 Mtetra
.751 .769 .867 r
.78282 .18828 .78645 .19151 .79458 .18841 .79097 .18517 Mtetra
.756 .771 .865 r
.79097 .18517 .79458 .18841 .80271 .18521 .79913 .18197 Mtetra
.76 .773 .863 r
.79913 .18197 .80271 .18521 .81085 .18194 .80728 .1787 Mtetra
.764 .775 .862 r
.80728 .1787 .81085 .18194 .81898 .1786 .81544 .17536 Mtetra
.766 .776 .861 r
.81544 .17536 .81898 .1786 .82712 .1752 .82359 .17196 Mtetra
.769 .778 .86 r
.82359 .17196 .82712 .1752 .83526 .17176 .83175 .16852 Mtetra
.77 .779 .86 r
.83175 .16852 .83526 .17176 .8434 .16829 .83992 .16505 Mtetra
.772 .78 .86 r
.83992 .16505 .8434 .16829 .85155 .16479 .84809 .16155 Mtetra
.772 .781 .86 r
.84809 .16155 .85155 .16479 .8597 .16128 .85626 .15804 Mtetra
.44 .661 .955 r
.25035 .2801 .25491 .28272 .26152 .28298 .25698 .28035 Mtetra
.443 .662 .954 r
.25698 .28035 .26152 .28298 .26817 .28324 .26363 .28059 Mtetra
.447 .663 .954 r
.26363 .28059 .26817 .28324 .27485 .28347 .27032 .28082 Mtetra
.453 .665 .953 r
.27032 .28082 .27485 .28347 .28156 .28368 .27704 .28101 Mtetra
.461 .668 .952 r
.27704 .28101 .28156 .28368 .2883 .28385 .28379 .28116 Mtetra
.47 .671 .951 r
.28379 .28116 .2883 .28385 .29508 .28397 .29057 .28127 Mtetra
.48 .675 .95 r
.29057 .28127 .29508 .28397 .30189 .28403 .29739 .28132 Mtetra
.493 .679 .949 r
.29739 .28132 .30189 .28403 .30874 .28402 .30425 .28129 Mtetra
.506 .684 .947 r
.30425 .28129 .30874 .28402 .31562 .28392 .31114 .28119 Mtetra
.52 .689 .945 r
.31114 .28119 .31562 .28392 .32254 .28374 .31807 .28099 Mtetra
.536 .695 .942 r
.31807 .28099 .32254 .28374 .3295 .28345 .32504 .28068 Mtetra
.552 .7 .938 r
.32504 .28068 .3295 .28345 .3365 .28304 .33205 .28026 Mtetra
.569 .706 .934 r
.33205 .28026 .3365 .28304 .34353 .2825 .33909 .2797 Mtetra
.586 .711 .93 r
.33909 .2797 .34353 .2825 .3506 .28182 .34617 .279 Mtetra
.604 .717 .924 r
.34617 .279 .3506 .28182 .35771 .28097 .35329 .27814 Mtetra
.621 .722 .918 r
.35329 .27814 .35771 .28097 .36486 .27996 .36045 .27711 Mtetra
.639 .727 .912 r
.36045 .27711 .36486 .27996 .37204 .27876 .36764 .27589 Mtetra
.657 .731 .904 r
.36764 .27589 .37204 .27876 .37926 .27735 .37487 .27446 Mtetra
.675 .736 .896 r
.37487 .27446 .37926 .27735 .38651 .27572 .38213 .27281 Mtetra
.692 .739 .887 r
.38213 .27281 .38651 .27572 .39379 .27386 .38943 .27093 Mtetra
.709 .743 .878 r
.38943 .27093 .39379 .27386 .40111 .27173 .39677 .26878 Mtetra
.725 .746 .868 r
.39677 .26878 .40111 .27173 .40846 .26933 .40413 .26635 Mtetra
.741 .748 .858 r
.40413 .26635 .40846 .26933 .41584 .26663 .41152 .26363 Mtetra
.756 .75 .847 r
.41152 .26363 .41584 .26663 .42325 .26362 .41895 .26059 Mtetra
.77 .751 .836 r
.41895 .26059 .42325 .26362 .43068 .26026 .42639 .2572 Mtetra
.784 .752 .824 r
.42639 .2572 .43068 .26026 .43813 .25653 .43386 .25345 Mtetra
.797 .753 .813 r
.43386 .25345 .43813 .25653 .4456 .25242 .44135 .24931 Mtetra
.809 .753 .801 r
.44135 .24931 .4456 .25242 .45309 .2479 .44886 .24477 Mtetra
.82 .754 .79 r
.44886 .24477 .45309 .2479 .46059 .24295 .45638 .23981 Mtetra
.243 .504 .902 r
.6163 .20662 .62024 .20993 .62826 .21178 .62432 .20847 Mtetra
.313 .546 .915 r
.62432 .20847 .62826 .21178 .63631 .21321 .63238 .20989 Mtetra
.375 .582 .923 r
.63238 .20989 .63631 .21321 .64438 .21422 .64046 .21092 Mtetra
.429 .613 .927 r
.64046 .21092 .64438 .21422 .65247 .21485 .64856 .21155 Mtetra
.475 .639 .927 r
.64856 .21155 .65247 .21485 .66057 .2151 .65667 .21182 Mtetra
.515 .66 .926 r
.65667 .21182 .66057 .2151 .66869 .21502 .6648 .21175 Mtetra
.55 .678 .923 r
.6648 .21175 .66869 .21502 .67682 .21461 .67295 .21135 Mtetra
.58 .693 .919 r
.67295 .21135 .67682 .21461 .68495 .2139 .6811 .21065 Mtetra
.606 .706 .915 r
.6811 .21065 .68495 .2139 .6931 .21291 .68926 .20966 Mtetra
.628 .717 .91 r
.68926 .20966 .6931 .21291 .70125 .21166 .69742 .20841 Mtetra
.648 .726 .905 r
.69742 .20841 .70125 .21166 .7094 .21016 .70559 .20692 Mtetra
.665 .733 .901 r
.70559 .20692 .7094 .21016 .71756 .20843 .71377 .2052 Mtetra
.68 .74 .896 r
.71377 .2052 .71756 .20843 .72572 .20649 .72194 .20326 Mtetra
.694 .746 .891 r
.72194 .20326 .72572 .20649 .73388 .20436 .73012 .20113 Mtetra
.705 .751 .887 r
.73012 .20113 .73388 .20436 .74204 .20205 .7383 .19882 Mtetra
.716 .755 .883 r
.7383 .19882 .74204 .20205 .75019 .19957 .74647 .19634 Mtetra
.725 .759 .88 r
.74647 .19634 .75019 .19957 .75835 .19694 .75465 .19372 Mtetra
.733 .762 .876 r
.75465 .19372 .75835 .19694 .76651 .19418 .76283 .19095 Mtetra
.74 .765 .873 r
.76283 .19095 .76651 .19418 .77466 .19128 .771 .18805 Mtetra
.746 .768 .871 r
.771 .18805 .77466 .19128 .78282 .18828 .77918 .18505 Mtetra
.751 .77 .868 r
.77918 .18505 .78282 .18828 .79097 .18517 .78735 .18194 Mtetra
.756 .772 .866 r
.78735 .18194 .79097 .18517 .79913 .18197 .79552 .17874 Mtetra
.76 .774 .864 r
.79552 .17874 .79913 .18197 .80728 .1787 .8037 .17546 Mtetra
.764 .776 .863 r
.8037 .17546 .80728 .1787 .81544 .17536 .81188 .17212 Mtetra
.766 .777 .862 r
.81188 .17212 .81544 .17536 .82359 .17196 .82005 .16872 Mtetra
.769 .778 .861 r
.82005 .16872 .82359 .17196 .83175 .16852 .82823 .16528 Mtetra
.77 .779 .86 r
.82823 .16528 .83175 .16852 .83992 .16505 .83642 .1618 Mtetra
.771 .78 .86 r
.83642 .1618 .83992 .16505 .84809 .16155 .84461 .1583 Mtetra
.772 .781 .86 r
.84461 .1583 .84809 .16155 .85626 .15804 .85281 .15478 Mtetra
.441 .662 .955 r
.24578 .27747 .25035 .2801 .25698 .28035 .25241 .27771 Mtetra
.444 .662 .954 r
.25241 .27771 .25698 .28035 .26363 .28059 .25908 .27794 Mtetra
.448 .664 .954 r
.25908 .27794 .26363 .28059 .27032 .28082 .26577 .27815 Mtetra
.453 .666 .954 r
.26577 .27815 .27032 .28082 .27704 .28101 .27249 .27834 Mtetra
.461 .669 .953 r
.27249 .27834 .27704 .28101 .28379 .28116 .27925 .27848 Mtetra
.47 .672 .952 r
.27925 .27848 .28379 .28116 .29057 .28127 .28604 .27858 Mtetra
.48 .676 .951 r
.28604 .27858 .29057 .28127 .29739 .28132 .29287 .27861 Mtetra
.492 .681 .95 r
.29287 .27861 .29739 .28132 .30425 .28129 .29974 .27858 Mtetra
.506 .686 .948 r
.29974 .27858 .30425 .28129 .31114 .28119 .30664 .27846 Mtetra
.52 .691 .946 r
.30664 .27846 .31114 .28119 .31807 .28099 .31358 .27825 Mtetra
.535 .697 .943 r
.31358 .27825 .31807 .28099 .32504 .28068 .32055 .27793 Mtetra
.552 .703 .94 r
.32055 .27793 .32504 .28068 .33205 .28026 .32757 .2775 Mtetra
.569 .709 .936 r
.32757 .2775 .33205 .28026 .33909 .2797 .33462 .27693 Mtetra
.586 .714 .932 r
.33462 .27693 .33909 .2797 .34617 .279 .34171 .27621 Mtetra
.604 .72 .927 r
.34171 .27621 .34617 .279 .35329 .27814 .34884 .27534 Mtetra
.622 .725 .921 r
.34884 .27534 .35329 .27814 .36045 .27711 .35601 .27429 Mtetra
.64 .731 .914 r
.35601 .27429 .36045 .27711 .36764 .27589 .36322 .27306 Mtetra
.658 .735 .907 r
.36322 .27306 .36764 .27589 .37487 .27446 .37046 .27162 Mtetra
.676 .74 .899 r
.37046 .27162 .37487 .27446 .38213 .27281 .37774 .26995 Mtetra
.693 .744 .89 r
.37774 .26995 .38213 .27281 .38943 .27093 .38505 .26804 Mtetra
.71 .747 .881 r
.38505 .26804 .38943 .27093 .39677 .26878 .3924 .26588 Mtetra
.727 .75 .871 r
.3924 .26588 .39677 .26878 .40413 .26635 .39977 .26344 Mtetra
.743 .753 .861 r
.39977 .26344 .40413 .26635 .41152 .26363 .40718 .26069 Mtetra
.758 .755 .85 r
.40718 .26069 .41152 .26363 .41895 .26059 .41462 .25763 Mtetra
.773 .757 .839 r
.41462 .25763 .41895 .26059 .42639 .2572 .42209 .25422 Mtetra
.787 .758 .827 r
.42209 .25422 .42639 .2572 .43386 .25345 .42957 .25045 Mtetra
.8 .759 .815 r
.42957 .25045 .43386 .25345 .44135 .24931 .43708 .24629 Mtetra
.812 .759 .804 r
.43708 .24629 .44135 .24931 .44886 .24477 .44461 .24173 Mtetra
.823 .76 .793 r
.44461 .24173 .44886 .24477 .45638 .23981 .45215 .23676 Mtetra
.229 .504 .905 r
.61234 .2034 .6163 .20662 .62432 .20847 .62037 .20524 Mtetra
.301 .547 .919 r
.62037 .20524 .62432 .20847 .63238 .20989 .62843 .20667 Mtetra
.365 .585 .928 r
.62843 .20667 .63238 .20989 .64046 .21092 .63652 .20769 Mtetra
.421 .616 .932 r
.63652 .20769 .64046 .21092 .64856 .21155 .64463 .20833 Mtetra
.469 .643 .933 r
.64463 .20833 .64856 .21155 .65667 .21182 .65276 .20861 Mtetra
.51 .664 .931 r
.65276 .20861 .65667 .21182 .6648 .21175 .66091 .20854 Mtetra
.546 .683 .928 r
.66091 .20854 .6648 .21175 .67295 .21135 .66906 .20814 Mtetra
.577 .698 .924 r
.66906 .20814 .67295 .21135 .6811 .21065 .67723 .20744 Mtetra
.604 .71 .919 r
.67723 .20744 .6811 .21065 .68926 .20966 .6854 .20646 Mtetra
.627 .721 .914 r
.6854 .20646 .68926 .20966 .69742 .20841 .69358 .20521 Mtetra
.647 .73 .909 r
.69358 .20521 .69742 .20841 .70559 .20692 .70177 .20372 Mtetra
.665 .737 .904 r
.70177 .20372 .70559 .20692 .71377 .2052 .70996 .202 Mtetra
.68 .744 .899 r
.70996 .202 .71377 .2052 .72194 .20326 .71815 .20006 Mtetra
.694 .749 .894 r
.71815 .20006 .72194 .20326 .73012 .20113 .72635 .19793 Mtetra
.705 .754 .89 r
.72635 .19793 .73012 .20113 .7383 .19882 .73454 .19562 Mtetra
.716 .758 .886 r
.73454 .19562 .7383 .19882 .74647 .19634 .74274 .19314 Mtetra
.725 .762 .882 r
.74274 .19314 .74647 .19634 .75465 .19372 .75093 .1905 Mtetra
.733 .765 .878 r
.75093 .1905 .75465 .19372 .76283 .19095 .75913 .18773 Mtetra
.74 .767 .875 r
.75913 .18773 .76283 .19095 .771 .18805 .76732 .18483 Mtetra
.746 .77 .872 r
.76732 .18483 .771 .18805 .77918 .18505 .77552 .18182 Mtetra
.752 .772 .869 r
.77552 .18182 .77918 .18505 .78735 .18194 .78371 .17871 Mtetra
.756 .774 .867 r
.78371 .17871 .78735 .18194 .79552 .17874 .79191 .1755 Mtetra
.76 .775 .865 r
.79191 .1755 .79552 .17874 .8037 .17546 .8001 .17222 Mtetra
.764 .777 .864 r
.8001 .17222 .8037 .17546 .81188 .17212 .8083 .16887 Mtetra
.766 .778 .862 r
.8083 .16887 .81188 .17212 .82005 .16872 .8165 .16547 Mtetra
.769 .779 .861 r
.8165 .16547 .82005 .16872 .82823 .16528 .8247 .16202 Mtetra
.77 .78 .861 r
.8247 .16202 .82823 .16528 .83642 .1618 .8329 .15854 Mtetra
.771 .78 .86 r
.8329 .15854 .83642 .1618 .84461 .1583 .84112 .15503 Mtetra
.772 .781 .86 r
.84112 .15503 .84461 .1583 .85281 .15478 .84934 .15151 Mtetra
.442 .662 .955 r
.24119 .27483 .24578 .27747 .25241 .27771 .24783 .27506 Mtetra
.444 .663 .955 r
.24783 .27506 .25241 .27771 .25908 .27794 .25449 .27528 Mtetra
.448 .664 .954 r
.25449 .27528 .25908 .27794 .26577 .27815 .26119 .27549 Mtetra
.453 .666 .954 r
.26119 .27549 .26577 .27815 .27249 .27834 .26793 .27566 Mtetra
.461 .669 .953 r
.26793 .27566 .27249 .27834 .27925 .27848 .27469 .2758 Mtetra
.469 .673 .953 r
.27469 .2758 .27925 .27848 .28604 .27858 .28149 .27589 Mtetra
.48 .677 .952 r
.28149 .27589 .28604 .27858 .29287 .27861 .28833 .27591 Mtetra
.492 .682 .951 r
.28833 .27591 .29287 .27861 .29974 .27858 .2952 .27587 Mtetra
.505 .687 .949 r
.2952 .27587 .29974 .27858 .30664 .27846 .30211 .27575 Mtetra
.519 .693 .947 r
.30211 .27575 .30664 .27846 .31358 .27825 .30906 .27552 Mtetra
.535 .699 .945 r
.30906 .27552 .31358 .27825 .32055 .27793 .31604 .2752 Mtetra
.551 .705 .942 r
.31604 .2752 .32055 .27793 .32757 .2775 .32307 .27475 Mtetra
.568 .711 .938 r
.32307 .27475 .32757 .2775 .33462 .27693 .33013 .27417 Mtetra
.586 .717 .934 r
.33013 .27417 .33462 .27693 .34171 .27621 .33723 .27345 Mtetra
.604 .723 .929 r
.33723 .27345 .34171 .27621 .34884 .27534 .34437 .27257 Mtetra
.622 .729 .923 r
.34437 .27257 .34884 .27534 .35601 .27429 .35155 .27151 Mtetra
.64 .734 .917 r
.35155 .27151 .35601 .27429 .36322 .27306 .35877 .27026 Mtetra
.658 .739 .91 r
.35877 .27026 .36322 .27306 .37046 .27162 .36602 .26881 Mtetra
.676 .744 .902 r
.36602 .26881 .37046 .27162 .37774 .26995 .37331 .26713 Mtetra
.694 .748 .893 r
.37331 .26713 .37774 .26995 .38505 .26804 .38064 .26521 Mtetra
.711 .752 .884 r
.38064 .26521 .38505 .26804 .3924 .26588 .388 .26304 Mtetra
.728 .755 .874 r
.388 .26304 .3924 .26588 .39977 .26344 .39539 .26058 Mtetra
.744 .758 .864 r
.39539 .26058 .39977 .26344 .40718 .26069 .40282 .25782 Mtetra
.76 .761 .853 r
.40282 .25782 .40718 .26069 .41462 .25763 .41027 .25474 Mtetra
.775 .762 .842 r
.41027 .25474 .41462 .25763 .42209 .25422 .41775 .25132 Mtetra
.789 .764 .83 r
.41775 .25132 .42209 .25422 .42957 .25045 .42526 .24753 Mtetra
.802 .765 .818 r
.42526 .24753 .42957 .25045 .43708 .24629 .43279 .24336 Mtetra
.815 .765 .807 r
.43279 .24336 .43708 .24629 .44461 .24173 .44033 .23878 Mtetra
.826 .765 .795 r
.44033 .23878 .44461 .24173 .45215 .23676 .44789 .2338 Mtetra
.216 .504 .907 r
.60836 .20026 .61234 .2034 .62037 .20524 .6164 .2021 Mtetra
.289 .549 .922 r
.6164 .2021 .62037 .20524 .62843 .20667 .62448 .20353 Mtetra
.355 .588 .932 r
.62448 .20353 .62843 .20667 .63652 .20769 .63258 .20455 Mtetra
.413 .62 .937 r
.63258 .20455 .63652 .20769 .64463 .20833 .6407 .20519 Mtetra
.463 .647 .938 r
.6407 .20519 .64463 .20833 .65276 .20861 .64884 .20547 Mtetra
.506 .669 .936 r
.64884 .20547 .65276 .20861 .66091 .20854 .65699 .20539 Mtetra
.543 .687 .933 r
.65699 .20539 .66091 .20854 .66906 .20814 .66516 .205 Mtetra
.575 .702 .929 r
.66516 .205 .66906 .20814 .67723 .20744 .67334 .20429 Mtetra
.603 .715 .923 r
.67334 .20429 .67723 .20744 .6854 .20646 .68153 .20331 Mtetra
.626 .725 .918 r
.68153 .20331 .6854 .20646 .69358 .20521 .68973 .20206 Mtetra
.647 .734 .913 r
.68973 .20206 .69358 .20521 .70177 .20372 .69793 .20056 Mtetra
.665 .741 .907 r
.69793 .20056 .70177 .20372 .70996 .202 .70614 .19883 Mtetra
.68 .747 .902 r
.70614 .19883 .70996 .202 .71815 .20006 .71435 .19689 Mtetra
.694 .752 .897 r
.71435 .19689 .71815 .20006 .72635 .19793 .72256 .19475 Mtetra
.706 .757 .892 r
.72256 .19475 .72635 .19793 .73454 .19562 .73077 .19243 Mtetra
.716 .761 .888 r
.73077 .19243 .73454 .19562 .74274 .19314 .73899 .18995 Mtetra
.725 .764 .884 r
.73899 .18995 .74274 .19314 .75093 .1905 .7472 .18731 Mtetra
.733 .767 .88 r
.7472 .18731 .75093 .1905 .75913 .18773 .75541 .18453 Mtetra
.74 .77 .876 r
.75541 .18453 .75913 .18773 .76732 .18483 .76363 .18162 Mtetra
.747 .772 .873 r
.76363 .18162 .76732 .18483 .77552 .18182 .77184 .1786 Mtetra
.752 .774 .871 r
.77184 .1786 .77552 .18182 .78371 .17871 .78006 .17548 Mtetra
.757 .775 .868 r
.78006 .17548 .78371 .17871 .79191 .1755 .78827 .17227 Mtetra
.76 .777 .866 r
.78827 .17227 .79191 .1755 .8001 .17222 .79649 .16898 Mtetra
.764 .778 .864 r
.79649 .16898 .8001 .17222 .8083 .16887 .8047 .16562 Mtetra
.766 .779 .863 r
.8047 .16562 .8083 .16887 .8165 .16547 .81292 .16221 Mtetra
.769 .78 .862 r
.81292 .16221 .8165 .16547 .8247 .16202 .82114 .15875 Mtetra
.77 .78 .861 r
.82114 .15875 .8247 .16202 .8329 .15854 .82937 .15526 Mtetra
.771 .781 .861 r
.82937 .15526 .8329 .15854 .84112 .15503 .8376 .15175 Mtetra
.772 .781 .861 r
.8376 .15175 .84112 .15503 .84934 .15151 .84584 .14822 Mtetra
.442 .662 .955 r
.23657 .27217 .24119 .27483 .24783 .27506 .24321 .2724 Mtetra
.444 .663 .955 r
.24321 .2724 .24783 .27506 .25449 .27528 .24989 .27261 Mtetra
.447 .664 .955 r
.24989 .27261 .25449 .27528 .26119 .27549 .2566 .27281 Mtetra
.453 .667 .954 r
.2566 .27281 .26119 .27549 .26793 .27566 .26333 .27298 Mtetra
.46 .67 .954 r
.26333 .27298 .26793 .27566 .27469 .2758 .27011 .27311 Mtetra
.469 .674 .954 r
.27011 .27311 .27469 .2758 .28149 .27589 .27691 .2732 Mtetra
.479 .678 .953 r
.27691 .2732 .28149 .27589 .28833 .27591 .28376 .27322 Mtetra
.491 .683 .952 r
.28376 .27322 .28833 .27591 .2952 .27587 .29064 .27317 Mtetra
.504 .689 .95 r
.29064 .27317 .2952 .27587 .30211 .27575 .29755 .27304 Mtetra
.518 .695 .949 r
.29755 .27304 .30211 .27575 .30906 .27552 .30451 .27281 Mtetra
.534 .701 .946 r
.30451 .27281 .30906 .27552 .31604 .2752 .3115 .27248 Mtetra
.55 .707 .944 r
.3115 .27248 .31604 .2752 .32307 .27475 .31854 .27203 Mtetra
.567 .713 .94 r
.31854 .27203 .32307 .27475 .33013 .27417 .32561 .27144 Mtetra
.585 .72 .936 r
.32561 .27144 .33013 .27417 .33723 .27345 .33272 .27071 Mtetra
.603 .726 .931 r
.33272 .27071 .33723 .27345 .34437 .27257 .33987 .26982 Mtetra
.621 .732 .926 r
.33987 .26982 .34437 .27257 .35155 .27151 .34706 .26876 Mtetra
.64 .738 .92 r
.34706 .26876 .35155 .27151 .35877 .27026 .35429 .2675 Mtetra
.658 .743 .913 r
.35429 .2675 .35877 .27026 .36602 .26881 .36156 .26604 Mtetra
.677 .748 .905 r
.36156 .26604 .36602 .26881 .37331 .26713 .36886 .26436 Mtetra
.695 .753 .896 r
.36886 .26436 .37331 .26713 .38064 .26521 .3762 .26243 Mtetra
.712 .757 .887 r
.3762 .26243 .38064 .26521 .388 .26304 .38358 .26025 Mtetra
.729 .76 .877 r
.38358 .26025 .388 .26304 .39539 .26058 .39098 .25778 Mtetra
.746 .763 .867 r
.39098 .25778 .39539 .26058 .40282 .25782 .39842 .25501 Mtetra
.762 .766 .856 r
.39842 .25501 .40282 .25782 .41027 .25474 .40589 .25192 Mtetra
.777 .768 .845 r
.40589 .25192 .41027 .25474 .41775 .25132 .41339 .24849 Mtetra
.791 .769 .833 r
.41339 .24849 .41775 .25132 .42526 .24753 .42092 .24469 Mtetra
.805 .77 .821 r
.42092 .24469 .42526 .24753 .43279 .24336 .42846 .24051 Mtetra
.817 .771 .809 r
.42846 .24051 .43279 .24336 .44033 .23878 .43603 .23593 Mtetra
.829 .771 .798 r
.43603 .23593 .44033 .23878 .44789 .2338 .44361 .23093 Mtetra
.201 .504 .908 r
.60437 .19722 .60836 .20026 .6164 .2021 .61242 .19905 Mtetra
.277 .551 .926 r
.61242 .19905 .6164 .2021 .62448 .20353 .6205 .20047 Mtetra
.345 .591 .936 r
.6205 .20047 .62448 .20353 .63258 .20455 .62861 .20149 Mtetra
.406 .624 .942 r
.62861 .20149 .63258 .20455 .6407 .20519 .63674 .20213 Mtetra
.458 .652 .943 r
.63674 .20213 .6407 .20519 .64884 .20547 .6449 .20239 Mtetra
.502 .674 .941 r
.6449 .20239 .64884 .20547 .65699 .20539 .65306 .20231 Mtetra
.541 .692 .938 r
.65306 .20231 .65699 .20539 .66516 .205 .66125 .20191 Mtetra
.573 .707 .933 r
.66125 .20191 .66516 .205 .67334 .20429 .66944 .2012 Mtetra
.601 .72 .928 r
.66944 .2012 .67334 .20429 .68153 .20331 .67765 .20021 Mtetra
.626 .73 .922 r
.67765 .20021 .68153 .20331 .68973 .20206 .68586 .19895 Mtetra
.647 .738 .916 r
.68586 .19895 .68973 .20206 .69793 .20056 .69408 .19744 Mtetra
.665 .745 .91 r
.69408 .19744 .69793 .20056 .70614 .19883 .7023 .1957 Mtetra
.68 .751 .905 r
.7023 .1957 .70614 .19883 .71435 .19689 .71053 .19375 Mtetra
.694 .756 .899 r
.71053 .19375 .71435 .19689 .72256 .19475 .71876 .19161 Mtetra
.706 .76 .894 r
.71876 .19161 .72256 .19475 .73077 .19243 .72699 .18928 Mtetra
.717 .764 .89 r
.72699 .18928 .73077 .19243 .73899 .18995 .73522 .18678 Mtetra
.726 .767 .885 r
.73522 .18678 .73899 .18995 .7472 .18731 .74345 .18413 Mtetra
.734 .77 .881 r
.74345 .18413 .7472 .18731 .75541 .18453 .75168 .18134 Mtetra
.741 .772 .878 r
.75168 .18134 .75541 .18453 .76363 .18162 .75992 .17842 Mtetra
.747 .774 .875 r
.75992 .17842 .76363 .18162 .77184 .1786 .76815 .17539 Mtetra
.752 .775 .872 r
.76815 .17539 .77184 .1786 .78006 .17548 .77638 .17226 Mtetra
.757 .777 .869 r
.77638 .17226 .78006 .17548 .78827 .17227 .78462 .16904 Mtetra
.761 .778 .867 r
.78462 .16904 .78827 .17227 .79649 .16898 .79285 .16574 Mtetra
.764 .779 .865 r
.79285 .16574 .79649 .16898 .8047 .16562 .80109 .16237 Mtetra
.767 .78 .864 r
.80109 .16237 .8047 .16562 .81292 .16221 .80933 .15895 Mtetra
.769 .78 .862 r
.80933 .15895 .81292 .16221 .82114 .15875 .81757 .15548 Mtetra
.77 .781 .861 r
.81757 .15548 .82114 .15875 .82937 .15526 .82582 .15197 Mtetra
.771 .781 .861 r
.82582 .15197 .82937 .15526 .8376 .15175 .83407 .14845 Mtetra
.772 .781 .861 r
.83407 .14845 .8376 .15175 .84584 .14822 .84233 .14491 Mtetra
.441 .662 .955 r
.23193 .2695 .23657 .27217 .24321 .2724 .23858 .26972 Mtetra
.443 .663 .955 r
.23858 .26972 .24321 .2724 .24989 .27261 .24526 .26994 Mtetra
.446 .664 .955 r
.24526 .26994 .24989 .27261 .2566 .27281 .25197 .27013 Mtetra
.452 .667 .955 r
.25197 .27013 .2566 .27281 .26333 .27298 .25872 .2703 Mtetra
.459 .67 .955 r
.25872 .2703 .26333 .27298 .27011 .27311 .2655 .27043 Mtetra
.467 .674 .954 r
.2655 .27043 .27011 .27311 .27691 .2732 .27231 .27051 Mtetra
.478 .679 .954 r
.27231 .27051 .27691 .2732 .28376 .27322 .27916 .27053 Mtetra
.489 .684 .953 r
.27916 .27053 .28376 .27322 .29064 .27317 .28605 .27048 Mtetra
.502 .69 .952 r
.28605 .27048 .29064 .27317 .29755 .27304 .29298 .27034 Mtetra
.517 .696 .95 r
.29298 .27034 .29755 .27304 .30451 .27281 .29994 .27011 Mtetra
.532 .702 .948 r
.29994 .27011 .30451 .27281 .3115 .27248 .30694 .26978 Mtetra
.549 .709 .946 r
.30694 .26978 .3115 .27248 .31854 .27203 .31398 .26932 Mtetra
.566 .715 .942 r
.31398 .26932 .31854 .27203 .32561 .27144 .32107 .26874 Mtetra
.584 .722 .938 r
.32107 .26874 .32561 .27144 .33272 .27071 .32819 .268 Mtetra
.602 .729 .934 r
.32819 .268 .33272 .27071 .33987 .26982 .33535 .26711 Mtetra
.62 .735 .929 r
.33535 .26711 .33987 .26982 .34706 .26876 .34255 .26604 Mtetra
.639 .741 .922 r
.34255 .26604 .34706 .26876 .35429 .2675 .34979 .26478 Mtetra
.658 .747 .916 r
.34979 .26478 .35429 .2675 .36156 .26604 .35707 .26332 Mtetra
.676 .752 .908 r
.35707 .26332 .36156 .26604 .36886 .26436 .36438 .26163 Mtetra
.695 .757 .9 r
.36438 .26163 .36886 .26436 .3762 .26243 .37174 .2597 Mtetra
.713 .761 .891 r
.37174 .2597 .3762 .26243 .38358 .26025 .37912 .25751 Mtetra
.73 .765 .881 r
.37912 .25751 .38358 .26025 .39098 .25778 .38655 .25504 Mtetra
.747 .769 .871 r
.38655 .25504 .39098 .25778 .39842 .25501 .394 .25227 Mtetra
.763 .771 .86 r
.394 .25227 .39842 .25501 .40589 .25192 .40149 .24918 Mtetra
.779 .774 .848 r
.40149 .24918 .40589 .25192 .41339 .24849 .40901 .24574 Mtetra
.793 .775 .836 r
.40901 .24574 .41339 .24849 .42092 .24469 .41655 .24194 Mtetra
.807 .776 .824 r
.41655 .24194 .42092 .24469 .42846 .24051 .42411 .23775 Mtetra
.82 .777 .812 r
.42411 .23775 .42846 .24051 .43603 .23593 .4317 .23316 Mtetra
.832 .777 .801 r
.4317 .23316 .43603 .23593 .44361 .23093 .4393 .22815 Mtetra
.186 .504 .909 r
.60036 .19427 .60437 .19722 .61242 .19905 .60842 .19609 Mtetra
.265 .552 .928 r
.60842 .19609 .61242 .19905 .6205 .20047 .61651 .19751 Mtetra
.336 .594 .941 r
.61651 .19751 .6205 .20047 .62861 .20149 .62463 .19852 Mtetra
.399 .629 .947 r
.62463 .19852 .62861 .20149 .63674 .20213 .63278 .19914 Mtetra
.453 .657 .948 r
.63278 .19914 .63674 .20213 .6449 .20239 .64094 .19939 Mtetra
.499 .679 .946 r
.64094 .19939 .6449 .20239 .65306 .20231 .64912 .1993 Mtetra
.539 .698 .943 r
.64912 .1993 .65306 .20231 .66125 .20191 .65732 .19888 Mtetra
.572 .713 .937 r
.65732 .19888 .66125 .20191 .66944 .2012 .66553 .19816 Mtetra
.601 .725 .932 r
.66553 .19816 .66944 .2012 .67765 .20021 .67375 .19715 Mtetra
.625 .735 .926 r
.67375 .19715 .67765 .20021 .68586 .19895 .68197 .19588 Mtetra
.647 .743 .919 r
.68197 .19588 .68586 .19895 .69408 .19744 .69021 .19436 Mtetra
.665 .749 .913 r
.69021 .19436 .69408 .19744 .7023 .1957 .69845 .19261 Mtetra
.681 .755 .907 r
.69845 .19261 .7023 .1957 .71053 .19375 .70669 .19064 Mtetra
.695 .76 .902 r
.70669 .19064 .71053 .19375 .71876 .19161 .71494 .18848 Mtetra
.707 .764 .896 r
.71494 .18848 .71876 .19161 .72699 .18928 .72319 .18614 Mtetra
.717 .767 .892 r
.72319 .18614 .72699 .18928 .73522 .18678 .73144 .18363 Mtetra
.727 .77 .887 r
.73144 .18363 .73522 .18678 .74345 .18413 .73969 .18097 Mtetra
.735 .772 .883 r
.73969 .18097 .74345 .18413 .75168 .18134 .74794 .17816 Mtetra
.742 .774 .879 r
.74794 .17816 .75168 .18134 .75992 .17842 .75619 .17523 Mtetra
.748 .776 .876 r
.75619 .17523 .75992 .17842 .76815 .17539 .76444 .17219 Mtetra
.753 .777 .873 r
.76444 .17219 .76815 .17539 .77638 .17226 .77269 .16904 Mtetra
.758 .778 .87 r
.77269 .16904 .77638 .17226 .78462 .16904 .78095 .16581 Mtetra
.761 .779 .868 r
.78095 .16581 .78462 .16904 .79285 .16574 .7892 .16249 Mtetra
.765 .78 .866 r
.7892 .16249 .79285 .16574 .80109 .16237 .79746 .15911 Mtetra
.767 .781 .864 r
.79746 .15911 .80109 .16237 .80933 .15895 .80572 .15567 Mtetra
.769 .781 .863 r
.80572 .15567 .80933 .15895 .81757 .15548 .81398 .15219 Mtetra
.771 .781 .862 r
.81398 .15219 .81757 .15548 .82582 .15197 .82225 .14867 Mtetra
.772 .781 .861 r
.82225 .14867 .82582 .15197 .83407 .14845 .83052 .14513 Mtetra
.83052 .14513 .83407 .14845 .84233 .14491 .8388 .14158 Mtetra
.441 .661 .955 r
.22727 .26681 .23193 .2695 .23858 .26972 .23392 .26704 Mtetra
.442 .662 .955 r
.23392 .26704 .23858 .26972 .24526 .26994 .24061 .26725 Mtetra
.445 .664 .955 r
.24061 .26725 .24526 .26994 .25197 .27013 .24733 .26745 Mtetra
.45 .667 .955 r
.24733 .26745 .25197 .27013 .25872 .2703 .25408 .26762 Mtetra
.457 .67 .955 r
.25408 .26762 .25872 .2703 .2655 .27043 .26086 .26774 Mtetra
.466 .675 .955 r
.26086 .26774 .2655 .27043 .27231 .27051 .26769 .26782 Mtetra
.476 .679 .955 r
.26769 .26782 .27231 .27051 .27916 .27053 .27454 .26784 Mtetra
.487 .685 .954 r
.27454 .26784 .27916 .27053 .28605 .27048 .28144 .26779 Mtetra
.5 .691 .953 r
.28144 .26779 .28605 .27048 .29298 .27034 .28837 .26766 Mtetra
.515 .697 .952 r
.28837 .26766 .29298 .27034 .29994 .27011 .29534 .26743 Mtetra
.53 .704 .95 r
.29534 .26743 .29994 .27011 .30694 .26978 .30235 .26709 Mtetra
.547 .711 .948 r
.30235 .26709 .30694 .26978 .31398 .26932 .3094 .26664 Mtetra
.564 .717 .945 r
.3094 .26664 .31398 .26932 .32107 .26874 .31649 .26605 Mtetra
.582 .724 .941 r
.31649 .26605 .32107 .26874 .32819 .268 .32362 .26532 Mtetra
.6 .731 .936 r
.32362 .26532 .32819 .268 .33535 .26711 .3308 .26442 Mtetra
.619 .738 .931 r
.3308 .26442 .33535 .26711 .34255 .26604 .33801 .26336 Mtetra
.638 .744 .926 r
.33801 .26336 .34255 .26604 .34979 .26478 .34526 .2621 Mtetra
.657 .75 .919 r
.34526 .2621 .34979 .26478 .35707 .26332 .35255 .26063 Mtetra
.676 .756 .911 r
.35255 .26063 .35707 .26332 .36438 .26163 .35988 .25895 Mtetra
.695 .761 .903 r
.35988 .25895 .36438 .26163 .37174 .2597 .36724 .25702 Mtetra
.713 .766 .894 r
.36724 .25702 .37174 .2597 .37912 .25751 .37464 .25483 Mtetra
.731 .77 .885 r
.37464 .25483 .37912 .25751 .38655 .25504 .38208 .25236 Mtetra
.748 .774 .874 r
.38208 .25236 .38655 .25504 .394 .25227 .38955 .24959 Mtetra
.764 .777 .863 r
.38955 .24959 .394 .25227 .40149 .24918 .39706 .2465 Mtetra
.78 .779 .852 r
.39706 .2465 .40149 .24918 .40901 .24574 .40459 .24307 Mtetra
.795 .781 .84 r
.40459 .24307 .40901 .24574 .41655 .24194 .41215 .23927 Mtetra
.809 .783 .828 r
.41215 .23927 .41655 .24194 .42411 .23775 .41973 .23508 Mtetra
.822 .783 .816 r
.41973 .23508 .42411 .23775 .4317 .23316 .42734 .23048 Mtetra
.834 .783 .803 r
.42734 .23048 .4317 .23316 .4393 .22815 .43496 .22546 Mtetra
.17 .503 .909 r
.59634 .1914 .60036 .19427 .60842 .19609 .6044 .19323 Mtetra
.252 .554 .931 r
.6044 .19323 .60842 .19609 .61651 .19751 .61251 .19463 Mtetra
.327 .598 .944 r
.61251 .19463 .61651 .19751 .62463 .19852 .62064 .19562 Mtetra
.392 .634 .951 r
.62064 .19562 .62463 .19852 .63278 .19914 .62879 .19622 Mtetra
.449 .662 .953 r
.62879 .19622 .63278 .19914 .64094 .19939 .63697 .19646 Mtetra
.496 .685 .951 r
.63697 .19646 .64094 .19939 .64912 .1993 .64516 .19635 Mtetra
.537 .704 .947 r
.64516 .19635 .64912 .1993 .65732 .19888 .65337 .19591 Mtetra
.571 .718 .942 r
.65337 .19591 .65732 .19888 .66553 .19816 .66159 .19517 Mtetra
.601 .73 .936 r
.66159 .19517 .66553 .19816 .67375 .19715 .66983 .19415 Mtetra
.626 .74 .929 r
.66983 .19415 .67375 .19715 .68197 .19588 .67807 .19285 Mtetra
.647 .748 .923 r
.67807 .19285 .68197 .19588 .69021 .19436 .68632 .19132 Mtetra
.666 .754 .916 r
.68632 .19132 .69021 .19436 .69845 .19261 .69458 .18955 Mtetra
.682 .759 .91 r
.69458 .18955 .69845 .19261 .70669 .19064 .70284 .18757 Mtetra
.696 .763 .904 r
.70284 .18757 .70669 .19064 .71494 .18848 .7111 .18539 Mtetra
.708 .767 .899 r
.7111 .18539 .71494 .18848 .72319 .18614 .71937 .18303 Mtetra
.718 .77 .893 r
.71937 .18303 .72319 .18614 .73144 .18363 .72764 .1805 Mtetra
.728 .773 .889 r
.72764 .1805 .73144 .18363 .73969 .18097 .7359 .17782 Mtetra
.736 .775 .884 r
.7359 .17782 .73969 .18097 .74794 .17816 .74417 .175 Mtetra
.743 .776 .88 r
.74417 .175 .74794 .17816 .75619 .17523 .75244 .17205 Mtetra
.749 .778 .877 r
.75244 .17205 .75619 .17523 .76444 .17219 .76072 .16899 Mtetra
.754 .779 .874 r
.76072 .16899 .76444 .17219 .77269 .16904 .76899 .16583 Mtetra
.758 .78 .871 r
.76899 .16583 .77269 .16904 .78095 .16581 .77726 .16258 Mtetra
.762 .781 .868 r
.77726 .16258 .78095 .16581 .7892 .16249 .78553 .15925 Mtetra
.765 .781 .866 r
.78553 .15925 .7892 .16249 .79746 .15911 .79381 .15585 Mtetra
.768 .782 .864 r
.79381 .15585 .79746 .15911 .80572 .15567 .80209 .15239 Mtetra
.77 .782 .863 r
.80209 .15239 .80572 .15567 .81398 .15219 .81037 .14889 Mtetra
.771 .782 .862 r
.81037 .14889 .81398 .15219 .82225 .14867 .81866 .14536 Mtetra
.772 .782 .861 r
.81866 .14536 .82225 .14867 .83052 .14513 .82695 .1418 Mtetra
.82695 .1418 .83052 .14513 .8388 .14158 .83525 .13823 Mtetra
.439 .661 .955 r
.22258 .26412 .22727 .26681 .23392 .26704 .22924 .26434 Mtetra
.44 .662 .955 r
.22924 .26434 .23392 .26704 .24061 .26725 .23594 .26456 Mtetra
.443 .664 .955 r
.23594 .26456 .24061 .26725 .24733 .26745 .24266 .26476 Mtetra
.448 .667 .956 r
.24266 .26476 .24733 .26745 .25408 .26762 .24942 .26493 Mtetra
.455 .67 .956 r
.24942 .26493 .25408 .26762 .26086 .26774 .25621 .26506 Mtetra
.463 .675 .956 r
.25621 .26506 .26086 .26774 .26769 .26782 .26303 .26514 Mtetra
.473 .68 .956 r
.26303 .26514 .26769 .26782 .27454 .26784 .2699 .26516 Mtetra
.485 .685 .955 r
.2699 .26516 .27454 .26784 .28144 .26779 .2768 .26511 Mtetra
.498 .692 .954 r
.2768 .26511 .28144 .26779 .28837 .26766 .28374 .26498 Mtetra
.512 .698 .953 r
.28374 .26498 .28837 .26766 .29534 .26743 .29072 .26475 Mtetra
.528 .705 .952 r
.29072 .26475 .29534 .26743 .30235 .26709 .29774 .26442 Mtetra
.544 .712 .95 r
.29774 .26442 .30235 .26709 .3094 .26664 .3048 .26397 Mtetra
.562 .719 .947 r
.3048 .26397 .3094 .26664 .31649 .26605 .31189 .26338 Mtetra
.58 .727 .943 r
.31189 .26338 .31649 .26605 .32362 .26532 .31903 .26266 Mtetra
.598 .734 .939 r
.31903 .26266 .32362 .26532 .3308 .26442 .32622 .26177 Mtetra
.617 .741 .934 r
.32622 .26177 .3308 .26442 .33801 .26336 .33344 .2607 Mtetra
.636 .748 .929 r
.33344 .2607 .33801 .26336 .34526 .2621 .3407 .25945 Mtetra
.656 .754 .922 r
.3407 .25945 .34526 .2621 .35255 .26063 .348 .25799 Mtetra
.675 .76 .915 r
.348 .25799 .35255 .26063 .35988 .25895 .35534 .25631 Mtetra
.694 .766 .907 r
.35534 .25631 .35988 .25895 .36724 .25702 .36272 .25439 Mtetra
.712 .771 .898 r
.36272 .25439 .36724 .25702 .37464 .25483 .37014 .2522 Mtetra
.731 .775 .888 r
.37014 .2522 .37464 .25483 .38208 .25236 .37759 .24974 Mtetra
.748 .779 .878 r
.37759 .24974 .38208 .25236 .38955 .24959 .38508 .24698 Mtetra
.765 .782 .867 r
.38508 .24698 .38955 .24959 .39706 .2465 .3926 .2439 Mtetra
.781 .785 .856 r
.3926 .2439 .39706 .2465 .40459 .24307 .40015 .24047 Mtetra
.797 .787 .844 r
.40015 .24047 .40459 .24307 .41215 .23927 .40772 .23668 Mtetra
.811 .789 .831 r
.40772 .23668 .41215 .23927 .41973 .23508 .41533 .23249 Mtetra
.825 .79 .819 r
.41533 .23249 .41973 .23508 .42734 .23048 .42295 .22789 Mtetra
.837 .79 .806 r
.42295 .22789 .42734 .23048 .43496 .22546 .4306 .22286 Mtetra
.153 .501 .909 r
.59229 .18863 .59634 .1914 .6044 .19323 .60037 .19045 Mtetra
.24 .556 .933 r
.60037 .19045 .6044 .19323 .61251 .19463 .60848 .19183 Mtetra
.318 .602 .948 r
.60848 .19183 .61251 .19463 .62064 .19562 .61662 .19281 Mtetra
.387 .639 .956 r
.61662 .19281 .62064 .19562 .62879 .19622 .62479 .19339 Mtetra
.445 .668 .958 r
.62479 .19339 .62879 .19622 .63697 .19646 .63298 .1936 Mtetra
.494 .692 .956 r
.63298 .1936 .63697 .19646 .64516 .19635 .64118 .19346 Mtetra
.536 .71 .952 r
.64118 .19346 .64516 .19635 .65337 .19591 .64941 .193 Mtetra
.571 .724 .946 r
.64941 .193 .65337 .19591 .66159 .19517 .65764 .19224 Mtetra
.601 .736 .939 r
.65764 .19224 .66159 .19517 .66983 .19415 .66589 .19119 Mtetra
.626 .745 .933 r
.66589 .19119 .66983 .19415 .67807 .19285 .67415 .18987 Mtetra
.648 .752 .926 r
.67415 .18987 .67807 .19285 .68632 .19132 .68242 .18831 Mtetra
.667 .758 .919 r
.68242 .18831 .68632 .19132 .69458 .18955 .69069 .18652 Mtetra
.683 .763 .912 r
.69069 .18652 .69458 .18955 .70284 .18757 .69897 .18452 Mtetra
.697 .767 .906 r
.69897 .18452 .70284 .18757 .7111 .18539 .70725 .18232 Mtetra
.709 .771 .9 r
.70725 .18232 .7111 .18539 .71937 .18303 .71553 .17994 Mtetra
.72 .773 .895 r
.71553 .17994 .71937 .18303 .72764 .1805 .72382 .17739 Mtetra
.729 .776 .89 r
.72382 .17739 .72764 .1805 .7359 .17782 .7321 .17469 Mtetra
.737 .777 .886 r
.7321 .17469 .7359 .17782 .74417 .175 .74039 .17185 Mtetra
.744 .779 .881 r
.74039 .17185 .74417 .175 .75244 .17205 .74868 .16888 Mtetra
.75 .78 .878 r
.74868 .16888 .75244 .17205 .76072 .16899 .75697 .1658 Mtetra
.755 .781 .874 r
.75697 .1658 .76072 .16899 .76899 .16583 .76526 .16262 Mtetra
.759 .782 .871 r
.76526 .16262 .76899 .16583 .77726 .16258 .77355 .15935 Mtetra
.763 .782 .869 r
.77355 .15935 .77726 .16258 .78553 .15925 .78185 .156 Mtetra
.766 .783 .867 r
.78185 .156 .78553 .15925 .79381 .15585 .79014 .15258 Mtetra
.768 .783 .865 r
.79014 .15258 .79381 .15585 .80209 .15239 .79844 .14911 Mtetra
.77 .783 .863 r
.79844 .14911 .80209 .15239 .81037 .14889 .80674 .14559 Mtetra
.772 .783 .862 r
.80674 .14559 .81037 .14889 .81866 .14536 .81505 .14203 Mtetra
.772 .782 .861 r
.81505 .14203 .81866 .14536 .82695 .1418 .82336 .13846 Mtetra
.773 .782 .86 r
.82336 .13846 .82695 .1418 .83525 .13823 .83168 .13486 Mtetra
.437 .66 .955 r
.21788 .26141 .22258 .26412 .22924 .26434 .22454 .26164 Mtetra
.438 .661 .955 r
.22454 .26164 .22924 .26434 .23594 .26456 .23124 .26186 Mtetra
.441 .663 .956 r
.23124 .26186 .23594 .26456 .24266 .26476 .23797 .26206 Mtetra
.446 .666 .956 r
.23797 .26206 .24266 .26476 .24942 .26493 .24473 .26223 Mtetra
.452 .67 .956 r
.24473 .26223 .24942 .26493 .25621 .26506 .25152 .26237 Mtetra
.461 .675 .957 r
.25152 .26237 .25621 .26506 .26303 .26514 .25836 .26246 Mtetra
.471 .68 .957 r
.25836 .26246 .26303 .26514 .2699 .26516 .26523 .26248 Mtetra
.482 .686 .956 r
.26523 .26248 .2699 .26516 .2768 .26511 .27213 .26244 Mtetra
.495 .692 .956 r
.27213 .26244 .2768 .26511 .28374 .26498 .27908 .26231 Mtetra
.509 .699 .955 r
.27908 .26231 .28374 .26498 .29072 .26475 .28607 .26209 Mtetra
.525 .706 .954 r
.28607 .26209 .29072 .26475 .29774 .26442 .29309 .26177 Mtetra
.541 .713 .952 r
.29309 .26177 .29774 .26442 .3048 .26397 .30016 .26132 Mtetra
.559 .721 .949 r
.30016 .26132 .3048 .26397 .31189 .26338 .30727 .26074 Mtetra
.577 .729 .946 r
.30727 .26074 .31189 .26338 .31903 .26266 .31442 .26002 Mtetra
.596 .736 .942 r
.31442 .26002 .31903 .26266 .32622 .26177 .32161 .25914 Mtetra
.615 .744 .937 r
.32161 .25914 .32622 .26177 .33344 .2607 .32884 .25808 Mtetra
.634 .751 .932 r
.32884 .25808 .33344 .2607 .3407 .25945 .33611 .25684 Mtetra
.654 .757 .926 r
.33611 .25684 .3407 .25945 .348 .25799 .34342 .25539 Mtetra
.673 .764 .919 r
.34342 .25539 .348 .25799 .35534 .25631 .35078 .25372 Mtetra
.693 .77 .911 r
.35078 .25372 .35534 .25631 .36272 .25439 .35817 .2518 Mtetra
.712 .775 .902 r
.35817 .2518 .36272 .25439 .37014 .2522 .3656 .24963 Mtetra
.73 .78 .893 r
.3656 .24963 .37014 .2522 .37759 .24974 .37307 .24718 Mtetra
.748 .784 .882 r
.37307 .24718 .37759 .24974 .38508 .24698 .38057 .24444 Mtetra
.766 .788 .871 r
.38057 .24444 .38508 .24698 .3926 .2439 .3881 .24137 Mtetra
.782 .791 .86 r
.3881 .24137 .3926 .2439 .40015 .24047 .39567 .23795 Mtetra
.798 .794 .848 r
.39567 .23795 .40015 .24047 .40772 .23668 .40327 .23417 Mtetra
.813 .795 .835 r
.40327 .23417 .40772 .23668 .41533 .23249 .41089 .22999 Mtetra
.827 .796 .822 r
.41089 .22999 .41533 .23249 .42295 .22789 .41854 .2254 Mtetra
.84 .796 .809 r
.41854 .2254 .42295 .22789 .4306 .22286 .4262 .22036 Mtetra
.136 .5 .908 r
.58823 .18596 .59229 .18863 .60037 .19045 .59632 .18777 Mtetra
.228 .559 .935 r
.59632 .18777 .60037 .19045 .60848 .19183 .60444 .18913 Mtetra
.31 .607 .952 r
.60444 .18913 .60848 .19183 .61662 .19281 .61259 .19008 Mtetra
.381 .645 .96 r
.61259 .19008 .61662 .19281 .62479 .19339 .62077 .19063 Mtetra
.442 .675 .962 r
.62077 .19063 .62479 .19339 .63298 .1936 .62897 .19081 Mtetra
.493 .698 .96 r
.62897 .19081 .63298 .1936 .64118 .19346 .63719 .19064 Mtetra
.535 .716 .956 r
.63719 .19064 .64118 .19346 .64941 .193 .64543 .19015 Mtetra
.571 .731 .95 r
.64543 .19015 .64941 .193 .65764 .19224 .65368 .18936 Mtetra
.602 .742 .943 r
.65368 .18936 .65764 .19224 .66589 .19119 .66194 .18828 Mtetra
.627 .751 .936 r
.66194 .18828 .66589 .19119 .67415 .18987 .67022 .18694 Mtetra
.649 .758 .929 r
.67022 .18694 .67415 .18987 .68242 .18831 .6785 .18535 Mtetra
.668 .763 .921 r
.6785 .18535 .68242 .18831 .69069 .18652 .68679 .18354 Mtetra
.684 .768 .915 r
.68679 .18354 .69069 .18652 .69897 .18452 .69508 .18151 Mtetra
.698 .771 .908 r
.69508 .18151 .69897 .18452 .70725 .18232 .70338 .17928 Mtetra
.71 .774 .902 r
.70338 .17928 .70725 .18232 .71553 .17994 .71168 .17688 Mtetra
.721 .777 .897 r
.71168 .17688 .71553 .17994 .72382 .17739 .71998 .1743 Mtetra
.73 .779 .891 r
.71998 .1743 .72382 .17739 .7321 .17469 .72829 .17158 Mtetra
.738 .78 .887 r
.72829 .17158 .7321 .17469 .74039 .17185 .73659 .16871 Mtetra
.745 .781 .882 r
.73659 .16871 .74039 .17185 .74868 .16888 .7449 .16572 Mtetra
.751 .782 .879 r
.7449 .16572 .74868 .16888 .75697 .1658 .75321 .16262 Mtetra
.756 .783 .875 r
.75321 .16262 .75697 .1658 .76526 .16262 .76152 .15941 Mtetra
.76 .783 .872 r
.76152 .15941 .76526 .16262 .77355 .15935 .76983 .15612 Mtetra
.764 .784 .869 r
.76983 .15612 .77355 .15935 .78185 .156 .77814 .15275 Mtetra
.767 .784 .867 r
.77814 .15275 .78185 .156 .79014 .15258 .78646 .14931 Mtetra
.769 .784 .865 r
.78646 .14931 .79014 .15258 .79844 .14911 .79478 .14581 Mtetra
.771 .784 .863 r
.79478 .14581 .79844 .14911 .80674 .14559 .8031 .14227 Mtetra
.772 .783 .862 r
.8031 .14227 .80674 .14559 .81505 .14203 .81142 .13869 Mtetra
.773 .783 .861 r
.81142 .13869 .81505 .14203 .82336 .13846 .81975 .13509 Mtetra
.773 .782 .86 r
.81975 .13509 .82336 .13846 .83168 .13486 .82809 .13148 Mtetra
.435 .659 .955 r
.21314 .25868 .21788 .26141 .22454 .26164 .21981 .25892 Mtetra
.436 .66 .955 r
.21981 .25892 .22454 .26164 .23124 .26186 .22651 .25915 Mtetra
.438 .663 .956 r
.22651 .25915 .23124 .26186 .23797 .26206 .23325 .25936 Mtetra
.443 .666 .957 r
.23325 .25936 .23797 .26206 .24473 .26223 .24001 .25954 Mtetra
.449 .67 .957 r
.24001 .25954 .24473 .26223 .25152 .26237 .24682 .25968 Mtetra
.457 .674 .957 r
.24682 .25968 .25152 .26237 .25836 .26246 .25365 .25978 Mtetra
.467 .68 .958 r
.25365 .25978 .25836 .26246 .26523 .26248 .26053 .25981 Mtetra
.479 .686 .958 r
.26053 .25981 .26523 .26248 .27213 .26244 .26744 .25977 Mtetra
.492 .692 .957 r
.26744 .25977 .27213 .26244 .27908 .26231 .2744 .25966 Mtetra
.506 .699 .957 r
.2744 .25966 .27908 .26231 .28607 .26209 .28139 .25944 Mtetra
.521 .707 .955 r
.28139 .25944 .28607 .26209 .29309 .26177 .28842 .25913 Mtetra
.538 .715 .954 r
.28842 .25913 .29309 .26177 .30016 .26132 .2955 .25869 Mtetra
.556 .722 .952 r
.2955 .25869 .30016 .26132 .30727 .26074 .30261 .25812 Mtetra
.574 .73 .949 r
.30261 .25812 .30727 .26074 .31442 .26002 .30977 .25741 Mtetra
.593 .738 .945 r
.30977 .25741 .31442 .26002 .32161 .25914 .31697 .25654 Mtetra
.612 .746 .941 r
.31697 .25654 .32161 .25914 .32884 .25808 .32421 .2555 Mtetra
.632 .754 .935 r
.32421 .2555 .32884 .25808 .33611 .25684 .3315 .25426 Mtetra
.652 .761 .929 r
.3315 .25426 .33611 .25684 .34342 .25539 .33882 .25283 Mtetra
.672 .768 .922 r
.33882 .25283 .34342 .25539 .35078 .25372 .34618 .25117 Mtetra
.691 .774 .915 r
.34618 .25117 .35078 .25372 .35817 .2518 .35359 .24927 Mtetra
.711 .78 .906 r
.35359 .24927 .35817 .2518 .3656 .24963 .36103 .24712 Mtetra
.73 .785 .897 r
.36103 .24712 .3656 .24963 .37307 .24718 .36851 .24469 Mtetra
.748 .79 .887 r
.36851 .24469 .37307 .24718 .38057 .24444 .37603 .24195 Mtetra
.766 .794 .876 r
.37603 .24195 .38057 .24444 .3881 .24137 .38358 .2389 Mtetra
.783 .797 .864 r
.38358 .2389 .3881 .24137 .39567 .23795 .39116 .23551 Mtetra
.799 .8 .852 r
.39116 .23551 .39567 .23795 .40327 .23417 .39878 .23175 Mtetra
.815 .802 .839 r
.39878 .23175 .40327 .23417 .41089 .22999 .40642 .22759 Mtetra
.829 .803 .826 r
.40642 .22759 .41089 .22999 .41854 .2254 .41409 .22301 Mtetra
.843 .803 .812 r
.41409 .22301 .41854 .2254 .4262 .22036 .42178 .21797 Mtetra
.118 .499 .906 r
.58415 .1834 .58823 .18596 .59632 .18777 .59225 .18519 Mtetra
.217 .562 .936 r
.59225 .18519 .59632 .18777 .60444 .18913 .60038 .18652 Mtetra
.303 .612 .955 r
.60038 .18652 .60444 .18913 .61259 .19008 .60854 .18743 Mtetra
.377 .651 .964 r
.60854 .18743 .61259 .19008 .62077 .19063 .61673 .18795 Mtetra
.44 .682 .967 r
.61673 .18795 .62077 .19063 .62897 .19081 .62494 .18809 Mtetra
.492 .705 .965 r
.62494 .18809 .62897 .19081 .63719 .19064 .63318 .18789 Mtetra
.535 .723 .96 r
.63318 .18789 .63719 .19064 .64543 .19015 .64143 .18736 Mtetra
.572 .737 .954 r
.64143 .18736 .64543 .19015 .65368 .18936 .64969 .18653 Mtetra
.603 .748 .946 r
.64969 .18653 .65368 .18936 .66194 .18828 .65797 .18542 Mtetra
.629 .756 .939 r
.65797 .18542 .66194 .18828 .67022 .18694 .66626 .18405 Mtetra
.651 .763 .931 r
.66626 .18405 .67022 .18694 .6785 .18535 .67456 .18243 Mtetra
.67 .768 .924 r
.67456 .18243 .6785 .18535 .68679 .18354 .68286 .18058 Mtetra
.686 .772 .917 r
.68286 .18058 .68679 .18354 .69508 .18151 .69117 .17852 Mtetra
.7 .775 .91 r
.69117 .17852 .69508 .18151 .70338 .17928 .69949 .17627 Mtetra
.712 .778 .904 r
.69949 .17627 .70338 .17928 .71168 .17688 .70781 .17383 Mtetra
.723 .78 .898 r
.70781 .17383 .71168 .17688 .71998 .1743 .71613 .17123 Mtetra
.732 .782 .893 r
.71613 .17123 .71998 .1743 .72829 .17158 .72445 .16848 Mtetra
.739 .783 .888 r
.72445 .16848 .72829 .17158 .73659 .16871 .73278 .16559 Mtetra
.746 .784 .883 r
.73278 .16559 .73659 .16871 .7449 .16572 .7411 .16257 Mtetra
.752 .784 .879 r
.7411 .16257 .7449 .16572 .75321 .16262 .74943 .15944 Mtetra
.757 .785 .876 r
.74943 .15944 .75321 .16262 .76152 .15941 .75776 .15621 Mtetra
.761 .785 .873 r
.75776 .15621 .76152 .15941 .76983 .15612 .76609 .15289 Mtetra
.765 .785 .87 r
.76609 .15289 .76983 .15612 .77814 .15275 .77442 .14949 Mtetra
.768 .785 .867 r
.77442 .14949 .77814 .15275 .78646 .14931 .78275 .14603 Mtetra
.77 .785 .865 r
.78275 .14603 .78646 .14931 .79478 .14581 .79109 .1425 Mtetra
.772 .785 .863 r
.79109 .1425 .79478 .14581 .8031 .14227 .79943 .13894 Mtetra
.773 .784 .862 r
.79943 .13894 .8031 .14227 .81142 .13869 .80778 .13534 Mtetra
.774 .783 .861 r
.80778 .13534 .81142 .13869 .81975 .13509 .81613 .13171 Mtetra
.774 .783 .86 r
.81613 .13171 .81975 .13509 .82809 .13148 .82449 .12808 Mtetra
.432 .658 .955 r
.20839 .25594 .21314 .25868 .21981 .25892 .21506 .25619 Mtetra
.433 .659 .956 r
.21506 .25619 .21981 .25892 .22651 .25915 .22177 .25643 Mtetra
.435 .662 .956 r
.22177 .25643 .22651 .25915 .23325 .25936 .2285 .25665 Mtetra
.44 .665 .957 r
.2285 .25665 .23325 .25936 .24001 .25954 .23528 .25684 Mtetra
.446 .669 .958 r
.23528 .25684 .24001 .25954 .24682 .25968 .24208 .25699 Mtetra
.454 .674 .958 r
.24208 .25699 .24682 .25968 .25365 .25978 .24893 .2571 Mtetra
.463 .679 .959 r
.24893 .2571 .25365 .25978 .26053 .25981 .25581 .25714 Mtetra
.475 .686 .959 r
.25581 .25714 .26053 .25981 .26744 .25977 .26273 .25712 Mtetra
.488 .692 .959 r
.26273 .25712 .26744 .25977 .2744 .25966 .26968 .25701 Mtetra
.502 .7 .958 r
.26968 .25701 .2744 .25966 .28139 .25944 .27668 .25681 Mtetra
.517 .708 .957 r
.27668 .25681 .28139 .25944 .28842 .25913 .28372 .2565 Mtetra
.534 .716 .956 r
.28372 .2565 .28842 .25913 .2955 .25869 .29081 .25608 Mtetra
.552 .724 .954 r
.29081 .25608 .2955 .25869 .30261 .25812 .29793 .25552 Mtetra
.57 .732 .951 r
.29793 .25552 .30261 .25812 .30977 .25741 .3051 .25483 Mtetra
.589 .74 .948 r
.3051 .25483 .30977 .25741 .31697 .25654 .31231 .25397 Mtetra
.609 .749 .944 r
.31231 .25397 .31697 .25654 .32421 .2555 .31956 .25294 Mtetra
.629 .756 .939 r
.31956 .25294 .32421 .2555 .3315 .25426 .32685 .25173 Mtetra
.649 .764 .933 r
.32685 .25173 .3315 .25426 .33882 .25283 .33418 .25031 Mtetra
.669 .771 .926 r
.33418 .25031 .33882 .25283 .34618 .25117 .34156 .24867 Mtetra
.689 .778 .919 r
.34156 .24867 .34618 .25117 .35359 .24927 .34898 .24679 Mtetra
.709 .784 .911 r
.34898 .24679 .35359 .24927 .36103 .24712 .35643 .24466 Mtetra
.728 .79 .901 r
.35643 .24466 .36103 .24712 .36851 .24469 .36393 .24225 Mtetra
.747 .795 .891 r
.36393 .24225 .36851 .24469 .37603 .24195 .37146 .23954 Mtetra
.765 .799 .881 r
.37146 .23954 .37603 .24195 .38358 .2389 .37903 .23651 Mtetra
.783 .803 .869 r
.37903 .23651 .38358 .2389 .39116 .23551 .38663 .23315 Mtetra
.8 .806 .857 r
.38663 .23315 .39116 .23551 .39878 .23175 .39426 .22941 Mtetra
.816 .808 .844 r
.39426 .22941 .39878 .23175 .40642 .22759 .40192 .22528 Mtetra
.831 .81 .83 r
.40192 .22528 .40642 .22759 .41409 .22301 .40961 .22071 Mtetra
.845 .81 .816 r
.40961 .22071 .41409 .22301 .42178 .21797 .41732 .21569 Mtetra
.859 .809 .8 r
.41732 .21569 .42178 .21797 .42949 .21244 .42506 .21015 Mtetra
0 .418 .853 r
.57198 .17867 .57609 .18112 .58415 .1834 .58004 .18094 Mtetra
.101 .499 .903 r
.58004 .18094 .58415 .1834 .59225 .18519 .58815 .1827 Mtetra
.206 .566 .938 r
.58815 .1827 .59225 .18519 .60038 .18652 .5963 .184 Mtetra
.297 .618 .958 r
.5963 .184 .60038 .18652 .60854 .18743 .60447 .18487 Mtetra
.374 .659 .968 r
.60447 .18487 .60854 .18743 .61673 .18795 .61267 .18534 Mtetra
.438 .689 .971 r
.61267 .18534 .61673 .18795 .62494 .18809 .6209 .18544 Mtetra
.492 .713 .969 r
.6209 .18544 .62494 .18809 .63318 .18789 .62915 .1852 Mtetra
.536 .73 .964 r
.62915 .1852 .63318 .18789 .64143 .18736 .63741 .18463 Mtetra
.573 .744 .957 r
.63741 .18463 .64143 .18736 .64969 .18653 .64569 .18376 Mtetra
.604 .754 .95 r
.64569 .18376 .64969 .18653 .65797 .18542 .65398 .18261 Mtetra
.631 .762 .942 r
.65398 .18261 .65797 .18542 .66626 .18405 .66229 .1812 Mtetra
.653 .768 .934 r
.66229 .1812 .66626 .18405 .67456 .18243 .6706 .17954 Mtetra
.672 .773 .926 r
.6706 .17954 .67456 .18243 .68286 .18058 .67892 .17766 Mtetra
.688 .777 .919 r
.67892 .17766 .68286 .18058 .69117 .17852 .68725 .17557 Mtetra
.702 .78 .912 r
.68725 .17557 .69117 .17852 .69949 .17627 .69558 .17328 Mtetra
.714 .782 .905 r
.69558 .17328 .69949 .17627 .70781 .17383 .70392 .17082 Mtetra
.724 .784 .899 r
.70392 .17082 .70781 .17383 .71613 .17123 .71226 .16818 Mtetra
.733 .785 .894 r
.71226 .16818 .71613 .17123 .72445 .16848 .7206 .1654 Mtetra
.741 .786 .889 r
.7206 .1654 .72445 .16848 .73278 .16559 .72894 .16248 Mtetra
.748 .786 .884 r
.72894 .16248 .73278 .16559 .7411 .16257 .73729 .15943 Mtetra
.754 .787 .88 r
.73729 .15943 .7411 .16257 .74943 .15944 .74563 .15627 Mtetra
.759 .787 .876 r
.74563 .15627 .74943 .15944 .75776 .15621 .75398 .15301 Mtetra
.763 .787 .873 r
.75398 .15301 .75776 .15621 .76609 .15289 .76233 .14966 Mtetra
.766 .787 .87 r
.76233 .14966 .76609 .15289 .77442 .14949 .77068 .14624 Mtetra
.769 .787 .867 r
.77068 .14624 .77442 .14949 .78275 .14603 .77903 .14274 Mtetra
.771 .786 .865 r
.77903 .14274 .78275 .14603 .79109 .1425 .78739 .13919 Mtetra
.773 .786 .863 r
.78739 .13919 .79109 .1425 .79943 .13894 .79575 .1356 Mtetra
.774 .785 .862 r
.79575 .1356 .79943 .13894 .80778 .13534 .80411 .13197 Mtetra
.775 .784 .861 r
.80411 .13197 .80778 .13534 .81613 .13171 .81248 .12832 Mtetra
.775 .783 .86 r
.81248 .12832 .81613 .13171 .82449 .12808 .82086 .12465 Mtetra
.429 .656 .955 r
.20361 .25319 .20839 .25594 .21506 .25619 .21029 .25345 Mtetra
.429 .658 .956 r
.21029 .25345 .21506 .25619 .22177 .25643 .217 .2537 Mtetra
.431 .66 .957 r
.217 .2537 .22177 .25643 .2285 .25665 .22374 .25393 Mtetra
.436 .664 .958 r
.22374 .25393 .2285 .25665 .23528 .25684 .23051 .25413 Mtetra
.442 .668 .958 r
.23051 .25413 .23528 .25684 .24208 .25699 .23732 .2543 Mtetra
.449 .673 .959 r
.23732 .2543 .24208 .25699 .24893 .2571 .24417 .25442 Mtetra
.459 .679 .96 r
.24417 .25442 .24893 .2571 .25581 .25714 .25106 .25448 Mtetra
.47 .685 .96 r
.25106 .25448 .25581 .25714 .26273 .25712 .25798 .25446 Mtetra
.483 .692 .96 r
.25798 .25446 .26273 .25712 .26968 .25701 .26495 .25437 Mtetra
.497 .7 .96 r
.26495 .25437 .26968 .25701 .27668 .25681 .27195 .25418 Mtetra
.513 .708 .959 r
.27195 .25418 .27668 .25681 .28372 .2565 .279 .25389 Mtetra
.53 .716 .958 r
.279 .25389 .28372 .2565 .29081 .25608 .28609 .25349 Mtetra
.547 .725 .956 r
.28609 .25349 .29081 .25608 .29793 .25552 .29322 .25295 Mtetra
.566 .734 .954 r
.29322 .25295 .29793 .25552 .3051 .25483 .30039 .25227 Mtetra
.585 .742 .951 r
.30039 .25227 .3051 .25483 .31231 .25397 .30761 .25143 Mtetra
.605 .751 .947 r
.30761 .25143 .31231 .25397 .31956 .25294 .31487 .25042 Mtetra
.625 .759 .943 r
.31487 .25042 .31956 .25294 .32685 .25173 .32217 .24922 Mtetra
.646 .767 .937 r
.32217 .24922 .32685 .25173 .33418 .25031 .32952 .24783 Mtetra
.666 .775 .931 r
.32952 .24783 .33418 .25031 .34156 .24867 .33691 .24621 Mtetra
.687 .782 .923 r
.33691 .24621 .34156 .24867 .34898 .24679 .34433 .24436 Mtetra
.707 .789 .915 r
.34433 .24436 .34898 .24679 .35643 .24466 .3518 .24225 Mtetra
.727 .795 .906 r
.3518 .24225 .35643 .24466 .36393 .24225 .35931 .23987 Mtetra
.746 .8 .896 r
.35931 .23987 .36393 .24225 .37146 .23954 .36686 .23719 Mtetra
.765 .805 .886 r
.36686 .23719 .37146 .23954 .37903 .23651 .37444 .2342 Mtetra
.783 .809 .874 r
.37444 .2342 .37903 .23651 .38663 .23315 .38206 .23086 Mtetra
.8 .813 .862 r
.38206 .23086 .38663 .23315 .39426 .22941 .38971 .22716 Mtetra
.817 .815 .849 r
.38971 .22716 .39426 .22941 .40192 .22528 .39739 .22306 Mtetra
.832 .817 .835 r
.39739 .22306 .40192 .22528 .40961 .22071 .4051 .21853 Mtetra
.847 .818 .82 r
.4051 .21853 .40961 .22071 .41732 .21569 .41283 .21352 Mtetra
.862 .817 .804 r
.41283 .21352 .41732 .21569 .42506 .21015 .42059 .20799 Mtetra
0 .412 .843 r
.56784 .17636 .57198 .17867 .58004 .18094 .57592 .1786 Mtetra
.085 .5 .9 r
.57592 .1786 .58004 .18094 .58815 .1827 .58404 .18032 Mtetra
.196 .571 .939 r
.58404 .18032 .58815 .1827 .5963 .184 .59219 .18157 Mtetra
.291 .625 .961 r
.59219 .18157 .5963 .184 .60447 .18487 .60038 .18239 Mtetra
.371 .667 .972 r
.60038 .18239 .60447 .18487 .61267 .18534 .60859 .18281 Mtetra
.438 .698 .975 r
.60859 .18281 .61267 .18534 .6209 .18544 .61683 .18286 Mtetra
.492 .721 .973 r
.61683 .18286 .6209 .18544 .62915 .1852 .62509 .18257 Mtetra
.538 .738 .968 r
.62509 .18257 .62915 .1852 .63741 .18463 .63337 .18195 Mtetra
.575 .751 .961 r
.63337 .18195 .63741 .18463 .64569 .18376 .64167 .18104 Mtetra
.607 .761 .953 r
.64167 .18104 .64569 .18376 .65398 .18261 .64998 .17985 Mtetra
.633 .768 .945 r
.64998 .17985 .65398 .18261 .66229 .1812 .6583 .17839 Mtetra
.655 .774 .936 r
.6583 .17839 .66229 .1812 .6706 .17954 .66663 .1767 Mtetra
.674 .778 .928 r
.66663 .1767 .6706 .17954 .67892 .17766 .67497 .17478 Mtetra
.69 .781 .921 r
.67497 .17478 .67892 .17766 .68725 .17557 .68331 .17265 Mtetra
.704 .784 .913 r
.68331 .17265 .68725 .17557 .69558 .17328 .69166 .17032 Mtetra
.716 .786 .907 r
.69166 .17032 .69558 .17328 .70392 .17082 .70001 .16782 Mtetra
.726 .787 .901 r
.70001 .16782 .70392 .17082 .71226 .16818 .70837 .16515 Mtetra
.735 .788 .895 r
.70837 .16515 .71226 .16818 .7206 .1654 .71673 .16234 Mtetra
.743 .789 .89 r
.71673 .16234 .7206 .1654 .72894 .16248 .72509 .15938 Mtetra
.75 .789 .885 r
.72509 .15938 .72894 .16248 .73729 .15943 .73345 .1563 Mtetra
.755 .789 .881 r
.73345 .1563 .73729 .15943 .74563 .15627 .74182 .15311 Mtetra
.76 .789 .877 r
.74182 .15311 .74563 .15627 .75398 .15301 .75018 .14982 Mtetra
.764 .789 .873 r
.75018 .14982 .75398 .15301 .76233 .14966 .75855 .14643 Mtetra
.768 .788 .87 r
.75855 .14643 .76233 .14966 .77068 .14624 .76692 .14298 Mtetra
.77 .788 .867 r
.76692 .14298 .77068 .14624 .77903 .14274 .77529 .13945 Mtetra
.772 .787 .865 r
.77529 .13945 .77903 .14274 .78739 .13919 .78366 .13587 Mtetra
.774 .787 .863 r
.78366 .13587 .78739 .13919 .79575 .1356 .79204 .13225 Mtetra
.775 .786 .861 r
.79204 .13225 .79575 .1356 .80411 .13197 .80042 .12859 Mtetra
.776 .785 .86 r
.80042 .12859 .80411 .13197 .81248 .12832 .80881 .12491 Mtetra
.776 .783 .859 r
.80881 .12491 .81248 .12832 .82086 .12465 .81721 .12121 Mtetra
.425 .654 .955 r
.19881 .25043 .20361 .25319 .21029 .25345 .20549 .2507 Mtetra
.425 .656 .956 r
.20549 .2507 .21029 .25345 .217 .2537 .2122 .25096 Mtetra
.427 .659 .957 r
.2122 .25096 .217 .2537 .22374 .25393 .21894 .25121 Mtetra
.431 .662 .958 r
.21894 .25121 .22374 .25393 .23051 .25413 .22572 .25143 Mtetra
.437 .667 .959 r
.22572 .25143 .23051 .25413 .23732 .2543 .23254 .25161 Mtetra
.445 .672 .96 r
.23254 .25161 .23732 .2543 .24417 .25442 .23939 .25174 Mtetra
.454 .678 .961 r
.23939 .25174 .24417 .25442 .25106 .25448 .24628 .25181 Mtetra
.465 .685 .961 r
.24628 .25181 .25106 .25448 .25798 .25446 .25321 .25182 Mtetra
.478 .692 .961 r
.25321 .25182 .25798 .25446 .26495 .25437 .26018 .25174 Mtetra
.492 .7 .962 r
.26018 .25174 .26495 .25437 .27195 .25418 .26719 .25157 Mtetra
.508 .708 .961 r
.26719 .25157 .27195 .25418 .279 .25389 .27424 .2513 Mtetra
.524 .717 .96 r
.27424 .2513 .279 .25389 .28609 .25349 .28134 .25091 Mtetra
.542 .726 .959 r
.28134 .25091 .28609 .25349 .29322 .25295 .28848 .25039 Mtetra
.561 .735 .957 r
.28848 .25039 .29322 .25295 .30039 .25227 .29566 .24973 Mtetra
.581 .744 .954 r
.29566 .24973 .30039 .25227 .30761 .25143 .30288 .24892 Mtetra
.601 .753 .951 r
.30288 .24892 .30761 .25143 .31487 .25042 .31015 .24793 Mtetra
.621 .762 .946 r
.31015 .24793 .31487 .25042 .32217 .24922 .31747 .24676 Mtetra
.642 .77 .941 r
.31747 .24676 .32217 .24922 .32952 .24783 .32482 .24539 Mtetra
.663 .778 .935 r
.32482 .24539 .32952 .24783 .33691 .24621 .33222 .2438 Mtetra
.683 .786 .928 r
.33222 .2438 .33691 .24621 .34433 .24436 .33966 .24197 Mtetra
.704 .793 .92 r
.33966 .24197 .34433 .24436 .3518 .24225 .34714 .23989 Mtetra
.724 .8 .911 r
.34714 .23989 .3518 .24225 .35931 .23987 .35466 .23755 Mtetra
.744 .806 .901 r
.35466 .23755 .35931 .23987 .36686 .23719 .36222 .2349 Mtetra
.763 .811 .891 r
.36222 .2349 .36686 .23719 .37444 .2342 .36982 .23195 Mtetra
.782 .816 .879 r
.36982 .23195 .37444 .2342 .38206 .23086 .37745 .22865 Mtetra
.8 .819 .867 r
.37745 .22865 .38206 .23086 .38971 .22716 .38512 .22499 Mtetra
.817 .822 .854 r
.38512 .22499 .38971 .22716 .39739 .22306 .39282 .22093 Mtetra
.833 .825 .84 r
.39282 .22093 .39739 .22306 .4051 .21853 .40055 .21644 Mtetra
.849 .826 .824 r
.40055 .21644 .4051 .21853 .41283 .21352 .40831 .21147 Mtetra
.864 .825 .808 r
.40831 .21147 .41283 .21352 .42059 .20799 .41609 .20597 Mtetra
0 .409 .833 r
.56369 .17418 .56784 .17636 .57592 .1786 .57177 .17638 Mtetra
.072 .503 .897 r
.57177 .17638 .57592 .1786 .58404 .18032 .5799 .17805 Mtetra
.189 .577 .939 r
.5799 .17805 .58404 .18032 .59219 .18157 .58807 .17924 Mtetra
.288 .633 .964 r
.58807 .17924 .59219 .18157 .60038 .18239 .59627 .18 Mtetra
.37 .675 .976 r
.59627 .18 .60038 .18239 .60859 .18281 .6045 .18036 Mtetra
.438 .706 .979 r
.6045 .18036 .60859 .18281 .61683 .18286 .61275 .18036 Mtetra
.494 .729 .977 r
.61275 .18036 .61683 .18286 .62509 .18257 .62102 .18001 Mtetra
.54 .746 .971 r
.62102 .18001 .62509 .18257 .63337 .18195 .62932 .17934 Mtetra
.578 .758 .964 r
.62932 .17934 .63337 .18195 .64167 .18104 .63763 .17837 Mtetra
.609 .768 .956 r
.63763 .17837 .64167 .18104 .64998 .17985 .64595 .17713 Mtetra
.636 .775 .947 r
.64595 .17713 .64998 .17985 .6583 .17839 .65429 .17563 Mtetra
.658 .78 .938 r
.65429 .17563 .6583 .17839 .66663 .1767 .66263 .17389 Mtetra
.677 .783 .93 r
.66263 .17389 .66663 .1767 .67497 .17478 .67099 .17193 Mtetra
.693 .786 .922 r
.67099 .17193 .67497 .17478 .68331 .17265 .67935 .16975 Mtetra
.707 .788 .915 r
.67935 .16975 .68331 .17265 .69166 .17032 .68771 .16739 Mtetra
.718 .79 .908 r
.68771 .16739 .69166 .17032 .70001 .16782 .69609 .16485 Mtetra
.729 .791 .902 r
.69609 .16485 .70001 .16782 .70837 .16515 .70446 .16214 Mtetra
.737 .791 .896 r
.70446 .16214 .70837 .16515 .71673 .16234 .71284 .15929 Mtetra
.745 .792 .89 r
.71284 .15929 .71673 .16234 .72509 .15938 .72122 .15629 Mtetra
.751 .792 .885 r
.72122 .15629 .72509 .15938 .73345 .1563 .7296 .15318 Mtetra
.757 .791 .881 r
.7296 .15318 .73345 .1563 .74182 .15311 .73798 .14995 Mtetra
.762 .791 .877 r
.73798 .14995 .74182 .15311 .75018 .14982 .74636 .14662 Mtetra
.766 .791 .873 r
.74636 .14662 .75018 .14982 .75855 .14643 .75475 .14321 Mtetra
.769 .79 .87 r
.75475 .14321 .75855 .14643 .76692 .14298 .76314 .13971 Mtetra
.772 .789 .867 r
.76314 .13971 .76692 .14298 .77529 .13945 .77153 .13616 Mtetra
.774 .789 .865 r
.77153 .13616 .77529 .13945 .78366 .13587 .77992 .13254 Mtetra
.775 .788 .863 r
.77992 .13254 .78366 .13587 .79204 .13225 .78832 .12889 Mtetra
.776 .786 .861 r
.78832 .12889 .79204 .13225 .80042 .12859 .79672 .12519 Mtetra
.777 .785 .86 r
.79672 .12519 .80042 .12859 .80881 .12491 .80512 .12148 Mtetra
.777 .784 .859 r
.80512 .12148 .80881 .12491 .81721 .12121 .81354 .11775 Mtetra
.42 .652 .955 r
.19398 .24765 .19881 .25043 .20549 .2507 .20067 .24793 Mtetra
.42 .654 .956 r
.20067 .24793 .20549 .2507 .2122 .25096 .20738 .24822 Mtetra
.422 .657 .957 r
.20738 .24822 .2122 .25096 .21894 .25121 .21413 .24848 Mtetra
.426 .661 .958 r
.21413 .24848 .21894 .25121 .22572 .25143 .22091 .24871 Mtetra
.432 .665 .959 r
.22091 .24871 .22572 .25143 .23254 .25161 .22772 .24891 Mtetra
.439 .671 .961 r
.22772 .24891 .23254 .25161 .23939 .25174 .23458 .24906 Mtetra
.449 .677 .961 r
.23458 .24906 .23939 .25174 .24628 .25181 .24147 .24916 Mtetra
.46 .684 .962 r
.24147 .24916 .24628 .25181 .25321 .25182 .24841 .24918 Mtetra
.472 .691 .963 r
.24841 .24918 .25321 .25182 .26018 .25174 .25538 .24912 Mtetra
.486 .699 .963 r
.25538 .24912 .26018 .25174 .26719 .25157 .2624 .24897 Mtetra
.502 .708 .963 r
.2624 .24897 .26719 .25157 .27424 .2513 .26946 .24872 Mtetra
.519 .717 .962 r
.26946 .24872 .27424 .2513 .28134 .25091 .27656 .24835 Mtetra
.537 .726 .961 r
.27656 .24835 .28134 .25091 .28848 .25039 .28371 .24786 Mtetra
.556 .736 .96 r
.28371 .24786 .28848 .25039 .29566 .24973 .2909 .24722 Mtetra
.575 .745 .957 r
.2909 .24722 .29566 .24973 .30288 .24892 .29813 .24643 Mtetra
.596 .755 .954 r
.29813 .24643 .30288 .24892 .31015 .24793 .30541 .24547 Mtetra
.616 .764 .95 r
.30541 .24547 .31015 .24793 .31747 .24676 .31273 .24433 Mtetra
.637 .773 .945 r
.31273 .24433 .31747 .24676 .32482 .24539 .32009 .24298 Mtetra
.659 .782 .939 r
.32009 .24298 .32482 .24539 .33222 .2438 .3275 .24143 Mtetra
.68 .79 .933 r
.3275 .24143 .33222 .2438 .33966 .24197 .33495 .23964 Mtetra
.701 .797 .925 r
.33495 .23964 .33966 .24197 .34714 .23989 .34245 .23759 Mtetra
.721 .804 .916 r
.34245 .23759 .34714 .23989 .35466 .23755 .34998 .23528 Mtetra
.742 .811 .907 r
.34998 .23528 .35466 .23755 .36222 .2349 .35755 .23268 Mtetra
.761 .817 .896 r
.35755 .23268 .36222 .2349 .36982 .23195 .36517 .22977 Mtetra
.78 .822 .885 r
.36517 .22977 .36982 .23195 .37745 .22865 .37282 .22652 Mtetra
.799 .826 .873 r
.37282 .22652 .37745 .22865 .38512 .22499 .3805 .22291 Mtetra
.817 .83 .859 r
.3805 .22291 .38512 .22499 .39282 .22093 .38822 .2189 Mtetra
.834 .832 .845 r
.38822 .2189 .39282 .22093 .40055 .21644 .39597 .21447 Mtetra
.85 .834 .83 r
.39597 .21447 .40055 .21644 .40831 .21147 .40375 .20955 Mtetra
.866 .834 .813 r
.40375 .20955 .40831 .21147 .41609 .20597 .41155 .2041 Mtetra
0 .408 .823 r
.55951 .17215 .56369 .17418 .57177 .17638 .56761 .17429 Mtetra
.061 .508 .894 r
.56761 .17429 .57177 .17638 .5799 .17805 .57575 .17589 Mtetra
.183 .585 .94 r
.57575 .17589 .5799 .17805 .58807 .17924 .58392 .17701 Mtetra
.286 .642 .966 r
.58392 .17701 .58807 .17924 .59627 .18 .59213 .1777 Mtetra
.371 .685 .979 r
.59213 .1777 .59627 .18 .6045 .18036 .60038 .17799 Mtetra
.44 .716 .983 r
.60038 .17799 .6045 .18036 .61275 .18036 .60864 .17792 Mtetra
.496 .738 .98 r
.60864 .17792 .61275 .18036 .62102 .18001 .61693 .17751 Mtetra
.543 .754 .975 r
.61693 .17751 .62102 .18001 .62932 .17934 .62524 .17678 Mtetra
.581 .766 .967 r
.62524 .17678 .62932 .17934 .63763 .17837 .63356 .17576 Mtetra
.613 .775 .958 r
.63356 .17576 .63763 .17837 .64595 .17713 .6419 .17446 Mtetra
.639 .781 .949 r
.6419 .17446 .64595 .17713 .65429 .17563 .65026 .17291 Mtetra
.661 .786 .94 r
.65026 .17291 .65429 .17563 .66263 .17389 .65862 .17112 Mtetra
.68 .789 .932 r
.65862 .17112 .66263 .17389 .67099 .17193 .66699 .16911 Mtetra
.696 .791 .924 r
.66699 .16911 .67099 .17193 .67935 .16975 .67537 .16689 Mtetra
.709 .793 .916 r
.67537 .16689 .67935 .16975 .68771 .16739 .68375 .16448 Mtetra
.721 .794 .909 r
.68375 .16448 .68771 .16739 .69609 .16485 .69214 .16189 Mtetra
.731 .794 .902 r
.69214 .16189 .69609 .16485 .70446 .16214 .70053 .15915 Mtetra
.74 .795 .896 r
.70053 .15915 .70446 .16214 .71284 .15929 .70893 .15625 Mtetra
.747 .795 .891 r
.70893 .15625 .71284 .15929 .72122 .15629 .71733 .15322 Mtetra
.754 .794 .886 r
.71733 .15322 .72122 .15629 .7296 .15318 .72572 .15006 Mtetra
.759 .794 .881 r
.72572 .15006 .7296 .15318 .73798 .14995 .73413 .1468 Mtetra
.764 .793 .877 r
.73413 .1468 .73798 .14995 .74636 .14662 .74253 .14343 Mtetra
.768 .793 .873 r
.74253 .14343 .74636 .14662 .75475 .14321 .75093 .13998 Mtetra
.771 .792 .87 r
.75093 .13998 .75475 .14321 .76314 .13971 .75934 .13645 Mtetra
.773 .791 .867 r
.75934 .13645 .76314 .13971 .77153 .13616 .76775 .13285 Mtetra
.775 .79 .865 r
.76775 .13285 .77153 .13616 .77992 .13254 .77616 .12921 Mtetra
.777 .789 .863 r
.77616 .12921 .77992 .13254 .78832 .12889 .78457 .12551 Mtetra
.778 .787 .861 r
.78457 .12551 .78832 .12889 .79672 .12519 .79299 .12179 Mtetra
.778 .786 .859 r
.79299 .12179 .79672 .12519 .80512 .12148 .80142 .11804 Mtetra
.778 .784 .858 r
.80142 .11804 .80512 .12148 .81354 .11775 .80985 .11427 Mtetra
.416 .65 .955 r
.18913 .24485 .19398 .24765 .20067 .24793 .19582 .24516 Mtetra
.415 .652 .956 r
.19582 .24516 .20067 .24793 .20738 .24822 .20253 .24546 Mtetra
.417 .655 .957 r
.20253 .24546 .20738 .24822 .21413 .24848 .20928 .24574 Mtetra
.421 .659 .959 r
.20928 .24574 .21413 .24848 .22091 .24871 .21607 .246 Mtetra
.426 .663 .96 r
.21607 .246 .22091 .24871 .22772 .24891 .22289 .24622 Mtetra
.433 .669 .961 r
.22289 .24622 .22772 .24891 .23458 .24906 .22974 .24639 Mtetra
.443 .675 .962 r
.22974 .24639 .23458 .24906 .24147 .24916 .23664 .2465 Mtetra
.454 .683 .963 r
.23664 .2465 .24147 .24916 .24841 .24918 .24358 .24655 Mtetra
.466 .69 .964 r
.24358 .24655 .24841 .24918 .25538 .24912 .25056 .24651 Mtetra
.48 .699 .965 r
.25056 .24651 .25538 .24912 .2624 .24897 .25758 .24639 Mtetra
.496 .708 .965 r
.25758 .24639 .2624 .24897 .26946 .24872 .26464 .24616 Mtetra
.512 .717 .965 r
.26464 .24616 .26946 .24872 .27656 .24835 .27175 .24582 Mtetra
.53 .727 .964 r
.27175 .24582 .27656 .24835 .28371 .24786 .2789 .24535 Mtetra
.549 .736 .963 r
.2789 .24535 .28371 .24786 .2909 .24722 .2861 .24474 Mtetra
.569 .746 .96 r
.2861 .24474 .2909 .24722 .29813 .24643 .29334 .24397 Mtetra
.59 .756 .958 r
.29334 .24397 .29813 .24643 .30541 .24547 .30063 .24304 Mtetra
.611 .766 .954 r
.30063 .24304 .30541 .24547 .31273 .24433 .30796 .24193 Mtetra
.632 .776 .949 r
.30796 .24193 .31273 .24433 .32009 .24298 .31533 .24062 Mtetra
.654 .785 .944 r
.31533 .24062 .32009 .24298 .3275 .24143 .32275 .2391 Mtetra
.675 .793 .937 r
.32275 .2391 .3275 .24143 .33495 .23964 .33021 .23735 Mtetra
.697 .802 .93 r
.33021 .23735 .33495 .23964 .34245 .23759 .33772 .23535 Mtetra
.718 .809 .922 r
.33772 .23535 .34245 .23759 .34998 .23528 .34526 .23308 Mtetra
.739 .816 .912 r
.34526 .23308 .34998 .23528 .35755 .23268 .35285 .23053 Mtetra
.759 .822 .902 r
.35285 .23053 .35755 .23268 .36517 .22977 .36048 .22766 Mtetra
.778 .828 .891 r
.36048 .22766 .36517 .22977 .37282 .22652 .36814 .22447 Mtetra
.798 .833 .879 r
.36814 .22447 .37282 .22652 .3805 .22291 .37584 .22091 Mtetra
.816 .837 .865 r
.37584 .22091 .3805 .22291 .38822 .2189 .38358 .21697 Mtetra
.834 .84 .851 r
.38358 .21697 .38822 .2189 .39597 .21447 .39135 .2126 Mtetra
.851 .842 .836 r
.39135 .2126 .39597 .21447 .40375 .20955 .39915 .20775 Mtetra
.868 .843 .819 r
.39915 .20775 .40375 .20955 .41155 .2041 .40697 .20237 Mtetra
0 .411 .814 r
.5553 .17027 .55951 .17215 .56761 .17429 .56341 .17231 Mtetra
.053 .515 .891 r
.56341 .17231 .56761 .17429 .57575 .17589 .57156 .17383 Mtetra
.18 .594 .941 r
.57156 .17383 .57575 .17589 .58392 .17701 .57975 .17486 Mtetra
.286 .652 .969 r
.57975 .17486 .58392 .17701 .59213 .1777 .58798 .17547 Mtetra
.372 .695 .982 r
.58798 .17547 .59213 .1777 .60038 .17799 .59623 .17569 Mtetra
.443 .725 .986 r
.59623 .17569 .60038 .17799 .60864 .17792 .60451 .17555 Mtetra
.5 .747 .983 r
.60451 .17555 .60864 .17792 .61693 .17751 .61282 .17507 Mtetra
.547 .763 .977 r
.61282 .17507 .61693 .17751 .62524 .17678 .62114 .17428 Mtetra
.585 .774 .969 r
.62114 .17428 .62524 .17678 .63356 .17576 .62948 .1732 Mtetra
.616 .782 .961 r
.62948 .1732 .63356 .17576 .6419 .17446 .63783 .17184 Mtetra
.643 .787 .951 r
.63783 .17184 .6419 .17446 .65026 .17291 .6462 .17023 Mtetra
.665 .791 .942 r
.6462 .17023 .65026 .17291 .65862 .17112 .65458 .16839 Mtetra
.683 .794 .933 r
.65458 .16839 .65862 .17112 .66699 .16911 .66297 .16632 Mtetra
.699 .796 .925 r
.66297 .16632 .66699 .16911 .67537 .16689 .67137 .16405 Mtetra
.712 .797 .917 r
.67137 .16405 .67537 .16689 .68375 .16448 .67977 .1616 Mtetra
.724 .798 .91 r
.67977 .1616 .68375 .16448 .69214 .16189 .68817 .15896 Mtetra
.734 .798 .903 r
.68817 .15896 .69214 .16189 .70053 .15915 .69658 .15617 Mtetra
.742 .798 .897 r
.69658 .15617 .70053 .15915 .70893 .15625 .705 .15323 Mtetra
.75 .798 .891 r
.705 .15323 .70893 .15625 .71733 .15322 .71341 .15015 Mtetra
.756 .797 .886 r
.71341 .15015 .71733 .15322 .72572 .15006 .72183 .14696 Mtetra
.761 .796 .881 r
.72183 .14696 .72572 .15006 .73413 .1468 .73025 .14365 Mtetra
.766 .795 .877 r
.73025 .14365 .73413 .1468 .74253 .14343 .73867 .14024 Mtetra
.769 .795 .873 r
.73867 .14024 .74253 .14343 .75093 .13998 .74709 .13675 Mtetra
.772 .793 .87 r
.74709 .13675 .75093 .13998 .75934 .13645 .75552 .13318 Mtetra
.775 .792 .867 r
.75552 .13318 .75934 .13645 .76775 .13285 .76395 .12955 Mtetra
.777 .791 .864 r
.76395 .12955 .76775 .13285 .77616 .12921 .77237 .12586 Mtetra
.778 .79 .862 r
.77237 .12586 .77616 .12921 .78457 .12551 .78081 .12213 Mtetra
.779 .788 .86 r
.78081 .12213 .78457 .12551 .79299 .12179 .78925 .11836 Mtetra
.779 .787 .859 r
.78925 .11836 .79299 .12179 .80142 .11804 .79769 .11457 Mtetra
.779 .785 .857 r
.79769 .11457 .80142 .11804 .80985 .11427 .80614 .11077 Mtetra
.41 .647 .955 r
.18426 .24205 .18913 .24485 .19582 .24516 .19094 .24237 Mtetra
.41 .65 .956 r
.19094 .24237 .19582 .24516 .20253 .24546 .19766 .2427 Mtetra
.411 .653 .958 r
.19766 .2427 .20253 .24546 .20928 .24574 .20441 .243 Mtetra
.415 .657 .959 r
.20441 .243 .20928 .24574 .21607 .246 .2112 .24328 Mtetra
.42 .661 .96 r
.2112 .24328 .21607 .246 .22289 .24622 .21802 .24352 Mtetra
.427 .667 .962 r
.21802 .24352 .22289 .24622 .22974 .24639 .22488 .24371 Mtetra
.436 .674 .963 r
.22488 .24371 .22974 .24639 .23664 .2465 .23178 .24385 Mtetra
.447 .681 .964 r
.23178 .24385 .23664 .2465 .24358 .24655 .23872 .24392 Mtetra
.459 .689 .965 r
.23872 .24392 .24358 .24655 .25056 .24651 .24571 .24391 Mtetra
.473 .698 .966 r
.24571 .24391 .25056 .24651 .25758 .24639 .25273 .24381 Mtetra
.489 .707 .967 r
.25273 .24381 .25758 .24639 .26464 .24616 .2598 .24361 Mtetra
.506 .717 .967 r
.2598 .24361 .26464 .24616 .27175 .24582 .26691 .24329 Mtetra
.524 .727 .966 r
.26691 .24329 .27175 .24582 .2789 .24535 .27407 .24285 Mtetra
.543 .737 .965 r
.27407 .24285 .2789 .24535 .2861 .24474 .28127 .24227 Mtetra
.563 .747 .964 r
.28127 .24227 .2861 .24474 .29334 .24397 .28852 .24154 Mtetra
.583 .758 .961 r
.28852 .24154 .29334 .24397 .30063 .24304 .29581 .24065 Mtetra
.605 .768 .958 r
.29581 .24065 .30063 .24304 .30796 .24193 .30315 .23957 Mtetra
.626 .778 .954 r
.30315 .23957 .30796 .24193 .31533 .24062 .31054 .2383 Mtetra
.648 .788 .949 r
.31054 .2383 .31533 .24062 .32275 .2391 .31796 .23682 Mtetra
.67 .797 .942 r
.31796 .23682 .32275 .2391 .33021 .23735 .32544 .23511 Mtetra
.692 .806 .935 r
.32544 .23511 .33021 .23735 .33772 .23535 .33295 .23315 Mtetra
.714 .814 .927 r
.33295 .23315 .33772 .23535 .34526 .23308 .34051 .23093 Mtetra
.735 .821 .918 r
.34051 .23093 .34526 .23308 .35285 .23053 .34811 .22843 Mtetra
.756 .828 .908 r
.34811 .22843 .35285 .23053 .36048 .22766 .35575 .22563 Mtetra
.776 .834 .897 r
.35575 .22563 .36048 .22766 .36814 .22447 .36343 .22249 Mtetra
.795 .84 .885 r
.36343 .22249 .36814 .22447 .37584 .22091 .37115 .219 Mtetra
.814 .844 .872 r
.37115 .219 .37584 .22091 .38358 .21697 .3789 .21513 Mtetra
.833 .848 .858 r
.3789 .21513 .38358 .21697 .39135 .2126 .38669 .21083 Mtetra
.851 .851 .842 r
.38669 .21083 .39135 .2126 .39915 .20775 .39451 .20607 Mtetra
.868 .853 .825 r
.39451 .20607 .39915 .20775 .40697 .20237 .40236 .20079 Mtetra
.885 .854 .807 r
.40236 .20079 .40697 .20237 .41483 .19636 .41024 .1949 Mtetra
0 .286 .688 r
.543 .166 .54724 .1676 .5553 .17027 .55107 .16853 Mtetra
0 .418 .807 r
.55107 .16853 .5553 .17027 .56341 .17231 .55919 .17046 Mtetra
.05 .524 .889 r
.55919 .17046 .56341 .17231 .57156 .17383 .56736 .17187 Mtetra
.18 .604 .942 r
.56736 .17187 .57156 .17383 .57975 .17486 .57556 .17282 Mtetra
.288 .663 .971 r
.57556 .17282 .57975 .17486 .58798 .17547 .5838 .17334 Mtetra
.376 .706 .985 r
.5838 .17334 .58798 .17547 .59623 .17569 .59207 .17347 Mtetra
.447 .736 .989 r
.59207 .17347 .59623 .17569 .60451 .17555 .60036 .17325 Mtetra
.504 .757 .986 r
.60036 .17325 .60451 .17555 .61282 .17507 .60868 .1727 Mtetra
.551 .772 .98 r
.60868 .1727 .61282 .17507 .62114 .17428 .61702 .17183 Mtetra
.589 .782 .972 r
.61702 .17183 .62114 .17428 .62948 .1732 .62537 .17068 Mtetra
.621 .789 .963 r
.62537 .17068 .62948 .1732 .63783 .17184 .63374 .16927 Mtetra
.647 .794 .953 r
.63374 .16927 .63783 .17184 .6462 .17023 .64213 .1676 Mtetra
.669 .797 .944 r
.64213 .1676 .6462 .17023 .65458 .16839 .65053 .16569 Mtetra
.687 .8 .935 r
.65053 .16569 .65458 .16839 .66297 .16632 .65893 .16357 Mtetra
.702 .801 .926 r
.65893 .16357 .66297 .16632 .67137 .16405 .66734 .16125 Mtetra
.716 .802 .918 r
.66734 .16125 .67137 .16405 .67977 .1616 .67576 .15874 Mtetra
.727 .802 .911 r
.67576 .15874 .67977 .1616 .68817 .15896 .68419 .15606 Mtetra
.737 .802 .904 r
.68419 .15606 .68817 .15896 .69658 .15617 .69262 .15321 Mtetra
.745 .801 .897 r
.69262 .15321 .69658 .15617 .705 .15323 .70105 .15022 Mtetra
.752 .801 .892 r
.70105 .15022 .705 .15323 .71341 .15015 .70948 .1471 Mtetra
.758 .8 .886 r
.70948 .1471 .71341 .15015 .72183 .14696 .71792 .14386 Mtetra
.763 .799 .882 r
.71792 .14386 .72183 .14696 .73025 .14365 .72636 .14051 Mtetra
.768 .798 .877 r
.72636 .14051 .73025 .14365 .73867 .14024 .73479 .13706 Mtetra
.771 .796 .873 r
.73479 .13706 .73867 .14024 .74709 .13675 .74324 .13352 Mtetra
.774 .795 .87 r
.74324 .13352 .74709 .13675 .75552 .13318 .75168 .12991 Mtetra
.777 .794 .867 r
.75168 .12991 .75552 .13318 .76395 .12955 .76012 .12623 Mtetra
.779 .792 .864 r
.76012 .12623 .76395 .12955 .77237 .12586 .76857 .1225 Mtetra
.78 .791 .862 r
.76857 .1225 .77237 .12586 .78081 .12213 .77702 .11873 Mtetra
.781 .789 .86 r
.77702 .11873 .78081 .12213 .78925 .11836 .78548 .11492 Mtetra
.781 .787 .858 r
.78548 .11492 .78925 .11836 .79769 .11457 .79394 .1111 Mtetra
.781 .786 .857 r
.79394 .1111 .79769 .11457 .80614 .11077 .80241 .10725 Mtetra
.404 .645 .955 r
.17936 .23922 .18426 .24205 .19094 .24237 .18605 .23958 Mtetra
.403 .647 .956 r
.18605 .23958 .19094 .24237 .19766 .2427 .19276 .23992 Mtetra
.405 .65 .958 r
.19276 .23992 .19766 .2427 .20441 .243 .19952 .24025 Mtetra
.408 .654 .959 r
.19952 .24025 .20441 .243 .2112 .24328 .2063 .24055 Mtetra
.413 .659 .961 r
.2063 .24055 .2112 .24328 .21802 .24352 .21313 .24082 Mtetra
.42 .665 .962 r
.21313 .24082 .21802 .24352 .22488 .24371 .21999 .24104 Mtetra
.429 .672 .964 r
.21999 .24104 .22488 .24371 .23178 .24385 .22689 .2412 Mtetra
.439 .679 .965 r
.22689 .2412 .23178 .24385 .23872 .24392 .23384 .2413 Mtetra
.452 .687 .967 r
.23384 .2413 .23872 .24392 .24571 .24391 .24082 .24132 Mtetra
.466 .696 .968 r
.24082 .24132 .24571 .24391 .25273 .24381 .24785 .24125 Mtetra
.481 .706 .968 r
.24785 .24125 .25273 .24381 .2598 .24361 .25493 .24107 Mtetra
.498 .716 .969 r
.25493 .24107 .2598 .24361 .26691 .24329 .26205 .24079 Mtetra
.516 .726 .969 r
.26205 .24079 .26691 .24329 .27407 .24285 .26921 .24038 Mtetra
.535 .737 .968 r
.26921 .24038 .27407 .24285 .28127 .24227 .27642 .23984 Mtetra
.555 .748 .967 r
.27642 .23984 .28127 .24227 .28852 .24154 .28367 .23914 Mtetra
.576 .759 .965 r
.28367 .23914 .28852 .24154 .29581 .24065 .29097 .23828 Mtetra
.598 .769 .962 r
.29097 .23828 .29581 .24065 .30315 .23957 .29832 .23724 Mtetra
.62 .78 .958 r
.29832 .23724 .30315 .23957 .31054 .2383 .30571 .23601 Mtetra
.642 .79 .953 r
.30571 .23601 .31054 .2383 .31796 .23682 .31315 .23458 Mtetra
.664 .8 .947 r
.31315 .23458 .31796 .23682 .32544 .23511 .32063 .23291 Mtetra
.687 .809 .941 r
.32063 .23291 .32544 .23511 .33295 .23315 .32816 .23101 Mtetra
.709 .818 .933 r
.32816 .23101 .33295 .23315 .34051 .23093 .33573 .22884 Mtetra
.73 .826 .924 r
.33573 .22884 .34051 .23093 .34811 .22843 .34334 .2264 Mtetra
.752 .834 .915 r
.34334 .2264 .34811 .22843 .35575 .22563 .35099 .22366 Mtetra
.772 .841 .904 r
.35099 .22366 .35575 .22563 .36343 .22249 .35869 .22059 Mtetra
.793 .847 .892 r
.35869 .22059 .36343 .22249 .37115 .219 .36642 .21717 Mtetra
.812 .852 .879 r
.36642 .21717 .37115 .219 .3789 .21513 .37419 .21338 Mtetra
.831 .856 .865 r
.37419 .21338 .3789 .21513 .38669 .21083 .38199 .20918 Mtetra
.85 .86 .85 r
.38199 .20918 .38669 .21083 .39451 .20607 .38983 .20452 Mtetra
.867 .863 .833 r
.38983 .20452 .39451 .20607 .40236 .20079 .3977 .19935 Mtetra
.885 .865 .814 r
.3977 .19935 .40236 .20079 .41024 .1949 .4056 .1936 Mtetra
0 .295 .677 r
.53873 .16456 .543 .166 .55107 .16853 .54681 .16694 Mtetra
0 .429 .801 r
.54681 .16694 .55107 .16853 .55919 .17046 .55495 .16874 Mtetra
.051 .536 .888 r
.55495 .16874 .55919 .17046 .56736 .17187 .56312 .17003 Mtetra
.183 .617 .943 r
.56312 .17003 .56736 .17187 .57556 .17282 .57134 .17086 Mtetra
.292 .676 .974 r
.57134 .17086 .57556 .17282 .5838 .17334 .57959 .17128 Mtetra
.381 .717 .988 r
.57959 .17128 .5838 .17334 .59207 .17347 .58787 .17133 Mtetra
.452 .747 .992 r
.58787 .17133 .59207 .17347 .60036 .17325 .59618 .17102 Mtetra
.51 .767 .989 r
.59618 .17102 .60036 .17325 .60868 .1727 .60452 .17038 Mtetra
.556 .781 .982 r
.60452 .17038 .60868 .1727 .61702 .17183 .61287 .16945 Mtetra
.594 .79 .974 r
.61287 .16945 .61702 .17183 .62537 .17068 .62124 .16822 Mtetra
.625 .797 .964 r
.62124 .16822 .62537 .17068 .63374 .16927 .62963 .16674 Mtetra
.651 .801 .955 r
.62963 .16674 .63374 .16927 .64213 .1676 .63803 .165 Mtetra
.673 .803 .945 r
.63803 .165 .64213 .1676 .65053 .16569 .64645 .16303 Mtetra
.691 .805 .936 r
.64645 .16303 .65053 .16569 .65893 .16357 .65487 .16085 Mtetra
.706 .806 .927 r
.65487 .16085 .65893 .16357 .66734 .16125 .6633 .15847 Mtetra
.719 .806 .919 r
.6633 .15847 .66734 .16125 .67576 .15874 .67174 .15591 Mtetra
.73 .806 .911 r
.67174 .15591 .67576 .15874 .68419 .15606 .68018 .15317 Mtetra
.74 .805 .904 r
.68018 .15317 .68419 .15606 .69262 .15321 .68863 .15027 Mtetra
.748 .804 .898 r
.68863 .15027 .69262 .15321 .70105 .15022 .69708 .14723 Mtetra
.755 .804 .892 r
.69708 .14723 .70105 .15022 .70948 .1471 .70553 .14406 Mtetra
.761 .802 .886 r
.70553 .14406 .70948 .1471 .71792 .14386 .71398 .14077 Mtetra
.766 .801 .881 r
.71398 .14077 .71792 .14386 .72636 .14051 .72244 .13737 Mtetra
.77 .8 .877 r
.72244 .13737 .72636 .14051 .73479 .13706 .7309 .13387 Mtetra
.774 .798 .873 r
.7309 .13387 .73479 .13706 .74324 .13352 .73936 .13029 Mtetra
.776 .797 .87 r
.73936 .13029 .74324 .13352 .75168 .12991 .74782 .12663 Mtetra
.779 .795 .866 r
.74782 .12663 .75168 .12991 .76012 .12623 .75628 .12291 Mtetra
.78 .794 .864 r
.75628 .12291 .76012 .12623 .76857 .1225 .76475 .11914 Mtetra
.782 .792 .861 r
.76475 .11914 .76857 .1225 .77702 .11873 .77322 .11532 Mtetra
.782 .79 .859 r
.77322 .11532 .77702 .11873 .78548 .11492 .78169 .11147 Mtetra
.782 .788 .857 r
.78169 .11147 .78548 .11492 .79394 .1111 .79017 .1076 Mtetra
.782 .786 .856 r
.79017 .1076 .79394 .1111 .80241 .10725 .79866 .10371 Mtetra
.398 .641 .955 r
.17444 .23639 .17936 .23922 .18605 .23958 .18112 .23677 Mtetra
.397 .644 .956 r
.18112 .23677 .18605 .23958 .19276 .23992 .18784 .23714 Mtetra
.398 .647 .958 r
.18784 .23714 .19276 .23992 .19952 .24025 .19459 .23749 Mtetra
.401 .651 .959 r
.19459 .23749 .19952 .24025 .2063 .24055 .20138 .23782 Mtetra
.405 .656 .961 r
.20138 .23782 .2063 .24055 .21313 .24082 .20821 .23812 Mtetra
.412 .662 .963 r
.20821 .23812 .21313 .24082 .21999 .24104 .21507 .23837 Mtetra
.421 .669 .965 r
.21507 .23837 .21999 .24104 .22689 .2412 .22198 .23856 Mtetra
.431 .677 .966 r
.22198 .23856 .22689 .2412 .23384 .2413 .22892 .23868 Mtetra
.443 .686 .968 r
.22892 .23868 .23384 .2413 .24082 .24132 .23591 .23873 Mtetra
.457 .695 .969 r
.23591 .23873 .24082 .24132 .24785 .24125 .24295 .23869 Mtetra
.473 .705 .97 r
.24295 .23869 .24785 .24125 .25493 .24107 .25002 .23855 Mtetra
.489 .715 .971 r
.25002 .23855 .25493 .24107 .26205 .24079 .25714 .2383 Mtetra
.508 .726 .971 r
.25714 .2383 .26205 .24079 .26921 .24038 .26431 .23793 Mtetra
.527 .737 .971 r
.26431 .23793 .26921 .24038 .27642 .23984 .27153 .23742 Mtetra
.547 .748 .97 r
.27153 .23742 .27642 .23984 .28367 .23914 .27879 .23677 Mtetra
.568 .759 .968 r
.27879 .23677 .28367 .23914 .29097 .23828 .28609 .23595 Mtetra
.59 .771 .966 r
.28609 .23595 .29097 .23828 .29832 .23724 .29345 .23495 Mtetra
.612 .782 .962 r
.29345 .23495 .29832 .23724 .30571 .23601 .30085 .23377 Mtetra
.635 .793 .958 r
.30085 .23377 .30571 .23601 .31315 .23458 .30829 .23238 Mtetra
.658 .803 .953 r
.30829 .23238 .31315 .23458 .32063 .23291 .31578 .23077 Mtetra
.68 .813 .946 r
.31578 .23077 .32063 .23291 .32816 .23101 .32332 .22892 Mtetra
.703 .822 .939 r
.32332 .22892 .32816 .23101 .33573 .22884 .3309 .22681 Mtetra
.725 .831 .931 r
.3309 .22681 .33573 .22884 .34334 .2264 .33853 .22443 Mtetra
.747 .839 .921 r
.33853 .22443 .34334 .2264 .35099 .22366 .34619 .22176 Mtetra
.768 .847 .911 r
.34619 .22176 .35099 .22366 .35869 .22059 .3539 .21876 Mtetra
.789 .854 .899 r
.3539 .21876 .35869 .22059 .36642 .21717 .36165 .21543 Mtetra
.809 .86 .886 r
.36165 .21543 .36642 .21717 .37419 .21338 .36944 .21173 Mtetra
.828 .865 .872 r
.36944 .21173 .37419 .21338 .38199 .20918 .37726 .20762 Mtetra
.847 .869 .857 r
.37726 .20762 .38199 .20918 .38983 .20452 .38511 .20308 Mtetra
.866 .873 .841 r
.38511 .20308 .38983 .20452 .3977 .19935 .393 .19804 Mtetra
.884 .877 .823 r
.393 .19804 .3977 .19935 .4056 .1936 .40092 .19246 Mtetra
0 .311 .672 r
.53443 .16329 .53873 .16456 .54681 .16694 .54252 .16548 Mtetra
0 .444 .799 r
.54252 .16548 .54681 .16694 .55495 .16874 .55067 .16712 Mtetra
.057 .551 .888 r
.55067 .16712 .55495 .16874 .56312 .17003 .55886 .16828 Mtetra
.189 .631 .944 r
.55886 .16828 .56312 .17003 .57134 .17086 .56709 .169 Mtetra
.299 .689 .976 r
.56709 .169 .57134 .17086 .57959 .17128 .57536 .16931 Mtetra
.388 .73 .99 r
.57536 .16931 .57959 .17128 .58787 .17133 .58366 .16925 Mtetra
.459 .758 .994 r
.58366 .16925 .58787 .17133 .59618 .17102 .59198 .16885 Mtetra
.516 .777 .991 r
.59198 .16885 .59618 .17102 .60452 .17038 .60033 .16813 Mtetra
.562 .79 .984 r
.60033 .16813 .60452 .17038 .61287 .16945 .6087 .16711 Mtetra
.6 .798 .976 r
.6087 .16711 .61287 .16945 .62124 .16822 .61709 .16581 Mtetra
.631 .804 .966 r
.61709 .16581 .62124 .16822 .62963 .16674 .6255 .16425 Mtetra
.656 .808 .956 r
.6255 .16425 .62963 .16674 .63803 .165 .63392 .16244 Mtetra
.677 .81 .946 r
.63392 .16244 .63803 .165 .64645 .16303 .64235 .16041 Mtetra
.695 .811 .937 r
.64235 .16041 .64645 .16303 .65487 .16085 .65079 .15817 Mtetra
.71 .811 .928 r
.65079 .15817 .65487 .16085 .6633 .15847 .65924 .15572 Mtetra
.723 .811 .919 r
.65924 .15572 .6633 .15847 .67174 .15591 .66769 .1531 Mtetra
.734 .81 .912 r
.66769 .1531 .67174 .15591 .68018 .15317 .67615 .1503 Mtetra
.743 .809 .904 r
.67615 .1503 .68018 .15317 .68863 .15027 .68462 .14735 Mtetra
.751 .808 .898 r
.68462 .14735 .68863 .15027 .69708 .14723 .69308 .14426 Mtetra
.758 .807 .892 r
.69308 .14426 .69708 .14723 .70553 .14406 .70156 .14103 Mtetra
.763 .805 .886 r
.70156 .14103 .70553 .14406 .71398 .14077 .71003 .13769 Mtetra
.768 .804 .881 r
.71003 .13769 .71398 .14077 .72244 .13737 .7185 .13423 Mtetra
.772 .802 .877 r
.7185 .13423 .72244 .13737 .7309 .13387 .72698 .13069 Mtetra
.776 .8 .873 r
.72698 .13069 .7309 .13387 .73936 .13029 .73546 .12706 Mtetra
.779 .799 .869 r
.73546 .12706 .73936 .13029 .74782 .12663 .74394 .12335 Mtetra
.781 .797 .866 r
.74394 .12335 .74782 .12663 .75628 .12291 .75242 .11958 Mtetra
.782 .795 .863 r
.75242 .11958 .75628 .12291 .76475 .11914 .7609 .11576 Mtetra
.783 .793 .86 r
.7609 .11576 .76475 .11914 .77322 .11532 .76939 .1119 Mtetra
.784 .791 .858 r
.76939 .1119 .77322 .11532 .78169 .11147 .77788 .108 Mtetra
.784 .789 .856 r
.77788 .108 .78169 .11147 .79017 .1076 .78638 .10409 Mtetra
.784 .787 .855 r
.78638 .10409 .79017 .1076 .79866 .10371 .79488 .10015 Mtetra
.39 .638 .954 r
.16949 .23354 .17444 .23639 .18112 .23677 .17617 .23394 Mtetra
.389 .64 .956 r
.17617 .23394 .18112 .23677 .18784 .23714 .18289 .23434 Mtetra
.39 .644 .958 r
.18289 .23434 .18784 .23714 .19459 .23749 .18964 .23473 Mtetra
.393 .648 .959 r
.18964 .23473 .19459 .23749 .20138 .23782 .19643 .23509 Mtetra
.397 .653 .961 r
.19643 .23509 .20138 .23782 .20821 .23812 .20326 .23541 Mtetra
.404 .66 .963 r
.20326 .23541 .20821 .23812 .21507 .23837 .21012 .23569 Mtetra
.412 .667 .965 r
.21012 .23569 .21507 .23837 .22198 .23856 .21703 .23591 Mtetra
.423 .675 .967 r
.21703 .23591 .22198 .23856 .22892 .23868 .22398 .23607 Mtetra
.435 .683 .969 r
.22398 .23607 .22892 .23868 .23591 .23873 .23097 .23615 Mtetra
.448 .693 .97 r
.23097 .23615 .23591 .23873 .24295 .23869 .23801 .23615 Mtetra
.464 .703 .972 r
.23801 .23615 .24295 .23869 .25002 .23855 .24509 .23605 Mtetra
.48 .714 .973 r
.24509 .23605 .25002 .23855 .25714 .2383 .25221 .23583 Mtetra
.498 .725 .973 r
.25221 .23583 .25714 .2383 .26431 .23793 .25938 .2355 Mtetra
.518 .736 .973 r
.25938 .2355 .26431 .23793 .27153 .23742 .2666 .23503 Mtetra
.538 .748 .973 r
.2666 .23503 .27153 .23742 .27879 .23677 .27387 .23441 Mtetra
.559 .76 .972 r
.27387 .23441 .27879 .23677 .28609 .23595 .28118 .23364 Mtetra
.581 .771 .97 r
.28118 .23364 .28609 .23595 .29345 .23495 .28854 .23269 Mtetra
.604 .783 .967 r
.28854 .23269 .29345 .23495 .30085 .23377 .29595 .23156 Mtetra
.627 .795 .963 r
.29595 .23156 .30085 .23377 .30829 .23238 .3034 .23022 Mtetra
.65 .806 .958 r
.3034 .23022 .30829 .23238 .31578 .23077 .3109 .22866 Mtetra
.673 .816 .952 r
.3109 .22866 .31578 .23077 .32332 .22892 .31845 .22687 Mtetra
.696 .826 .945 r
.31845 .22687 .32332 .22892 .3309 .22681 .32604 .22483 Mtetra
.719 .836 .937 r
.32604 .22483 .3309 .22681 .33853 .22443 .33368 .22252 Mtetra
.741 .845 .928 r
.33368 .22252 .33853 .22443 .34619 .22176 .34136 .21992 Mtetra
.763 .853 .918 r
.34136 .21992 .34619 .22176 .3539 .21876 .34908 .21701 Mtetra
.784 .86 .906 r
.34908 .21701 .3539 .21876 .36165 .21543 .35684 .21376 Mtetra
.805 .867 .894 r
.35684 .21376 .36165 .21543 .36944 .21173 .36464 .21016 Mtetra
.825 .873 .881 r
.36464 .21016 .36944 .21173 .37726 .20762 .37248 .20616 Mtetra
.844 .879 .866 r
.37248 .20616 .37726 .20762 .38511 .20308 .38035 .20175 Mtetra
.863 .884 .85 r
.38035 .20175 .38511 .20308 .393 .19804 .38826 .19687 Mtetra
.881 .888 .833 r
.38826 .19687 .393 .19804 .40092 .19246 .39619 .19148 Mtetra
.899 .893 .815 r
.39619 .19148 .40092 .19246 .40886 .18627 .40416 .18552 Mtetra
.407 0 0 r
.52204 .15963 .52639 .16049 .53443 .16329 .5301 .16217 Mtetra
0 .333 .672 r
.5301 .16217 .53443 .16329 .54252 .16548 .53821 .16415 Mtetra
0 .463 .799 r
.53821 .16415 .54252 .16548 .55067 .16712 .54637 .16562 Mtetra
.068 .568 .889 r
.54637 .16562 .55067 .16712 .55886 .16828 .55457 .16663 Mtetra
.199 .647 .946 r
.55457 .16663 .55886 .16828 .56709 .169 .56282 .16722 Mtetra
.308 .703 .978 r
.56282 .16722 .56709 .169 .57536 .16931 .5711 .16742 Mtetra
.396 .743 .993 r
.5711 .16742 .57536 .16931 .58366 .16925 .57942 .16725 Mtetra
.467 .769 .996 r
.57942 .16725 .58366 .16925 .59198 .16885 .58776 .16675 Mtetra
.524 .787 .993 r
.58776 .16675 .59198 .16885 .60033 .16813 .59612 .16594 Mtetra
.569 .799 .986 r
.59612 .16594 .60033 .16813 .6087 .16711 .60451 .16483 Mtetra
.606 .807 .977 r
.60451 .16483 .6087 .16711 .61709 .16581 .61292 .16345 Mtetra
.637 .812 .967 r
.61292 .16345 .61709 .16581 .6255 .16425 .62134 .16181 Mtetra
.662 .814 .957 r
.62134 .16181 .6255 .16425 .63392 .16244 .62978 .15993 Mtetra
.682 .816 .947 r
.62978 .15993 .63392 .16244 .64235 .16041 .63822 .15782 Mtetra
.7 .816 .937 r
.63822 .15782 .64235 .16041 .65079 .15817 .64668 .15551 Mtetra
.714 .816 .928 r
.64668 .15551 .65079 .15817 .65924 .15572 .65515 .153 Mtetra
.727 .815 .92 r
.65515 .153 .65924 .15572 .66769 .1531 .66362 .15031 Mtetra
.737 .814 .912 r
.66362 .15031 .66769 .1531 .67615 .1503 .6721 .14745 Mtetra
.746 .813 .904 r
.6721 .14745 .67615 .1503 .68462 .14735 .68058 .14444 Mtetra
.754 .811 .898 r
.68058 .14444 .68462 .14735 .69308 .14426 .68907 .14129 Mtetra
.761 .81 .892 r
.68907 .14129 .69308 .14426 .70156 .14103 .69756 .13801 Mtetra
.766 .808 .886 r
.69756 .13801 .70156 .14103 .71003 .13769 .70605 .13461 Mtetra
.771 .806 .881 r
.70605 .13461 .71003 .13769 .7185 .13423 .71455 .13111 Mtetra
.775 .804 .876 r
.71455 .13111 .7185 .13423 .72698 .13069 .72304 .12751 Mtetra
.778 .802 .872 r
.72304 .12751 .72698 .13069 .73546 .12706 .73154 .12382 Mtetra
.781 .8 .869 r
.73154 .12382 .73546 .12706 .74394 .12335 .74004 .12007 Mtetra
.783 .798 .865 r
.74004 .12007 .74394 .12335 .75242 .11958 .74854 .11625 Mtetra
.784 .796 .862 r
.74854 .11625 .75242 .11958 .7609 .11576 .75704 .11238 Mtetra
.785 .794 .86 r
.75704 .11238 .7609 .11576 .76939 .1119 .76554 .10847 Mtetra
.786 .792 .857 r
.76554 .10847 .76939 .1119 .77788 .108 .77405 .10452 Mtetra
.786 .79 .856 r
.77405 .10452 .77788 .108 .78638 .10409 .78257 .10055 Mtetra
.785 .787 .854 r
.78257 .10055 .78638 .10409 .79488 .10015 .79109 .09657 Mtetra
.383 .634 .954 r
.16452 .23067 .16949 .23354 .17617 .23394 .1712 .23111 Mtetra
.381 .637 .956 r
.1712 .23111 .17617 .23394 .18289 .23434 .17792 .23154 Mtetra
.382 .64 .957 r
.17792 .23154 .18289 .23434 .18964 .23473 .18467 .23196 Mtetra
.384 .645 .959 r
.18467 .23196 .18964 .23473 .19643 .23509 .19146 .23235 Mtetra
.389 .65 .961 r
.19146 .23235 .19643 .23509 .20326 .23541 .19828 .23271 Mtetra
.395 .656 .963 r
.19828 .23271 .20326 .23541 .21012 .23569 .20515 .23302 Mtetra
.403 .663 .965 r
.20515 .23302 .21012 .23569 .21703 .23591 .21206 .23327 Mtetra
.413 .672 .967 r
.21206 .23327 .21703 .23591 .22398 .23607 .21901 .23347 Mtetra
.425 .681 .969 r
.21901 .23347 .22398 .23607 .23097 .23615 .226 .23358 Mtetra
.438 .69 .971 r
.226 .23358 .23097 .23615 .23801 .23615 .23304 .23362 Mtetra
.454 .701 .973 r
.23304 .23362 .23801 .23615 .24509 .23605 .24012 .23355 Mtetra
.47 .712 .974 r
.24012 .23355 .24509 .23605 .25221 .23583 .24725 .23338 Mtetra
.488 .723 .975 r
.24725 .23338 .25221 .23583 .25938 .2355 .25442 .23308 Mtetra
.508 .735 .976 r
.25442 .23308 .25938 .2355 .2666 .23503 .26165 .23266 Mtetra
.528 .747 .976 r
.26165 .23266 .2666 .23503 .27387 .23441 .26892 .23209 Mtetra
.55 .76 .975 r
.26892 .23209 .27387 .23441 .28118 .23364 .27624 .23136 Mtetra
.572 .772 .973 r
.27624 .23136 .28118 .23364 .28854 .23269 .2836 .23047 Mtetra
.595 .784 .971 r
.2836 .23047 .28854 .23269 .29595 .23156 .29102 .22938 Mtetra
.618 .796 .967 r
.29102 .22938 .29595 .23156 .3034 .23022 .29848 .2281 Mtetra
.641 .808 .963 r
.29848 .2281 .3034 .23022 .3109 .22866 .30599 .22661 Mtetra
.665 .819 .958 r
.30599 .22661 .3109 .22866 .31845 .22687 .31354 .22488 Mtetra
.688 .83 .951 r
.31354 .22488 .31845 .22687 .32604 .22483 .32115 .22291 Mtetra
.712 .84 .943 r
.32115 .22291 .32604 .22483 .33368 .22252 .32879 .22067 Mtetra
.734 .85 .935 r
.32879 .22067 .33368 .22252 .34136 .21992 .33648 .21815 Mtetra
.757 .859 .925 r
.33648 .21815 .34136 .21992 .34908 .21701 .34422 .21532 Mtetra
.778 .867 .914 r
.34422 .21532 .34908 .21701 .35684 .21376 .35199 .21218 Mtetra
.8 .874 .902 r
.35199 .21218 .35684 .21376 .36464 .21016 .35981 .20868 Mtetra
.82 .881 .889 r
.35981 .20868 .36464 .21016 .37248 .20616 .36766 .2048 Mtetra
.84 .888 .875 r
.36766 .2048 .37248 .20616 .38035 .20175 .37555 .20053 Mtetra
.859 .894 .86 r
.37555 .20053 .38035 .20175 .38826 .19687 .38347 .19581 Mtetra
.877 .9 .843 r
.38347 .19581 .38826 .19687 .39619 .19148 .39142 .19063 Mtetra
.895 .906 .826 r
.39142 .19063 .39619 .19148 .40416 .18552 .3994 .18493 Mtetra
.379 0 0 r
.51766 .15892 .52204 .15963 .5301 .16217 .52573 .16118 Mtetra
0 .359 .677 r
.52573 .16118 .5301 .16217 .53821 .16415 .53386 .16294 Mtetra
0 .485 .802 r
.53386 .16294 .53821 .16415 .54637 .16562 .54203 .16423 Mtetra
.082 .587 .891 r
.54203 .16423 .54637 .16562 .55457 .16663 .55026 .16508 Mtetra
.212 .664 .948 r
.55026 .16508 .55457 .16663 .56282 .16722 .55852 .16553 Mtetra
.32 .718 .98 r
.55852 .16553 .56282 .16722 .5711 .16742 .56682 .1656 Mtetra
.407 .756 .994 r
.56682 .1656 .5711 .16742 .57942 .16725 .57515 .16532 Mtetra
.476 .781 .998 r
.57515 .16532 .57942 .16725 .58776 .16675 .5835 .16472 Mtetra
.532 .798 .994 r
.5835 .16472 .58776 .16675 .59612 .16594 .59189 .1638 Mtetra
.577 .809 .987 r
.59189 .1638 .59612 .16594 .60451 .16483 .60029 .1626 Mtetra
.613 .815 .978 r
.60029 .1626 .60451 .16483 .61292 .16345 .60872 .16113 Mtetra
.643 .819 .968 r
.60872 .16113 .61292 .16345 .62134 .16181 .61716 .15941 Mtetra
.667 .821 .957 r
.61716 .15941 .62134 .16181 .62978 .15993 .62561 .15745 Mtetra
.688 .822 .947 r
.62561 .15745 .62978 .15993 .63822 .15782 .63408 .15527 Mtetra
.705 .822 .937 r
.63408 .15527 .63822 .15782 .64668 .15551 .64255 .15288 Mtetra
.719 .821 .928 r
.64255 .15288 .64668 .15551 .65515 .153 .65104 .1503 Mtetra
.731 .82 .92 r
.65104 .1503 .65515 .153 .66362 .15031 .65953 .14755 Mtetra
.741 .818 .912 r
.65953 .14755 .66362 .15031 .6721 .14745 .66803 .14463 Mtetra
.75 .816 .904 r
.66803 .14463 .6721 .14745 .68058 .14444 .67653 .14155 Mtetra
.758 .814 .898 r
.67653 .14155 .68058 .14444 .68907 .14129 .68504 .13834 Mtetra
.764 .813 .891 r
.68504 .13834 .68907 .14129 .69756 .13801 .69354 .135 Mtetra
.769 .811 .886 r
.69354 .135 .69756 .13801 .70605 .13461 .70206 .13154 Mtetra
.774 .808 .881 r
.70206 .13154 .70605 .13461 .71455 .13111 .71057 .12798 Mtetra
.778 .806 .876 r
.71057 .12798 .71455 .13111 .72304 .12751 .71908 .12433 Mtetra
.781 .804 .872 r
.71908 .12433 .72304 .12751 .73154 .12382 .7276 .12059 Mtetra
.783 .802 .868 r
.7276 .12059 .73154 .12382 .74004 .12007 .73611 .11678 Mtetra
.785 .8 .865 r
.73611 .11678 .74004 .12007 .74854 .11625 .74463 .11291 Mtetra
.787 .798 .862 r
.74463 .11291 .74854 .11625 .75704 .11238 .75315 .10898 Mtetra
.787 .795 .859 r
.75315 .10898 .75704 .11238 .76554 .10847 .76168 .10502 Mtetra
.788 .793 .857 r
.76168 .10502 .76554 .10847 .77405 .10452 .7702 .10102 Mtetra
.788 .791 .855 r
.7702 .10102 .77405 .10452 .78257 .10055 .77874 .097 Mtetra
.787 .788 .853 r
.77874 .097 .78257 .10055 .79109 .09657 .78727 .09297 Mtetra
.374 .63 .953 r
.15952 .22779 .16452 .23067 .1712 .23111 .1662 .22826 Mtetra
.373 .633 .955 r
.1662 .22826 .1712 .23111 .17792 .23154 .17291 .22873 Mtetra
.373 .636 .957 r
.17291 .22873 .17792 .23154 .18467 .23196 .17966 .22918 Mtetra
.375 .641 .959 r
.17966 .22918 .18467 .23196 .19146 .23235 .18645 .2296 Mtetra
.379 .646 .961 r
.18645 .2296 .19146 .23235 .19828 .23271 .19328 .23 Mtetra
.385 .653 .963 r
.19328 .23 .19828 .23271 .20515 .23302 .20014 .23034 Mtetra
.393 .66 .966 r
.20014 .23034 .20515 .23302 .21206 .23327 .20705 .23064 Mtetra
.403 .668 .968 r
.20705 .23064 .21206 .23327 .21901 .23347 .214 .23087 Mtetra
.414 .677 .97 r
.214 .23087 .21901 .23347 .226 .23358 .221 .23102 Mtetra
.428 .687 .972 r
.221 .23102 .226 .23358 .23304 .23362 .22804 .23109 Mtetra
.443 .698 .974 r
.22804 .23109 .23304 .23362 .24012 .23355 .23512 .23107 Mtetra
.46 .709 .976 r
.23512 .23107 .24012 .23355 .24725 .23338 .24225 .23094 Mtetra
.478 .721 .977 r
.24225 .23094 .24725 .23338 .25442 .23308 .24943 .23069 Mtetra
.497 .734 .978 r
.24943 .23069 .25442 .23308 .26165 .23266 .25666 .23031 Mtetra
.518 .746 .978 r
.25666 .23031 .26165 .23266 .26892 .23209 .26393 .22979 Mtetra
.539 .759 .978 r
.26393 .22979 .26892 .23209 .27624 .23136 .27126 .22912 Mtetra
.561 .772 .977 r
.27126 .22912 .27624 .23136 .2836 .23047 .27863 .22827 Mtetra
.584 .785 .975 r
.27863 .22827 .2836 .23047 .29102 .22938 .28605 .22725 Mtetra
.608 .797 .972 r
.28605 .22725 .29102 .22938 .29848 .2281 .29352 .22602 Mtetra
.632 .81 .968 r
.29352 .22602 .29848 .2281 .30599 .22661 .30103 .22459 Mtetra
.656 .822 .963 r
.30103 .22459 .30599 .22661 .31354 .22488 .3086 .22294 Mtetra
.68 .833 .957 r
.3086 .22294 .31354 .22488 .32115 .22291 .31621 .22104 Mtetra
.703 .844 .95 r
.31621 .22104 .32115 .22291 .32879 .22067 .32387 .21888 Mtetra
.726 .855 .942 r
.32387 .21888 .32879 .22067 .33648 .21815 .33157 .21644 Mtetra
.749 .864 .933 r
.33157 .21644 .33648 .21815 .34422 .21532 .33931 .21371 Mtetra
.771 .873 .922 r
.33931 .21371 .34422 .21532 .35199 .21218 .3471 .21066 Mtetra
.793 .882 .911 r
.3471 .21066 .35199 .21218 .35981 .20868 .35493 .20728 Mtetra
.814 .889 .898 r
.35493 .20728 .35981 .20868 .36766 .2048 .3628 .20354 Mtetra
.834 .897 .884 r
.3628 .20354 .36766 .2048 .37555 .20053 .3707 .19941 Mtetra
.853 .904 .87 r
.3707 .19941 .37555 .20053 .38347 .19581 .37864 .19487 Mtetra
.871 .911 .854 r
.37864 .19487 .38347 .19581 .39142 .19063 .3866 .1899 Mtetra
.888 .919 .838 r
.3866 .1899 .39142 .19063 .3994 .18493 .3946 .18447 Mtetra
.904 .929 .822 r
.3946 .18447 .3994 .18493 .4074 .17872 .40261 .17861 Mtetra
.469 0 0 r
.50521 .15593 .50965 .15615 .51766 .15892 .51324 .15835 Mtetra
.345 0 0 r
.51324 .15835 .51766 .15892 .52573 .16118 .52133 .16032 Mtetra
0 .39 .686 r
.52133 .16032 .52573 .16118 .53386 .16294 .52947 .16184 Mtetra
0 .511 .808 r
.52947 .16184 .53386 .16294 .54203 .16423 .53767 .16294 Mtetra
.102 .609 .895 r
.53767 .16294 .54203 .16423 .55026 .16508 .54591 .16362 Mtetra
.228 .682 .951 r
.54591 .16362 .55026 .16508 .55852 .16553 .55419 .16392 Mtetra
.333 .734 .982 r
.55419 .16392 .55852 .16553 .56682 .1656 .5625 .16386 Mtetra
.418 .77 .996 r
.5625 .16386 .56682 .1656 .57515 .16532 .57085 .16346 Mtetra
.487 .793 .999 r
.57085 .16346 .57515 .16532 .5835 .16472 .57922 .16274 Mtetra
.541 .808 .995 r
.57922 .16274 .5835 .16472 .59189 .1638 .58762 .16172 Mtetra
.585 .818 .988 r
.58762 .16172 .59189 .1638 .60029 .1626 .59605 .16043 Mtetra
.621 .824 .978 r
.59605 .16043 .60029 .1626 .60872 .16113 .60449 .15886 Mtetra
.65 .827 .968 r
.60449 .15886 .60872 .16113 .61716 .15941 .61295 .15705 Mtetra
.673 .828 .958 r
.61295 .15705 .61716 .15941 .62561 .15745 .62142 .15501 Mtetra
.693 .828 .947 r
.62142 .15501 .62561 .15745 .63408 .15527 .62991 .15275 Mtetra
.71 .827 .937 r
.62991 .15275 .63408 .15527 .64255 .15288 .6384 .15029 Mtetra
.724 .826 .928 r
.6384 .15029 .64255 .15288 .65104 .1503 .64691 .14763 Mtetra
.735 .824 .919 r
.64691 .14763 .65104 .1503 .65953 .14755 .65542 .14481 Mtetra
.745 .822 .911 r
.65542 .14481 .65953 .14755 .66803 .14463 .66393 .14182 Mtetra
.754 .82 .904 r
.66393 .14182 .66803 .14463 .67653 .14155 .67245 .13868 Mtetra
.761 .818 .897 r
.67245 .13868 .67653 .14155 .68504 .13834 .68098 .1354 Mtetra
.767 .815 .891 r
.68098 .1354 .68504 .13834 .69354 .135 .68951 .132 Mtetra
.772 .813 .885 r
.68951 .132 .69354 .135 .70206 .13154 .69804 .12848 Mtetra
.777 .811 .88 r
.69804 .12848 .70206 .13154 .71057 .12798 .70657 .12486 Mtetra
.78 .809 .875 r
.70657 .12486 .71057 .12798 .71908 .12433 .7151 .12114 Mtetra
.783 .806 .871 r
.7151 .12114 .71908 .12433 .7276 .12059 .72363 .11735 Mtetra
.786 .804 .867 r
.72363 .11735 .7276 .12059 .73611 .11678 .73217 .11348 Mtetra
.787 .801 .864 r
.73217 .11348 .73611 .11678 .74463 .11291 .74071 .10956 Mtetra
.789 .799 .861 r
.74071 .10956 .74463 .11291 .75315 .10898 .74924 .10558 Mtetra
.79 .796 .858 r
.74924 .10558 .75315 .10898 .76168 .10502 .75779 .10156 Mtetra
.79 .794 .856 r
.75779 .10156 .76168 .10502 .7702 .10102 .76633 .09751 Mtetra
.79 .791 .854 r
.76633 .09751 .7702 .10102 .77874 .097 .77488 .09344 Mtetra
.789 .789 .852 r
.77488 .09344 .77874 .097 .78727 .09297 .78343 .08935 Mtetra
.365 .626 .953 r
.1545 .2249 .15952 .22779 .1662 .22826 .16117 .2254 Mtetra
.363 .628 .955 r
.16117 .2254 .1662 .22826 .17291 .22873 .16789 .2259 Mtetra
.363 .632 .957 r
.16789 .2259 .17291 .22873 .17966 .22918 .17463 .22639 Mtetra
.365 .636 .959 r
.17463 .22639 .17966 .22918 .18645 .2296 .18142 .22685 Mtetra
.369 .642 .961 r
.18142 .22685 .18645 .2296 .19328 .23 .18824 .22728 Mtetra
.375 .649 .963 r
.18824 .22728 .19328 .23 .20014 .23034 .19511 .22767 Mtetra
.382 .656 .966 r
.19511 .22767 .20014 .23034 .20705 .23064 .20202 .228 Mtetra
.392 .665 .968 r
.20202 .228 .20705 .23064 .214 .23087 .20897 .22827 Mtetra
.403 .674 .97 r
.20897 .22827 .214 .23087 .221 .23102 .21596 .22847 Mtetra
.417 .684 .973 r
.21596 .22847 .221 .23102 .22804 .23109 .223 .22858 Mtetra
.431 .695 .975 r
.223 .22858 .22804 .23109 .23512 .23107 .23009 .2286 Mtetra
.448 .707 .977 r
.23009 .2286 .23512 .23107 .24225 .23094 .23722 .22852 Mtetra
.466 .719 .979 r
.23722 .22852 .24225 .23094 .24943 .23069 .2444 .22831 Mtetra
.485 .732 .98 r
.2444 .22831 .24943 .23069 .25666 .23031 .25163 .22799 Mtetra
.506 .745 .981 r
.25163 .22799 .25666 .23031 .26393 .22979 .25891 .22752 Mtetra
.527 .758 .981 r
.25891 .22752 .26393 .22979 .27126 .22912 .26624 .22689 Mtetra
.55 .771 .98 r
.26624 .22689 .27126 .22912 .27863 .22827 .27362 .22611 Mtetra
.573 .785 .979 r
.27362 .22611 .27863 .22827 .28605 .22725 .28104 .22514 Mtetra
.597 .798 .977 r
.28104 .22514 .28605 .22725 .29352 .22602 .28852 .22399 Mtetra
.621 .811 .973 r
.28852 .22399 .29352 .22602 .30103 .22459 .29604 .22262 Mtetra
.645 .824 .969 r
.29604 .22262 .30103 .22459 .3086 .22294 .30362 .22104 Mtetra
.67 .836 .963 r
.30362 .22104 .3086 .22294 .31621 .22104 .31124 .21921 Mtetra
.694 .848 .957 r
.31124 .21921 .31621 .22104 .32387 .21888 .3189 .21714 Mtetra
.717 .859 .949 r
.3189 .21714 .32387 .21888 .33157 .21644 .32661 .21479 Mtetra
.741 .869 .94 r
.32661 .21479 .33157 .21644 .33931 .21371 .33437 .21216 Mtetra
.763 .879 .93 r
.33437 .21216 .33931 .21371 .3471 .21066 .34217 .20922 Mtetra
.785 .888 .919 r
.34217 .20922 .3471 .21066 .35493 .20728 .35001 .20596 Mtetra
.806 .897 .907 r
.35001 .20596 .35493 .20728 .3628 .20354 .35789 .20235 Mtetra
.826 .906 .894 r
.35789 .20235 .3628 .20354 .3707 .19941 .36581 .19838 Mtetra
.846 .914 .88 r
.36581 .19838 .3707 .19941 .37864 .19487 .37376 .19403 Mtetra
.864 .922 .866 r
.37376 .19403 .37864 .19487 .3866 .1899 .38174 .18928 Mtetra
.88 .931 .851 r
.38174 .18928 .3866 .1899 .3946 .18447 .38975 .18413 Mtetra
.894 .942 .836 r
.38975 .18413 .3946 .18447 .40261 .17861 .39778 .1786 Mtetra
.903 .956 .821 r
.39778 .1786 .40261 .17861 .41064 .17234 .40581 .17276 Mtetra
.509 0 0 r
.49274 .15346 .49725 .15313 .50521 .15593 .50073 .15582 Mtetra
.424 0 0 r
.50073 .15582 .50521 .15593 .51324 .15835 .50879 .15788 Mtetra
.305 0 0 r
.50879 .15788 .51324 .15835 .52133 .16032 .51689 .15956 Mtetra
0 .425 .699 r
.51689 .15956 .52133 .16032 .52947 .16184 .52506 .16085 Mtetra
0 .539 .815 r
.52506 .16085 .52947 .16184 .53767 .16294 .53327 .16174 Mtetra
.124 .632 .899 r
.53327 .16174 .53767 .16294 .54591 .16362 .54153 .16225 Mtetra
.247 .701 .953 r
.54153 .16225 .54591 .16362 .55419 .16392 .54982 .16239 Mtetra
.349 .751 .983 r
.54982 .16239 .55419 .16392 .5625 .16386 .55816 .16219 Mtetra
.432 .784 .997 r
.55816 .16219 .5625 .16386 .57085 .16346 .56652 .16166 Mtetra
.498 .805 1 r
.56652 .16166 .57085 .16346 .57922 .16274 .57492 .16083 Mtetra
.551 .819 .996 r
.57492 .16083 .57922 .16274 .58762 .16172 .58333 .1597 Mtetra
.594 .827 .988 r
.58333 .1597 .58762 .16172 .59605 .16043 .59178 .1583 Mtetra
.629 .832 .979 r
.59178 .1583 .59605 .16043 .60449 .15886 .60024 .15664 Mtetra
.657 .834 .968 r
.60024 .15664 .60449 .15886 .61295 .15705 .60871 .15474 Mtetra
.68 .834 .958 r
.60871 .15474 .61295 .15705 .62142 .15501 .61721 .15261 Mtetra
.699 .834 .947 r
.61721 .15261 .62142 .15501 .62991 .15275 .62571 .15026 Mtetra
.715 .832 .937 r
.62571 .15026 .62991 .15275 .6384 .15029 .63422 .14772 Mtetra
.729 .831 .928 r
.63422 .14772 .6384 .15029 .64691 .14763 .64275 .14499 Mtetra
.74 .828 .919 r
.64275 .14499 .64691 .14763 .65542 .14481 .65128 .14209 Mtetra
.75 .826 .911 r
.65128 .14209 .65542 .14481 .66393 .14182 .65981 .13903 Mtetra
.758 .824 .904 r
.65981 .13903 .66393 .14182 .67245 .13868 .66835 .13582 Mtetra
.765 .821 .897 r
.66835 .13582 .67245 .13868 .68098 .1354 .6769 .13247 Mtetra
.771 .818 .89 r
.6769 .13247 .68098 .1354 .68951 .132 .68544 .129 Mtetra
.776 .816 .885 r
.68544 .129 .68951 .132 .69804 .12848 .69399 .12542 Mtetra
.78 .813 .879 r
.69399 .12542 .69804 .12848 .70657 .12486 .70254 .12174 Mtetra
.783 .811 .875 r
.70254 .12174 .70657 .12486 .7151 .12114 .7111 .11796 Mtetra
.786 .808 .87 r
.7111 .11796 .7151 .12114 .72363 .11735 .71965 .11411 Mtetra
.788 .806 .866 r
.71965 .11411 .72363 .11735 .73217 .11348 .7282 .11018 Mtetra
.79 .803 .863 r
.7282 .11018 .73217 .11348 .74071 .10956 .73676 .1062 Mtetra
.791 .8 .86 r
.73676 .1062 .74071 .10956 .74924 .10558 .74531 .10216 Mtetra
.792 .798 .857 r
.74531 .10216 .74924 .10558 .75779 .10156 .75387 .09809 Mtetra
.792 .795 .855 r
.75387 .09809 .75779 .10156 .76633 .09751 .76244 .09398 Mtetra
.792 .792 .852 r
.76244 .09398 .76633 .09751 .77488 .09344 .771 .08985 Mtetra
.791 .789 .851 r
.771 .08985 .77488 .09344 .78343 .08935 .77958 .08571 Mtetra
.356 .621 .952 r
.14945 .22199 .1545 .2249 .16117 .2254 .15612 .22253 Mtetra
.353 .624 .954 r
.15612 .22253 .16117 .2254 .16789 .2259 .16283 .22307 Mtetra
.353 .627 .956 r
.16283 .22307 .16789 .2259 .17463 .22639 .16958 .2236 Mtetra
.355 .632 .958 r
.16958 .2236 .17463 .22639 .18142 .22685 .17636 .2241 Mtetra
.358 .637 .96 r
.17636 .2241 .18142 .22685 .18824 .22728 .18318 .22457 Mtetra
.363 .644 .963 r
.18318 .22457 .18824 .22728 .19511 .22767 .19005 .22499 Mtetra
.371 .652 .965 r
.19005 .22499 .19511 .22767 .20202 .228 .19695 .22537 Mtetra
.38 .66 .968 r
.19695 .22537 .20202 .228 .20897 .22827 .2039 .22568 Mtetra
.391 .67 .971 r
.2039 .22568 .20897 .22827 .21596 .22847 .2109 .22592 Mtetra
.404 .68 .973 r
.2109 .22592 .21596 .22847 .223 .22858 .21794 .22608 Mtetra
.419 .691 .976 r
.21794 .22608 .223 .22858 .23009 .2286 .22502 .22614 Mtetra
.435 .703 .978 r
.22502 .22614 .23009 .2286 .23722 .22852 .23216 .22611 Mtetra
.453 .716 .98 r
.23216 .22611 .23722 .22852 .2444 .22831 .23934 .22596 Mtetra
.472 .729 .982 r
.23934 .22596 .2444 .22831 .25163 .22799 .24658 .22568 Mtetra
.493 .743 .983 r
.24658 .22568 .25163 .22799 .25891 .22752 .25386 .22527 Mtetra
.515 .756 .984 r
.25386 .22527 .25891 .22752 .26624 .22689 .26119 .2247 Mtetra
.537 .77 .984 r
.26119 .2247 .26624 .22689 .27362 .22611 .26857 .22398 Mtetra
.561 .784 .983 r
.26857 .22398 .27362 .22611 .28104 .22514 .276 .22307 Mtetra
.585 .798 .981 r
.276 .22307 .28104 .22514 .28852 .22399 .28348 .22198 Mtetra
.609 .812 .978 r
.28348 .22198 .28852 .22399 .29604 .22262 .29101 .22069 Mtetra
.634 .826 .974 r
.29101 .22069 .29604 .22262 .30362 .22104 .29859 .21918 Mtetra
.658 .839 .969 r
.29859 .21918 .30362 .22104 .31124 .21921 .30622 .21744 Mtetra
.683 .851 .963 r
.30622 .21744 .31124 .21921 .3189 .21714 .3139 .21546 Mtetra
.707 .863 .956 r
.3139 .21546 .3189 .21714 .32661 .21479 .32162 .21321 Mtetra
.731 .874 .948 r
.32162 .21321 .32661 .21479 .33437 .21216 .32939 .21068 Mtetra
.754 .885 .938 r
.32939 .21068 .33437 .21216 .34217 .20922 .3372 .20785 Mtetra
.776 .895 .928 r
.3372 .20785 .34217 .20922 .35001 .20596 .34505 .20472 Mtetra
.797 .905 .916 r
.34505 .20472 .35001 .20596 .35789 .20235 .35294 .20125 Mtetra
.817 .914 .904 r
.35294 .20125 .35789 .20235 .36581 .19838 .36087 .19744 Mtetra
.836 .923 .891 r
.36087 .19744 .36581 .19838 .37376 .19403 .36884 .19328 Mtetra
.854 .932 .877 r
.36884 .19328 .37376 .19403 .38174 .18928 .37683 .18875 Mtetra
.869 .943 .863 r
.37683 .18875 .38174 .18928 .38975 .18413 .38485 .18387 Mtetra
.881 .954 .849 r
.38485 .18387 .38975 .18413 .39778 .1786 .39289 .17867 Mtetra
.887 .968 .835 r
.39289 .17867 .39778 .1786 .40581 .17276 .40094 .17323 Mtetra
.456 0 0 r
.4882 .15385 .49274 .15346 .50073 .15582 .49622 .1558 Mtetra
.374 0 0 r
.49622 .1558 .50073 .15582 .50879 .15788 .50429 .15751 Mtetra
.26 0 0 r
.50429 .15751 .50879 .15788 .51689 .15956 .51242 .1589 Mtetra
0 .462 .715 r
.51242 .1589 .51689 .15956 .52506 .16085 .52061 .15994 Mtetra
.016 .569 .824 r
.52061 .15994 .52506 .16085 .53327 .16174 .52884 .16063 Mtetra
.15 .656 .904 r
.52884 .16063 .53327 .16174 .54153 .16225 .53711 .16095 Mtetra
.268 .721 .956 r
.53711 .16095 .54153 .16225 .54982 .16239 .54543 .16094 Mtetra
.366 .767 .985 r
.54543 .16094 .54982 .16239 .55816 .16219 .55378 .16059 Mtetra
.446 .798 .998 r
.55378 .16059 .55816 .16219 .56652 .16166 .56217 .15993 Mtetra
.511 .818 1 r
.56217 .15993 .56652 .16166 .57492 .16083 .57058 .15897 Mtetra
.562 .83 .996 r
.57058 .15897 .57492 .16083 .58333 .1597 .57902 .15773 Mtetra
.603 .837 .988 r
.57902 .15773 .58333 .1597 .59178 .1583 .58748 .15622 Mtetra
.637 .84 .978 r
.58748 .15622 .59178 .1583 .60024 .15664 .59596 .15446 Mtetra
.664 .841 .968 r
.59596 .15446 .60024 .15664 .60871 .15474 .60445 .15246 Mtetra
.687 .841 .957 r
.60445 .15246 .60871 .15474 .61721 .15261 .61297 .15024 Mtetra
.705 .84 .947 r
.61297 .15024 .61721 .15261 .62571 .15026 .62149 .14781 Mtetra
.721 .838 .937 r
.62149 .14781 .62571 .15026 .63422 .14772 .63002 .14518 Mtetra
.734 .835 .927 r
.63002 .14518 .63422 .14772 .64275 .14499 .63857 .14237 Mtetra
.745 .833 .919 r
.63857 .14237 .64275 .14499 .65128 .14209 .64712 .13939 Mtetra
.754 .83 .91 r
.64712 .13939 .65128 .14209 .65981 .13903 .65567 .13626 Mtetra
.762 .827 .903 r
.65567 .13626 .65981 .13903 .66835 .13582 .66423 .13297 Mtetra
.769 .824 .896 r
.66423 .13297 .66835 .13582 .6769 .13247 .67279 .12956 Mtetra
.774 .821 .89 r
.67279 .12956 .6769 .13247 .68544 .129 .68136 .12602 Mtetra
.779 .818 .884 r
.68136 .12602 .68544 .129 .69399 .12542 .68993 .12237 Mtetra
.783 .816 .878 r
.68993 .12237 .69399 .12542 .70254 .12174 .6985 .11862 Mtetra
.786 .813 .874 r
.6985 .11862 .70254 .12174 .7111 .11796 .70707 .11478 Mtetra
.789 .81 .869 r
.70707 .11478 .7111 .11796 .71965 .11411 .71564 .11087 Mtetra
.791 .807 .865 r
.71564 .11087 .71965 .11411 .7282 .11018 .72421 .10688 Mtetra
.792 .804 .862 r
.72421 .10688 .7282 .11018 .73676 .1062 .73279 .10283 Mtetra
.793 .802 .859 r
.73279 .10283 .73676 .1062 .74531 .10216 .74136 .09874 Mtetra
.794 .799 .856 r
.74136 .09874 .74531 .10216 .75387 .09809 .74994 .0946 Mtetra
.794 .796 .853 r
.74994 .0946 .75387 .09809 .76244 .09398 .75852 .09044 Mtetra
.794 .793 .851 r
.75852 .09044 .76244 .09398 .771 .08985 .76711 .08625 Mtetra
.793 .79 .849 r
.76711 .08625 .771 .08985 .77958 .08571 .77569 .08205 Mtetra
.345 .616 .951 r
.14437 .21906 .14945 .22199 .15612 .22253 .15104 .21965 Mtetra
.343 .619 .953 r
.15104 .21965 .15612 .22253 .16283 .22307 .15775 .22023 Mtetra
.342 .622 .955 r
.15775 .22023 .16283 .22307 .16958 .2236 .16449 .22079 Mtetra
.343 .627 .957 r
.16449 .22079 .16958 .2236 .17636 .2241 .17127 .22134 Mtetra
.346 .632 .96 r
.17127 .22134 .17636 .2241 .18318 .22457 .17809 .22185 Mtetra
.352 .639 .962 r
.17809 .22185 .18318 .22457 .19005 .22499 .18495 .22231 Mtetra
.359 .647 .965 r
.18495 .22231 .19005 .22499 .19695 .22537 .19186 .22273 Mtetra
.368 .656 .968 r
.19186 .22273 .19695 .22537 .2039 .22568 .19881 .22309 Mtetra
.378 .665 .97 r
.19881 .22309 .2039 .22568 .2109 .22592 .2058 .22338 Mtetra
.391 .676 .973 r
.2058 .22338 .2109 .22592 .21794 .22608 .21284 .22358 Mtetra
.406 .687 .976 r
.21284 .22358 .21794 .22608 .22502 .22614 .21993 .2237 Mtetra
.422 .7 .979 r
.21993 .2237 .22502 .22614 .23216 .22611 .22706 .22371 Mtetra
.44 .712 .981 r
.22706 .22371 .23216 .22611 .23934 .22596 .23425 .22361 Mtetra
.459 .726 .983 r
.23425 .22361 .23934 .22596 .24658 .22568 .24148 .22339 Mtetra
.479 .74 .985 r
.24148 .22339 .24658 .22568 .25386 .22527 .24877 .22304 Mtetra
.501 .754 .986 r
.24877 .22304 .25386 .22527 .26119 .2247 .2561 .22253 Mtetra
.524 .769 .987 r
.2561 .22253 .26119 .2247 .26857 .22398 .26349 .22187 Mtetra
.547 .783 .986 r
.26349 .22187 .26857 .22398 .276 .22307 .27092 .22104 Mtetra
.571 .798 .985 r
.27092 .22104 .276 .22307 .28348 .22198 .27841 .22002 Mtetra
.596 .812 .983 r
.27841 .22002 .28348 .22198 .29101 .22069 .28594 .2188 Mtetra
.621 .827 .979 r
.28594 .2188 .29101 .22069 .29859 .21918 .29353 .21738 Mtetra
.646 .84 .975 r
.29353 .21738 .29859 .21918 .30622 .21744 .30117 .21572 Mtetra
.671 .854 .97 r
.30117 .21572 .30622 .21744 .3139 .21546 .30885 .21383 Mtetra
.695 .866 .963 r
.30885 .21383 .3139 .21546 .32162 .21321 .31658 .21168 Mtetra
.719 .878 .955 r
.31658 .21168 .32162 .21321 .32939 .21068 .32436 .20926 Mtetra
.742 .89 .946 r
.32436 .20926 .32939 .21068 .3372 .20785 .33218 .20655 Mtetra
.765 .901 .936 r
.33218 .20655 .3372 .20785 .34505 .20472 .34004 .20355 Mtetra
.786 .911 .925 r
.34004 .20355 .34505 .20472 .35294 .20125 .34795 .20023 Mtetra
.807 .921 .914 r
.34795 .20023 .35294 .20125 .36087 .19744 .35589 .19659 Mtetra
.825 .931 .901 r
.35589 .19659 .36087 .19744 .36884 .19328 .36387 .19261 Mtetra
.842 .942 .888 r
.36387 .19261 .36884 .19328 .37683 .18875 .37187 .18831 Mtetra
.856 .953 .875 r
.37187 .18831 .37683 .18875 .38485 .18387 .37991 .1837 Mtetra
.866 .965 .862 r
.37991 .1837 .38485 .18387 .39289 .17867 .38796 .17881 Mtetra
.869 .978 .848 r
.38796 .17881 .39289 .17867 .40094 .17323 .39602 .17373 Mtetra
.858 .992 .833 r
.39602 .17373 .40094 .17323 .40899 .16769 .40408 .1686 Mtetra
.822 1 .812 r
.40408 .1686 .40899 .16769 .41702 .16228 .41213 .16362 Mtetra
.453 0 0 r
.46767 .15121 .47233 .14992 .48024 .15181 .47562 .15266 Mtetra
.444 0 0 r
.47562 .15266 .48024 .15181 .4882 .15385 .48361 .15427 Mtetra
.399 0 0 r
.48361 .15427 .4882 .15385 .49622 .1558 .49165 .15583 Mtetra
.32 0 0 r
.49165 .15583 .49622 .1558 .50429 .15751 .49976 .15721 Mtetra
.212 0 0 r
.49976 .15721 .50429 .15751 .51242 .1589 .50791 .15832 Mtetra
0 .5 .732 r
.50791 .15832 .51242 .1589 .52061 .15994 .51612 .15912 Mtetra
.051 .599 .835 r
.51612 .15912 .52061 .15994 .52884 .16063 .52437 .1596 Mtetra
.178 .681 .91 r
.52437 .1596 .52884 .16063 .53711 .16095 .53267 .15974 Mtetra
.291 .741 .959 r
.53267 .15974 .53711 .16095 .54543 .16094 .541 .15956 Mtetra
.385 .784 .986 r
.541 .15956 .54543 .16094 .55378 .16059 .54937 .15906 Mtetra
.462 .812 .998 r
.54937 .15906 .55378 .16059 .56217 .15993 .55778 .15826 Mtetra
.524 .83 1 r
.55778 .15826 .56217 .15993 .57058 .15897 .56621 .15717 Mtetra
.573 .84 .995 r
.56621 .15717 .57058 .15897 .57902 .15773 .57467 .15581 Mtetra
.613 .846 .987 r
.57467 .15581 .57902 .15773 .58748 .15622 .58315 .15419 Mtetra
.646 .848 .978 r
.58315 .15419 .58748 .15622 .59596 .15446 .59165 .15232 Mtetra
.672 .848 .967 r
.59165 .15232 .59596 .15446 .60445 .15246 .60017 .15022 Mtetra
.694 .847 .956 r
.60017 .15022 .60445 .15246 .61297 .15024 .6087 .1479 Mtetra
.712 .845 .946 r
.6087 .1479 .61297 .15024 .62149 .14781 .61724 .14538 Mtetra
.727 .843 .936 r
.61724 .14538 .62149 .14781 .63002 .14518 .6258 .14267 Mtetra
.739 .84 .927 r
.6258 .14267 .63002 .14518 .63857 .14237 .63436 .13977 Mtetra
.75 .837 .918 r
.63436 .13977 .63857 .14237 .64712 .13939 .64293 .13671 Mtetra
.759 .834 .91 r
.64293 .13671 .64712 .13939 .65567 .13626 .6515 .1335 Mtetra
.766 .831 .902 r
.6515 .1335 .65567 .13626 .66423 .13297 .66008 .13014 Mtetra
.772 .827 .895 r
.66008 .13014 .66423 .13297 .67279 .12956 .66867 .12665 Mtetra
.778 .824 .889 r
.66867 .12665 .67279 .12956 .68136 .12602 .67725 .12304 Mtetra
.782 .821 .883 r
.67725 .12304 .68136 .12602 .68993 .12237 .68584 .11933 Mtetra
.786 .818 .878 r
.68584 .11933 .68993 .12237 .6985 .11862 .69443 .11551 Mtetra
.789 .815 .873 r
.69443 .11551 .6985 .11862 .70707 .11478 .70302 .1116 Mtetra
.792 .812 .868 r
.70302 .1116 .70707 .11478 .71564 .11087 .71161 .10762 Mtetra
.794 .809 .864 r
.71161 .10762 .71564 .11087 .72421 .10688 .7202 .10357 Mtetra
.795 .806 .861 r
.7202 .10357 .72421 .10688 .73279 .10283 .72879 .09946 Mtetra
.796 .803 .858 r
.72879 .09946 .73279 .10283 .74136 .09874 .73739 .0953 Mtetra
.796 .8 .855 r
.73739 .0953 .74136 .09874 .74994 .0946 .74598 .0911 Mtetra
.797 .797 .852 r
.74598 .0911 .74994 .0946 .75852 .09044 .75458 .08687 Mtetra
.796 .794 .85 r
.75458 .08687 .75852 .09044 .76711 .08625 .76318 .08263 Mtetra
.795 .791 .848 r
.76318 .08263 .76711 .08625 .77569 .08205 .77179 .07837 Mtetra
.334 .61 .95 r
.13927 .21612 .14437 .21906 .15104 .21965 .14594 .21675 Mtetra
.331 .613 .952 r
.14594 .21675 .15104 .21965 .15775 .22023 .15264 .21737 Mtetra
.33 .617 .954 r
.15264 .21737 .15775 .22023 .16449 .22079 .15938 .21798 Mtetra
.331 .621 .956 r
.15938 .21798 .16449 .22079 .17127 .22134 .16615 .21857 Mtetra
.334 .627 .959 r
.16615 .21857 .17127 .22134 .17809 .22185 .17297 .21912 Mtetra
.339 .634 .961 r
.17297 .21912 .17809 .22185 .18495 .22231 .17983 .21964 Mtetra
.346 .641 .964 r
.17983 .21964 .18495 .22231 .19186 .22273 .18673 .2201 Mtetra
.354 .65 .967 r
.18673 .2201 .19186 .22273 .19881 .22309 .19368 .2205 Mtetra
.365 .66 .97 r
.19368 .2205 .19881 .22309 .2058 .22338 .20067 .22084 Mtetra
.377 .671 .973 r
.20067 .22084 .2058 .22338 .21284 .22358 .20771 .2211 Mtetra
.391 .683 .976 r
.20771 .2211 .21284 .22358 .21993 .2237 .2148 .22126 Mtetra
.407 .695 .979 r
.2148 .22126 .21993 .2237 .22706 .22371 .22193 .22133 Mtetra
.425 .708 .982 r
.22193 .22133 .22706 .22371 .23425 .22361 .22912 .22129 Mtetra
.444 .722 .985 r
.22912 .22129 .23425 .22361 .24148 .22339 .23635 .22113 Mtetra
.464 .736 .987 r
.23635 .22113 .24148 .22339 .24877 .22304 .24364 .22083 Mtetra
.486 .751 .988 r
.24364 .22083 .24877 .22304 .2561 .22253 .25098 .22039 Mtetra
.509 .766 .989 r
.25098 .22039 .2561 .22253 .26349 .22187 .25836 .2198 Mtetra
.532 .782 .989 r
.25836 .2198 .26349 .22187 .27092 .22104 .2658 .21904 Mtetra
.556 .797 .989 r
.2658 .21904 .27092 .22104 .27841 .22002 .27329 .21809 Mtetra
.581 .812 .987 r
.27329 .21809 .27841 .22002 .28594 .2188 .28084 .21695 Mtetra
.606 .827 .984 r
.28084 .21695 .28594 .2188 .29353 .21738 .28843 .21561 Mtetra
.632 .841 .981 r
.28843 .21561 .29353 .21738 .30117 .21572 .29607 .21405 Mtetra
.657 .855 .976 r
.29607 .21405 .30117 .21572 .30885 .21383 .30376 .21225 Mtetra
.682 .869 .97 r
.30376 .21225 .30885 .21383 .31658 .21168 .3115 .2102 Mtetra
.706 .882 .963 r
.3115 .2102 .31658 .21168 .32436 .20926 .31929 .2079 Mtetra
.73 .894 .954 r
.31929 .2079 .32436 .20926 .33218 .20655 .32712 .20531 Mtetra
.752 .906 .945 r
.32712 .20531 .33218 .20655 .34004 .20355 .33499 .20245 Mtetra
.774 .917 .935 r
.33499 .20245 .34004 .20355 .34795 .20023 .34291 .19928 Mtetra
.794 .928 .923 r
.34291 .19928 .34795 .20023 .35589 .19659 .35086 .19581 Mtetra
.812 .939 .911 r
.35086 .19581 .35589 .19659 .36387 .19261 .35885 .19203 Mtetra
.828 .95 .899 r
.35885 .19203 .36387 .19261 .37187 .18831 .36687 .18795 Mtetra
.841 .961 .886 r
.36687 .18795 .37187 .18831 .37991 .1837 .37492 .18359 Mtetra
.848 .973 .873 r
.37492 .18359 .37991 .1837 .38796 .17881 .38298 .179 Mtetra
.848 .985 .86 r
.38298 .179 .38796 .17881 .39602 .17373 .39105 .17425 Mtetra
.833 .996 .844 r
.39105 .17425 .39602 .17373 .40408 .1686 .39913 .16948 Mtetra
.792 .999 .822 r
.39913 .16948 .40408 .1686 .41213 .16362 .40719 .16487 Mtetra
.706 .979 .782 r
.40719 .16487 .41213 .16362 .42015 .15907 .41523 .16063 Mtetra
.361 0 0 r
.45502 .15173 .45976 .1502 .46767 .15121 .46297 .15241 Mtetra
.392 0 0 r
.46297 .15241 .46767 .15121 .47562 .15266 .47095 .15348 Mtetra
.384 0 0 r
.47095 .15348 .47562 .15266 .48361 .15427 .47898 .15471 Mtetra
.34 0 0 r
.47898 .15471 .48361 .15427 .49165 .15583 .48705 .15592 Mtetra
.264 0 0 r
.48705 .15592 .49165 .15583 .49976 .15721 .49518 .15699 Mtetra
.161 0 0 r
.49518 .15699 .49976 .15721 .50791 .15832 .50336 .15782 Mtetra
0 .539 .75 r
.50336 .15782 .50791 .15832 .51612 .15912 .51159 .15838 Mtetra
.088 .631 .845 r
.51159 .15838 .51612 .15912 .52437 .1596 .51987 .15864 Mtetra
.209 .706 .915 r
.51987 .15864 .52437 .1596 .53267 .15974 .52818 .15859 Mtetra
.315 .761 .961 r
.52818 .15859 .53267 .15974 .541 .15956 .53654 .15824 Mtetra
.405 .8 .987 r
.53654 .15824 .541 .15956 .54937 .15906 .54494 .15759 Mtetra
.479 .826 .998 r
.54494 .15759 .54937 .15906 .55778 .15826 .55336 .15665 Mtetra
.538 .841 .999 r
.55336 .15665 .55778 .15826 .56621 .15717 .56181 .15543 Mtetra
.585 .85 .994 r
.56181 .15543 .56621 .15717 .57467 .15581 .57029 .15394 Mtetra
.624 .855 .986 r
.57029 .15394 .57467 .15581 .58315 .15419 .57879 .1522 Mtetra
.655 .856 .977 r
.57879 .1522 .58315 .15419 .59165 .15232 .58731 .15023 Mtetra
.68 .855 .966 r
.58731 .15023 .59165 .15232 .60017 .15022 .59585 .14802 Mtetra
.701 .854 .955 r
.59585 .14802 .60017 .15022 .6087 .1479 .6044 .14561 Mtetra
.718 .851 .945 r
.6044 .14561 .6087 .1479 .61724 .14538 .61297 .14299 Mtetra
.733 .848 .935 r
.61297 .14299 .61724 .14538 .6258 .14267 .62154 .14018 Mtetra
.745 .845 .926 r
.62154 .14018 .6258 .14267 .63436 .13977 .63013 .1372 Mtetra
.755 .841 .917 r
.63013 .1372 .63436 .13977 .64293 .13671 .63872 .13406 Mtetra
.763 .838 .909 r
.63872 .13406 .64293 .13671 .6515 .1335 .64731 .13076 Mtetra
.77 .834 .901 r
.64731 .13076 .6515 .1335 .66008 .13014 .65591 .12733 Mtetra
.776 .83 .894 r
.65591 .12733 .66008 .13014 .66867 .12665 .66451 .12376 Mtetra
.782 .827 .888 r
.66451 .12376 .66867 .12665 .67725 .12304 .67312 .12008 Mtetra
.786 .824 .882 r
.67312 .12008 .67725 .12304 .68584 .11933 .68173 .11628 Mtetra
.789 .82 .876 r
.68173 .11628 .68584 .11933 .69443 .11551 .69034 .1124 Mtetra
.792 .817 .872 r
.69034 .1124 .69443 .11551 .70302 .1116 .69895 .10842 Mtetra
.795 .814 .867 r
.69895 .10842 .70302 .1116 .71161 .10762 .70756 .10437 Mtetra
.796 .811 .863 r
.70756 .10437 .71161 .10762 .7202 .10357 .71617 .10025 Mtetra
.798 .807 .86 r
.71617 .10025 .7202 .10357 .72879 .09946 .72478 .09607 Mtetra
.799 .804 .856 r
.72478 .09607 .72879 .09946 .73739 .0953 .73339 .09185 Mtetra
.799 .801 .853 r
.73339 .09185 .73739 .0953 .74598 .0911 .74201 .08759 Mtetra
.799 .798 .851 r
.74201 .08759 .74598 .0911 .75458 .08687 .75062 .0833 Mtetra
.798 .795 .849 r
.75062 .0833 .75458 .08687 .76318 .08263 .75924 .07898 Mtetra
.798 .791 .847 r
.75924 .07898 .76318 .08263 .77179 .07837 .76786 .07466 Mtetra
.323 .604 .949 r
.13415 .21317 .13927 .21612 .14594 .21675 .14081 .21384 Mtetra
.319 .607 .951 r
.14081 .21384 .14594 .21675 .15264 .21737 .1475 .21451 Mtetra
.318 .61 .953 r
.1475 .21451 .15264 .21737 .15938 .21798 .15423 .21516 Mtetra
.318 .615 .955 r
.15423 .21516 .15938 .21798 .16615 .21857 .16101 .21579 Mtetra
.321 .621 .957 r
.16101 .21579 .16615 .21857 .17297 .21912 .16782 .21639 Mtetra
.325 .628 .96 r
.16782 .21639 .17297 .21912 .17983 .21964 .17467 .21696 Mtetra
.332 .635 .963 r
.17467 .21696 .17983 .21964 .18673 .2201 .18157 .21747 Mtetra
.34 .644 .966 r
.18157 .21747 .18673 .2201 .19368 .2205 .18852 .21792 Mtetra
.35 .654 .969 r
.18852 .21792 .19368 .2205 .20067 .22084 .19551 .21831 Mtetra
.362 .665 .972 r
.19551 .21831 .20067 .22084 .20771 .2211 .20254 .21862 Mtetra
.376 .677 .976 r
.20254 .21862 .20771 .2211 .2148 .22126 .20963 .21884 Mtetra
.392 .69 .979 r
.20963 .21884 .2148 .22126 .22193 .22133 .21677 .21897 Mtetra
.409 .703 .982 r
.21677 .21897 .22193 .22133 .22912 .22129 .22395 .21898 Mtetra
.428 .718 .985 r
.22395 .21898 .22912 .22129 .23635 .22113 .23119 .21888 Mtetra
.448 .732 .988 r
.23119 .21888 .23635 .22113 .24364 .22083 .23847 .21865 Mtetra
.47 .748 .99 r
.23847 .21865 .24364 .22083 .25098 .22039 .24581 .21828 Mtetra
.492 .763 .991 r
.24581 .21828 .25098 .22039 .25836 .2198 .2532 .21775 Mtetra
.516 .779 .992 r
.2532 .21775 .25836 .2198 .2658 .21904 .26065 .21706 Mtetra
.54 .795 .992 r
.26065 .21706 .2658 .21904 .27329 .21809 .26814 .2162 Mtetra
.565 .811 .991 r
.26814 .2162 .27329 .21809 .28084 .21695 .27569 .21514 Mtetra
.591 .826 .989 r
.27569 .21514 .28084 .21695 .28843 .21561 .28328 .21389 Mtetra
.616 .842 .986 r
.28328 .21389 .28843 .21561 .29607 .21405 .29093 .21242 Mtetra
.641 .856 .981 r
.29093 .21242 .29607 .21405 .30376 .21225 .29863 .21072 Mtetra
.666 .871 .976 r
.29863 .21072 .30376 .21225 .3115 .2102 .30638 .20878 Mtetra
.691 .885 .969 r
.30638 .20878 .3115 .2102 .31929 .2079 .31417 .20659 Mtetra
.715 .898 .962 r
.31417 .20659 .31929 .2079 .32712 .20531 .32201 .20414 Mtetra
.738 .91 .953 r
.32201 .20414 .32712 .20531 .33499 .20245 .3299 .20141 Mtetra
.759 .922 .943 r
.3299 .20141 .33499 .20245 .34291 .19928 .33782 .1984 Mtetra
.779 .934 .933 r
.33782 .1984 .34291 .19928 .35086 .19581 .34579 .1951 Mtetra
.797 .945 .921 r
.34579 .1951 .35086 .19581 .35885 .19203 .35379 .19151 Mtetra
.812 .957 .909 r
.35379 .19151 .35885 .19203 .36687 .18795 .36182 .18765 Mtetra
.823 .968 .897 r
.36182 .18765 .36687 .18795 .37492 .18359 .36988 .18354 Mtetra
.828 .979 .884 r
.36988 .18354 .37492 .18359 .38298 .179 .37795 .17923 Mtetra
.824 .99 .87 r
.37795 .17923 .38298 .179 .39105 .17425 .38604 .17479 Mtetra
.806 .998 .853 r
.38604 .17479 .39105 .17425 .39913 .16948 .39413 .17034 Mtetra
.763 .996 .83 r
.39413 .17034 .39913 .16948 .40719 .16487 .40221 .16603 Mtetra
.683 .974 .792 r
.40221 .16603 .40719 .16487 .41523 .16063 .41027 .16205 Mtetra
.556 .916 .733 r
.41027 .16205 .41523 .16063 .42324 .15701 .41832 .15857 Mtetra
.397 .824 .659 r
.41832 .15857 .42324 .15701 .43122 .15418 .42633 .15571 Mtetra
0 0 0 r
.42633 .15571 .43122 .15418 .43917 .1524 .43431 .15392 Mtetra
.099 0 0 r
.43431 .15392 .43917 .1524 .44709 .15166 .44227 .1532 Mtetra
.229 0 0 r
.44227 .1532 .44709 .15166 .45502 .15173 .45024 .15311 Mtetra
.303 0 0 r
.45024 .15311 .45502 .15173 .46297 .15241 .45822 .15352 Mtetra
.332 0 0 r
.45822 .15352 .46297 .15241 .47095 .15348 .46624 .15427 Mtetra
.323 0 0 r
.46624 .15427 .47095 .15348 .47898 .15471 .4743 .15516 Mtetra
.28 0 0 r
.4743 .15516 .47898 .15471 .48705 .15592 .48241 .15605 Mtetra
.207 0 0 r
.48241 .15605 .48705 .15592 .49518 .15699 .49056 .15682 Mtetra
.108 0 0 r
.49056 .15682 .49518 .15699 .50336 .15782 .49877 .15739 Mtetra
.007 .578 .769 r
.49877 .15739 .50336 .15782 .51159 .15838 .50702 .15771 Mtetra
.127 .662 .856 r
.50702 .15771 .51159 .15838 .51987 .15864 .51532 .15776 Mtetra
.24 .731 .921 r
.51532 .15776 .51987 .15864 .52818 .15859 .52367 .15752 Mtetra
.341 .781 .963 r
.52367 .15752 .52818 .15859 .53654 .15824 .53205 .15699 Mtetra
.426 .816 .987 r
.53205 .15699 .53654 .15824 .54494 .15759 .54046 .15618 Mtetra
.496 .839 .997 r
.54046 .15618 .54494 .15759 .55336 .15665 .54891 .15509 Mtetra
.552 .853 .998 r
.54891 .15509 .55336 .15665 .56181 .15543 .55739 .15373 Mtetra
.598 .86 .993 r
.55739 .15373 .56181 .15543 .57029 .15394 .56589 .15212 Mtetra
.634 .863 .985 r
.56589 .15212 .57029 .15394 .57879 .1522 .57441 .15026 Mtetra
.664 .864 .975 r
.57441 .15026 .57879 .1522 .58731 .15023 .58295 .14817 Mtetra
.688 .862 .965 r
.58295 .14817 .58731 .15023 .59585 .14802 .59151 .14586 Mtetra
.708 .86 .954 r
.59151 .14586 .59585 .14802 .6044 .14561 .60008 .14334 Mtetra
.725 .856 .944 r
.60008 .14334 .6044 .14561 .61297 .14299 .60867 .14062 Mtetra
.739 .853 .934 r
.60867 .14062 .61297 .14299 .62154 .14018 .61726 .13772 Mtetra
.75 .849 .924 r
.61726 .13772 .62154 .14018 .63013 .1372 .62587 .13465 Mtetra
.76 .845 .916 r
.62587 .13465 .63013 .1372 .63872 .13406 .63448 .13142 Mtetra
.768 .841 .907 r
.63448 .13142 .63872 .13406 .64731 .13076 .64309 .12804 Mtetra
.775 .837 .9 r
.64309 .12804 .64731 .13076 .65591 .12733 .65171 .12452 Mtetra
.781 .833 .893 r
.65171 .12452 .65591 .12733 .66451 .12376 .66034 .12088 Mtetra
.785 .83 .886 r
.66034 .12088 .66451 .12376 .67312 .12008 .66896 .11711 Mtetra
.789 .826 .881 r
.66896 .11711 .67312 .12008 .68173 .11628 .67759 .11325 Mtetra
.793 .823 .875 r
.67759 .11325 .68173 .11628 .69034 .1124 .68622 .10929 Mtetra
.796 .819 .87 r
.68622 .10929 .69034 .1124 .69895 .10842 .69485 .10524 Mtetra
.798 .816 .866 r
.69485 .10524 .69895 .10842 .70756 .10437 .70348 .10112 Mtetra
.799 .812 .862 r
.70348 .10112 .70756 .10437 .71617 .10025 .71211 .09693 Mtetra
.8 .809 .858 r
.71211 .09693 .71617 .10025 .72478 .09607 .72074 .09268 Mtetra
.801 .806 .855 r
.72074 .09268 .72478 .09607 .73339 .09185 .72937 .08839 Mtetra
.801 .802 .852 r
.72937 .08839 .73339 .09185 .74201 .08759 .73801 .08406 Mtetra
.801 .799 .849 r
.73801 .08406 .74201 .08759 .75062 .0833 .74664 .0797 Mtetra
.801 .796 .847 r
.74664 .0797 .75062 .0833 .75924 .07898 .75528 .07532 Mtetra
.8 .792 .845 r
.75528 .07532 .75924 .07898 .76786 .07466 .76391 .07094 Mtetra
.31 .598 .947 r
.12899 .2102 .13415 .21317 .14081 .21384 .13565 .21092 Mtetra
.307 .6 .949 r
.13565 .21092 .14081 .21384 .1475 .21451 .14234 .21163 Mtetra
.305 .604 .951 r
.14234 .21163 .1475 .21451 .15423 .21516 .14906 .21233 Mtetra
.305 .609 .953 r
.14906 .21233 .15423 .21516 .16101 .21579 .15583 .21301 Mtetra
.307 .614 .956 r
.15583 .21301 .16101 .21579 .16782 .21639 .16264 .21366 Mtetra
.311 .621 .958 r
.16264 .21366 .16782 .21639 .17467 .21696 .16949 .21427 Mtetra
.317 .629 .961 r
.16949 .21427 .17467 .21696 .18157 .21747 .17638 .21484 Mtetra
.325 .638 .964 r
.17638 .21484 .18157 .21747 .18852 .21792 .18332 .21534 Mtetra
.335 .648 .968 r
.18332 .21534 .18852 .21792 .19551 .21831 .19031 .21578 Mtetra
.346 .659 .971 r
.19031 .21578 .19551 .21831 .20254 .21862 .19735 .21615 Mtetra
.36 .671 .975 r
.19735 .21615 .20254 .21862 .20963 .21884 .20443 .21643 Mtetra
.375 .684 .979 r
.20443 .21643 .20963 .21884 .21677 .21897 .21156 .21661 Mtetra
.392 .698 .982 r
.21156 .21661 .21677 .21897 .22395 .21898 .21875 .21669 Mtetra
.411 .712 .985 r
.21875 .21669 .22395 .21898 .23119 .21888 .22598 .21665 Mtetra
.431 .727 .988 r
.22598 .21665 .23119 .21888 .23847 .21865 .23327 .21649 Mtetra
.452 .743 .991 r
.23327 .21649 .23847 .21865 .24581 .21828 .24061 .21619 Mtetra
.475 .759 .993 r
.24061 .21619 .24581 .21828 .2532 .21775 .24801 .21574 Mtetra
.498 .775 .994 r
.24801 .21574 .2532 .21775 .26065 .21706 .25545 .21512 Mtetra
.523 .792 .994 r
.25545 .21512 .26065 .21706 .26814 .2162 .26295 .21434 Mtetra
.548 .808 .994 r
.26295 .21434 .26814 .2162 .27569 .21514 .2705 .21337 Mtetra
.573 .825 .993 r
.2705 .21337 .27569 .21514 .28328 .21389 .2781 .21221 Mtetra
.599 .841 .99 r
.2781 .21221 .28328 .21389 .29093 .21242 .28575 .21083 Mtetra
.624 .856 .987 r
.28575 .21083 .29093 .21242 .29863 .21072 .29346 .20924 Mtetra
.649 .872 .982 r
.29346 .20924 .29863 .21072 .30638 .20878 .30121 .20741 Mtetra
.674 .886 .976 r
.30121 .20741 .30638 .20878 .31417 .20659 .30901 .20535 Mtetra
.698 .9 .969 r
.30901 .20535 .31417 .20659 .32201 .20414 .31686 .20302 Mtetra
.721 .914 .961 r
.31686 .20302 .32201 .20414 .3299 .20141 .32475 .20044 Mtetra
.742 .926 .951 r
.32475 .20044 .3299 .20141 .33782 .1984 .33269 .19758 Mtetra
.762 .939 .941 r
.33269 .19758 .33782 .1984 .34579 .1951 .34066 .19445 Mtetra
.779 .95 .93 r
.34066 .19445 .34579 .1951 .35379 .19151 .34868 .19106 Mtetra
.793 .962 .918 r
.34868 .19106 .35379 .19151 .36182 .18765 .35672 .18742 Mtetra
.802 .973 .906 r
.35672 .18742 .36182 .18765 .36988 .18354 .36479 .18354 Mtetra
.805 .983 .893 r
.36479 .18354 .36988 .18354 .37795 .17923 .37288 .17949 Mtetra
.799 .992 .878 r
.37288 .17949 .37795 .17923 .38604 .17479 .38098 .17533 Mtetra
.778 .996 .86 r
.38098 .17533 .38604 .17479 .39413 .17034 .38908 .17117 Mtetra
.735 .991 .836 r
.38908 .17117 .39413 .17034 .40221 .16603 .39718 .16713 Mtetra
.662 .968 .8 r
.39718 .16713 .40221 .16603 .41027 .16205 .40527 .16336 Mtetra
.556 .92 .751 r
.40527 .16336 .41027 .16205 .41832 .15857 .41334 .15998 Mtetra
.435 .853 .696 r
.41334 .15998 .41832 .15857 .42633 .15571 .4214 .15709 Mtetra
0 0 0 r
.4214 .15709 .42633 .15571 .43431 .15392 .42942 .15529 Mtetra
.078 0 0 r
.42942 .15529 .43431 .15392 .44227 .1532 .4374 .15459 Mtetra
.185 0 0 r
.4374 .15459 .44227 .1532 .45024 .15311 .4454 .15438 Mtetra
.248 0 0 r
.4454 .15438 .45024 .15311 .45822 .15352 .45343 .15457 Mtetra
.272 0 0 r
.45343 .15457 .45822 .15352 .46624 .15427 .46148 .15503 Mtetra
.262 0 0 r
.46148 .15503 .46624 .15427 .4743 .15516 .46958 .15562 Mtetra
.219 0 0 r
.46958 .15562 .4743 .15516 .48241 .15605 .47772 .15621 Mtetra
.149 0 0 r
.47772 .15621 .48241 .15605 .49056 .15682 .4859 .1567 Mtetra
.055 0 0 r
.4859 .1567 .49056 .15682 .49877 .15739 .49414 .15701 Mtetra
.054 .616 .787 r
.49414 .15701 .49877 .15739 .50702 .15771 .50242 .1571 Mtetra
.166 .693 .867 r
.50242 .1571 .50702 .15771 .51532 .15776 .51075 .15694 Mtetra
.273 .755 .926 r
.51075 .15694 .51532 .15776 .52367 .15752 .51911 .1565 Mtetra
.368 .801 .965 r
.51911 .1565 .52367 .15752 .53205 .15699 .52752 .1558 Mtetra
.448 .832 .987 r
.52752 .1558 .53205 .15699 .54046 .15618 .53596 .15483 Mtetra
.514 .852 .996 r
.53596 .15483 .54046 .15618 .54891 .15509 .54443 .15359 Mtetra
.567 .864 .996 r
.54443 .15359 .54891 .15509 .55739 .15373 .55292 .15209 Mtetra
.611 .87 .991 r
.55292 .15209 .55739 .15373 .56589 .15212 .56145 .15035 Mtetra
.645 .872 .983 r
.56145 .15035 .56589 .15212 .57441 .15026 .56999 .14836 Mtetra
.674 .871 .973 r
.56999 .14836 .57441 .15026 .58295 .14817 .57856 .14615 Mtetra
.697 .869 .963 r
.57856 .14615 .58295 .14817 .59151 .14586 .58714 .14373 Mtetra
.716 .866 .952 r
.58714 .14373 .59151 .14586 .60008 .14334 .59573 .1411 Mtetra
.732 .862 .942 r
.59573 .1411 .60008 .14334 .60867 .14062 .60434 .13829 Mtetra
.745 .858 .932 r
.60434 .13829 .60867 .14062 .61726 .13772 .61295 .13529 Mtetra
.756 .853 .923 r
.61295 .13529 .61726 .13772 .62587 .13465 .62158 .13212 Mtetra
.765 .849 .914 r
.62158 .13212 .62587 .13465 .63448 .13142 .63021 .1288 Mtetra
.773 .845 .906 r
.63021 .1288 .63448 .13142 .64309 .12804 .63885 .12533 Mtetra
.779 .841 .898 r
.63885 .12533 .64309 .12804 .65171 .12452 .64749 .12173 Mtetra
.785 .836 .892 r
.64749 .12173 .65171 .12452 .66034 .12088 .65614 .118 Mtetra
.789 .832 .885 r
.65614 .118 .66034 .12088 .66896 .11711 .66478 .11416 Mtetra
.793 .829 .879 r
.66478 .11416 .66896 .11711 .67759 .11325 .67343 .11021 Mtetra
.796 .825 .874 r
.67343 .11021 .67759 .11325 .68622 .10929 .68208 .10618 Mtetra
.799 .821 .869 r
.68208 .10618 .68622 .10929 .69485 .10524 .69073 .10205 Mtetra
.801 .817 .865 r
.69073 .10205 .69485 .10524 .70348 .10112 .69938 .09786 Mtetra
.802 .814 .861 r
.69938 .09786 .70348 .10112 .71211 .09693 .70803 .0936 Mtetra
.803 .81 .857 r
.70803 .0936 .71211 .09693 .72074 .09268 .71668 .08928 Mtetra
.804 .807 .854 r
.71668 .08928 .72074 .09268 .72937 .08839 .72533 .08492 Mtetra
.804 .803 .851 r
.72533 .08492 .72937 .08839 .73801 .08406 .73398 .08052 Mtetra
.804 .8 .848 r
.73398 .08052 .73801 .08406 .74664 .0797 .74263 .07609 Mtetra
.803 .796 .846 r
.74263 .07609 .74664 .0797 .75528 .07532 .75129 .07164 Mtetra
.802 .793 .844 r
.75129 .07164 .75528 .07532 .76391 .07094 .75994 .06719 Mtetra
.297 .591 .945 r
.12382 .20721 .12899 .2102 .13565 .21092 .13046 .20798 Mtetra
.293 .593 .947 r
.13046 .20798 .13565 .21092 .14234 .21163 .13714 .20874 Mtetra
.291 .597 .949 r
.13714 .20874 .14234 .21163 .14906 .21233 .14386 .20949 Mtetra
.29 .601 .951 r
.14386 .20949 .14906 .21233 .15583 .21301 .15062 .21022 Mtetra
.292 .607 .954 r
.15062 .21022 .15583 .21301 .16264 .21366 .15743 .21093 Mtetra
.296 .614 .956 r
.15743 .21093 .16264 .21366 .16949 .21427 .16427 .21159 Mtetra
.301 .622 .959 r
.16427 .21159 .16949 .21427 .17638 .21484 .17116 .21221 Mtetra
.309 .631 .963 r
.17116 .21221 .17638 .21484 .18332 .21534 .1781 .21277 Mtetra
.318 .641 .966 r
.1781 .21277 .18332 .21534 .19031 .21578 .18508 .21326 Mtetra
.329 .652 .97 r
.18508 .21326 .19031 .21578 .19735 .21615 .19211 .21369 Mtetra
.343 .664 .974 r
.19211 .21369 .19735 .21615 .20443 .21643 .1992 .21402 Mtetra
.357 .677 .977 r
.1992 .21402 .20443 .21643 .21156 .21661 .20633 .21427 Mtetra
.374 .691 .981 r
.20633 .21427 .21156 .21661 .21875 .21669 .21351 .21441 Mtetra
.392 .706 .985 r
.21351 .21441 .21875 .21669 .22598 .21665 .22075 .21444 Mtetra
.412 .722 .988 r
.22075 .21444 .22598 .21665 .23327 .21649 .22803 .21435 Mtetra
.433 .738 .991 r
.22803 .21435 .23327 .21649 .24061 .21619 .23537 .21412 Mtetra
.456 .754 .993 r
.23537 .21412 .24061 .21619 .24801 .21574 .24277 .21374 Mtetra
.479 .771 .995 r
.24277 .21374 .24801 .21574 .25545 .21512 .25021 .21321 Mtetra
.503 .788 .996 r
.25021 .21321 .25545 .21512 .26295 .21434 .25771 .21251 Mtetra
.528 .805 .997 r
.25771 .21251 .26295 .21434 .2705 .21337 .26527 .21163 Mtetra
.554 .822 .996 r
.26527 .21163 .2705 .21337 .2781 .21221 .27287 .21056 Mtetra
.579 .839 .994 r
.27287 .21056 .2781 .21221 .28575 .21083 .28053 .20929 Mtetra
.605 .855 .991 r
.28053 .20929 .28575 .21083 .29346 .20924 .28824 .20781 Mtetra
.63 .871 .987 r
.28824 .20781 .29346 .20924 .30121 .20741 .296 .2061 Mtetra
.655 .887 .982 r
.296 .2061 .30121 .20741 .30901 .20535 .30381 .20415 Mtetra
.679 .902 .975 r
.30381 .20415 .30901 .20535 .31686 .20302 .31166 .20196 Mtetra
.702 .916 .968 r
.31166 .20196 .31686 .20302 .32475 .20044 .31956 .19952 Mtetra
.723 .929 .959 r
.31956 .19952 .32475 .20044 .33269 .19758 .32751 .19682 Mtetra
.742 .942 .949 r
.32751 .19682 .33269 .19758 .34066 .19445 .33549 .19387 Mtetra
.759 .954 .938 r
.33549 .19387 .34066 .19445 .34868 .19106 .34352 .19067 Mtetra
.771 .965 .926 r
.34352 .19067 .34868 .19106 .35672 .18742 .35157 .18723 Mtetra
.779 .976 .914 r
.35157 .18723 .35672 .18742 .36479 .18354 .35965 .18359 Mtetra
.78 .985 .9 r
.35965 .18359 .36479 .18354 .37288 .17949 .36775 .17979 Mtetra
.772 .992 .884 r
.36775 .17979 .37288 .17949 .38098 .17533 .37587 .17589 Mtetra
.749 .993 .865 r
.37587 .17589 .38098 .17533 .38908 .17117 .38399 .17198 Mtetra
.707 .985 .84 r
.38399 .17198 .38908 .17117 .39718 .16713 .39211 .16817 Mtetra
.642 .963 .806 r
.39211 .16817 .39718 .16713 .40527 .16336 .40023 .16457 Mtetra
.556 .923 .765 r
.40023 .16457 .40527 .16336 .41334 .15998 .40833 .16129 Mtetra
.464 .873 .724 r
.40833 .16129 .41334 .15998 .4214 .15709 .41642 .15836 Mtetra
0 0 0 r
.41642 .15836 .4214 .15709 .42942 .15529 .42447 .15656 Mtetra
.063 0 0 r
.42447 .15656 .42942 .15529 .4374 .15459 .43249 .15588 Mtetra
.146 0 0 r
.43249 .15588 .4374 .15459 .4454 .15438 .44053 .15556 Mtetra
.197 0 0 r
.44053 .15556 .4454 .15438 .45343 .15457 .44859 .15555 Mtetra
.215 0 0 r
.44859 .15555 .45343 .15457 .46148 .15503 .45668 .15577 Mtetra
.202 0 0 r
.45668 .15577 .46148 .15503 .46958 .15562 .46481 .15609 Mtetra
.16 0 0 r
.46481 .15609 .46958 .15562 .47772 .15621 .47298 .1564 Mtetra
.091 0 0 r
.47298 .1564 .47772 .15621 .4859 .1567 .4812 .15663 Mtetra
0 .576 .717 r
.4812 .15663 .4859 .1567 .49414 .15701 .48947 .15669 Mtetra
.101 .653 .804 r
.48947 .15669 .49414 .15701 .50242 .1571 .49778 .15655 Mtetra
.206 .722 .877 r
.49778 .15655 .50242 .1571 .51075 .15694 .50613 .15618 Mtetra
.306 .778 .931 r
.50613 .15618 .51075 .15694 .51911 .1565 .51452 .15555 Mtetra
.394 .819 .966 r
.51452 .15555 .51911 .1565 .52752 .1558 .52295 .15467 Mtetra
.47 .847 .986 r
.52295 .15467 .52752 .1558 .53596 .15483 .53141 .15353 Mtetra
.532 .865 .994 r
.53141 .15353 .53596 .15483 .54443 .15359 .53991 .15214 Mtetra
.583 .875 .994 r
.53991 .15214 .54443 .15359 .55292 .15209 .54843 .1505 Mtetra
.623 .879 .989 r
.54843 .1505 .55292 .15209 .56145 .15035 .55698 .14862 Mtetra
.657 .88 .981 r
.55698 .14862 .56145 .15035 .56999 .14836 .56554 .14651 Mtetra
.684 .878 .971 r
.56554 .14651 .56999 .14836 .57856 .14615 .57413 .14418 Mtetra
.706 .875 .961 r
.57413 .14418 .57856 .14615 .58714 .14373 .58273 .14164 Mtetra
.724 .871 .95 r
.58273 .14164 .58714 .14373 .59573 .1411 .59135 .1389 Mtetra
.739 .867 .94 r
.59135 .1389 .59573 .1411 .60434 .13829 .59998 .13598 Mtetra
.751 .862 .93 r
.59998 .13598 .60434 .13829 .61295 .13529 .60862 .13288 Mtetra
.762 .858 .921 r
.60862 .13288 .61295 .13529 .62158 .13212 .61727 .12961 Mtetra
.77 .853 .912 r
.61727 .12961 .62158 .13212 .63021 .1288 .62592 .1262 Mtetra
.778 .848 .904 r
.62592 .1262 .63021 .1288 .63885 .12533 .63458 .12264 Mtetra
.784 .844 .897 r
.63458 .12264 .63885 .12533 .64749 .12173 .64324 .11895 Mtetra
.789 .839 .89 r
.64324 .11895 .64749 .12173 .65614 .118 .65191 .11513 Mtetra
.793 .835 .884 r
.65191 .11513 .65614 .118 .66478 .11416 .66058 .11121 Mtetra
.797 .831 .878 r
.66058 .11121 .66478 .11416 .67343 .11021 .66925 .10718 Mtetra
.8 .827 .872 r
.66925 .10718 .67343 .11021 .68208 .10618 .67792 .10307 Mtetra
.802 .823 .868 r
.67792 .10307 .68208 .10618 .69073 .10205 .68659 .09887 Mtetra
.804 .819 .863 r
.68659 .09887 .69073 .10205 .69938 .09786 .69526 .09459 Mtetra
.805 .815 .859 r
.69526 .09459 .69938 .09786 .70803 .0936 .70393 .09026 Mtetra
.806 .812 .855 r
.70393 .09026 .70803 .0936 .71668 .08928 .71259 .08587 Mtetra
.807 .808 .852 r
.71259 .08587 .71668 .08928 .72533 .08492 .72126 .08143 Mtetra
.807 .805 .849 r
.72126 .08143 .72533 .08492 .73398 .08052 .72993 .07696 Mtetra
.806 .801 .846 r
.72993 .07696 .73398 .08052 .74263 .07609 .7386 .07246 Mtetra
.806 .797 .844 r
.7386 .07246 .74263 .07609 .75129 .07164 .74727 .06795 Mtetra
.805 .794 .842 r
.74727 .06795 .75129 .07164 .75994 .06719 .75595 .06342 Mtetra
.283 .584 .943 r
.11861 .20421 .12382 .20721 .13046 .20798 .12525 .20503 Mtetra
.279 .586 .945 r
.12525 .20503 .13046 .20798 .13714 .20874 .13192 .20584 Mtetra
.276 .589 .947 r
.13192 .20584 .13714 .20874 .14386 .20949 .13863 .20665 Mtetra
.275 .594 .949 r
.13863 .20665 .14386 .20949 .15062 .21022 .14539 .20743 Mtetra
.276 .599 .951 r
.14539 .20743 .15062 .21022 .15743 .21093 .15218 .20818 Mtetra
.28 .606 .954 r
.15218 .20818 .15743 .21093 .16427 .21159 .15902 .2089 Mtetra
.285 .614 .957 r
.15902 .2089 .16427 .21159 .17116 .21221 .16591 .20957 Mtetra
.292 .623 .96 r
.16591 .20957 .17116 .21221 .1781 .21277 .17284 .21019 Mtetra
.301 .633 .964 r
.17284 .21019 .1781 .21277 .18508 .21326 .17982 .21075 Mtetra
.311 .644 .968 r
.17982 .21075 .18508 .21326 .19211 .21369 .18685 .21123 Mtetra
.324 .657 .972 r
.18685 .21123 .19211 .21369 .1992 .21402 .19393 .21163 Mtetra
.339 .67 .976 r
.19393 .21163 .1992 .21402 .20633 .21427 .20105 .21194 Mtetra
.355 .684 .98 r
.20105 .21194 .20633 .21427 .21351 .21441 .20824 .21215 Mtetra
.373 .699 .983 r
.20824 .21215 .21351 .21441 .22075 .21444 .21547 .21225 Mtetra
.392 .715 .987 r
.21547 .21225 .22075 .21444 .22803 .21435 .22276 .21223 Mtetra
.413 .731 .991 r
.22276 .21223 .22803 .21435 .23537 .21412 .2301 .21207 Mtetra
.435 .748 .994 r
.2301 .21207 .23537 .21412 .24277 .21374 .23749 .21178 Mtetra
.458 .765 .996 r
.23749 .21178 .24277 .21374 .25021 .21321 .24494 .21133 Mtetra
.482 .783 .998 r
.24494 .21133 .25021 .21321 .25771 .21251 .25244 .21072 Mtetra
.507 .801 .998 r
.25244 .21072 .25771 .21251 .26527 .21163 .25999 .20993 Mtetra
.533 .818 .998 r
.25999 .20993 .26527 .21163 .27287 .21056 .2676 .20896 Mtetra
.558 .836 .997 r
.2676 .20896 .27287 .21056 .28053 .20929 .27526 .20779 Mtetra
.584 .853 .995 r
.27526 .20779 .28053 .20929 .28824 .20781 .28298 .20642 Mtetra
.609 .87 .991 r
.28298 .20642 .28824 .20781 .296 .2061 .29074 .20483 Mtetra
.634 .886 .987 r
.29074 .20483 .296 .2061 .30381 .20415 .29856 .20301 Mtetra
.658 .901 .981 r
.29856 .20301 .30381 .20415 .31166 .20196 .30642 .20095 Mtetra
.681 .916 .973 r
.30642 .20095 .31166 .20196 .31956 .19952 .31433 .19866 Mtetra
.701 .93 .965 r
.31433 .19866 .31956 .19952 .32751 .19682 .32228 .19612 Mtetra
.72 .943 .955 r
.32228 .19612 .32751 .19682 .33549 .19387 .33027 .19335 Mtetra
.736 .956 .945 r
.33027 .19335 .33549 .19387 .34352 .19067 .33831 .19033 Mtetra
.747 .967 .933 r
.33831 .19033 .34352 .19067 .35157 .18723 .34637 .1871 Mtetra
.754 .977 .92 r
.34637 .1871 .35157 .18723 .35965 .18359 .35446 .18368 Mtetra
.753 .984 .905 r
.35446 .18368 .35965 .18359 .36775 .17979 .36258 .18011 Mtetra
.743 .989 .888 r
.36258 .18011 .36775 .17979 .37587 .17589 .37071 .17645 Mtetra
.72 .988 .868 r
.37071 .17645 .37587 .17589 .38399 .17198 .37885 .17277 Mtetra
.68 .978 .842 r
.37885 .17277 .38399 .17198 .39211 .16817 .38699 .16917 Mtetra
.623 .957 .81 r
.38699 .16917 .39211 .16817 .40023 .16457 .39513 .16572 Mtetra
.553 .924 .775 r
.39513 .16572 .40023 .16457 .40833 .16129 .40327 .16251 Mtetra
.485 .888 .744 r
.40327 .16251 .40833 .16129 .41642 .15836 .4114 .15956 Mtetra
0 0 0 r
.4114 .15956 .41642 .15836 .42447 .15656 .41948 .15775 Mtetra
.051 0 0 r
.41948 .15775 .42447 .15656 .43249 .15588 .42753 .15708 Mtetra
.113 0 0 r
.42753 .15708 .43249 .15588 .44053 .15556 .4356 .15667 Mtetra
.151 0 0 r
.4356 .15667 .44053 .15556 .44859 .15555 .4437 .1565 Mtetra
.161 0 0 r
.4437 .1565 .44859 .15555 .45668 .15577 .45183 .15649 Mtetra
.145 0 0 r
.45183 .15649 .45668 .15577 .46481 .15609 .45999 .15656 Mtetra
.101 0 0 r
.45999 .15656 .46481 .15609 .47298 .1564 .4682 .15662 Mtetra
.035 0 0 r
.4682 .15662 .47298 .1564 .4812 .15663 .47645 .15659 Mtetra
.051 .618 .74 r
.47645 .15659 .4812 .15663 .48947 .15669 .48475 .15642 Mtetra
.147 .688 .82 r
.48475 .15642 .48947 .15669 .49778 .15655 .49309 .15605 Mtetra
.246 .751 .886 r
.49309 .15605 .49778 .15655 .50613 .15618 .50147 .15547 Mtetra
.339 .801 .935 r
.50147 .15547 .50613 .15618 .51452 .15555 .50989 .15465 Mtetra
.421 .837 .967 r
.50989 .15465 .51452 .15555 .52295 .15467 .51835 .15359 Mtetra
.492 .862 .985 r
.51835 .15359 .52295 .15467 .53141 .15353 .52684 .15229 Mtetra
.55 .877 .992 r
.52684 .15229 .53141 .15353 .53991 .15214 .53535 .15074 Mtetra
.598 .885 .991 r
.53535 .15074 .53991 .15214 .54843 .1505 .5439 .14895 Mtetra
.637 .888 .986 r
.5439 .14895 .54843 .1505 .55698 .14862 .55247 .14693 Mtetra
.668 .887 .978 r
.55247 .14693 .55698 .14862 .56554 .14651 .56106 .14469 Mtetra
.694 .885 .969 r
.56106 .14469 .56554 .14651 .57413 .14418 .56967 .14223 Mtetra
.714 .881 .958 r
.56967 .14223 .57413 .14418 .58273 .14164 .5783 .13957 Mtetra
.732 .877 .948 r
.5783 .13957 .58273 .14164 .59135 .1389 .58694 .13672 Mtetra
.746 .872 .938 r
.58694 .13672 .59135 .1389 .59998 .13598 .59559 .13369 Mtetra
.758 .867 .928 r
.59559 .13369 .59998 .13598 .60862 .13288 .60426 .13049 Mtetra
.767 .862 .919 r
.60426 .13049 .60862 .13288 .61727 .12961 .61293 .12713 Mtetra
.776 .857 .911 r
.61293 .12713 .61727 .12961 .62592 .1262 .6216 .12361 Mtetra
.783 .852 .903 r
.6216 .12361 .62592 .1262 .63458 .12264 .63028 .11996 Mtetra
.788 .847 .895 r
.63028 .11996 .63458 .12264 .64324 .11895 .63897 .11618 Mtetra
.793 .842 .888 r
.63897 .11618 .64324 .11895 .65191 .11513 .64766 .11227 Mtetra
.797 .838 .882 r
.64766 .11227 .65191 .11513 .66058 .11121 .65635 .10826 Mtetra
.801 .833 .876 r
.65635 .10826 .66058 .11121 .66925 .10718 .66504 .10415 Mtetra
.803 .829 .871 r
.66504 .10415 .66925 .10718 .67792 .10307 .67373 .09996 Mtetra
.806 .825 .866 r
.67373 .09996 .67792 .10307 .68659 .09887 .68242 .09568 Mtetra
.807 .821 .862 r
.68242 .09568 .68659 .09887 .69526 .09459 .69111 .09132 Mtetra
.808 .817 .858 r
.69111 .09132 .69526 .09459 .70393 .09026 .6998 .08691 Mtetra
.809 .813 .854 r
.6998 .08691 .70393 .09026 .71259 .08587 .70849 .08245 Mtetra
.809 .809 .851 r
.70849 .08245 .71259 .08587 .72126 .08143 .71717 .07794 Mtetra
.809 .806 .848 r
.71717 .07794 .72126 .08143 .72993 .07696 .72586 .07339 Mtetra
.809 .802 .845 r
.72586 .07339 .72993 .07696 .7386 .07246 .73455 .06882 Mtetra
.808 .798 .842 r
.73455 .06882 .7386 .07246 .74727 .06795 .74324 .06423 Mtetra
.807 .794 .84 r
.74324 .06423 .74727 .06795 .75595 .06342 .75193 .05963 Mtetra
.268 .576 .94 r
.11338 .20119 .11861 .20421 .12525 .20503 .12 .20207 Mtetra
.264 .578 .942 r
.12 .20207 .12525 .20503 .13192 .20584 .12667 .20293 Mtetra
.26 .581 .944 r
.12667 .20293 .13192 .20584 .13863 .20665 .13337 .20379 Mtetra
.259 .586 .946 r
.13337 .20379 .13863 .20665 .14539 .20743 .14012 .20463 Mtetra
.26 .591 .948 r
.14012 .20463 .14539 .20743 .15218 .20818 .14691 .20544 Mtetra
.263 .598 .951 r
.14691 .20544 .15218 .20818 .15902 .2089 .15374 .20621 Mtetra
.267 .606 .954 r
.15374 .20621 .15902 .2089 .16591 .20957 .16062 .20694 Mtetra
.274 .615 .957 r
.16062 .20694 .16591 .20957 .17284 .21019 .16755 .20762 Mtetra
.282 .625 .961 r
.16755 .20762 .17284 .21019 .17982 .21075 .17452 .20824 Mtetra
.292 .636 .965 r
.17452 .20824 .17982 .21075 .18685 .21123 .18155 .20878 Mtetra
.305 .648 .969 r
.18155 .20878 .18685 .21123 .19393 .21163 .18862 .20925 Mtetra
.319 .661 .973 r
.18862 .20925 .19393 .21163 .20105 .21194 .19575 .20962 Mtetra
.334 .676 .977 r
.19575 .20962 .20105 .21194 .20824 .21215 .20292 .2099 Mtetra
.352 .691 .981 r
.20292 .2099 .20824 .21215 .21547 .21225 .21015 .21007 Mtetra
.371 .707 .986 r
.21015 .21007 .21547 .21225 .22276 .21223 .21744 .21013 Mtetra
.391 .724 .989 r
.21744 .21013 .22276 .21223 .2301 .21207 .22478 .21005 Mtetra
.413 .741 .993 r
.22478 .21005 .2301 .21207 .23749 .21178 .23217 .20984 Mtetra
.436 .759 .996 r
.23217 .20984 .23749 .21178 .24494 .21133 .23962 .20948 Mtetra
.46 .777 .998 r
.23962 .20948 .24494 .21133 .25244 .21072 .24712 .20896 Mtetra
.484 .795 .999 r
.24712 .20896 .25244 .21072 .25999 .20993 .25468 .20826 Mtetra
.51 .813 1 r
.25468 .20826 .25999 .20993 .2676 .20896 .26229 .20739 Mtetra
.535 .831 .999 r
.26229 .20739 .2676 .20896 .27526 .20779 .26995 .20633 Mtetra
.561 .849 .997 r
.26995 .20633 .27526 .20779 .28298 .20642 .27767 .20507 Mtetra
.586 .867 .995 r
.27767 .20507 .28298 .20642 .29074 .20483 .28544 .2036 Mtetra
.611 .884 .99 r
.28544 .2036 .29074 .20483 .29856 .20301 .29326 .20191 Mtetra
.634 .9 .985 r
.29326 .20191 .29856 .20301 .30642 .20095 .30113 .2 Mtetra
.657 .915 .978 r
.30113 .2 .30642 .20095 .31433 .19866 .30904 .19785 Mtetra
.677 .929 .97 r
.30904 .19785 .31433 .19866 .32228 .19612 .317 .19548 Mtetra
.695 .943 .961 r
.317 .19548 .32228 .19612 .33027 .19335 .32501 .19287 Mtetra
.71 .955 .95 r
.32501 .19287 .33027 .19335 .33831 .19033 .33305 .19005 Mtetra
.721 .966 .938 r
.33305 .19005 .33831 .19033 .34637 .1871 .34112 .18701 Mtetra
.726 .975 .924 r
.34112 .18701 .34637 .1871 .35446 .18368 .34923 .1838 Mtetra
.724 .981 .909 r
.34923 .1838 .35446 .18368 .36258 .18011 .35735 .18045 Mtetra
.712 .984 .891 r
.35735 .18045 .36258 .18011 .37071 .17645 .3655 .17701 Mtetra
.689 .981 .869 r
.3655 .17701 .37071 .17645 .37885 .17277 .37366 .17355 Mtetra
.653 .97 .843 r
.37366 .17355 .37885 .17277 .38699 .16917 .38182 .17013 Mtetra
.604 .95 .813 r
.38182 .17013 .38699 .16917 .39513 .16572 .38999 .16682 Mtetra
.549 .923 .782 r
.38999 .16682 .39513 .16572 .40327 .16251 .39816 .16368 Mtetra
.499 .897 .758 r
.39816 .16368 .40327 .16251 .4114 .15956 .40633 .16071 Mtetra
0 0 0 r
.40633 .16071 .4114 .15956 .41948 .15775 .41445 .15889 Mtetra
.042 0 0 r
.41445 .15889 .41948 .15775 .42753 .15708 .42252 .15822 Mtetra
.084 0 0 r
.42252 .15822 .42753 .15708 .4356 .15667 .43063 .15773 Mtetra
.108 0 0 r
.43063 .15773 .4356 .15667 .4437 .1565 .43876 .15741 Mtetra
.111 0 0 r
.43876 .15741 .4437 .1565 .45183 .15649 .44693 .1572 Mtetra
.09 0 0 r
.44693 .1572 .45183 .15649 .45999 .15656 .45513 .15704 Mtetra
.045 0 0 r
.45513 .15704 .45999 .15656 .4682 .15662 .46338 .15686 Mtetra
0 0 0 r
.46338 .15686 .4682 .15662 .47645 .15659 .47166 .15659 Mtetra
.102 .657 .762 r
.47166 .15659 .47645 .15659 .48475 .15642 .47999 .15619 Mtetra
.192 .721 .834 r
.47999 .15619 .48475 .15642 .49309 .15605 .48836 .15561 Mtetra
.284 .777 .894 r
.48836 .15561 .49309 .15605 .50147 .15547 .49677 .15482 Mtetra
.371 .822 .938 r
.49677 .15482 .50147 .15547 .50989 .15465 .50522 .15381 Mtetra
.448 .854 .967 r
.50522 .15381 .50989 .15465 .51835 .15359 .5137 .15257 Mtetra
.514 .876 .983 r
.5137 .15257 .51835 .15359 .52684 .15229 .52222 .15109 Mtetra
.569 .888 .989 r
.52222 .15109 .52684 .15229 .53535 .15074 .53076 .14938 Mtetra
.613 .894 .988 r
.53076 .14938 .53535 .15074 .5439 .14895 .53934 .14745 Mtetra
.65 .896 .983 r
.53934 .14745 .5439 .14895 .55247 .14693 .54793 .14528 Mtetra
.679 .895 .975 r
.54793 .14528 .55247 .14693 .56106 .14469 .55655 .14291 Mtetra
.704 .891 .966 r
.55655 .14291 .56106 .14469 .56967 .14223 .56518 .14033 Mtetra
.723 .887 .956 r
.56518 .14033 .56967 .14223 .5783 .13957 .57384 .13755 Mtetra
.739 .882 .945 r
.57384 .13755 .5783 .13957 .58694 .13672 .5825 .13458 Mtetra
.753 .876 .936 r
.5825 .13458 .58694 .13672 .59559 .13369 .59118 .13143 Mtetra
.764 .871 .926 r
.59118 .13143 .59559 .13369 .60426 .13049 .59986 .12812 Mtetra
.773 .865 .917 r
.59986 .12812 .60426 .13049 .61293 .12713 .60856 .12466 Mtetra
.781 .86 .909 r
.60856 .12466 .61293 .12713 .6216 .12361 .61726 .12104 Mtetra
.788 .855 .901 r
.61726 .12104 .6216 .12361 .63028 .11996 .62596 .11729 Mtetra
.793 .85 .893 r
.62596 .11729 .63028 .11996 .63897 .11618 .63467 .11342 Mtetra
.798 .845 .887 r
.63467 .11342 .63897 .11618 .64766 .11227 .64338 .10942 Mtetra
.801 .84 .88 r
.64338 .10942 .64766 .11227 .65635 .10826 .65209 .10532 Mtetra
.805 .835 .875 r
.65209 .10532 .65635 .10826 .66504 .10415 .6608 .10113 Mtetra
.807 .831 .869 r
.6608 .10113 .66504 .10415 .67373 .09996 .66951 .09684 Mtetra
.809 .827 .864 r
.66951 .09684 .67373 .09996 .68242 .09568 .67822 .09248 Mtetra
.81 .823 .86 r
.67822 .09248 .68242 .09568 .69111 .09132 .68693 .08805 Mtetra
.811 .819 .856 r
.68693 .08805 .69111 .09132 .6998 .08691 .69564 .08356 Mtetra
.812 .815 .852 r
.69564 .08356 .6998 .08691 .70849 .08245 .70435 .07901 Mtetra
.812 .811 .849 r
.70435 .07901 .70849 .08245 .71717 .07794 .71306 .07443 Mtetra
.812 .807 .846 r
.71306 .07443 .71717 .07794 .72586 .07339 .72177 .0698 Mtetra
.812 .803 .843 r
.72177 .0698 .72586 .07339 .73455 .06882 .73047 .06516 Mtetra
.811 .799 .841 r
.73047 .06516 .73455 .06882 .74324 .06423 .73918 .06049 Mtetra
.81 .795 .838 r
.73918 .06049 .74324 .06423 .75193 .05963 .74789 .05581 Mtetra
.253 .567 .937 r
.10812 .19816 .11338 .20119 .12 .20207 .11473 .19909 Mtetra
.248 .569 .939 r
.11473 .19909 .12 .20207 .12667 .20293 .12139 .20001 Mtetra
.244 .572 .941 r
.12139 .20001 .12667 .20293 .13337 .20379 .12809 .20093 Mtetra
.242 .577 .942 r
.12809 .20093 .13337 .20379 .14012 .20463 .13482 .20182 Mtetra
.243 .582 .945 r
.13482 .20182 .14012 .20463 .14691 .20544 .1416 .20269 Mtetra
.245 .589 .947 r
.1416 .20269 .14691 .20544 .15374 .20621 .14843 .20352 Mtetra
.249 .596 .95 r
.14843 .20352 .15374 .20621 .16062 .20694 .1553 .20431 Mtetra
.255 .605 .954 r
.1553 .20431 .16062 .20694 .16755 .20762 .16222 .20505 Mtetra
.263 .615 .957 r
.16222 .20505 .16755 .20762 .17452 .20824 .16919 .20573 Mtetra
.272 .626 .961 r
.16919 .20573 .17452 .20824 .18155 .20878 .17621 .20634 Mtetra
.284 .639 .965 r
.17621 .20634 .18155 .20878 .18862 .20925 .18328 .20687 Mtetra
.297 .652 .97 r
.18328 .20687 .18862 .20925 .19575 .20962 .1904 .20732 Mtetra
.313 .667 .974 r
.1904 .20732 .19575 .20962 .20292 .2099 .19757 .20767 Mtetra
.329 .682 .979 r
.19757 .20767 .20292 .2099 .21015 .21007 .2048 .20791 Mtetra
.348 .698 .983 r
.2048 .20791 .21015 .21007 .21744 .21013 .21208 .20804 Mtetra
.368 .715 .987 r
.21208 .20804 .21744 .21013 .22478 .21005 .21942 .20805 Mtetra
.389 .733 .991 r
.21942 .20805 .22478 .21005 .23217 .20984 .22681 .20792 Mtetra
.412 .751 .994 r
.22681 .20792 .23217 .20984 .23962 .20948 .23426 .20765 Mtetra
.435 .769 .997 r
.23426 .20765 .23962 .20948 .24712 .20896 .24176 .20722 Mtetra
.459 .788 .999 r
.24176 .20722 .24712 .20896 .25468 .20826 .24932 .20663 Mtetra
.484 .807 1 r
.24932 .20663 .25468 .20826 .26229 .20739 .25693 .20586 Mtetra
.51 .825 1 r
.25693 .20586 .26229 .20739 .26995 .20633 .2646 .20491 Mtetra
.535 .844 .999 r
.2646 .20491 .26995 .20633 .27767 .20507 .27232 .20377 Mtetra
.56 .862 .996 r
.27232 .20377 .27767 .20507 .28544 .2036 .28009 .20242 Mtetra
.585 .879 .993 r
.28009 .20242 .28544 .2036 .29326 .20191 .28791 .20086 Mtetra
.608 .896 .988 r
.28791 .20086 .29326 .20191 .30113 .2 .29579 .19909 Mtetra
.63 .912 .981 r
.29579 .19909 .30113 .2 .30904 .19785 .30371 .1971 Mtetra
.65 .927 .974 r
.30371 .1971 .30904 .19785 .317 .19548 .31168 .19488 Mtetra
.667 .94 .964 r
.31168 .19488 .317 .19548 .32501 .19287 .31969 .19245 Mtetra
.681 .952 .953 r
.31969 .19245 .32501 .19287 .33305 .19005 .32774 .18981 Mtetra
.691 .963 .941 r
.32774 .18981 .33305 .19005 .34112 .18701 .33582 .18697 Mtetra
.695 .971 .927 r
.33582 .18697 .34112 .18701 .34923 .1838 .34394 .18397 Mtetra
.692 .976 .91 r
.34394 .18397 .34923 .1838 .35735 .18045 .35208 .18082 Mtetra
.68 .977 .891 r
.35208 .18082 .35735 .18045 .3655 .17701 .36024 .17759 Mtetra
.658 .972 .868 r
.36024 .17759 .3655 .17701 .37366 .17355 .36842 .17432 Mtetra
.626 .961 .842 r
.36842 .17432 .37366 .17355 .38182 .17013 .37661 .17107 Mtetra
.585 .942 .813 r
.37661 .17107 .38182 .17013 .38999 .16682 .3848 .16789 Mtetra
.541 .92 .786 r
.3848 .16789 .38999 .16682 .39816 .16368 .393 .16481 Mtetra
.506 .901 .766 r
.393 .16481 .39816 .16368 .40633 .16071 .40121 .16183 Mtetra
.246 .744 .67 r
.40121 .16183 .40633 .16071 .41445 .15889 .40936 .16001 Mtetra
.035 0 0 r
.40936 .16001 .41445 .15889 .42252 .15822 .41747 .15933 Mtetra
.058 0 0 r
.41747 .15933 .42252 .15822 .43063 .15773 .42561 .15876 Mtetra
.07 0 0 r
.42561 .15876 .43063 .15773 .43876 .15741 .43378 .15829 Mtetra
.064 0 0 r
.43378 .15829 .43876 .15741 .44693 .1572 .44198 .1579 Mtetra
.038 0 0 r
.44198 .1579 .44693 .1572 .45513 .15704 .45022 .15753 Mtetra
0 0 0 r
.45022 .15753 .45513 .15704 .46338 .15686 .4585 .15713 Mtetra
.072 .634 .71 r
.4585 .15713 .46338 .15686 .47166 .15659 .46682 .15663 Mtetra
.151 .694 .781 r
.46682 .15663 .47166 .15659 .47999 .15619 .47519 .156 Mtetra
.236 .752 .846 r
.47519 .156 .47999 .15619 .48836 .15561 .48359 .15521 Mtetra
.322 .802 .9 r
.48359 .15521 .48836 .15561 .49677 .15482 .49203 .15422 Mtetra
.403 .842 .94 r
.49203 .15422 .49677 .15482 .50522 .15381 .50051 .15301 Mtetra
.475 .87 .966 r
.50051 .15301 .50522 .15381 .5137 .15257 .50902 .15159 Mtetra
.536 .888 .981 r
.50902 .15159 .5137 .15257 .52222 .15109 .51757 .14995 Mtetra
.587 .899 .986 r
.51757 .14995 .52222 .15109 .53076 .14938 .52614 .14808 Mtetra
.629 .903 .985 r
.52614 .14808 .53076 .14938 .53934 .14745 .53474 .14598 Mtetra
.663 .904 .979 r
.53474 .14598 .53934 .14745 .54793 .14528 .54336 .14368 Mtetra
.691 .901 .972 r
.54336 .14368 .54793 .14528 .55655 .14291 .552 .14117 Mtetra
.714 .897 .962 r
.552 .14117 .55655 .14291 .56518 .14033 .56066 .13845 Mtetra
.732 .892 .953 r
.56066 .13845 .56518 .14033 .57384 .13755 .56934 .13555 Mtetra
.747 .887 .943 r
.56934 .13555 .57384 .13755 .5825 .13458 .57803 .13246 Mtetra
.76 .881 .933 r
.57803 .13246 .5825 .13458 .59118 .13143 .58673 .1292 Mtetra
.771 .875 .923 r
.58673 .1292 .59118 .13143 .59986 .12812 .59544 .12578 Mtetra
.779 .869 .915 r
.59544 .12578 .59986 .12812 .60856 .12466 .60416 .1222 Mtetra
.787 .863 .906 r
.60416 .1222 .60856 .12466 .61726 .12104 .61288 .11849 Mtetra
.793 .858 .898 r
.61288 .11849 .61726 .12104 .62596 .11729 .62161 .11464 Mtetra
.798 .853 .891 r
.62161 .11464 .62596 .11729 .63467 .11342 .63034 .11067 Mtetra
.802 .847 .885 r
.63034 .11067 .63467 .11342 .64338 .10942 .63907 .10658 Mtetra
.806 .842 .878 r
.63907 .10658 .64338 .10942 .65209 .10532 .6478 .10239 Mtetra
.808 .838 .873 r
.6478 .10239 .65209 .10532 .6608 .10113 .65654 .0981 Mtetra
.811 .833 .867 r
.65654 .0981 .6608 .10113 .66951 .09684 .66527 .09373 Mtetra
.812 .829 .863 r
.66527 .09373 .66951 .09684 .67822 .09248 .674 .08929 Mtetra
.814 .824 .858 r
.674 .08929 .67822 .09248 .68693 .08805 .68274 .08477 Mtetra
.815 .82 .854 r
.68274 .08477 .68693 .08805 .69564 .08356 .69147 .0802 Mtetra
.815 .816 .85 r
.69147 .0802 .69564 .08356 .70435 .07901 .70019 .07557 Mtetra
.815 .812 .847 r
.70019 .07557 .70435 .07901 .71306 .07443 .70892 .0709 Mtetra
.815 .808 .844 r
.70892 .0709 .71306 .07443 .72177 .0698 .71765 .0662 Mtetra
.814 .804 .841 r
.71765 .0662 .72177 .0698 .73047 .06516 .72637 .06147 Mtetra
.813 .8 .839 r
.72637 .06147 .73047 .06516 .73918 .06049 .7351 .05673 Mtetra
.812 .796 .837 r
.7351 .05673 .73918 .06049 .74789 .05581 .74382 .05198 Mtetra
.237 .558 .934 r
.10283 .19511 .10812 .19816 .11473 .19909 .10944 .1961 Mtetra
.231 .56 .935 r
.10944 .1961 .11473 .19909 .12139 .20001 .11608 .19708 Mtetra
.227 .563 .937 r
.11608 .19708 .12139 .20001 .12809 .20093 .12277 .19805 Mtetra
.225 .567 .939 r
.12277 .19805 .12809 .20093 .13482 .20182 .1295 .199 Mtetra
.224 .572 .941 r
.1295 .199 .13482 .20182 .1416 .20269 .13627 .19993 Mtetra
.226 .579 .943 r
.13627 .19993 .1416 .20269 .14843 .20352 .14309 .20082 Mtetra
.229 .586 .946 r
.14309 .20082 .14843 .20352 .1553 .20431 .14995 .20168 Mtetra
.235 .595 .949 r
.14995 .20168 .1553 .20431 .16222 .20505 .15686 .20248 Mtetra
.242 .605 .953 r
.15686 .20248 .16222 .20505 .16919 .20573 .16382 .20322 Mtetra
.251 .616 .957 r
.16382 .20322 .16919 .20573 .17621 .20634 .17084 .2039 Mtetra
.262 .629 .961 r
.17084 .2039 .17621 .20634 .18328 .20687 .1779 .2045 Mtetra
.275 .642 .966 r
.1779 .2045 .18328 .20687 .1904 .20732 .18501 .20502 Mtetra
.29 .656 .97 r
.18501 .20502 .1904 .20732 .19757 .20767 .19218 .20544 Mtetra
.306 .672 .975 r
.19218 .20544 .19757 .20767 .2048 .20791 .19941 .20577 Mtetra
.324 .688 .979 r
.19941 .20577 .2048 .20791 .21208 .20804 .20669 .20598 Mtetra
.343 .705 .984 r
.20669 .20598 .21208 .20804 .21942 .20805 .21402 .20607 Mtetra
.364 .723 .988 r
.21402 .20607 .21942 .20805 .22681 .20792 .22141 .20603 Mtetra
.386 .741 .992 r
.22141 .20603 .22681 .20792 .23426 .20765 .22885 .20585 Mtetra
.409 .76 .995 r
.22885 .20585 .23426 .20765 .24176 .20722 .23636 .20552 Mtetra
.433 .779 .997 r
.23636 .20552 .24176 .20722 .24932 .20663 .24391 .20503 Mtetra
.457 .798 .999 r
.24391 .20503 .24932 .20663 .25693 .20586 .25153 .20437 Mtetra
.482 .818 .999 r
.25153 .20437 .25693 .20586 .2646 .20491 .25919 .20353 Mtetra
.507 .837 .999 r
.25919 .20353 .2646 .20491 .27232 .20377 .26692 .2025 Mtetra
.532 .855 .997 r
.26692 .2025 .27232 .20377 .28009 .20242 .27469 .20128 Mtetra
.556 .873 .994 r
.27469 .20128 .28009 .20242 .28791 .20086 .28252 .19986 Mtetra
.579 .89 .989 r
.28252 .19986 .28791 .20086 .29579 .19909 .2904 .19823 Mtetra
.601 .907 .983 r
.2904 .19823 .29579 .19909 .30371 .1971 .29833 .19639 Mtetra
.62 .922 .975 r
.29833 .19639 .30371 .1971 .31168 .19488 .3063 .19434 Mtetra
.637 .935 .966 r
.3063 .19434 .31168 .19488 .31969 .19245 .31432 .19207 Mtetra
.65 .947 .955 r
.31432 .19207 .31969 .19245 .32774 .18981 .32238 .18961 Mtetra
.659 .957 .942 r
.32238 .18961 .32774 .18981 .33582 .18697 .33047 .18697 Mtetra
.662 .964 .926 r
.33047 .18697 .33582 .18697 .34394 .18397 .3386 .18416 Mtetra
.658 .968 .909 r
.3386 .18416 .34394 .18397 .35208 .18082 .34675 .18122 Mtetra
.646 .967 .888 r
.34675 .18122 .35208 .18082 .36024 .17759 .35493 .17818 Mtetra
.626 .961 .865 r
.35493 .17818 .36024 .17759 .36842 .17432 .36313 .1751 Mtetra
.598 .95 .839 r
.36313 .1751 .36842 .17432 .37661 .17107 .37134 .172 Mtetra
.564 .934 .811 r
.37134 .172 .37661 .17107 .3848 .16789 .37956 .16894 Mtetra
.531 .916 .787 r
.37956 .16894 .3848 .16789 .393 .16481 .38779 .16593 Mtetra
.508 .903 .77 r
.38779 .16593 .393 .16481 .40121 .16183 .39603 .16296 Mtetra
.25 .747 .674 r
.39603 .16296 .40121 .16183 .40936 .16001 .40422 .16112 Mtetra
.028 0 0 r
.40422 .16112 .40936 .16001 .41747 .15933 .41236 .16042 Mtetra
.035 0 0 r
.41236 .16042 .41747 .15933 .42561 .15876 .42054 .15977 Mtetra
.42054 .15977 .42561 .15876 .43378 .15829 .42874 .15917 Mtetra
.02 0 0 r
.42874 .15917 .43378 .15829 .44198 .1579 .43699 .15861 Mtetra
0 0 0 r
.43699 .15861 .44198 .1579 .45022 .15753 .44527 .15803 Mtetra
.44527 .15803 .45022 .15753 .4585 .15713 .45358 .15742 Mtetra
.122 .672 .732 r
.45358 .15742 .4585 .15713 .46682 .15663 .46194 .1567 Mtetra
.197 .727 .797 r
.46194 .1567 .46682 .15663 .47519 .156 .47034 .15586 Mtetra
.278 .78 .857 r
.47034 .15586 .47519 .156 .48359 .15521 .47877 .15485 Mtetra
.359 .825 .906 r
.47877 .15485 .48359 .15521 .49203 .15422 .48725 .15366 Mtetra
.434 .86 .942 r
.48725 .15366 .49203 .15422 .50051 .15301 .49576 .15227 Mtetra
.5 .885 .965 r
.49576 .15227 .50051 .15301 .50902 .15159 .5043 .15066 Mtetra
.557 .9 .978 r
.5043 .15066 .50902 .15159 .51757 .14995 .51287 .14884 Mtetra
.605 .909 .982 r
.51287 .14884 .51757 .14995 .52614 .14808 .52147 .14681 Mtetra
.644 .912 .981 r
.52147 .14681 .52614 .14808 .53474 .14598 .5301 .14456 Mtetra
.676 .911 .975 r
.5301 .14456 .53474 .14598 .54336 .14368 .53875 .14211 Mtetra
.702 .908 .968 r
.53875 .14211 .54336 .14368 .552 .14117 .54742 .13946 Mtetra
.723 .903 .959 r
.54742 .13946 .552 .14117 .56066 .13845 .55611 .13661 Mtetra
.741 .897 .949 r
.55611 .13661 .56066 .13845 .56934 .13555 .56481 .13358 Mtetra
.755 .891 .939 r
.56481 .13358 .56934 .13555 .57803 .13246 .57353 .13037 Mtetra
.767 .885 .93 r
.57353 .13037 .57803 .13246 .58673 .1292 .58225 .12699 Mtetra
.777 .879 .921 r
.58225 .12699 .58673 .1292 .59544 .12578 .59099 .12345 Mtetra
.785 .873 .912 r
.59099 .12345 .59544 .12578 .60416 .1222 .59973 .11977 Mtetra
.792 .867 .904 r
.59973 .11977 .60416 .1222 .61288 .11849 .60847 .11595 Mtetra
.798 .861 .896 r
.60847 .11595 .61288 .11849 .62161 .11464 .61723 .112 Mtetra
.803 .855 .889 r
.61723 .112 .62161 .11464 .63034 .11067 .62598 .10792 Mtetra
.806 .85 .882 r
.62598 .10792 .63034 .11067 .63907 .10658 .63474 .10374 Mtetra
.81 .845 .876 r
.63474 .10374 .63907 .10658 .6478 .10239 .64349 .09946 Mtetra
.812 .84 .871 r
.64349 .09946 .6478 .10239 .65654 .0981 .65225 .09508 Mtetra
.814 .835 .865 r
.65225 .09508 .65654 .0981 .66527 .09373 .66101 .09062 Mtetra
.816 .83 .861 r
.66101 .09062 .66527 .09373 .674 .08929 .66976 .08608 Mtetra
.817 .826 .856 r
.66976 .08608 .674 .08929 .68274 .08477 .67851 .08148 Mtetra
.818 .821 .852 r
.67851 .08148 .68274 .08477 .69147 .0802 .68726 .07682 Mtetra
.818 .817 .849 r
.68726 .07682 .69147 .0802 .70019 .07557 .69601 .07212 Mtetra
.818 .813 .845 r
.69601 .07212 .70019 .07557 .70892 .0709 .70476 .06737 Mtetra
.818 .809 .842 r
.70476 .06737 .70892 .0709 .71765 .0662 .7135 .06258 Mtetra
.817 .805 .84 r
.7135 .06258 .71765 .0662 .72637 .06147 .72225 .05778 Mtetra
.816 .801 .837 r
.72225 .05778 .72637 .06147 .7351 .05673 .73099 .05295 Mtetra
.815 .797 .835 r
.73099 .05295 .7351 .05673 .74382 .05198 .73974 .04812 Mtetra
.219 .548 .93 r
.09751 .19205 .10283 .19511 .10944 .1961 .10411 .19309 Mtetra
.213 .55 .931 r
.10411 .19309 .10944 .1961 .11608 .19708 .11074 .19413 Mtetra
.209 .553 .933 r
.11074 .19413 .11608 .19708 .12277 .19805 .11742 .19517 Mtetra
.206 .557 .934 r
.11742 .19517 .12277 .19805 .1295 .199 .12414 .19618 Mtetra
.205 .562 .936 r
.12414 .19618 .1295 .199 .13627 .19993 .1309 .19717 Mtetra
.206 .568 .938 r
.1309 .19717 .13627 .19993 .14309 .20082 .13771 .19812 Mtetra
.209 .576 .941 r
.13771 .19812 .14309 .20082 .14995 .20168 .14456 .19904 Mtetra
.214 .584 .944 r
.14456 .19904 .14995 .20168 .15686 .20248 .15147 .19991 Mtetra
.221 .594 .948 r
.15147 .19991 .15686 .20248 .16382 .20322 .15842 .20072 Mtetra
.229 .605 .952 r
.15842 .20072 .16382 .20322 .17084 .2039 .16543 .20147 Mtetra
.24 .617 .956 r
.16543 .20147 .17084 .2039 .1779 .2045 .17248 .20214 Mtetra
.252 .631 .961 r
.17248 .20214 .1779 .2045 .18501 .20502 .17959 .20273 Mtetra
.266 .645 .965 r
.17959 .20273 .18501 .20502 .19218 .20544 .18676 .20323 Mtetra
.281 .66 .97 r
.18676 .20323 .19218 .20544 .19941 .20577 .19398 .20364 Mtetra
.298 .677 .975 r
.19398 .20364 .19941 .20577 .20669 .20598 .20125 .20393 Mtetra
.317 .694 .979 r
.20125 .20393 .20669 .20598 .21402 .20607 .20858 .20411 Mtetra
.337 .712 .984 r
.20858 .20411 .21402 .20607 .22141 .20603 .21597 .20416 Mtetra
.358 .73 .988 r
.21597 .20416 .22141 .20603 .22885 .20585 .22341 .20407 Mtetra
.381 .749 .991 r
.22341 .20407 .22885 .20585 .23636 .20552 .23091 .20384 Mtetra
.404 .769 .994 r
.23091 .20384 .23636 .20552 .24391 .20503 .23846 .20345 Mtetra
.428 .788 .996 r
.23846 .20345 .24391 .20503 .25153 .20437 .24608 .2029 Mtetra
.452 .808 .997 r
.24608 .2029 .25153 .20437 .25919 .20353 .25374 .20218 Mtetra
.477 .827 .997 r
.25374 .20218 .25919 .20353 .26692 .2025 .26147 .20128 Mtetra
.501 .846 .995 r
.26147 .20128 .26692 .2025 .27469 .20128 .26925 .20019 Mtetra
.525 .865 .993 r
.26925 .20019 .27469 .20128 .28252 .19986 .27708 .1989 Mtetra
.547 .882 .988 r
.27708 .1989 .28252 .19986 .2904 .19823 .28496 .19741 Mtetra
.568 .899 .982 r
.28496 .19741 .2904 .19823 .29833 .19639 .29289 .19573 Mtetra
.587 .914 .975 r
.29289 .19573 .29833 .19639 .3063 .19434 .30087 .19384 Mtetra
.603 .927 .965 r
.30087 .19384 .3063 .19434 .31432 .19207 .3089 .19175 Mtetra
.615 .939 .954 r
.3089 .19175 .31432 .19207 .32238 .18961 .31696 .18947 Mtetra
.623 .948 .94 r
.31696 .18947 .32238 .18961 .33047 .18697 .32507 .18701 Mtetra
.626 .954 .924 r
.32507 .18701 .33047 .18697 .3386 .18416 .3332 .18439 Mtetra
.622 .957 .905 r
.3332 .18439 .3386 .18416 .34675 .18122 .34137 .18164 Mtetra
.611 .955 .884 r
.34137 .18164 .34675 .18122 .35493 .17818 .34957 .17879 Mtetra
.593 .949 .86 r
.34957 .17879 .35493 .17818 .36313 .1751 .35778 .17588 Mtetra
.568 .938 .834 r
.35778 .17588 .36313 .1751 .37134 .172 .36601 .17294 Mtetra
.541 .924 .808 r
.36601 .17294 .37134 .172 .37956 .16894 .37426 .16999 Mtetra
.517 .91 .785 r
.37426 .16999 .37956 .16894 .38779 .16593 .38253 .16704 Mtetra
.504 .901 .771 r
.38253 .16704 .38779 .16593 .39603 .16296 .3908 .16409 Mtetra
.25 .747 .674 r
.3908 .16409 .39603 .16296 .40422 .16112 .39902 .16225 Mtetra
.02 0 0 r
.39902 .16225 .40422 .16112 .41236 .16042 .4072 .16152 Mtetra
.014 0 0 r
.4072 .16152 .41236 .16042 .42054 .15977 .41541 .16078 Mtetra
.002 0 0 r
.41541 .16078 .42054 .15977 .42874 .15917 .42366 .16005 Mtetra
0 0 0 r
.42366 .16005 .42874 .15917 .43699 .15861 .43194 .15932 Mtetra
.43194 .15932 .43699 .15861 .44527 .15803 .44026 .15855 Mtetra
.44026 .15855 .44527 .15803 .45358 .15742 .44861 .15773 Mtetra
.17 .707 .752 r
.44861 .15773 .45358 .15742 .46194 .1567 .45701 .15681 Mtetra
.242 .758 .812 r
.45701 .15681 .46194 .1567 .47034 .15586 .46544 .15575 Mtetra
.318 .806 .866 r
.46544 .15575 .47034 .15586 .47877 .15485 .47391 .15454 Mtetra
.394 .846 .91 r
.47391 .15454 .47877 .15485 .48725 .15366 .48242 .15315 Mtetra
.464 .877 .942 r
.48242 .15315 .48725 .15366 .49576 .15227 .49096 .15156 Mtetra
.526 .898 .963 r
.49096 .15156 .49576 .15227 .5043 .15066 .49954 .14978 Mtetra
.578 .911 .974 r
.49954 .14978 .5043 .15066 .51287 .14884 .50814 .14779 Mtetra
.623 .918 .978 r
.50814 .14779 .51287 .14884 .52147 .14681 .51677 .14559 Mtetra
.659 .92 .976 r
.51677 .14559 .52147 .14681 .5301 .14456 .52543 .14318 Mtetra
.689 .918 .971 r
.52543 .14318 .5301 .14456 .53875 .14211 .53411 .14058 Mtetra
.713 .914 .964 r
.53411 .14058 .53875 .14211 .54742 .13946 .5428 .13778 Mtetra
.733 .908 .955 r
.5428 .13778 .54742 .13946 .55611 .13661 .55152 .1348 Mtetra
.75 .902 .945 r
.55152 .1348 .55611 .13661 .56481 .13358 .56025 .13163 Mtetra
.763 .896 .936 r
.56025 .13163 .56481 .13358 .57353 .13037 .56899 .1283 Mtetra
.774 .889 .927 r
.56899 .1283 .57353 .13037 .58225 .12699 .57774 .1248 Mtetra
.784 .882 .918 r
.57774 .1248 .58225 .12699 .59099 .12345 .5865 .12115 Mtetra
.791 .876 .909 r
.5865 .12115 .59099 .12345 .59973 .11977 .59527 .11735 Mtetra
.798 .87 .901 r
.59527 .11735 .59973 .11977 .60847 .11595 .60404 .11342 Mtetra
.803 .864 .894 r
.60404 .11342 .60847 .11595 .61723 .112 .61282 .10936 Mtetra
.807 .858 .887 r
.61282 .10936 .61723 .112 .62598 .10792 .62159 .10519 Mtetra
.811 .852 .88 r
.62159 .10519 .62598 .10792 .63474 .10374 .63037 .10091 Mtetra
.814 .847 .874 r
.63037 .10091 .63474 .10374 .64349 .09946 .63915 .09653 Mtetra
.816 .842 .869 r
.63915 .09653 .64349 .09946 .65225 .09508 .64793 .09206 Mtetra
.818 .837 .863 r
.64793 .09206 .65225 .09508 .66101 .09062 .65671 .0875 Mtetra
.819 .832 .859 r
.65671 .0875 .66101 .09062 .66976 .08608 .66549 .08288 Mtetra
.82 .827 .854 r
.66549 .08288 .66976 .08608 .67851 .08148 .67426 .07819 Mtetra
.821 .823 .85 r
.67426 .07819 .67851 .08148 .68726 .07682 .68303 .07344 Mtetra
.821 .818 .847 r
.68303 .07344 .68726 .07682 .69601 .07212 .6918 .06865 Mtetra
.821 .814 .843 r
.6918 .06865 .69601 .07212 .70476 .06737 .70057 .06382 Mtetra
.821 .81 .84 r
.70057 .06382 .70476 .06737 .7135 .06258 .70934 .05895 Mtetra
.82 .806 .838 r
.70934 .05895 .7135 .06258 .72225 .05778 .7181 .05406 Mtetra
.819 .801 .835 r
.7181 .05406 .72225 .05778 .73099 .05295 .72686 .04915 Mtetra
.817 .797 .833 r
.72686 .04915 .73099 .05295 .73974 .04812 .73562 .04424 Mtetra
.201 .538 .926 r
.09217 .18897 .09751 .19205 .10411 .19309 .09875 .19008 Mtetra
.195 .539 .927 r
.09875 .19008 .10411 .19309 .11074 .19413 .10538 .19118 Mtetra
.19 .542 .928 r
.10538 .19118 .11074 .19413 .11742 .19517 .11204 .19227 Mtetra
.186 .546 .929 r
.11204 .19227 .11742 .19517 .12414 .19618 .11875 .19335 Mtetra
.185 .551 .931 r
.11875 .19335 .12414 .19618 .1309 .19717 .1255 .1944 Mtetra
.186 .557 .933 r
.1255 .1944 .1309 .19717 .13771 .19812 .1323 .19542 Mtetra
.188 .564 .936 r
.1323 .19542 .13771 .19812 .14456 .19904 .13914 .1964 Mtetra
.192 .573 .939 r
.13914 .1964 .14456 .19904 .15147 .19991 .14604 .19734 Mtetra
.198 .582 .942 r
.14604 .19734 .15147 .19991 .15842 .20072 .15298 .19822 Mtetra
.206 .593 .946 r
.15298 .19822 .15842 .20072 .16543 .20147 .15998 .19904 Mtetra
.216 .605 .95 r
.15998 .19904 .16543 .20147 .17248 .20214 .16703 .19978 Mtetra
.227 .618 .954 r
.16703 .19978 .17248 .20214 .17959 .20273 .17413 .20045 Mtetra
.24 .632 .959 r
.17413 .20045 .17959 .20273 .18676 .20323 .18129 .20103 Mtetra
.255 .648 .964 r
.18129 .20103 .18676 .20323 .19398 .20364 .1885 .20152 Mtetra
.271 .664 .969 r
.1885 .20152 .19398 .20364 .20125 .20393 .19577 .2019 Mtetra
.289 .681 .973 r
.19577 .2019 .20125 .20393 .20858 .20411 .2031 .20216 Mtetra
.308 .699 .978 r
.2031 .20216 .20858 .20411 .21597 .20416 .21048 .20231 Mtetra
.329 .718 .982 r
.21048 .20231 .21597 .20416 .22341 .20407 .21792 .20232 Mtetra
.351 .737 .986 r
.21792 .20232 .22341 .20407 .23091 .20384 .22542 .20219 Mtetra
.373 .757 .989 r
.22542 .20219 .23091 .20384 .23846 .20345 .23297 .20191 Mtetra
.396 .776 .991 r
.23297 .20191 .23846 .20345 .24608 .2029 .24058 .20147 Mtetra
.42 .796 .993 r
.24058 .20147 .24608 .2029 .25374 .20218 .24825 .20087 Mtetra
.444 .816 .993 r
.24825 .20087 .25374 .20218 .26147 .20128 .25597 .20009 Mtetra
.468 .835 .992 r
.25597 .20009 .26147 .20128 .26925 .20019 .26375 .19913 Mtetra
.491 .854 .989 r
.26375 .19913 .26925 .20019 .27708 .1989 .27159 .19798 Mtetra
.513 .872 .985 r
.27159 .19798 .27708 .1989 .28496 .19741 .27947 .19664 Mtetra
.533 .888 .98 r
.27947 .19664 .28496 .19741 .29289 .19573 .28741 .19511 Mtetra
.551 .903 .972 r
.28741 .19511 .29289 .19573 .30087 .19384 .29539 .19338 Mtetra
.566 .917 .962 r
.29539 .19338 .30087 .19384 .3089 .19175 .30342 .19146 Mtetra
.578 .928 .95 r
.30342 .19146 .3089 .19175 .31696 .18947 .3115 .18936 Mtetra
.585 .936 .936 r
.3115 .18936 .31696 .18947 .32507 .18701 .31961 .18708 Mtetra
.587 .942 .919 r
.31961 .18708 .32507 .18701 .3332 .18439 .32776 .18465 Mtetra
.583 .943 .899 r
.32776 .18465 .3332 .18439 .34137 .18164 .33594 .18209 Mtetra
.573 .941 .877 r
.33594 .18209 .34137 .18164 .34957 .17879 .34415 .17942 Mtetra
.558 .934 .853 r
.34415 .17942 .34957 .17879 .35778 .17588 .35238 .17668 Mtetra
.538 .924 .827 r
.35238 .17668 .35778 .17588 .36601 .17294 .36064 .17388 Mtetra
.517 .912 .802 r
.36064 .17388 .36601 .17294 .37426 .16999 .36891 .17104 Mtetra
.501 .902 .782 r
.36891 .17104 .37426 .16999 .38253 .16704 .37721 .16817 Mtetra
.495 .897 .768 r
.37721 .16817 .38253 .16704 .3908 .16409 .38552 .16525 Mtetra
.247 .745 .671 r
.38552 .16525 .3908 .16409 .39902 .16225 .39378 .1634 Mtetra
.012 0 0 r
.39378 .1634 .39902 .16225 .4072 .16152 .40199 .16262 Mtetra
0 0 0 r
.40199 .16262 .4072 .16152 .41541 .16078 .41024 .16179 Mtetra
.41024 .16179 .41541 .16078 .42366 .16005 .41852 .16093 Mtetra
.41852 .16093 .42366 .16005 .43194 .15932 .42684 .16004 Mtetra
.42684 .16004 .43194 .15932 .44026 .15855 .4352 .1591 Mtetra
.152 .691 .712 r
.4352 .1591 .44026 .15855 .44861 .15773 .4436 .15807 Mtetra
.215 .738 .769 r
.4436 .15807 .44861 .15773 .45701 .15681 .45203 .15694 Mtetra
.284 .786 .824 r
.45203 .15694 .45701 .15681 .46544 .15575 .4605 .15568 Mtetra
.357 .829 .873 r
.4605 .15568 .46544 .15575 .47391 .15454 .46901 .15427 Mtetra
.427 .865 .913 r
.46901 .15427 .47391 .15454 .48242 .15315 .47755 .15268 Mtetra
.492 .892 .942 r
.47755 .15268 .48242 .15315 .49096 .15156 .48612 .1509 Mtetra
.55 .911 .961 r
.48612 .1509 .49096 .15156 .49954 .14978 .49473 .14894 Mtetra
.599 .922 .971 r
.49473 .14894 .49954 .14978 .50814 .14779 .50337 .14677 Mtetra
.64 .926 .974 r
.50337 .14677 .50814 .14779 .51677 .14559 .51203 .1444 Mtetra
.674 .927 .972 r
.51203 .1444 .51677 .14559 .52543 .14318 .52072 .14184 Mtetra
.702 .924 .966 r
.52072 .14184 .52543 .14318 .53411 .14058 .52942 .13908 Mtetra
.725 .919 .959 r
.52942 .13908 .53411 .14058 .5428 .13778 .53815 .13614 Mtetra
.743 .913 .951 r
.53815 .13614 .5428 .13778 .55152 .1348 .54689 .13302 Mtetra
.758 .907 .942 r
.54689 .13302 .55152 .1348 .56025 .13163 .55565 .12972 Mtetra
.771 .9 .932 r
.55565 .12972 .56025 .13163 .56899 .1283 .56442 .12625 Mtetra
.781 .893 .923 r
.56442 .12625 .56899 .1283 .57774 .1248 .5732 .12263 Mtetra
.79 .886 .915 r
.5732 .12263 .57774 .1248 .5865 .12115 .58198 .11886 Mtetra
.797 .879 .906 r
.58198 .11886 .5865 .12115 .59527 .11735 .59078 .11495 Mtetra
.803 .873 .898 r
.59078 .11495 .59527 .11735 .60404 .11342 .59958 .11091 Mtetra
.808 .866 .891 r
.59958 .11091 .60404 .11342 .61282 .10936 .60838 .10674 Mtetra
.812 .86 .884 r
.60838 .10674 .61282 .10936 .62159 .10519 .61718 .10246 Mtetra
.815 .854 .878 r
.61718 .10246 .62159 .10519 .63037 .10091 .62598 .09808 Mtetra
.818 .849 .872 r
.62598 .09808 .63037 .10091 .63915 .09653 .63479 .0936 Mtetra
.82 .844 .866 r
.63479 .0936 .63915 .09653 .64793 .09206 .64359 .08903 Mtetra
.822 .839 .861 r
.64359 .08903 .64793 .09206 .65671 .0875 .65239 .08439 Mtetra
.823 .834 .857 r
.65239 .08439 .65671 .0875 .66549 .08288 .66119 .07967 Mtetra
.824 .829 .852 r
.66119 .07967 .66549 .08288 .67426 .07819 .66999 .07489 Mtetra
.824 .824 .848 r
.66999 .07489 .67426 .07819 .68303 .07344 .67878 .07005 Mtetra
.824 .82 .845 r
.67878 .07005 .68303 .07344 .6918 .06865 .68757 .06517 Mtetra
.824 .815 .841 r
.68757 .06517 .6918 .06865 .70057 .06382 .69636 .06025 Mtetra
.824 .811 .838 r
.69636 .06025 .70057 .06382 .70934 .05895 .70514 .0553 Mtetra
.823 .807 .836 r
.70514 .0553 .70934 .05895 .7181 .05406 .71393 .05032 Mtetra
.822 .802 .833 r
.71393 .05032 .7181 .05406 .72686 .04915 .72271 .04533 Mtetra
.82 .798 .831 r
.72271 .04533 .72686 .04915 .73562 .04424 .73149 .04033 Mtetra
.183 .527 .921 r
.0868 .18588 .09217 .18897 .09875 .19008 .09337 .18704 Mtetra
.175 .528 .921 r
.09337 .18704 .09875 .19008 .10538 .19118 .09998 .18821 Mtetra
.17 .531 .922 r
.09998 .18821 .10538 .19118 .11204 .19227 .10663 .18936 Mtetra
.166 .534 .923 r
.10663 .18936 .11204 .19227 .11875 .19335 .11333 .19051 Mtetra
.164 .539 .925 r
.11333 .19051 .11875 .19335 .1255 .1944 .12007 .19162 Mtetra
.164 .545 .927 r
.12007 .19162 .1255 .1944 .1323 .19542 .12685 .19271 Mtetra
.166 .552 .929 r
.12685 .19271 .1323 .19542 .13914 .1964 .13369 .19376 Mtetra
.169 .56 .932 r
.13369 .19376 .13914 .1964 .14604 .19734 .14057 .19477 Mtetra
.175 .57 .935 r
.14057 .19477 .14604 .19734 .15298 .19822 .14751 .19572 Mtetra
.182 .58 .939 r
.14751 .19572 .15298 .19822 .15998 .19904 .1545 .19661 Mtetra
.191 .592 .943 r
.1545 .19661 .15998 .19904 .16703 .19978 .16154 .19743 Mtetra
.201 .605 .947 r
.16154 .19743 .16703 .19978 .17413 .20045 .16863 .19818 Mtetra
.213 .619 .952 r
.16863 .19818 .17413 .20045 .18129 .20103 .17578 .19884 Mtetra
.227 .634 .957 r
.17578 .19884 .18129 .20103 .1885 .20152 .18299 .19941 Mtetra
.243 .65 .961 r
.18299 .19941 .1885 .20152 .19577 .2019 .19025 .19988 Mtetra
.26 .667 .966 r
.19025 .19988 .19577 .2019 .2031 .20216 .19757 .20024 Mtetra
.278 .685 .971 r
.19757 .20024 .2031 .20216 .21048 .20231 .20495 .20048 Mtetra
.298 .704 .975 r
.20495 .20048 .21048 .20231 .21792 .20232 .21239 .20059 Mtetra
.319 .723 .979 r
.21239 .20059 .21792 .20232 .22542 .20219 .21988 .20056 Mtetra
.34 .742 .982 r
.21988 .20056 .22542 .20219 .23297 .20191 .22743 .20039 Mtetra
.363 .762 .985 r
.22743 .20039 .23297 .20191 .24058 .20147 .23504 .20007 Mtetra
.386 .782 .987 r
.23504 .20007 .24058 .20147 .24825 .20087 .24271 .19959 Mtetra
.409 .802 .987 r
.24271 .19959 .24825 .20087 .25597 .20009 .25043 .19894 Mtetra
.432 .822 .986 r
.25043 .19894 .25597 .20009 .26375 .19913 .25821 .19811 Mtetra
.454 .84 .984 r
.25821 .19811 .26375 .19913 .27159 .19798 .26604 .1971 Mtetra
.475 .858 .98 r
.26604 .1971 .27159 .19798 .27947 .19664 .27393 .19591 Mtetra
.494 .875 .974 r
.27393 .19591 .27947 .19664 .28741 .19511 .28187 .19453 Mtetra
.512 .89 .966 r
.28187 .19453 .28741 .19511 .29539 .19338 .28986 .19297 Mtetra
.526 .903 .956 r
.28986 .19297 .29539 .19338 .30342 .19146 .29789 .19122 Mtetra
.537 .914 .943 r
.29789 .19122 .30342 .19146 .3115 .18936 .30598 .18929 Mtetra
.544 .921 .928 r
.30598 .18929 .3115 .18936 .31961 .18708 .3141 .1872 Mtetra
.546 .926 .911 r
.3141 .1872 .31961 .18708 .32776 .18465 .32226 .18495 Mtetra
.543 .927 .89 r
.32226 .18495 .32776 .18465 .33594 .18209 .33045 .18257 Mtetra
.534 .924 .868 r
.33045 .18257 .33594 .18209 .34415 .17942 .33868 .18008 Mtetra
.521 .918 .843 r
.33868 .18008 .34415 .17942 .35238 .17668 .34693 .1775 Mtetra
.506 .909 .818 r
.34693 .1775 .35238 .17668 .36064 .17388 .35521 .17484 Mtetra
.491 .899 .794 r
.35521 .17484 .36064 .17388 .36891 .17104 .36351 .17212 Mtetra
.481 .891 .775 r
.36351 .17212 .36891 .17104 .37721 .16817 .37183 .16932 Mtetra
.482 .89 .763 r
.37183 .16932 .37721 .16817 .38552 .16525 .38018 .16644 Mtetra
.242 .741 .665 r
.38018 .16644 .38552 .16525 .39378 .1634 .38847 .16458 Mtetra
.003 0 0 r
.38847 .16458 .39378 .1634 .40199 .16262 .39672 .16375 Mtetra
0 0 0 r
.39672 .16375 .40199 .16262 .41024 .16179 .405 .16283 Mtetra
.405 .16283 .41024 .16179 .41852 .16093 .41333 .16184 Mtetra
.41333 .16184 .41852 .16093 .42684 .16004 .42169 .16078 Mtetra
.42169 .16078 .42684 .16004 .4352 .1591 .43009 .15966 Mtetra
.194 .721 .729 r
.43009 .15966 .4352 .1591 .4436 .15807 .43853 .15844 Mtetra
.257 .767 .783 r
.43853 .15844 .4436 .15807 .45203 .15694 .447 .15712 Mtetra
.324 .811 .834 r
.447 .15712 .45203 .15694 .4605 .15568 .45551 .15565 Mtetra
.393 .85 .879 r
.45551 .15565 .4605 .15568 .46901 .15427 .46405 .15404 Mtetra
.459 .883 .915 r
.46405 .15404 .46901 .15427 .47755 .15268 .47263 .15225 Mtetra
.52 .906 .941 r
.47263 .15225 .47755 .15268 .48612 .1509 .48124 .15029 Mtetra
.573 .922 .958 r
.48124 .15029 .48612 .1509 .49473 .14894 .48988 .14813 Mtetra
.619 .931 .966 r
.48988 .14813 .49473 .14894 .50337 .14677 .49855 .14579 Mtetra
.657 .934 .969 r
.49855 .14579 .50337 .14677 .51203 .1444 .50725 .14326 Mtetra
.688 .933 .967 r
.50725 .14326 .51203 .1444 .52072 .14184 .51597 .14053 Mtetra
.714 .93 .961 r
.51597 .14053 .52072 .14184 .52942 .13908 .5247 .13762 Mtetra
.736 .924 .954 r
.5247 .13762 .52942 .13908 .53815 .13614 .53346 .13453 Mtetra
.753 .918 .946 r
.53346 .13453 .53815 .13614 .54689 .13302 .54223 .13126 Mtetra
.767 .911 .937 r
.54223 .13126 .54689 .13302 .55565 .12972 .55102 .12783 Mtetra
.779 .904 .928 r
.55102 .12783 .55565 .12972 .56442 .12625 .55982 .12423 Mtetra
.788 .896 .92 r
.55982 .12423 .56442 .12625 .5732 .12263 .56862 .12048 Mtetra
.796 .889 .911 r
.56862 .12048 .5732 .12263 .58198 .11886 .57744 .11659 Mtetra
.803 .882 .903 r
.57744 .11659 .58198 .11886 .59078 .11495 .58626 .11256 Mtetra
.809 .875 .895 r
.58626 .11256 .59078 .11495 .59958 .11091 .59508 .1084 Mtetra
.813 .869 .888 r
.59508 .1084 .59958 .11091 .60838 .10674 .60391 .10413 Mtetra
.817 .863 .882 r
.60391 .10413 .60838 .10674 .61718 .10246 .61273 .09974 Mtetra
.82 .857 .875 r
.61273 .09974 .61718 .10246 .62598 .09808 .62156 .09525 Mtetra
.822 .851 .869 r
.62156 .09525 .62598 .09808 .63479 .0936 .63039 .09067 Mtetra
.824 .845 .864 r
.63039 .09067 .63479 .0936 .64359 .08903 .63922 .08601 Mtetra
.825 .84 .859 r
.63922 .08601 .64359 .08903 .65239 .08439 .64804 .08126 Mtetra
.826 .835 .854 r
.64804 .08126 .65239 .08439 .66119 .07967 .65686 .07645 Mtetra
.827 .83 .85 r
.65686 .07645 .66119 .07967 .66999 .07489 .66568 .07158 Mtetra
.827 .826 .846 r
.66568 .07158 .66999 .07489 .67878 .07005 .6745 .06665 Mtetra
.827 .821 .843 r
.6745 .06665 .67878 .07005 .68757 .06517 .68331 .06168 Mtetra
.827 .816 .839 r
.68331 .06168 .68757 .06517 .69636 .06025 .69212 .05667 Mtetra
.826 .812 .836 r
.69212 .05667 .69636 .06025 .70514 .0553 .70093 .05163 Mtetra
.826 .807 .834 r
.70093 .05163 .70514 .0553 .71393 .05032 .70973 .04657 Mtetra
.824 .803 .831 r
.70973 .04657 .71393 .05032 .72271 .04533 .71853 .04149 Mtetra
.823 .799 .829 r
.71853 .04149 .72271 .04533 .73149 .04033 .72733 .03641 Mtetra
.163 .515 .915 r
.0814 .18277 .0868 .18588 .09337 .18704 .08796 .184 Mtetra
.155 .516 .916 r
.08796 .184 .09337 .18704 .09998 .18821 .09455 .18523 Mtetra
.149 .519 .916 r
.09455 .18523 .09998 .18821 .10663 .18936 .10119 .18645 Mtetra
.145 .522 .917 r
.10119 .18645 .10663 .18936 .11333 .19051 .10787 .18766 Mtetra
.142 .526 .918 r
.10787 .18766 .11333 .19051 .12007 .19162 .1146 .18884 Mtetra
.142 .532 .92 r
.1146 .18884 .12007 .19162 .12685 .19271 .12137 .19 Mtetra
.143 .539 .922 r
.12137 .19 .12685 .19271 .13369 .19376 .1282 .19112 Mtetra
.146 .547 .925 r
.1282 .19112 .13369 .19376 .14057 .19477 .13507 .1922 Mtetra
.15 .556 .928 r
.13507 .1922 .14057 .19477 .14751 .19572 .142 .19322 Mtetra
.156 .566 .931 r
.142 .19322 .14751 .19572 .1545 .19661 .14898 .19419 Mtetra
.165 .578 .935 r
.14898 .19419 .1545 .19661 .16154 .19743 .15601 .19509 Mtetra
.174 .59 .939 r
.15601 .19509 .16154 .19743 .16863 .19818 .1631 .19592 Mtetra
.186 .604 .943 r
.1631 .19592 .16863 .19818 .17578 .19884 .17024 .19666 Mtetra
.199 .619 .948 r
.17024 .19666 .17578 .19884 .18299 .19941 .17744 .19732 Mtetra
.213 .635 .953 r
.17744 .19732 .18299 .19941 .19025 .19988 .18469 .19788 Mtetra
.229 .651 .957 r
.18469 .19788 .19025 .19988 .19757 .20024 .19201 .19833 Mtetra
.247 .669 .962 r
.19201 .19833 .19757 .20024 .20495 .20048 .19938 .19867 Mtetra
.265 .688 .966 r
.19938 .19867 .20495 .20048 .21239 .20059 .20681 .19888 Mtetra
.285 .707 .97 r
.20681 .19888 .21239 .20059 .21988 .20056 .2143 .19896 Mtetra
.306 .726 .974 r
.2143 .19896 .21988 .20056 .22743 .20039 .22184 .1989 Mtetra
.327 .746 .976 r
.22184 .1989 .22743 .20039 .23504 .20007 .22945 .1987 Mtetra
.349 .766 .978 r
.22945 .1987 .23504 .20007 .24271 .19959 .23711 .19834 Mtetra
.371 .786 .979 r
.23711 .19834 .24271 .19959 .25043 .19894 .24484 .19782 Mtetra
.393 .805 .978 r
.24484 .19782 .25043 .19894 .25821 .19811 .25261 .19713 Mtetra
.414 .824 .976 r
.25261 .19713 .25821 .19811 .26604 .1971 .26045 .19626 Mtetra
.435 .842 .972 r
.26045 .19626 .26604 .1971 .27393 .19591 .26834 .19522 Mtetra
.453 .858 .966 r
.26834 .19522 .27393 .19591 .28187 .19453 .27628 .194 Mtetra
.47 .873 .957 r
.27628 .194 .28187 .19453 .28986 .19297 .28427 .19259 Mtetra
.483 .886 .947 r
.28427 .19259 .28986 .19297 .29789 .19122 .29231 .19102 Mtetra
.494 .896 .934 r
.29231 .19102 .29789 .19122 .30598 .18929 .3004 .18926 Mtetra
.5 .903 .918 r
.3004 .18926 .30598 .18929 .3141 .1872 .30853 .18735 Mtetra
.502 .907 .9 r
.30853 .18735 .3141 .1872 .32226 .18495 .3167 .18529 Mtetra
.5 .908 .879 r
.3167 .18529 .32226 .18495 .33045 .18257 .32491 .18308 Mtetra
.493 .905 .856 r
.32491 .18308 .33045 .18257 .33868 .18008 .33315 .18076 Mtetra
.483 .899 .831 r
.33315 .18076 .33868 .18008 .34693 .1775 .34142 .17834 Mtetra
.471 .891 .807 r
.34142 .17834 .34693 .1775 .35521 .17484 .34972 .17582 Mtetra
.462 .883 .784 r
.34972 .17582 .35521 .17484 .36351 .17212 .35804 .17321 Mtetra
.458 .879 .766 r
.35804 .17321 .36351 .17212 .37183 .16932 .3664 .17051 Mtetra
.464 .88 .755 r
.3664 .17051 .37183 .16932 .38018 .16644 .37478 .16768 Mtetra
0 0 0 r
.37478 .16768 .38018 .16644 .38847 .16458 .38311 .16581 Mtetra
.38311 .16581 .38847 .16458 .39672 .16375 .39139 .16491 Mtetra
.39139 .16491 .39672 .16375 .405 .16283 .39972 .16389 Mtetra
.39972 .16389 .405 .16283 .41333 .16184 .40808 .16276 Mtetra
.40808 .16276 .41333 .16184 .42169 .16078 .41649 .16155 Mtetra
.178 .706 .694 r
.41649 .16155 .42169 .16078 .43009 .15966 .42493 .16025 Mtetra
.235 .749 .744 r
.42493 .16025 .43009 .15966 .43853 .15844 .43341 .15885 Mtetra
.297 .793 .794 r
.43341 .15885 .43853 .15844 .447 .15712 .44192 .15732 Mtetra
.362 .834 .842 r
.44192 .15732 .447 .15712 .45551 .15565 .45047 .15566 Mtetra
.428 .87 .883 r
.45047 .15566 .45551 .15565 .46405 .15404 .45905 .15384 Mtetra
.49 .898 .916 r
.45905 .15384 .46405 .15404 .47263 .15225 .46767 .15186 Mtetra
.546 .919 .939 r
.46767 .15186 .47263 .15225 .48124 .15029 .47632 .14971 Mtetra
.596 .932 .954 r
.47632 .14971 .48124 .15029 .48988 .14813 .48499 .14737 Mtetra
.638 .939 .962 r
.48499 .14737 .48988 .14813 .49855 .14579 .4937 .14485 Mtetra
.673 .941 .964 r
.4937 .14485 .49855 .14579 .50725 .14326 .50243 .14215 Mtetra
.703 .939 .961 r
.50243 .14215 .50725 .14326 .51597 .14053 .51118 .13926 Mtetra
.727 .935 .956 r
.51118 .13926 .51597 .14053 .5247 .13762 .51995 .13619 Mtetra
.746 .929 .949 r
.51995 .13619 .5247 .13762 .53346 .13453 .52873 .13295 Mtetra
.762 .922 .941 r
.52873 .13295 .53346 .13453 .54223 .13126 .53754 .12954 Mtetra
.776 .915 .933 r
.53754 .12954 .54223 .13126 .55102 .12783 .54635 .12596 Mtetra
.786 .907 .924 r
.54635 .12596 .55102 .12783 .55982 .12423 .55518 .12223 Mtetra
.795 .899 .916 r
.55518 .12223 .55982 .12423 .56862 .12048 .56401 .11835 Mtetra
.803 .892 .908 r
.56401 .11835 .56862 .12048 .57744 .11659 .57285 .11433 Mtetra
.809 .885 .9 r
.57285 .11433 .57744 .11659 .58626 .11256 .5817 .11018 Mtetra
.814 .878 .892 r
.5817 .11018 .58626 .11256 .59508 .1084 .59055 .10591 Mtetra
.818 .871 .885 r
.59055 .10591 .59508 .1084 .60391 .10413 .59941 .10152 Mtetra
.821 .865 .879 r
.59941 .10152 .60391 .10413 .61273 .09974 .60826 .09703 Mtetra
.824 .859 .873 r
.60826 .09703 .61273 .09974 .62156 .09525 .61711 .09243 Mtetra
.826 .853 .867 r
.61711 .09243 .62156 .09525 .63039 .09067 .62597 .08775 Mtetra
.828 .847 .862 r
.62597 .08775 .63039 .09067 .63922 .08601 .63482 .08298 Mtetra
.829 .842 .857 r
.63482 .08298 .63922 .08601 .64804 .08126 .64367 .07814 Mtetra
.83 .837 .852 r
.64367 .07814 .64804 .08126 .65686 .07645 .65251 .07323 Mtetra
.831 .832 .848 r
.65251 .07323 .65686 .07645 .66568 .07158 .66135 .06826 Mtetra
.831 .827 .844 r
.66135 .06826 .66568 .07158 .6745 .06665 .67019 .06324 Mtetra
.831 .822 .841 r
.67019 .06324 .6745 .06665 .68331 .06168 .67903 .05818 Mtetra
.83 .817 .837 r
.67903 .05818 .68331 .06168 .69212 .05667 .68786 .05308 Mtetra
.829 .813 .834 r
.68786 .05308 .69212 .05667 .70093 .05163 .69668 .04795 Mtetra
.828 .808 .832 r
.69668 .04795 .70093 .05163 .70973 .04657 .7055 .0428 Mtetra
.827 .804 .829 r
.7055 .0428 .70973 .04657 .71853 .04149 .71432 .03763 Mtetra
.826 .799 .827 r
.71432 .03763 .71853 .04149 .72733 .03641 .72314 .03246 Mtetra
.142 .503 .909 r
.07597 .17964 .0814 .18277 .08796 .184 .08251 .18093 Mtetra
.134 .504 .909 r
.08251 .18093 .08796 .184 .09455 .18523 .08909 .18223 Mtetra
.128 .506 .909 r
.08909 .18223 .09455 .18523 .10119 .18645 .09572 .18352 Mtetra
.123 .509 .91 r
.09572 .18352 .10119 .18645 .10787 .18766 .10239 .1848 Mtetra
.12 .513 .911 r
.10239 .1848 .10787 .18766 .1146 .18884 .1091 .18605 Mtetra
.118 .518 .912 r
.1091 .18605 .1146 .18884 .12137 .19 .11586 .18728 Mtetra
.119 .525 .914 r
.11586 .18728 .12137 .19 .1282 .19112 .12267 .18847 Mtetra
.121 .532 .916 r
.12267 .18847 .1282 .19112 .13507 .1922 .12954 .18962 Mtetra
.125 .541 .919 r
.12954 .18962 .13507 .1922 .142 .19322 .13645 .19072 Mtetra
.13 .551 .922 r
.13645 .19072 .142 .19322 .14898 .19419 .14342 .19177 Mtetra
.137 .562 .925 r
.14342 .19177 .14898 .19419 .15601 .19509 .15044 .19275 Mtetra
.146 .575 .929 r
.15044 .19275 .15601 .19509 .1631 .19592 .15752 .19366 Mtetra
.157 .588 .934 r
.15752 .19366 .1631 .19592 .17024 .19666 .16465 .1945 Mtetra
.169 .602 .938 r
.16465 .1945 .17024 .19666 .17744 .19732 .17184 .19524 Mtetra
.182 .618 .943 r
.17184 .19524 .17744 .19732 .18469 .19788 .17909 .19589 Mtetra
.197 .634 .947 r
.17909 .19589 .18469 .19788 .19201 .19833 .1864 .19644 Mtetra
.213 .652 .952 r
.1864 .19644 .19201 .19833 .19938 .19867 .19376 .19687 Mtetra
.231 .67 .956 r
.19376 .19687 .19938 .19867 .20681 .19888 .20118 .19719 Mtetra
.25 .689 .96 r
.20118 .19719 .20681 .19888 .2143 .19896 .20867 .19738 Mtetra
.269 .708 .963 r
.20867 .19738 .2143 .19896 .22184 .1989 .21621 .19744 Mtetra
.29 .728 .966 r
.21621 .19744 .22184 .1989 .22945 .1987 .22381 .19736 Mtetra
.31 .747 .967 r
.22381 .19736 .22945 .1987 .23711 .19834 .23147 .19712 Mtetra
.331 .767 .968 r
.23147 .19712 .23711 .19834 .24484 .19782 .23919 .19673 Mtetra
.352 .786 .967 r
.23919 .19673 .24484 .19782 .25261 .19713 .24697 .19618 Mtetra
.372 .805 .965 r
.24697 .19618 .25261 .19713 .26045 .19626 .2548 .19546 Mtetra
.391 .822 .96 r
.2548 .19546 .26045 .19626 .26834 .19522 .26269 .19457 Mtetra
.409 .838 .954 r
.26269 .19457 .26834 .19522 .27628 .194 .27064 .1935 Mtetra
.425 .853 .945 r
.27064 .1935 .27628 .194 .28427 .19259 .27863 .19226 Mtetra
.438 .865 .934 r
.27863 .19226 .28427 .19259 .29231 .19102 .28668 .19085 Mtetra
.448 .875 .921 r
.28668 .19085 .29231 .19102 .3004 .18926 .29477 .18928 Mtetra
.454 .882 .905 r
.29477 .18928 .3004 .18926 .30853 .18735 .30291 .18754 Mtetra
.456 .885 .886 r
.30291 .18754 .30853 .18735 .3167 .18529 .31109 .18565 Mtetra
.455 .885 .864 r
.31109 .18565 .3167 .18529 .32491 .18308 .31931 .18363 Mtetra
.45 .883 .841 r
.31931 .18363 .32491 .18308 .33315 .18076 .32756 .18148 Mtetra
.442 .877 .817 r
.32756 .18148 .33315 .18076 .34142 .17834 .33585 .17921 Mtetra
.435 .871 .793 r
.33585 .17921 .34142 .17834 .34972 .17582 .34417 .17683 Mtetra
.43 .865 .772 r
.34417 .17683 .34972 .17582 .35804 .17321 .35252 .17435 Mtetra
.431 .863 .755 r
.35252 .17435 .35804 .17321 .3664 .17051 .3609 .17174 Mtetra
.442 .867 .744 r
.3609 .17174 .3664 .17051 .37478 .16768 .36932 .16897 Mtetra
0 0 0 r
.36932 .16897 .37478 .16768 .38311 .16581 .37768 .1671 Mtetra
.37768 .1671 .38311 .16581 .39139 .16491 .386 .16611 Mtetra
.386 .16611 .39139 .16491 .39972 .16389 .39437 .16498 Mtetra
.39437 .16498 .39972 .16389 .40808 .16276 .40278 .16372 Mtetra
.40278 .16372 .40808 .16276 .41649 .16155 .41123 .16235 Mtetra
.215 .731 .708 r
.41123 .16235 .41649 .16155 .42493 .16025 .41971 .16087 Mtetra
.273 .774 .756 r
.41971 .16087 .42493 .16025 .43341 .15885 .42823 .15928 Mtetra
.334 .816 .804 r
.42823 .15928 .43341 .15885 .44192 .15732 .43679 .15756 Mtetra
.398 .855 .848 r
.43679 .15756 .44192 .15732 .45047 .15566 .44538 .1557 Mtetra
.46 .887 .886 r
.44538 .1557 .45047 .15566 .45905 .15384 .454 .15369 Mtetra
.518 .913 .915 r
.454 .15369 .45905 .15384 .46767 .15186 .46266 .15151 Mtetra
.571 .931 .937 r
.46266 .15151 .46767 .15186 .47632 .14971 .47134 .14917 Mtetra
.617 .942 .95 r
.47134 .14917 .47632 .14971 .48499 .14737 .48006 .14665 Mtetra
.656 .947 .957 r
.48006 .14665 .48499 .14737 .4937 .14485 .4888 .14395 Mtetra
.689 .947 .958 r
.4888 .14395 .4937 .14485 .50243 .14215 .49756 .14107 Mtetra
.716 .945 .956 r
.49756 .14107 .50243 .14215 .51118 .13926 .50634 .13802 Mtetra
.738 .94 .951 r
.50634 .13802 .51118 .13926 .51995 .13619 .51515 .13479 Mtetra
.757 .933 .944 r
.51515 .13479 .51995 .13619 .52873 .13295 .52397 .13139 Mtetra
.772 .926 .937 r
.52397 .13139 .52873 .13295 .53754 .12954 .5328 .12783 Mtetra
.784 .918 .928 r
.5328 .12783 .53754 .12954 .54635 .12596 .54165 .12412 Mtetra
.794 .91 .92 r
.54165 .12412 .54635 .12596 .55518 .12223 .5505 .12025 Mtetra
.802 .902 .912 r
.5505 .12025 .55518 .12223 .56401 .11835 .55937 .11624 Mtetra
.809 .895 .904 r
.55937 .11624 .56401 .11835 .57285 .11433 .56824 .11209 Mtetra
.815 .887 .896 r
.56824 .11209 .57285 .11433 .5817 .11018 .57711 .10782 Mtetra
.819 .88 .889 r
.57711 .10782 .5817 .11018 .59055 .10591 .58599 .10343 Mtetra
.823 .873 .882 r
.58599 .10343 .59055 .10591 .59941 .10152 .59487 .09893 Mtetra
.826 .867 .876 r
.59487 .09893 .59941 .10152 .60826 .09703 .60375 .09432 Mtetra
.828 .861 .87 r
.60375 .09432 .60826 .09703 .61711 .09243 .61263 .08961 Mtetra
.83 .855 .864 r
.61263 .08961 .61711 .09243 .62597 .08775 .62151 .08482 Mtetra
.832 .849 .859 r
.62151 .08482 .62597 .08775 .63482 .08298 .63039 .07995 Mtetra
.833 .843 .854 r
.63039 .07995 .63482 .08298 .64367 .07814 .63926 .07501 Mtetra
.834 .838 .85 r
.63926 .07501 .64367 .07814 .65251 .07323 .64813 .07 Mtetra
.834 .833 .846 r
.64813 .07 .65251 .07323 .66135 .06826 .657 .06494 Mtetra
.834 .828 .842 r
.657 .06494 .66135 .06826 .67019 .06324 .66586 .05982 Mtetra
.834 .823 .838 r
.66586 .05982 .67019 .06324 .67903 .05818 .67471 .05466 Mtetra
.833 .818 .835 r
.67471 .05466 .67903 .05818 .68786 .05308 .68357 .04947 Mtetra
.832 .814 .832 r
.68357 .04947 .68786 .05308 .69668 .04795 .69241 .04425 Mtetra
.831 .809 .829 r
.69241 .04425 .69668 .04795 .7055 .0428 .70125 .03901 Mtetra
.83 .805 .827 r
.70125 .03901 .7055 .0428 .71432 .03763 .71009 .03375 Mtetra
.828 .8 .825 r
.71009 .03375 .71432 .03763 .72314 .03246 .71893 .02849 Mtetra
.121 .49 .902 r
.07052 .17649 .07597 .17964 .08251 .18093 .07704 .17786 Mtetra
.112 .49 .902 r
.07704 .17786 .08251 .18093 .08909 .18223 .0836 .17922 Mtetra
.105 .492 .902 r
.0836 .17922 .08909 .18223 .09572 .18352 .09021 .18058 Mtetra
.1 .495 .902 r
.09021 .18058 .09572 .18352 .10239 .1848 .09687 .18193 Mtetra
.096 .499 .902 r
.09687 .18193 .10239 .1848 .1091 .18605 .10357 .18326 Mtetra
.094 .504 .903 r
.10357 .18326 .1091 .18605 .11586 .18728 .11032 .18456 Mtetra
.094 .51 .905 r
.11032 .18456 .11586 .18728 .12267 .18847 .11711 .18582 Mtetra
.095 .517 .907 r
.11711 .18582 .12267 .18847 .12954 .18962 .12396 .18705 Mtetra
.098 .526 .909 r
.12396 .18705 .12954 .18962 .13645 .19072 .13087 .18823 Mtetra
.103 .535 .912 r
.13087 .18823 .13645 .19072 .14342 .19177 .13782 .18935 Mtetra
.109 .546 .915 r
.13782 .18935 .14342 .19177 .15044 .19275 .14483 .19042 Mtetra
.117 .558 .919 r
.14483 .19042 .15044 .19275 .15752 .19366 .1519 .19141 Mtetra
.127 .571 .922 r
.1519 .19141 .15752 .19366 .16465 .1945 .15902 .19233 Mtetra
.138 .585 .926 r
.15902 .19233 .16465 .1945 .17184 .19524 .1662 .19317 Mtetra
.15 .6 .931 r
.1662 .19317 .17184 .19524 .17909 .19589 .17344 .19391 Mtetra
.164 .616 .935 r
.17344 .19391 .17909 .19589 .1864 .19644 .18074 .19456 Mtetra
.179 .633 .939 r
.18074 .19456 .1864 .19644 .19376 .19687 .1881 .1951 Mtetra
.195 .65 .943 r
.1881 .1951 .19376 .19687 .20118 .19719 .19551 .19553 Mtetra
.213 .669 .947 r
.19551 .19553 .20118 .19719 .20867 .19738 .20299 .19583 Mtetra
.231 .688 .95 r
.20299 .19583 .20867 .19738 .21621 .19744 .21053 .196 Mtetra
.25 .707 .952 r
.21053 .196 .21621 .19744 .22381 .19736 .21813 .19604 Mtetra
.269 .726 .954 r
.21813 .19604 .22381 .19736 .23147 .19712 .22578 .19593 Mtetra
.289 .745 .954 r
.22578 .19593 .23147 .19712 .23919 .19673 .2335 .19567 Mtetra
.309 .764 .953 r
.2335 .19567 .23919 .19673 .24697 .19618 .24127 .19526 Mtetra
.328 .782 .95 r
.24127 .19526 .24697 .19618 .2548 .19546 .24911 .19469 Mtetra
.346 .8 .946 r
.24911 .19469 .2548 .19546 .26269 .19457 .25699 .19395 Mtetra
.362 .815 .939 r
.25699 .19395 .26269 .19457 .27064 .1935 .26494 .19304 Mtetra
.377 .829 .93 r
.26494 .19304 .27064 .1935 .27863 .19226 .27294 .19197 Mtetra
.389 .841 .919 r
.27294 .19197 .27863 .19226 .28668 .19085 .28098 .19073 Mtetra
.399 .85 .904 r
.28098 .19073 .28668 .19085 .29477 .18928 .28908 .18933 Mtetra
.405 .856 .888 r
.28908 .18933 .29477 .18928 .30291 .18754 .29723 .18777 Mtetra
.408 .86 .868 r
.29723 .18777 .30291 .18754 .31109 .18565 .30542 .18606 Mtetra
.407 .86 .847 r
.30542 .18606 .31109 .18565 .31931 .18363 .31365 .18421 Mtetra
.404 .857 .824 r
.31365 .18421 .31931 .18363 .32756 .18148 .32192 .18223 Mtetra
.4 .853 .8 r
.32192 .18223 .32756 .18148 .33585 .17921 .33022 .18012 Mtetra
.396 .848 .777 r
.33022 .18012 .33585 .17921 .34417 .17683 .33856 .17788 Mtetra
.396 .845 .757 r
.33856 .17788 .34417 .17683 .35252 .17435 .34694 .17552 Mtetra
.401 .845 .741 r
.34694 .17552 .35252 .17435 .3609 .17174 .35535 .17301 Mtetra
.416 .851 .731 r
.35535 .17301 .3609 .17174 .36932 .16897 .36379 .17033 Mtetra
0 0 0 r
.36379 .17033 .36932 .16897 .37768 .1671 .37219 .16845 Mtetra
.37219 .16845 .37768 .1671 .386 .16611 .38056 .16737 Mtetra
.38056 .16737 .386 .16611 .39437 .16498 .38897 .16611 Mtetra
.38897 .16611 .39437 .16498 .40278 .16372 .39742 .16471 Mtetra
.39742 .16471 .40278 .16372 .41123 .16235 .40591 .16318 Mtetra
.249 .755 .719 r
.40591 .16318 .41123 .16235 .41971 .16087 .41444 .16153 Mtetra
.309 .798 .767 r
.41444 .16153 .41971 .16087 .42823 .15928 .42301 .15975 Mtetra
.37 .838 .812 r
.42301 .15975 .42823 .15928 .43679 .15756 .43161 .15784 Mtetra
.432 .873 .853 r
.43161 .15784 .43679 .15756 .44538 .1557 .44024 .15578 Mtetra
.491 .903 .888 r
.44024 .15578 .44538 .1557 .454 .15369 .4489 .15357 Mtetra
.546 .925 .914 r
.4489 .15357 .454 .15369 .46266 .15151 .4576 .1512 Mtetra
.595 .941 .934 r
.4576 .1512 .46266 .15151 .47134 .14917 .46632 .14867 Mtetra
.638 .95 .945 r
.46632 .14867 .47134 .14917 .48006 .14665 .47508 .14596 Mtetra
.674 .953 .951 r
.47508 .14596 .48006 .14665 .4888 .14395 .48385 .14308 Mtetra
.704 .953 .952 r
.48385 .14308 .4888 .14395 .49756 .14107 .49265 .14003 Mtetra
.729 .949 .95 r
.49265 .14003 .49756 .14107 .50634 .13802 .50147 .13681 Mtetra
.75 .944 .945 r
.50147 .13681 .50634 .13802 .51515 .13479 .51031 .13342 Mtetra
.767 .937 .939 r
.51031 .13342 .51515 .13479 .52397 .13139 .51916 .12987 Mtetra
.781 .929 .931 r
.51916 .12987 .52397 .13139 .5328 .12783 .52803 .12616 Mtetra
.792 .921 .924 r
.52803 .12616 .5328 .12783 .54165 .12412 .53691 .1223 Mtetra
.801 .913 .916 r
.53691 .1223 .54165 .12412 .5505 .12025 .54579 .11829 Mtetra
.809 .905 .908 r
.54579 .11829 .5505 .12025 .55937 .11624 .55469 .11414 Mtetra
.815 .897 .9 r
.55469 .11414 .55937 .11624 .56824 .11209 .56359 .10987 Mtetra
.82 .89 .893 r
.56359 .10987 .56824 .11209 .57711 .10782 .57249 .10547 Mtetra
.825 .882 .886 r
.57249 .10547 .57711 .10782 .58599 .10343 .5814 .10096 Mtetra
.828 .875 .879 r
.5814 .10096 .58599 .10343 .59487 .09893 .59031 .09633 Mtetra
.831 .869 .873 r
.59031 .09633 .59487 .09893 .60375 .09432 .59922 .09161 Mtetra
.833 .862 .867 r
.59922 .09161 .60375 .09432 .61263 .08961 .60812 .0868 Mtetra
.834 .856 .862 r
.60812 .0868 .61263 .08961 .62151 .08482 .61703 .0819 Mtetra
.836 .85 .856 r
.61703 .0819 .62151 .08482 .63039 .07995 .62593 .07692 Mtetra
.837 .845 .852 r
.62593 .07692 .63039 .07995 .63926 .07501 .63483 .07187 Mtetra
.837 .839 .847 r
.63483 .07187 .63926 .07501 .64813 .07 .64372 .06677 Mtetra
.837 .834 .843 r
.64372 .06677 .64813 .07 .657 .06494 .65261 .0616 Mtetra
.837 .829 .84 r
.65261 .0616 .657 .06494 .66586 .05982 .6615 .05639 Mtetra
.837 .824 .836 r
.6615 .05639 .66586 .05982 .67471 .05466 .67038 .05113 Mtetra
.836 .819 .833 r
.67038 .05113 .67471 .05466 .68357 .04947 .67925 .04585 Mtetra
.835 .815 .83 r
.67925 .04585 .68357 .04947 .69241 .04425 .68812 .04053 Mtetra
.834 .81 .827 r
.68812 .04053 .69241 .04425 .70125 .03901 .69698 .0352 Mtetra
.833 .805 .825 r
.69698 .0352 .70125 .03901 .71009 .03375 .70584 .02985 Mtetra
.831 .801 .822 r
.70584 .02985 .71009 .03375 .71893 .02849 .71469 .02449 Mtetra
.099 .476 .895 r
.06503 .17333 .07052 .17649 .07704 .17786 .07154 .17477 Mtetra
.09 .476 .894 r
.07154 .17477 .07704 .17786 .0836 .17922 .07808 .17621 Mtetra
.082 .478 .893 r
.07808 .17621 .0836 .17922 .09021 .18058 .08468 .17764 Mtetra
.076 .48 .893 r
.08468 .17764 .09021 .18058 .09687 .18193 .09131 .17905 Mtetra
.072 .484 .893 r
.09131 .17905 .09687 .18193 .10357 .18326 .098 .18045 Mtetra
.069 .488 .894 r
.098 .18045 .10357 .18326 .11032 .18456 .10473 .18183 Mtetra
.068 .494 .895 r
.10473 .18183 .11032 .18456 .11711 .18582 .11152 .18317 Mtetra
.069 .501 .896 r
.11152 .18317 .11711 .18582 .12396 .18705 .11836 .18447 Mtetra
.071 .509 .898 r
.11836 .18447 .12396 .18705 .13087 .18823 .12524 .18573 Mtetra
.075 .518 .9 r
.12524 .18573 .13087 .18823 .13782 .18935 .13219 .18694 Mtetra
.081 .528 .903 r
.13219 .18694 .13782 .18935 .14483 .19042 .13919 .18809 Mtetra
.087 .54 .906 r
.13919 .18809 .14483 .19042 .1519 .19141 .14624 .18917 Mtetra
.096 .552 .91 r
.14624 .18917 .1519 .19141 .15902 .19233 .15335 .19018 Mtetra
.106 .566 .914 r
.15335 .19018 .15902 .19233 .1662 .19317 .16052 .19111 Mtetra
.117 .58 .917 r
.16052 .19111 .1662 .19317 .17344 .19391 .16775 .19195 Mtetra
.129 .596 .921 r
.16775 .19195 .17344 .19391 .18074 .19456 .17504 .1927 Mtetra
.143 .612 .925 r
.17504 .1927 .18074 .19456 .1881 .1951 .18239 .19334 Mtetra
.158 .629 .929 r
.18239 .19334 .1881 .1951 .19551 .19553 .1898 .19388 Mtetra
.174 .647 .932 r
.1898 .19388 .19551 .19553 .20299 .19583 .19727 .19429 Mtetra
.191 .665 .935 r
.19727 .19429 .20299 .19583 .21053 .196 .2048 .19459 Mtetra
.209 .684 .937 r
.2048 .19459 .21053 .196 .21813 .19604 .21239 .19475 Mtetra
.227 .703 .938 r
.21239 .19475 .21813 .19604 .22578 .19593 .22004 .19477 Mtetra
.245 .721 .938 r
.22004 .19477 .22578 .19593 .2335 .19567 .22775 .19465 Mtetra
.263 .74 .936 r
.22775 .19465 .2335 .19567 .24127 .19526 .23552 .19438 Mtetra
.281 .757 .933 r
.23552 .19438 .24127 .19526 .24911 .19469 .24335 .19395 Mtetra
.298 .774 .928 r
.24335 .19395 .24911 .19469 .25699 .19395 .25124 .19337 Mtetra
.313 .789 .921 r
.25124 .19337 .25699 .19395 .26494 .19304 .25919 .19262 Mtetra
.327 .802 .911 r
.25919 .19262 .26494 .19304 .27294 .19197 .26718 .19172 Mtetra
.339 .813 .899 r
.26718 .19172 .27294 .19197 .28098 .19073 .27524 .19065 Mtetra
.348 .822 .885 r
.27524 .19065 .28098 .19073 .28908 .18933 .28334 .18942 Mtetra
.354 .828 .867 r
.28334 .18942 .28908 .18933 .29723 .18777 .29149 .18804 Mtetra
.357 .831 .848 r
.29149 .18804 .29723 .18777 .30542 .18606 .29969 .1865 Mtetra
.358 .831 .826 r
.29969 .1865 .30542 .18606 .31365 .18421 .30793 .18483 Mtetra
.357 .829 .803 r
.30793 .18483 .31365 .18421 .32192 .18223 .31621 .18301 Mtetra
.356 .826 .78 r
.31621 .18301 .32192 .18223 .33022 .18012 .32453 .18106 Mtetra
.355 .823 .758 r
.32453 .18106 .33022 .18012 .33856 .17788 .33289 .17898 Mtetra
.359 .822 .739 r
.33289 .17898 .33856 .17788 .34694 .17552 .34129 .17674 Mtetra
.368 .825 .724 r
.34129 .17674 .34694 .17552 .35535 .17301 .34973 .17435 Mtetra
.387 .832 .715 r
.34973 .17435 .35535 .17301 .36379 .17033 .3582 .17175 Mtetra
0 0 0 r
.3582 .17175 .36379 .17033 .37219 .16845 .36664 .16986 Mtetra
.36664 .16986 .37219 .16845 .38056 .16737 .37505 .16867 Mtetra
.37505 .16867 .38056 .16737 .38897 .16611 .3835 .16729 Mtetra
.3835 .16729 .38897 .16611 .39742 .16471 .392 .16575 Mtetra
.224 .733 .682 r
.392 .16575 .39742 .16471 .40591 .16318 .40054 .16405 Mtetra
.283 .777 .729 r
.40054 .16405 .40591 .16318 .41444 .16153 .40911 .16222 Mtetra
.343 .819 .775 r
.40911 .16222 .41444 .16153 .42301 .15975 .41772 .16026 Mtetra
.404 .857 .818 r
.41772 .16026 .42301 .15975 .43161 .15784 .42637 .15815 Mtetra
.464 .89 .856 r
.42637 .15815 .43161 .15784 .44024 .15578 .43505 .1559 Mtetra
.52 .917 .888 r
.43505 .1559 .44024 .15578 .4489 .15357 .44375 .15349 Mtetra
.572 .937 .913 r
.44375 .15349 .4489 .15357 .4576 .1512 .45249 .15093 Mtetra
.618 .95 .93 r
.45249 .15093 .4576 .1512 .46632 .14867 .46126 .1482 Mtetra
.657 .957 .94 r
.46126 .1482 .46632 .14867 .47508 .14596 .47005 .14531 Mtetra
.691 .959 .946 r
.47005 .14531 .47508 .14596 .48385 .14308 .47886 .14225 Mtetra
.719 .958 .946 r
.47886 .14225 .48385 .14308 .49265 .14003 .4877 .13902 Mtetra
.742 .954 .944 r
.4877 .13902 .49265 .14003 .50147 .13681 .49656 .13563 Mtetra
.761 .948 .939 r
.49656 .13563 .50147 .13681 .51031 .13342 .50543 .13208 Mtetra
.777 .94 .933 r
.50543 .13208 .51031 .13342 .51916 .12987 .51432 .12837 Mtetra
.79 .932 .926 r
.51432 .12837 .51916 .12987 .52803 .12616 .52322 .1245 Mtetra
.8 .924 .919 r
.52322 .1245 .52803 .12616 .53691 .1223 .53213 .1205 Mtetra
.809 .916 .911 r
.53213 .1205 .53691 .1223 .54579 .11829 .54105 .11635 Mtetra
.816 .907 .903 r
.54105 .11635 .54579 .11829 .55469 .11414 .54997 .11206 Mtetra
.821 .899 .896 r
.54997 .11206 .55469 .11414 .56359 .10987 .5589 .10766 Mtetra
.826 .892 .889 r
.5589 .10766 .56359 .10987 .57249 .10547 .56784 .10313 Mtetra
.83 .884 .882 r
.56784 .10313 .57249 .10547 .5814 .10096 .57678 .09849 Mtetra
.833 .877 .876 r
.57678 .09849 .5814 .10096 .59031 .09633 .58571 .09375 Mtetra
.835 .87 .87 r
.58571 .09375 .59031 .09633 .59922 .09161 .59465 .08891 Mtetra
.837 .864 .864 r
.59465 .08891 .59922 .09161 .60812 .0868 .60358 .08398 Mtetra
.839 .858 .859 r
.60358 .08398 .60812 .0868 .61703 .0819 .61252 .07897 Mtetra
.84 .852 .854 r
.61252 .07897 .61703 .0819 .62593 .07692 .62144 .07389 Mtetra
.84 .846 .849 r
.62144 .07389 .62593 .07692 .63483 .07187 .63037 .06873 Mtetra
.841 .841 .845 r
.63037 .06873 .63483 .07187 .64372 .06677 .63929 .06352 Mtetra
.841 .835 .841 r
.63929 .06352 .64372 .06677 .65261 .0616 .6482 .05826 Mtetra
.84 .83 .837 r
.6482 .05826 .65261 .0616 .6615 .05639 .65711 .05294 Mtetra
.84 .825 .834 r
.65711 .05294 .6615 .05639 .67038 .05113 .66601 .04759 Mtetra
.839 .82 .831 r
.66601 .04759 .67038 .05113 .67925 .04585 .67491 .04221 Mtetra
.838 .815 .828 r
.67491 .04221 .67925 .04585 .68812 .04053 .6838 .03679 Mtetra
.837 .811 .825 r
.6838 .03679 .68812 .04053 .69698 .0352 .69268 .03136 Mtetra
.835 .806 .822 r
.69268 .03136 .69698 .0352 .70584 .02985 .70156 .02592 Mtetra
.834 .801 .82 r
.70156 .02592 .70584 .02985 .71469 .02449 .71043 .02047 Mtetra
.076 .461 .886 r
.05951 .17016 .06503 .17333 .07154 .17477 .066 .17166 Mtetra
.066 .461 .885 r
.066 .17166 .07154 .17477 .07808 .17621 .07253 .17317 Mtetra
.058 .463 .884 r
.07253 .17317 .07808 .17621 .08468 .17764 .07911 .17468 Mtetra
.052 .465 .883 r
.07911 .17468 .08468 .17764 .09131 .17905 .08573 .17617 Mtetra
.047 .468 .883 r
.08573 .17617 .09131 .17905 .098 .18045 .0924 .17764 Mtetra
.044 .472 .883 r
.0924 .17764 .098 .18045 .10473 .18183 .09912 .17909 Mtetra
.042 .477 .884 r
.09912 .17909 .10473 .18183 .11152 .18317 .10589 .18051 Mtetra
.042 .484 .885 r
.10589 .18051 .11152 .18317 .11836 .18447 .11271 .18189 Mtetra
.043 .491 .886 r
.11271 .18189 .11836 .18447 .12524 .18573 .11958 .18323 Mtetra
.046 .5 .888 r
.11958 .18323 .12524 .18573 .13219 .18694 .12651 .18453 Mtetra
.051 .51 .89 r
.12651 .18453 .13219 .18694 .13919 .18809 .1335 .18576 Mtetra
.057 .521 .893 r
.1335 .18576 .13919 .18809 .14624 .18917 .14054 .18693 Mtetra
.064 .532 .896 r
.14054 .18693 .14624 .18917 .15335 .19018 .14764 .18803 Mtetra
.073 .545 .899 r
.14764 .18803 .15335 .19018 .16052 .19111 .1548 .18906 Mtetra
.083 .559 .902 r
.1548 .18906 .16052 .19111 .16775 .19195 .16202 .19 Mtetra
.094 .574 .906 r
.16202 .19 .16775 .19195 .17504 .1927 .1693 .19085 Mtetra
.107 .59 .909 r
.1693 .19085 .17504 .1927 .18239 .19334 .17664 .1916 Mtetra
.12 .606 .912 r
.17664 .1916 .18239 .19334 .1898 .19388 .18404 .19225 Mtetra
.135 .623 .915 r
.18404 .19225 .1898 .19388 .19727 .19429 .1915 .19278 Mtetra
.15 .641 .917 r
.1915 .19278 .19727 .19429 .2048 .19459 .19902 .1932 Mtetra
.166 .659 .919 r
.19902 .1932 .2048 .19459 .21239 .19475 .2066 .19348 Mtetra
.183 .677 .919 r
.2066 .19348 .21239 .19475 .22004 .19477 .21425 .19364 Mtetra
.2 .695 .918 r
.21425 .19364 .22004 .19477 .22775 .19465 .22196 .19366 Mtetra
.216 .712 .916 r
.22196 .19366 .22775 .19465 .23552 .19438 .22972 .19353 Mtetra
.233 .729 .913 r
.22972 .19353 .23552 .19438 .24335 .19395 .23755 .19325 Mtetra
.248 .745 .907 r
.23755 .19325 .24335 .19395 .25124 .19337 .24543 .19282 Mtetra
.262 .759 .899 r
.24543 .19282 .25124 .19337 .25919 .19262 .25338 .19224 Mtetra
.275 .772 .889 r
.25338 .19224 .25919 .19262 .26718 .19172 .26138 .1915 Mtetra
.286 .782 .877 r
.26138 .1915 .26718 .19172 .27524 .19065 .26943 .1906 Mtetra
.295 .79 .861 r
.26943 .1906 .27524 .19065 .28334 .18942 .27753 .18955 Mtetra
.301 .796 .844 r
.27753 .18955 .28334 .18942 .29149 .18804 .28569 .18834 Mtetra
.305 .799 .824 r
.28569 .18834 .29149 .18804 .29969 .1865 .29389 .18699 Mtetra
.307 .8 .803 r
.29389 .18699 .29969 .1865 .30793 .18483 .30214 .18549 Mtetra
.308 .799 .78 r
.30214 .18549 .30793 .18483 .31621 .18301 .31044 .18384 Mtetra
.31 .797 .758 r
.31044 .18384 .31621 .18301 .32453 .18106 .31878 .18205 Mtetra
.312 .795 .737 r
.31878 .18205 .32453 .18106 .33289 .17898 .32716 .18011 Mtetra
.319 .796 .719 r
.32716 .18011 .33289 .17898 .34129 .17674 .33558 .17802 Mtetra
.332 .801 .705 r
.33558 .17802 .34129 .17674 .34973 .17435 .34404 .17574 Mtetra
.353 .81 .696 r
.34404 .17574 .34973 .17435 .3582 .17175 .35255 .17325 Mtetra
0 0 0 r
.35255 .17325 .3582 .17175 .36664 .16986 .36102 .17135 Mtetra
.36102 .17135 .36664 .16986 .37505 .16867 .36948 .17004 Mtetra
.36948 .17004 .37505 .16867 .3835 .16729 .37798 .16852 Mtetra
.37798 .16852 .3835 .16729 .392 .16575 .38652 .16683 Mtetra
.254 .753 .691 r
.38652 .16683 .392 .16575 .40054 .16405 .39511 .16497 Mtetra
.315 .797 .737 r
.39511 .16497 .40054 .16405 .40911 .16222 .40373 .16296 Mtetra
.376 .838 .782 r
.40373 .16296 .40911 .16222 .41772 .16026 .41239 .1608 Mtetra
.436 .875 .823 r
.41239 .1608 .41772 .16026 .42637 .15815 .42108 .1585 Mtetra
.494 .905 .858 r
.42108 .1585 .42637 .15815 .43505 .1559 .4298 .15605 Mtetra
.547 .929 .888 r
.4298 .15605 .43505 .1559 .44375 .15349 .43855 .15345 Mtetra
.596 .947 .91 r
.43855 .15345 .44375 .15349 .45249 .15093 .44733 .15069 Mtetra
.639 .958 .926 r
.44733 .15069 .45249 .15093 .46126 .1482 .45614 .14777 Mtetra
.676 .964 .935 r
.45614 .14777 .46126 .1482 .47005 .14531 .46497 .14469 Mtetra
.707 .965 .94 r
.46497 .14469 .47005 .14531 .47886 .14225 .47383 .14145 Mtetra
.733 .962 .94 r
.47383 .14145 .47886 .14225 .4877 .13902 .4827 .13805 Mtetra
.755 .957 .938 r
.4827 .13805 .4877 .13902 .49656 .13563 .4916 .13448 Mtetra
.772 .951 .933 r
.4916 .13448 .49656 .13563 .50543 .13208 .50051 .13076 Mtetra
.787 .943 .927 r
.50051 .13076 .50543 .13208 .51432 .12837 .50943 .12689 Mtetra
.798 .935 .921 r
.50943 .12689 .51432 .12837 .52322 .1245 .51837 .12287 Mtetra
.808 .927 .914 r
.51837 .12287 .52322 .1245 .53213 .1205 .52731 .11871 Mtetra
.816 .918 .906 r
.52731 .11871 .53213 .1205 .54105 .11635 .53626 .11442 Mtetra
.822 .91 .899 r
.53626 .11442 .54105 .11635 .54997 .11206 .54522 .11 Mtetra
.827 .902 .892 r
.54522 .11 .54997 .11206 .5589 .10766 .55418 .10546 Mtetra
.832 .894 .885 r
.55418 .10546 .5589 .10766 .56784 .10313 .56315 .1008 Mtetra
.835 .886 .879 r
.56315 .1008 .56784 .10313 .57678 .09849 .57212 .09603 Mtetra
.838 .879 .872 r
.57212 .09603 .57678 .09849 .58571 .09375 .58108 .09117 Mtetra
.84 .872 .866 r
.58108 .09117 .58571 .09375 .59465 .08891 .59005 .08621 Mtetra
.841 .865 .861 r
.59005 .08621 .59465 .08891 .60358 .08398 .59901 .08117 Mtetra
.843 .859 .856 r
.59901 .08117 .60358 .08398 .61252 .07897 .60797 .07604 Mtetra
.843 .853 .851 r
.60797 .07604 .61252 .07897 .62144 .07389 .61693 .07085 Mtetra
.844 .847 .846 r
.61693 .07085 .62144 .07389 .63037 .06873 .62588 .06559 Mtetra
.844 .842 .842 r
.62588 .06559 .63037 .06873 .63929 .06352 .63482 .06027 Mtetra
.844 .836 .838 r
.63482 .06027 .63929 .06352 .6482 .05826 .64376 .0549 Mtetra
.844 .831 .835 r
.64376 .0549 .6482 .05826 .65711 .05294 .65269 .04949 Mtetra
.843 .826 .831 r
.65269 .04949 .65711 .05294 .66601 .04759 .66162 .04403 Mtetra
.842 .821 .828 r
.66162 .04403 .66601 .04759 .67491 .04221 .67053 .03855 Mtetra
.841 .816 .825 r
.67053 .03855 .67491 .04221 .6838 .03679 .67945 .03304 Mtetra
.84 .811 .823 r
.67945 .03304 .6838 .03679 .69268 .03136 .68835 .02751 Mtetra
.838 .807 .82 r
.68835 .02751 .69268 .03136 .70156 .02592 .69725 .02197 Mtetra
.837 .802 .818 r
.69725 .02197 .70156 .02592 .71043 .02047 .70614 .01643 Mtetra
.052 .446 .877 r
.05397 .16697 .05951 .17016 .066 .17166 .06044 .16855 Mtetra
.042 .446 .875 r
.06044 .16855 .066 .17166 .07253 .17317 .06695 .17013 Mtetra
.034 .447 .874 r
.06695 .17013 .07253 .17317 .07911 .17468 .07351 .1717 Mtetra
.027 .448 .873 r
.07351 .1717 .07911 .17468 .08573 .17617 .08011 .17327 Mtetra
.021 .451 .872 r
.08011 .17327 .08573 .17617 .0924 .17764 .08676 .17482 Mtetra
.018 .455 .871 r
.08676 .17482 .0924 .17764 .09912 .17909 .09347 .17635 Mtetra
.015 .46 .872 r
.09347 .17635 .09912 .17909 .10589 .18051 .10022 .17785 Mtetra
.014 .466 .872 r
.10022 .17785 .10589 .18051 .11271 .18189 .10702 .17931 Mtetra
.015 .473 .873 r
.10702 .17931 .11271 .18189 .11958 .18323 .11388 .18074 Mtetra
.017 .481 .874 r
.11388 .18074 .11958 .18323 .12651 .18453 .1208 .18211 Mtetra
.02 .49 .876 r
.1208 .18211 .12651 .18453 .1335 .18576 .12777 .18344 Mtetra
.025 .5 .878 r
.12777 .18344 .1335 .18576 .14054 .18693 .1348 .1847 Mtetra
.032 .512 .88 r
.1348 .1847 .14054 .18693 .14764 .18803 .14189 .18589 Mtetra
.039 .524 .883 r
.14189 .18589 .14764 .18803 .1548 .18906 .14903 .18702 Mtetra
.048 .537 .886 r
.14903 .18702 .1548 .18906 .16202 .19 .15624 .18806 Mtetra
.058 .551 .888 r
.15624 .18806 .16202 .19 .1693 .19085 .16351 .18901 Mtetra
.069 .566 .891 r
.16351 .18901 .1693 .19085 .17664 .1916 .17084 .18987 Mtetra
.081 .581 .894 r
.17084 .18987 .17664 .1916 .18404 .19225 .17823 .19063 Mtetra
.094 .598 .896 r
.17823 .19063 .18404 .19225 .1915 .19278 .18568 .19129 Mtetra
.108 .614 .897 r
.18568 .19129 .1915 .19278 .19902 .1932 .19319 .19182 Mtetra
.123 .631 .898 r
.19319 .19182 .19902 .1932 .2066 .19348 .20077 .19224 Mtetra
.138 .648 .898 r
.20077 .19224 .2066 .19348 .21425 .19364 .2084 .19253 Mtetra
.153 .665 .896 r
.2084 .19253 .21425 .19364 .22196 .19366 .2161 .19269 Mtetra
.168 .682 .894 r
.2161 .19269 .22196 .19366 .22972 .19353 .22387 .19271 Mtetra
.183 .698 .889 r
.22387 .19271 .22972 .19353 .23755 .19325 .23169 .19258 Mtetra
.197 .713 .883 r
.23169 .19258 .23755 .19325 .24543 .19282 .23957 .19231 Mtetra
.21 .726 .874 r
.23957 .19231 .24543 .19282 .25338 .19224 .24751 .19189 Mtetra
.222 .738 .864 r
.24751 .19189 .25338 .19224 .26138 .1915 .25551 .19132 Mtetra
.232 .748 .851 r
.25551 .19132 .26138 .1915 .26943 .1906 .26356 .19059 Mtetra
.24 .756 .835 r
.26356 .19059 .26943 .1906 .27753 .18955 .27167 .18972 Mtetra
.247 .761 .817 r
.27167 .18972 .27753 .18955 .28569 .18834 .27983 .18869 Mtetra
.252 .764 .797 r
.27983 .18869 .28569 .18834 .29389 .18699 .28804 .18751 Mtetra
.255 .765 .776 r
.28804 .18751 .29389 .18699 .30214 .18549 .2963 .18619 Mtetra
.258 .765 .754 r
.2963 .18619 .30214 .18549 .31044 .18384 .30461 .18471 Mtetra
.262 .765 .733 r
.30461 .18471 .31044 .18384 .31878 .18205 .31296 .18309 Mtetra
.267 .765 .713 r
.31296 .18309 .31878 .18205 .32716 .18011 .32136 .1813 Mtetra
.277 .767 .696 r
.32136 .1813 .32716 .18011 .33558 .17802 .3298 .17935 Mtetra
.293 .774 .683 r
.3298 .17935 .33558 .17802 .34404 .17574 .33829 .1772 Mtetra
.316 .785 .674 r
.33829 .1772 .34404 .17574 .35255 .17325 .34682 .17483 Mtetra
0 0 0 r
.34682 .17483 .35255 .17325 .36102 .17135 .35533 .17292 Mtetra
.35533 .17292 .36102 .17135 .36948 .17004 .36384 .17148 Mtetra
.36384 .17148 .36948 .17004 .37798 .16852 .37239 .16981 Mtetra
.37239 .16981 .37798 .16852 .38652 .16683 .38098 .16796 Mtetra
.284 .772 .698 r
.38098 .16796 .38652 .16683 .39511 .16497 .38961 .16592 Mtetra
.347 .816 .744 r
.38961 .16592 .39511 .16497 .40373 .16296 .39828 .16373 Mtetra
.408 .856 .788 r
.39828 .16373 .40373 .16296 .41239 .1608 .40699 .16139 Mtetra
.467 .89 .826 r
.40699 .16139 .41239 .1608 .42108 .1585 .41573 .15889 Mtetra
.522 .919 .859 r
.41573 .15889 .42108 .1585 .4298 .15605 .4245 .15625 Mtetra
.574 .941 .886 r
.4245 .15625 .4298 .15605 .43855 .15345 .4333 .15345 Mtetra
.619 .956 .907 r
.4333 .15345 .43855 .15345 .44733 .15069 .44212 .15049 Mtetra
.659 .965 .921 r
.44212 .15049 .44733 .15069 .45614 .14777 .45098 .14738 Mtetra
.694 .969 .929 r
.45098 .14738 .45614 .14777 .46497 .14469 .45985 .14411 Mtetra
.723 .969 .933 r
.45985 .14411 .46497 .14469 .47383 .14145 .46875 .14068 Mtetra
.747 .966 .934 r
.46875 .14068 .47383 .14145 .4827 .13805 .47766 .1371 Mtetra
.766 .961 .931 r
.47766 .1371 .4827 .13805 .4916 .13448 .4866 .13336 Mtetra
.783 .954 .927 r
.4866 .13336 .4916 .13448 .50051 .13076 .49554 .12947 Mtetra
.796 .946 .921 r
.49554 .12947 .50051 .13076 .50943 .12689 .5045 .12544 Mtetra
.807 .937 .915 r
.5045 .12544 .50943 .12689 .51837 .12287 .51347 .12126 Mtetra
.815 .929 .908 r
.51347 .12126 .51837 .12287 .52731 .11871 .52245 .11695 Mtetra
.823 .92 .901 r
.52245 .11695 .52731 .11871 .53626 .11442 .53144 .11251 Mtetra
.828 .912 .894 r
.53144 .11251 .53626 .11442 .54522 .11 .54043 .10795 Mtetra
.833 .903 .888 r
.54043 .10795 .54522 .11 .55418 .10546 .54943 .10327 Mtetra
.837 .895 .881 r
.54943 .10327 .55418 .10546 .56315 .1008 .55842 .09848 Mtetra
.84 .888 .875 r
.55842 .09848 .56315 .1008 .57212 .09603 .56742 .09358 Mtetra
.842 .88 .869 r
.56742 .09358 .57212 .09603 .58108 .09117 .57642 .08859 Mtetra
.844 .874 .863 r
.57642 .08859 .58108 .09117 .59005 .08621 .58541 .08351 Mtetra
.846 .867 .858 r
.58541 .08351 .59005 .08621 .59901 .08117 .59441 .07835 Mtetra
.847 .86 .853 r
.59441 .07835 .59901 .08117 .60797 .07604 .60339 .07311 Mtetra
.847 .854 .848 r
.60339 .07311 .60797 .07604 .61693 .07085 .61238 .0678 Mtetra
.847 .849 .844 r
.61238 .0678 .61693 .07085 .62588 .06559 .62135 .06244 Mtetra
.847 .843 .84 r
.62135 .06244 .62588 .06559 .63482 .06027 .63032 .05701 Mtetra
.847 .837 .836 r
.63032 .05701 .63482 .06027 .64376 .0549 .63929 .05153 Mtetra
.847 .832 .832 r
.63929 .05153 .64376 .0549 .65269 .04949 .64824 .04602 Mtetra
.846 .827 .829 r
.64824 .04602 .65269 .04949 .66162 .04403 .65719 .04046 Mtetra
.845 .822 .826 r
.65719 .04046 .66162 .04403 .67053 .03855 .66614 .03488 Mtetra
.844 .817 .823 r
.66614 .03488 .67053 .03855 .67945 .03304 .67507 .02927 Mtetra
.843 .812 .82 r
.67507 .02927 .67945 .03304 .68835 .02751 .684 .02364 Mtetra
.841 .807 .818 r
.684 .02364 .68835 .02751 .69725 .02197 .69292 .018 Mtetra
.839 .803 .815 r
.69292 .018 .69725 .02197 .70614 .01643 .70183 .01236 Mtetra
.028 .43 .867 r
.0484 .16376 .05397 .16697 .06044 .16855 .05484 .16541 Mtetra
.017 .43 .865 r
.05484 .16541 .06044 .16855 .06695 .17013 .06134 .16707 Mtetra
.008 .43 .863 r
.06134 .16707 .06695 .17013 .07351 .1717 .06787 .16872 Mtetra
.001 .431 .861 r
.06787 .16872 .07351 .1717 .08011 .17327 .07446 .17036 Mtetra
0 .434 .86 r
.07446 .17036 .08011 .17327 .08676 .17482 .08109 .17199 Mtetra
0 .437 .859 r
.08109 .17199 .08676 .17482 .09347 .17635 .08778 .1736 Mtetra
0 .442 .858 r
.08778 .1736 .09347 .17635 .10022 .17785 .09451 .17518 Mtetra
0 .447 .858 r
.09451 .17518 .10022 .17785 .10702 .17931 .1013 .17673 Mtetra
0 .454 .859 r
.1013 .17673 .10702 .17931 .11388 .18074 .10815 .17824 Mtetra
0 .461 .859 r
.10815 .17824 .11388 .18074 .1208 .18211 .11505 .1797 Mtetra
0 .47 .861 r
.11505 .1797 .1208 .18211 .12777 .18344 .122 .18111 Mtetra
0 .479 .862 r
.122 .18111 .12777 .18344 .1348 .1847 .12902 .18247 Mtetra
0 .49 .864 r
.12902 .18247 .1348 .1847 .14189 .18589 .13609 .18376 Mtetra
.005 .501 .865 r
.13609 .18376 .14189 .18589 .14903 .18702 .14322 .18498 Mtetra
.012 .513 .867 r
.14322 .18498 .14903 .18702 .15624 .18806 .15042 .18613 Mtetra
.021 .526 .869 r
.15042 .18613 .15624 .18806 .16351 .18901 .15767 .18719 Mtetra
.031 .54 .871 r
.15767 .18719 .16351 .18901 .17084 .18987 .16499 .18816 Mtetra
.041 .555 .873 r
.16499 .18816 .17084 .18987 .17823 .19063 .17237 .18904 Mtetra
.053 .57 .874 r
.17237 .18904 .17823 .19063 .18568 .19129 .17981 .18981 Mtetra
.065 .586 .875 r
.17981 .18981 .18568 .19129 .19319 .19182 .18731 .19047 Mtetra
.078 .602 .875 r
.18731 .19047 .19319 .19182 .20077 .19224 .19488 .19102 Mtetra
.091 .618 .874 r
.19488 .19102 .20077 .19224 .2084 .19253 .20251 .19145 Mtetra
.105 .634 .872 r
.20251 .19145 .2084 .19253 .2161 .19269 .2102 .19175 Mtetra
.119 .649 .868 r
.2102 .19175 .2161 .19269 .22387 .19271 .21795 .19191 Mtetra
.132 .664 .863 r
.21795 .19191 .22387 .19271 .23169 .19258 .22577 .19194 Mtetra
.145 .678 .856 r
.22577 .19194 .23169 .19258 .23957 .19231 .23365 .19183 Mtetra
.157 .691 .847 r
.23365 .19183 .23957 .19231 .24751 .19189 .24159 .19158 Mtetra
.167 .702 .835 r
.24159 .19158 .24751 .19189 .25551 .19132 .24958 .19117 Mtetra
.177 .711 .821 r
.24958 .19117 .25551 .19132 .26356 .19059 .25763 .19062 Mtetra
.185 .718 .806 r
.25763 .19062 .26356 .19059 .27167 .18972 .26574 .18992 Mtetra
.192 .723 .788 r
.26574 .18992 .27167 .18972 .27983 .18869 .27391 .18907 Mtetra
.197 .726 .768 r
.27391 .18907 .27983 .18869 .28804 .18751 .28213 .18808 Mtetra
.202 .728 .747 r
.28213 .18808 .28804 .18751 .2963 .18619 .29039 .18693 Mtetra
.207 .729 .726 r
.29039 .18693 .2963 .18619 .30461 .18471 .29871 .18563 Mtetra
.212 .73 .705 r
.29871 .18563 .30461 .18471 .31296 .18309 .30708 .18417 Mtetra
.221 .731 .686 r
.30708 .18417 .31296 .18309 .32136 .1813 .31549 .18255 Mtetra
.233 .736 .67 r
.31549 .18255 .32136 .1813 .3298 .17935 .32396 .18074 Mtetra
0 0 0 r
.32396 .18074 .3298 .17935 .33829 .1772 .33247 .17873 Mtetra
.33247 .17873 .33829 .1772 .34682 .17483 .34103 .17649 Mtetra
.34103 .17649 .34682 .17483 .35533 .17292 .34958 .17457 Mtetra
.34958 .17457 .35533 .17292 .36384 .17148 .35813 .17298 Mtetra
.35813 .17298 .36384 .17148 .37239 .16981 .36673 .17116 Mtetra
.36673 .17116 .37239 .16981 .38098 .16796 .37537 .16914 Mtetra
.313 .79 .704 r
.37537 .16914 .38098 .16796 .38961 .16592 .38406 .16693 Mtetra
.377 .834 .75 r
.38406 .16693 .38961 .16592 .39828 .16373 .39278 .16455 Mtetra
.438 .872 .792 r
.39278 .16455 .39828 .16373 .40699 .16139 .40154 .16202 Mtetra
.496 .905 .828 r
.40154 .16202 .40699 .16139 .41573 .15889 .41033 .15933 Mtetra
.55 .931 .859 r
.41033 .15933 .41573 .15889 .4245 .15625 .41914 .15648 Mtetra
.598 .951 .884 r
.41914 .15648 .4245 .15625 .4333 .15345 .42799 .15348 Mtetra
.641 .964 .903 r
.42799 .15348 .4333 .15345 .44212 .15049 .43686 .15033 Mtetra
.679 .971 .916 r
.43686 .15033 .44212 .15049 .45098 .14738 .44576 .14702 Mtetra
.711 .974 .923 r
.44576 .14702 .45098 .14738 .45985 .14411 .45468 .14356 Mtetra
.737 .973 .927 r
.45468 .14356 .45985 .14411 .46875 .14068 .46362 .13994 Mtetra
.76 .969 .927 r
.46362 .13994 .46875 .14068 .47766 .1371 .47257 .13618 Mtetra
.778 .963 .925 r
.47257 .13618 .47766 .1371 .4866 .13336 .48155 .13226 Mtetra
.793 .956 .921 r
.48155 .13226 .4866 .13336 .49554 .12947 .49053 .1282 Mtetra
.805 .948 .915 r
.49053 .1282 .49554 .12947 .5045 .12544 .49953 .12401 Mtetra
.815 .939 .909 r
.49953 .12401 .5045 .12544 .51347 .12126 .50854 .11967 Mtetra
.823 .931 .903 r
.50854 .11967 .51347 .12126 .52245 .11695 .51756 .11521 Mtetra
.829 .922 .896 r
.51756 .11521 .52245 .11695 .53144 .11251 .52658 .11062 Mtetra
.835 .913 .89 r
.52658 .11062 .53144 .11251 .54043 .10795 .53561 .10591 Mtetra
.839 .905 .883 r
.53561 .10591 .54043 .10795 .54943 .10327 .54463 .10109 Mtetra
.842 .897 .877 r
.54463 .10109 .54943 .10327 .55842 .09848 .55366 .09616 Mtetra
.845 .889 .871 r
.55366 .09616 .55842 .09848 .56742 .09358 .56269 .09114 Mtetra
.847 .882 .865 r
.56269 .09114 .56742 .09358 .57642 .08859 .57172 .08602 Mtetra
.849 .875 .86 r
.57172 .08602 .57642 .08859 .58541 .08351 .58075 .08082 Mtetra
.85 .868 .855 r
.58075 .08082 .58541 .08351 .59441 .07835 .58977 .07553 Mtetra
.85 .862 .85 r
.58977 .07553 .59441 .07835 .60339 .07311 .59879 .07018 Mtetra
.851 .856 .845 r
.59879 .07018 .60339 .07311 .61238 .0678 .6078 .06476 Mtetra
.851 .85 .841 r
.6078 .06476 .61238 .0678 .62135 .06244 .6168 .05927 Mtetra
.851 .844 .837 r
.6168 .05927 .62135 .06244 .63032 .05701 .6258 .05374 Mtetra
.851 .838 .833 r
.6258 .05374 .63032 .05701 .63929 .05153 .63479 .04816 Mtetra
.85 .833 .83 r
.63479 .04816 .63929 .05153 .64824 .04602 .64377 .04253 Mtetra
.849 .828 .826 r
.64377 .04253 .64824 .04602 .65719 .04046 .65274 .03688 Mtetra
.848 .823 .823 r
.65274 .03688 .65719 .04046 .66614 .03488 .66171 .03119 Mtetra
.847 .818 .82 r
.66171 .03119 .66614 .03488 .67507 .02927 .67067 .02548 Mtetra
.845 .813 .818 r
.67067 .02548 .67507 .02927 .684 .02364 .67962 .01975 Mtetra
.844 .808 .815 r
.67962 .01975 .684 .02364 .69292 .018 .68856 .01401 Mtetra
.842 .803 .813 r
.68856 .01401 .69292 .018 .70183 .01236 .69749 .00827 Mtetra
.003 .413 .856 r
.04279 .16053 .0484 .16376 .05484 .16541 .04922 .16226 Mtetra
0 .413 .853 r
.04922 .16226 .05484 .16541 .06134 .16707 .05569 .164 Mtetra
0 .413 .851 r
.05569 .164 .06134 .16707 .06787 .16872 .06221 .16573 Mtetra
0 .414 .848 r
.06221 .16573 .06787 .16872 .07446 .17036 .06877 .16745 Mtetra
0 .416 .847 r
.06877 .16745 .07446 .17036 .08109 .17199 .07539 .16916 Mtetra
0 .419 .845 r
.07539 .16916 .08109 .17199 .08778 .1736 .08205 .17084 Mtetra
0 .423 .844 r
.08205 .17084 .08778 .1736 .09451 .17518 .08877 .17251 Mtetra
0 .428 .844 r
.08877 .17251 .09451 .17518 .1013 .17673 .09554 .17414 Mtetra
0 .433 .843 r
.09554 .17414 .1013 .17673 .10815 .17824 .10237 .17573 Mtetra
0 .44 .843 r
.10237 .17573 .10815 .17824 .11505 .1797 .10925 .17729 Mtetra
0 .448 .844 r
.10925 .17729 .11505 .1797 .122 .18111 .11619 .17879 Mtetra
0 .457 .844 r
.11619 .17879 .122 .18111 .12902 .18247 .12319 .18024 Mtetra
0 .467 .845 r
.12319 .18024 .12902 .18247 .13609 .18376 .13025 .18163 Mtetra
0 .477 .847 r
.13025 .18163 .13609 .18376 .14322 .18498 .13737 .18295 Mtetra
0 .489 .848 r
.13737 .18295 .14322 .18498 .15042 .18613 .14455 .18421 Mtetra
0 .501 .849 r
.14455 .18421 .15042 .18613 .15767 .18719 .15179 .18538 Mtetra
0 .514 .85 r
.15179 .18538 .15767 .18719 .16499 .18816 .15909 .18646 Mtetra
.001 .527 .851 r
.15909 .18646 .16499 .18816 .17237 .18904 .16646 .18746 Mtetra
.011 .542 .851 r
.16646 .18746 .17237 .18904 .17981 .18981 .17389 .18835 Mtetra
.022 .556 .851 r
.17389 .18835 .17981 .18981 .18731 .19047 .18138 .18914 Mtetra
.033 .571 .85 r
.18138 .18914 .18731 .19047 .19488 .19102 .18894 .18982 Mtetra
.045 .586 .848 r
.18894 .18982 .19488 .19102 .20251 .19145 .19656 .19039 Mtetra
.057 .6 .844 r
.19656 .19039 .20251 .19145 .2102 .19175 .20424 .19083 Mtetra
.069 .615 .84 r
.20424 .19083 .2102 .19175 .21795 .19191 .21199 .19115 Mtetra
.081 .628 .834 r
.21199 .19115 .21795 .19191 .22577 .19194 .2198 .19133 Mtetra
.092 .641 .826 r
.2198 .19133 .22577 .19194 .23365 .19183 .22767 .19138 Mtetra
.103 .653 .816 r
.22767 .19138 .23365 .19183 .24159 .19158 .2356 .19129 Mtetra
.113 .663 .804 r
.2356 .19129 .24159 .19158 .24958 .19117 .2436 .19106 Mtetra
.121 .671 .79 r
.2436 .19106 .24958 .19117 .25763 .19062 .25165 .19069 Mtetra
.129 .678 .773 r
.25165 .19069 .25763 .19062 .26574 .18992 .25976 .19017 Mtetra
.136 .683 .755 r
.25976 .19017 .26574 .18992 .27391 .18907 .26792 .1895 Mtetra
.142 .686 .736 r
.26792 .1895 .27391 .18907 .28213 .18808 .27614 .18868 Mtetra
.148 .689 .715 r
.27614 .18868 .28213 .18808 .29039 .18693 .28442 .18772 Mtetra
.154 .69 .695 r
.28442 .18772 .29039 .18693 .29871 .18563 .29275 .18659 Mtetra
0 0 0 r
.29275 .18659 .29871 .18563 .30708 .18417 .30113 .18531 Mtetra
.30113 .18531 .30708 .18417 .31549 .18255 .30956 .18385 Mtetra
.30956 .18385 .31549 .18255 .32396 .18074 .31804 .1822 Mtetra
.31804 .1822 .32396 .18074 .33247 .17873 .32657 .18034 Mtetra
.32657 .18034 .33247 .17873 .34103 .17649 .33516 .17823 Mtetra
.33516 .17823 .34103 .17649 .34958 .17457 .34375 .17631 Mtetra
.34375 .17631 .34958 .17457 .35813 .17298 .35235 .17456 Mtetra
.35235 .17456 .35813 .17298 .36673 .17116 .361 .17258 Mtetra
.274 .758 .661 r
.361 .17258 .36673 .17116 .37537 .16914 .3697 .17038 Mtetra
.342 .807 .71 r
.3697 .17038 .37537 .16914 .38406 .16693 .37844 .16799 Mtetra
.407 .851 .755 r
.37844 .16799 .38406 .16693 .39278 .16455 .38722 .16542 Mtetra
.467 .888 .795 r
.38722 .16542 .39278 .16455 .40154 .16202 .39602 .16269 Mtetra
.524 .918 .83 r
.39602 .16269 .40154 .16202 .41033 .15933 .40486 .1598 Mtetra
.575 .942 .859 r
.40486 .1598 .41033 .15933 .41914 .15648 .41373 .15675 Mtetra
.622 .959 .882 r
.41373 .15675 .41914 .15648 .42799 .15348 .42263 .15355 Mtetra
.662 .971 .899 r
.42263 .15355 .42799 .15348 .43686 .15033 .43155 .1502 Mtetra
.697 .977 .91 r
.43155 .1502 .43686 .15033 .44576 .14702 .44049 .14669 Mtetra
.727 .978 .917 r
.44049 .14669 .44576 .14702 .45468 .14356 .44946 .14304 Mtetra
.751 .977 .92 r
.44946 .14304 .45468 .14356 .46362 .13994 .45844 .13924 Mtetra
.772 .972 .92 r
.45844 .13924 .46362 .13994 .47257 .13618 .46744 .13529 Mtetra
.789 .966 .918 r
.46744 .13529 .47257 .13618 .48155 .13226 .47645 .13119 Mtetra
.802 .958 .914 r
.47645 .13119 .48155 .13226 .49053 .1282 .48548 .12696 Mtetra
.814 .95 .909 r
.48548 .12696 .49053 .1282 .49953 .12401 .49452 .12259 Mtetra
.823 .941 .904 r
.49452 .12259 .49953 .12401 .50854 .11967 .50357 .1181 Mtetra
.83 .932 .898 r
.50357 .1181 .50854 .11967 .51756 .11521 .51262 .11348 Mtetra
.836 .923 .891 r
.51262 .11348 .51756 .11521 .52658 .11062 .52168 .10873 Mtetra
.841 .915 .885 r
.52168 .10873 .52658 .11062 .53561 .10591 .53074 .10388 Mtetra
.844 .906 .879 r
.53074 .10388 .53561 .10591 .54463 .10109 .5398 .09892 Mtetra
.847 .898 .873 r
.5398 .09892 .54463 .10109 .55366 .09616 .54887 .09385 Mtetra
.85 .891 .867 r
.54887 .09385 .55366 .09616 .56269 .09114 .55793 .08869 Mtetra
.851 .883 .861 r
.55793 .08869 .56269 .09114 .57172 .08602 .56699 .08345 Mtetra
.853 .876 .856 r
.56699 .08345 .57172 .08602 .58075 .08082 .57605 .07812 Mtetra
.854 .869 .851 r
.57605 .07812 .58075 .08082 .58977 .07553 .5851 .07271 Mtetra
.854 .863 .847 r
.5851 .07271 .58977 .07553 .59879 .07018 .59414 .06724 Mtetra
.855 .857 .842 r
.59414 .06724 .59879 .07018 .6078 .06476 .60318 .0617 Mtetra
.855 .851 .838 r
.60318 .0617 .6078 .06476 .6168 .05927 .61222 .05611 Mtetra
.854 .845 .834 r
.61222 .05611 .6168 .05927 .6258 .05374 .62124 .05046 Mtetra
.854 .839 .83 r
.62124 .05046 .6258 .05374 .63479 .04816 .63026 .04477 Mtetra
.853 .834 .827 r
.63026 .04477 .63479 .04816 .64377 .04253 .63927 .03904 Mtetra
.852 .829 .824 r
.63927 .03904 .64377 .04253 .65274 .03688 .64827 .03327 Mtetra
.851 .824 .821 r
.64827 .03327 .65274 .03688 .66171 .03119 .65726 .02748 Mtetra
.85 .818 .818 r
.65726 .02748 .66171 .03119 .67067 .02548 .66624 .02167 Mtetra
.848 .814 .815 r
.66624 .02167 .67067 .02548 .67962 .01975 .67521 .01584 Mtetra
.847 .809 .813 r
.67521 .01584 .67962 .01975 .68856 .01401 .68417 .01 Mtetra
.845 .804 .811 r
.68417 .01 .68856 .01401 .69749 .00827 .69313 .00416 Mtetra
0 .396 .844 r
.03716 .15729 .04279 .16053 .04922 .16226 .04356 .1591 Mtetra
0 .395 .841 r
.04356 .1591 .04922 .16226 .05569 .164 .05001 .16091 Mtetra
0 .395 .838 r
.05001 .16091 .05569 .164 .06221 .16573 .05651 .16272 Mtetra
0 .395 .835 r
.05651 .16272 .06221 .16573 .06877 .16745 .06305 .16452 Mtetra
0 .397 .833 r
.06305 .16452 .06877 .16745 .07539 .16916 .06964 .16631 Mtetra
0 .399 .831 r
.06964 .16631 .07539 .16916 .08205 .17084 .07629 .16808 Mtetra
0 .403 .829 r
.07629 .16808 .08205 .17084 .08877 .17251 .08299 .16983 Mtetra
0 .407 .828 r
.08299 .16983 .08877 .17251 .09554 .17414 .08974 .17155 Mtetra
0 .413 .827 r
.08974 .17155 .09554 .17414 .10237 .17573 .09655 .17323 Mtetra
0 .419 .826 r
.09655 .17323 .10237 .17573 .10925 .17729 .10342 .17487 Mtetra
0 .426 .826 r
.10342 .17487 .10925 .17729 .11619 .17879 .11034 .17647 Mtetra
0 .434 .826 r
.11034 .17647 .11619 .17879 .12319 .18024 .11732 .17802 Mtetra
0 .443 .826 r
.11732 .17802 .12319 .18024 .13025 .18163 .12437 .17951 Mtetra
0 .452 .826 r
.12437 .17951 .13025 .18163 .13737 .18295 .13147 .18093 Mtetra
0 .463 .826 r
.13147 .18093 .13737 .18295 .14455 .18421 .13863 .18229 Mtetra
0 .474 .827 r
.13863 .18229 .14455 .18421 .15179 .18538 .14586 .18357 Mtetra
0 .486 .827 r
.14586 .18357 .15179 .18538 .15909 .18646 .15315 .18477 Mtetra
0 .498 .826 r
.15315 .18477 .15909 .18646 .16646 .18746 .1605 .18589 Mtetra
0 .511 .826 r
.1605 .18589 .16646 .18746 .17389 .18835 .16792 .18691 Mtetra
0 .525 .824 r
.16792 .18691 .17389 .18835 .18138 .18914 .1754 .18783 Mtetra
0 .538 .822 r
.1754 .18783 .18138 .18914 .18894 .18982 .18294 .18865 Mtetra
0 .552 .819 r
.18294 .18865 .18894 .18982 .19656 .19039 .19055 .18935 Mtetra
.008 .565 .815 r
.19055 .18935 .19656 .19039 .20424 .19083 .19823 .18994 Mtetra
.019 .578 .809 r
.19823 .18994 .20424 .19083 .21199 .19115 .20596 .19041 Mtetra
.029 .591 .802 r
.20596 .19041 .21199 .19115 .2198 .19133 .21377 .19075 Mtetra
.039 .602 .793 r
.21377 .19075 .2198 .19133 .22767 .19138 .22163 .19097 Mtetra
.049 .613 .783 r
.22163 .19097 .22767 .19138 .2356 .19129 .22956 .19105 Mtetra
.058 .622 .77 r
.22956 .19105 .2356 .19129 .2436 .19106 .23755 .19099 Mtetra
.066 .63 .755 r
.23755 .19099 .2436 .19106 .25165 .19069 .2456 .19079 Mtetra
.074 .636 .739 r
.2456 .19079 .25165 .19069 .25976 .19017 .25371 .19045 Mtetra
.081 .641 .721 r
.25371 .19045 .25976 .19017 .26792 .1895 .26187 .18997 Mtetra
0 0 0 r
.26187 .18997 .26792 .1895 .27614 .18868 .2701 .18933 Mtetra
.2701 .18933 .27614 .18868 .28442 .18772 .27838 .18855 Mtetra
.27838 .18855 .28442 .18772 .29275 .18659 .28672 .18761 Mtetra
.28672 .18761 .29275 .18659 .30113 .18531 .29511 .1865 Mtetra
.29511 .1865 .30113 .18531 .30956 .18385 .30355 .18521 Mtetra
.30355 .18521 .30956 .18385 .31804 .1822 .31205 .18372 Mtetra
.31205 .18372 .31804 .1822 .32657 .18034 .3206 .18202 Mtetra
.3206 .18202 .32657 .18034 .33516 .17823 .32921 .18006 Mtetra
.32921 .18006 .33516 .17823 .34375 .17631 .33785 .17813 Mtetra
.33785 .17813 .34375 .17631 .35235 .17456 .3465 .17622 Mtetra
.3465 .17622 .35235 .17456 .361 .17258 .35521 .17406 Mtetra
.302 .775 .666 r
.35521 .17406 .361 .17258 .3697 .17038 .36396 .17168 Mtetra
.371 .824 .715 r
.36396 .17168 .3697 .17038 .37844 .16799 .37276 .1691 Mtetra
.436 .866 .758 r
.37276 .1691 .37844 .16799 .38722 .16542 .38159 .16634 Mtetra
.496 .901 .797 r
.38159 .16634 .38722 .16542 .39602 .16269 .39045 .16341 Mtetra
.55 .93 .83 r
.39045 .16341 .39602 .16269 .40486 .1598 .39934 .16031 Mtetra
.6 .952 .857 r
.39934 .16031 .40486 .1598 .41373 .15675 .40826 .15706 Mtetra
.644 .967 .878 r
.40826 .15706 .41373 .15675 .42263 .15355 .41721 .15366 Mtetra
.682 .977 .894 r
.41721 .15366 .42263 .15355 .43155 .1502 .42618 .1501 Mtetra
.714 .981 .904 r
.42618 .1501 .43155 .1502 .44049 .14669 .43517 .1464 Mtetra
.742 .982 .911 r
.43517 .1464 .44049 .14669 .44946 .14304 .44418 .14255 Mtetra
.765 .979 .914 r
.44418 .14255 .44946 .14304 .45844 .13924 .45321 .13856 Mtetra
.784 .974 .914 r
.45321 .13856 .45844 .13924 .46744 .13529 .46226 .13442 Mtetra
.799 .968 .911 r
.46226 .13442 .46744 .13529 .47645 .13119 .47131 .13015 Mtetra
.812 .96 .908 r
.47131 .13015 .47645 .13119 .48548 .12696 .48038 .12574 Mtetra
.822 .951 .903 r
.48038 .12574 .48548 .12696 .49452 .12259 .48946 .1212 Mtetra
.83 .942 .898 r
.48946 .1212 .49452 .12259 .50357 .1181 .49855 .11654 Mtetra
.837 .934 .892 r
.49855 .11654 .50357 .1181 .51262 .11348 .50764 .11176 Mtetra
.842 .925 .886 r
.50764 .11176 .51262 .11348 .52168 .10873 .51674 .10686 Mtetra
.846 .916 .88 r
.51674 .10686 .52168 .10873 .53074 .10388 .52583 .10186 Mtetra
.85 .908 .874 r
.52583 .10186 .53074 .10388 .5398 .09892 .53493 .09675 Mtetra
.852 .899 .869 r
.53493 .09675 .5398 .09892 .54887 .09385 .54403 .09155 Mtetra
.854 .892 .863 r
.54403 .09155 .54887 .09385 .55793 .08869 .55313 .08626 Mtetra
.856 .884 .858 r
.55313 .08626 .55793 .08869 .56699 .08345 .56222 .08088 Mtetra
.857 .877 .853 r
.56222 .08088 .56699 .08345 .57605 .07812 .57131 .07542 Mtetra
.858 .87 .848 r
.57131 .07542 .57605 .07812 .5851 .07271 .58039 .06989 Mtetra
.858 .864 .843 r
.58039 .06989 .5851 .07271 .59414 .06724 .58947 .0643 Mtetra
.858 .858 .839 r
.58947 .0643 .59414 .06724 .60318 .0617 .59854 .05864 Mtetra
.858 .852 .835 r
.59854 .05864 .60318 .0617 .61222 .05611 .6076 .05293 Mtetra
.858 .846 .831 r
.6076 .05293 .61222 .05611 .62124 .05046 .61666 .04717 Mtetra
.857 .84 .828 r
.61666 .04717 .62124 .05046 .63026 .04477 .6257 .04137 Mtetra
.856 .835 .824 r
.6257 .04137 .63026 .04477 .63927 .03904 .63473 .03553 Mtetra
.855 .829 .821 r
.63473 .03553 .63927 .03904 .64827 .03327 .64376 .02966 Mtetra
.854 .824 .818 r
.64376 .02966 .64827 .03327 .65726 .02748 .65277 .02376 Mtetra
.853 .819 .815 r
.65277 .02376 .65726 .02748 .66624 .02167 .66178 .01784 Mtetra
.851 .814 .813 r
.66178 .01784 .66624 .02167 .67521 .01584 .67078 .01191 Mtetra
.849 .809 .81 r
.67078 .01191 .67521 .01584 .68417 .01 .67976 .00596 Mtetra
.848 .804 .808 r
.67976 .00596 .68417 .01 .69313 .00416 .68874 2e-05 Mtetra
0 g
.68874 0 m
.96935 .26459 L
s
.96935 .26459 m
1 .40283 L
s
1 .40283 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.03716 .15727 m
0 .30182 L
s
0 .30182 m
.70298 .15129 L
s
.70298 .15129 m
.68874 0 L
s
.68874 0 m
.03716 .15727 L
s
.03716 .15727 m
.68874 0 L
s
.03716 .15727 m
.04196 .16003 L
s
[(-4)] .02757 .15175 1 .93395 Mshowa
.18558 .12145 m
.19014 .12435 L
s
[(-2)] .17646 .11563 .96648 1 Mshowa
.34306 .08344 m
.34735 .0865 L
s
[(0)] .3345 .07731 .86223 1 Mshowa
.51046 .04303 m
.51442 .04625 L
s
[(2)] .50253 .03658 .75799 1 Mshowa
.68874 0 m
.69233 .00339 L
s
[(4)] .68156 -0.00677 .65374 1 Mshowa
.125 Mabswid
.07346 .14851 m
.0763 .15019 L
s
.11029 .13962 m
.1131 .14132 L
s
.14766 .1306 m
.15043 .13232 L
s
.22407 .11216 m
.22677 .11392 L
s
.26314 .10273 m
.2658 .10452 L
s
.3028 .09315 m
.30541 .09497 L
s
.38395 .07357 m
.38647 .07543 L
s
.42547 .06355 m
.42794 .06543 L
s
.46763 .05337 m
.47006 .05528 L
s
.55397 .03253 m
.55629 .03449 L
s
.59817 .02186 m
.60044 .02384 L
s
.64309 .01102 m
.6453 .01302 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00<OG00<0emL0E]L00<OG
00<0emL0E]L00<CG1@1Ge`00a=L0103Ge`1He`00aML00`3G001He`00a]L200gG1017e`00amL00`3G
e`0;e`030=OG04SG003Fe`030=OG04OG003?e`@01=L00`3Ge`16e`00bML300cG00<0emL0AML00<GG
1@000j`00008e`040=OG04OG0031e`@01=L01Jc@0=4000SG0P18e`00UML402CG1005e`F/00@0[:`0
DML009GG00<0emL08ML400;G00<0emL00mL02jcG[=6/d@3A[=L0053G002Fe`030=OG01cG100;e`N/
00<0[:`00Z`00`3Ge`1=e`00UmL00`3Ge`0Ge`@03]L03jcG[=N/ejcA[02/dJcA001>e`00V=L00`3G
e`0Be`@00mL00`3Ge`0:e`^/00<0[:`00j`00`3Ge`1;e`00UML0103Ge`0@e`@04]L05JcG[=N/ejcG
[=N/ej`0[=6/dJcA001<e`00U]L200gG100Ee`j/00<0[:`01J`204[G002Qe`@06=L06ZcG[=N/ejcG
[=N/ejcG[02/dJcA[=6/dML0BML009cG1@0Iea:/00<0[:`01j`00mL0e`17e`00V=L501cG022/ejcG
[=N/ejcG[=N/ejcG[=N/0:cA[=6/dJcA[=7G04OG002De`@01ML00`3Ge`0HeaB/00<0[:`02J`204KG
001Ze`809=L4027G02J/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[02/dJcA[=6/dJcA[=6/04GG001Ye`04
0=OG01oG10000mL0e`0Qe`03[=2/01F/00<0[:`03:`00`3Ge`12e`00JML0103Ge`0Ke`@09mL0:ZcG
[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG0=N/dJcA[=6/dJcA[=6/00kG100ae`00JML0103Ge`0Ge`@0
:ML00mJ/eP0I[0030:b/00f/00<0emL03ML00`3Ge`0`e`00JML0103Ge`0Ce`@00]L00`3Ge`0Xe`0^
[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/e`3G[=6/dJcA[=6/[Jb][:f/00kG00<0emL0<=L006WG
00@0emL03mL402kG00B/eZbb6j`00`2/[00?[0030=OG00?G1004e`030=OG033G001Ze`803=L4037G
03B/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/e`3G[=N/dJcA[:f/[Jb][:f/[J`03=L00`3G
e`0`e`00LmL503?G00^b[;://Zbb[;://P0G[0030:b/016/00<0emL01mL303;G001_e`@0=]L0>ZcG
[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/e`3G[:f/[Jb][:f/[Jb][:f/[Jb][00:e`03
0=OG033G001[e`@00]L00`3Ge`0ce`0I/jbc[;>//jbc[;>//jbc[:f/[Jb][:f/[@03[003[Jb]00N/
00<0[:`04j`00`3Ge`0je`00?mL402CG100je`10[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG
[=N/ejcG[=N//`2c[;>/[Jb][:f/[Jb][:f/[Jb][:f/03_G000oe`030=OG027G100me`0/[;>//jbc
[;>//jbc[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/[J`0[:dE[0030=OG03SG0010e`030=OG01cG
1010e`13[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[=N/ejbc[;>//jbc[02//jb][:f/[Jb]
[:f/[Jb][:f/[Jb][00203SG000ie`@01=L00`3Ge`0Fe`D0@ML0>Zbc[;>//jbc[;>//jbc[;>//jbc
[;>/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:d0[Jb][:f/[Jb][:d=[003e`3G03KG0012e`030=OG01;G
1@13e`1;/]Nbek;G/]N/ejcG[=N/ejcG[=N/ejcG[=N/ejcG[;>//jbc[;>//jbc[;>//j`0[;>//jb]
[:f/[Jb][:f/[Jb][:f/[Jb][=L003KG000oe`040=OG013G1016e`11/jbc[;>//jbc[;>//jbc[;>/
/jbc[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/[@2][:f/[Jb][:f/[Jb][:d02j`00mL0e`0de`00
@=L200gG1018e`1A/]Nbek;G/]Nbek;G[=N/ejcG[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc
[;>/0:bc[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][=L003CG001;e`@0B]L0Ck>//jbc[;>//jbc[;>/
/jbc[;>//jbc[;>//jbc[;>/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:d00j`00mL0e`0be`00A]L504cG00Zbek;G/]Ncek?G1[<0Ajfc[K>]/jfc[K>]/jbc[;>//jbc
[;>//jbc[;>//jbc[;>//jbc[02//jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:d003;G0012e`@0
00?G0=L0C=L0F[>//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[;>//jbc[:f/[Jb][:f/[Jb][:f/
[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]037G000Ie`030=OG02;G101Ce`03
/mNc00nc04V]/jfc[K>]/jfc[K>]/jfc[K>]/jfc[K>//jbc[;>//jbc[;>//j`0[;>/[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:d0033G000Ie`030=OG01kG101Ce`1P/k:c/[>b/jbc[;>//jbc[;>/
/jbc[;>//jbc[;>8/hRc[;>//jbc[:f/[Jb][:f/[Jb][:f/[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:d02=L202GG000Fe`D06mL405GG6;<0Bjfc[K>]/jfc[K>]/jfc[K>]/jfc
[K>]/jfc[;>//jbc[;>//jbc[;<0[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]0006e`04
0=OG02CG000Ae`@000GG0=OG000He`@0EmL0I[>b/hjcS[>>/hjcR;>8/hVcRK>9/hVcRK>9/hVcRK>9
/hRcR;>8/hRcR;>8[HR]R:f8[HR]R:f8[HR]R:f/[Jb][02/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb]00GG00@0emL09=L001OG00<0e`005=L40003e`3G05GG2k<00hncS`03/`1ISk>?/hnc
Sk>?/hncRK>9/hVcRK>]/jfc[K>]/jfc[K>]/jfc[K>]/jfc[;>//jbc[;>/[@2][:f/[Jb][:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[@001=L0103Ge`0Te`006=L2013G101Je`1]S[>>/hjcS[>>/hjc
RHn9/hV?RHn9ShV?RK>9ShV?RK>9/hVcRK>9/hVcRK>9[HR]R:f8[HR]R:f8[HR]R:f8[HR]R:f8[HP0
R:f8[HR]R:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]0003e`040=OG02CG000Ie`030=OG00[G
101Le`05/hncSk<01Hl00k>?S`0<S`0XRHn9ShV?RK>9/hVcRK>9/hVcRK>9/hVcRK>9/jfc[K>]/jfc
[K>]/`:]00B/[Jb]0`009Zf/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:d00]L0103G
e`0Te`008=L00`3G000305gG02^cSXn>Shj?R8mTSfB?I8mTSfA[I6]UJfE[IHmUSfF?IHn9ShV?RHn9
ShV?00>901R]RJf9[HV]R:f8[HR]R:f8[HR]R:f8[HP4000Z[HR]0:f8[HR]R:f8[HR][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:d00]L202GG000Oe`<0GmL07HjcSXn>Shi[I6]0ID1U@6E0@D11@450ID1U
@FE100AU02:?IHmUShV?RHn9ShV?RK>9/hVcRK>9/hVcRK>9/hVcRK>91@02[@0/[:f/[Jb]0:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:d202OG000Ge`801]L200034=OG05[G00B8SVAZ
0f@00d0ie`0Fe`<F00A1>fDk16D01XUURFF9I@Z900J]RJf8[HP5000>R:f8[HR]R:f8[HR]R:d2000U
R:f8[HR]R:f8[HR]R:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]000We`005]L0103Ge`04e`800]L00a4@
4@1Ee`03SVB>009T00>>/Xh08ML00a0k>`04I@04RFF9I@R900F?RK>9[@04000;RJf9[HV]RJf9[HT0
0jd0;:b][:f/[J`0[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb]0P0Ue`005]L0103G
e`04e`030=OG00?G00<04A000Q1=e`0306YS009T0Xh4/RGG00<941000S/00fEOI@03I@05RFF9IHT0
1@04R@0m[HR]R:f8[HR]R:f8[HR]R:f8[HR]R028[HR]R:f8[HR]R:f8[HR]R:f/[Jb][:f/[Jb][:f/
[Jb][:gG000Te`005]L0103Ge`04e`030=OG00GG00LG41L@4A0A04KG0V@02Cn>S[>>/hkG/P0[e`03
43/k008k0VD00hT0000300J9046]RJf9[HV]RJf9[HV]RJf9[HV]RJf/[Jb][02/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/000Se`005]L0103Ge`03e`802=L01cD@4A0A41400Q0oe`80
00mZI8iT/hjcS[>b/k;F/]H0:mL240@000QUGfEOREn9I@N903J8RHR9R:f8[HR]R:f8[HR]R:f8[HR]
R028[HR]R:f8[HR]R:f8[HR]R:f/[Jb][:f/[Jb][:d7[0030=OG023G000Fe`040=OG00?G00<0emL0
2ML03A0k43/@5a0G41L@5a00=ML2000AI8mZShjcS[>b/k:c/]Nbek80:]L5000743/kIC]UG`02I@03
RFF900V903f]RJf9[HV]RJf9[HV]R:f8[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:f/[ML0027G000Ge`801=L200_G00`@>a0k43/@5a0G41L542cG01L0I6YTSXR?SXn>/hjc/[>b
/k;G/]J/eP0Ue`D01mL0:S/d>c]O>fEOIEn9GhUORH>9PhV8RHR9R:f8[HR]R:f8[HR]R:f8[HR]R080
01N]R:f8[HR]R:f8[HR]R:f8[Jb][:f/[@0<[0808=L001gG00<0emL03=L05@0k>cDk4C/A>a4k43/@
5a0G41L@5`0Qe`06041[I8mZ18l00k>?/`05/`0<ek;G/]Nbek;G/]N/7mL400kG00/A>c]O>fEOREn9
G`08R@0m[HV]RJf9[HV]RJf8[HR]R:f/[Jb][:d0[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:gG000Oe`007ML00`3Ge`0>e`0I03/@>a0k43/@>a0k41L@5a0G41L@5a0G40025Q7G02DE@41U
@6ETJfB?I8n8ShVcRK>9/hjc/[>b/jbc[;>/ejcF[=J/01_G1@0De`0m>c@k>UlkIEn9GhUOREj9GXV2
RH:9PXV2RH:9PZf2[H:]PZf8[HR]R:d0[HR]R:f8[HR]R:f8[HR]R:f/[@0A[0030=OG00KG100Be`00
7=L00`3Ge`0Ae`dk00LG>c/k5c/G00<k00/G@C]1>d4k@C]1>`04@@0>ID5UIF]UJfF?IHn9ShT2S`04
/hncS`Rc00kG/]Nbek;G/]N/ejcG[1GG1@0Je`04>cEO>`9O00QUGhUORH>9P`B903f]RJf9[HV]RJf9
[HR]R:f8[Jb][:f/[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[J`000WG00<0emL0
4ML001cG00<0emL04]L063/d>c@k=3/d>a0k>S/F>cXk5S/j>cXk>P8k00Y1>d4kIC]U>fE126D09HmU
SfF?RHn9ShVcRK>9/hVc[;>//jbc[;>//jcG[=J/eZc@[=003mL4027G00Dd>cYOGP03G`0_GXUNREj9
GXV2RH:9PXV2RH:9PZf2[H:]PZf2[H:]PZd0[H:]PZf8[HR]R:f8[HP05Z`00`3Ge`06e`030=OG017G
000Le`805ML0101O>el=>`0<IC]U>fDkIC]U>fE126D048mUSfF?RHn9ShVcRK>9/hl:/`0>ek;G[=N/
ejcG[=N/ej`<e`D09]L00cEO>`02G`0:IEn9GhUORH>9P`B903^]RJf9[HV]R:f8[HR]R:f/[Jb][:d0
[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/0007e`030=OG017G0008e`801=L00`3G
e`02e`<01]L00`3Ge`0Fe`0:03Xk>S/j>cXk>PPk00aO>c/kIC]U>fDkIEl6I@04RFF9I@:902B?RHn9
ShV?RK>9/hVcR;>//jbc[;>//jbc[;://Zc@[=2/d:`4e`D0;=L0:3AO=5ljGeiOGXUNREj9PXV2RH:9
PXV2RH:9PZf2[H:]PZf2[H:]PZd2000=PZf2[H:]PZf2[8:/R00F[0030=OG00CG00<0emL04ML000OG
00@0emL02mL00`3Ge`02e`806]L05c]O>elkGc]O>elkGc]U>fDkIC]U>fEO00IU02n9IHUURFF?IHn9
ShV?RK>9/hVcRK>9/jfc[K>]/jfc[;>/ejcG[=N/ejcG[=N/eP0403;G00<dGc/015l02XUOREn9PhV3
RH<2R@0k[HV]RJf8[HR]R:f8[HR]R:f/[Jb][02/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][0000mL301?G0007e`040=OG00_G00<0emL00]L00`3Ge`0Je`0M>UljGcYO>elkGc]O>elkGc]U
>fDkIC]UGfEOIEl00VD018UURFD<R@0E/hVcR;>8/hRc[;>//jbc[;>/[Jb]00:/1@000m2/e`0de`0g
=3/dGcYOGUmNPej3GXV2RH:9PXV2RH:]PZf2[H:]PZf2[H:]PZf2[H80PZf2[H:/PZb2[:J/YP0F[003
0=OG00;G00<0emL04ML000OG00@0emL02=L300GG00<0emL07=L05P0kGc]O>elkIC]U>fEOIEmUGfEO
IEl4I@06RFF9IHUU18T06hn9ShVcRK>9/hVc[K>]/jfc[K>]/jbc[=N/e`050006ejcG[=N/=]L00c/d
G`03G`19Pen9GhUORH>9PhV3RH>]PZf8[HR]R:f8[HR]R:f8[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][:f/000Ge`001mL0103Ge`08e`030=OG00CG0P0Pe`0S>UlkGc]O>elkGc]O
>elkGc]UGfEOIEmUGfEORFF9IHUURFD01XT04:f9[HR]R:f8[HR][:f/[J`40003[Jb]00Z/=ML0>3Dd
GcAOGUmNPej3GX=NRH:9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[H:]PP22[8:/PZb2[8:/YZbV5Z`00`3G
e`0De`001mL0103Ge`08e`030=OG00CG00<0emL08ML076EOIEmUGfEOIEmUGfEOIEmUGfEOREn9IHUU
RFD8R@0>/hVcRK>9/hVc[K>]/jd5000C[;>//jbc[=N/ejcA[=6/d:c@[00de`1?GcAOGUmNPen9GhV3
RH>9PhV2RH:]PZf2[HR]R:f8[HR]R:f8[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/
[Jb][:f/000Ee`002=L200WG1003e`808mL035lkGc]O>elkGc]O>`9O011UGfEOIEmUGfEOREn9GhUO
2XT01Jf8[HR]00@000b8[HR]R:f/[Jb][:d=[3CG02Xe=5ldGeiOGX=NPej3GX>2RH:9PXV2RH:9PZf2
[H:]PZf2[H:]PZf2[882000@[8:/PZb2[:J/YZbV[:J/YQ:/0P0Ce`006]L00`3Ge`0Te`0K06EOIEmU
GfEOIEmUGfEOIEn9GhUORFF9IHUU00R900>]RJd01@007jf9/hVc[K>//jbc[:f/[Jb][=6/dJcA[=6/
dJc@[=00<]L0DCAOF5mNGej3GXUNRH:9PXV2RH:]PZf2[H:]PZf8[HR]R:f8[HR][:f/[Jb]0:f/[Jb]
[:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[JcA000Be`006ML00`3Ge`0We`aO011UGfEOIEmUGfEO
REn9GhUO0hT500:901>]R:f8[HR]R:f8[HR][:f/[Jb]012/<ML2=00lF3AOF5mNPej3GX=NPh:3PXV2
RH:9PXV2RH:]PZf2[H:]PZf2[8:/PZb2[02/PZb2[8:/YZbV[:J/YZbV4Z`00mL0e`0@e`006ML202WG
01QUGfEOIEmUGfEOIEmUGhUOREn9GhUURFD2R@@018T02Zf9[HV]RJf9[HT5[@0H[:f/[Jb][:f/[Jb]
[:f/[Jc@[=2/d:c@<ML0DUldGeQOGUmNPej9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[HR]R:f/[Jb][:f/
[@2][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[JcA[=6/e`0@e`006ML00`3Ge`0Ze`0305mO00QO
00QUGfEOIEmUG`D000EOREn9P`05R@0DR8V8RHR]R:f8[HR]R:f8[HR][:d<[007YZbV[:J/YP0_e`0m
=5PdGUQOF5mNPej3GX=NPh:3PX>2RH:9PXV2[H:]PZf2[8:/PZb2[8:/PZb2[02/PZb2[:J/YZbV[:J/
YP0E[0030=OG00gG000Ie`80;ML036EOIEmUGfEOIEn9G`D000EOREn9I@0<R@0O[HV]RJf9[HV]RJf/
[Jb][:f/[Jb][:f/[Jb][:f/[@05[006d:c@[=2/:]L0E5TdGeQOF5mNPej3GX>2Ph:9PXV2[H:]PZf2
[H:]PZf2[H:]R:f/[Jb][:f/[Jb]0:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/dJcA[=6/dJcA00OG
1003e`004=L400CG0P0_e`MO1000;5mUGfEOIEn9GhUOREn9GhV3RH:9PXV2RHR9R:f8[HR]R:f8[HR]
R:f8[Jb]1Z`03jJ/YZbV[:J/YZbV[:J/YP0Ye`03=5Pd009H02]NF5iHPej3GX=NPh:3PX>2Ph:9PXV2
RH:]PZb2[8:/PZb2[8:/PZb2[8:/008000n2[:J/YZbV[:J/YZbV[:H04Z`00mL0e`05e`030=OG00CG
000Be`030=OG00?G00<0emL0<=L5000@REn9GhUOREn9GhUOREn9G`b901n]RJf9[HV]RJf8[HR][:f/
[Jb][:f/[Jb][:f/[Jb]00V/00?@[=L09]L3F01DGUQOF5mNPej3GX>2Ph:3PXV2RH:]PZf2[H:]PZf2
[H:]PZfV[Jb][:f/[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[Jb][=6/dJcA[=6/dJcA[=401]L00`3G
e`03e`004]L00`3Ge`03e`80;=L500;G25l0@VEOIEmUGfEOREn9GhUOREn9PXV2RH:9PXV2RH:]PZf2
[H:]PZf2[H:]PZf2[8:/YZbV[:J/YZbV[:J/YZbV[:J/YP;G00>/YML08ML015PdF3@4F00?GUR2F89N
Pej3GX>2Ph:300>202Z8PZb2[8:/PZb2[8:/PZb2[8:/PZb2[8:/PP2V[:J/YZbV[:J/YZbV[:HC[003
0=OG00CG00<0emL00]L001;G00<0emL00mL00`3Ge`0We`@02ML05@29GhUOREn9GhUOREn9GhUOREn9
P`0:R@0M[HV]RJf9[HV]R:f8[Jb][:f/[Jb][:f/[Jb][:d02Z`01jJ/Y]2V[:H07mL00eSGe`02F01D
GUQNF5mHPej3GX>2Ph:3PX>2RH:9PZf2[H:]PZf2[H:]PZf2[JJ][:f/[Jb][:f/[J`0[:f/[Jb][:f/
[Jb][:f/[Jb][=6/dJcA[=6/dJc@[=2/0P06e`030=OG007G000Be`030=OG00;G00<0emL08mL500oG
1Ul0AFEOIEmUGhUOREn9GhUNREj9GXV2RH:9PXV2RH:9PZf2[H:]PZf2[H:]PZf2[8:/YZbV[:J/YZbV
[:J/YZbV[:F/YJbU[002e`03YJcG01[G00=HEeP01eP02UiHPUR2F89NPUh:PP0ZR8:/PZb2[8:/PZb2
[8:/PZb2[8:/PZb2[:H0YZbV[:J/YZbV[:J/YZbV4J`200?G00@0emL00mL0013G0`04e`807mL501GG
01J9GhUOREn9GhUOREn9GhUOREn9PhV328T07Jf9[HV]RJf8[HR]R:f8[Jb][:f/[Jb][:f/[Jb]00B/
00nV[:J/YZbV[:J/YZbV[:H00]L01JbVejJ/01?G05V2F89HPUR2F89HPeR3F8=NPh:3PX>2Ph:3PXV2
[H:]PZf2[H:]PZf2[H:]YZfV[JJ]YZf/[Jb][:f/0:b][:f/[Jb][:f/[Jb][:f/[JcA[=2/d:c@[=2/
d002e`030=OG00;G0P04e`004]L00`3Ge`02e`030=OG01[G100Le`0305mO00AO04aUGfEOREn9GXUN
REj9GXUNRH:9PXV2RH:9PXV2RH:]PZf2[H:]PZf2[8:/PZb2[8:/YZbV[:J/YZbV[:J/YJbU[:F/YJbU
YZFVYJJU0mL00h6VP@0=e`04EgaGO0EH00YNF5iHPUR2F89N3X80:Zb2[8:/PZb2[8:/PZb2[8:/PZb2
[8:/PZbV0:J/YZbV[:J/YZbV[:J/YPb/1ML00`3Ge`07e`005mL00`3Ge`0Ee`D08]L06XUOREn9GhUO
REn9GhUOREn9GhV3RH>9PhV30XT0>Zf9[HV]R:f8[HR]R:f8[Jb][:f/[Jb][:f/[JJ]YZbV[:J/YZbV
[:J/YZbV[:J/YZbV[:J/Y]NV[:D4YP;G04BVPZJ2YWb2O89lPUR2F89HPUR2F89NPej3PX>2Ph:3PX>2
Ph:]PZf2[H:]PZf2[H:]PZf2[JJ]YZfV[JJ][:f/[Jb][08000N][:f/[Jb]00N/00W@[=2/d:c@[=00
1mL00`3Ge`07e`005]L00`3Ge`0Ae`D0:ML7G`1^IEiUGXUNREj9GXUNREj9GXV2RH:9PXV2RH:9PZf2
[H:]PZf2[H:/PZb2[8:/PZb2[8:/PZbV[:J/YZbU[:F/YJbUYZFVYJJUYX6VPJJ1YX6VPJJ1PW^2Nh9k
PUN2EgaGO5R2F89HPUR2F89HPUP@PP0ZYX:/PZb2[8:/PZb2[8:/PZb2[8:/YZbV[:J/0:bV[:J/YZbV
[:J/YZbV1j`8e`030=OG00OG000Fe`030=OG00gG100_e`1@GhUOREn9GhUOREn9GhUOREn9PhV3RH>9
PhV3RH>]RJf9[HR]R:f8[HR]R:f8[Jb]YZfV[JJ]YZbV[:J/YZbV[:J/YZbV[:J/YZbV[:J/YZ`6YP08
PZJ2YX:VPZH2PP0?O89lPWb2F89HPUR2F89H00:202f3PX>2Ph:3PX>2Ph:]PZf2[H:]PZf2[H:]PZfV
[JJ]YZfV[JJ]YZf/[Jb][:d00Z`00`2/[00:[007d:c@[=2/d009e`030=OG00OG000Fe`802ML503GG
00<0Gel00Ul0KEiOGVENREj9GXUNREj9GXUNREj9PXV2RH:9PXV2RH:9PZf2[H:]PZb2[8:/PZb2[8:/
PZb2[8:/PZbV[:F/YJJUYZFVPJJ1YX6VPJJ1YX6VPJJ1YW^VNh9kPW^2Eh9GPUR2F89HPUR2F89HPUP0
4880;:J2YX:/PZb2[8:/PZb2[8:/PZb2[8:/YZbV[:J/0:bV[:J/YZbV[:J/YZbV0j`;e`030=OG00KG
000Fe`030=OG00?G1@0le`1<GhUOREn9GhUOREn9GhUOREn9PhV3RH>9PhV3RH>9PZf2[H:]PZf2[H:]
PZf2[JJ]YZfV[JJ/YZbV[:J/YZbV[:J/YZbV[:J/YZbV[0RV01N2YX:VPZJ2YWb2O89lPWb2O89HPWb2
O004PP0VPh:3PX>2Ph:3PZf2[H:]PZf2[H:]PZf2[H:]YZfV[JJ]YZfV[JH9[0030:b/00J/00K@[=2/
d:`=e`030=OG00KG000Ee`030=OG00@0@mL5G`1[GUmNGeiOGXUNREj9GXUNREj9PXV2RH:9PXV2RH:9
PZf2[H:]PZb2[8:/PZb2[8:/PZb2[8:/PZb2[8:VPZJ1YX6VPJJ1YX6VPJJ1YX6VPJJ1YW^2Nh9kPW^2
Eh9GPUR2F89HPUR2F89HPUP03880;JJ2YX:VPZJ2[8:/PZb2[8:/PZb2[8:/YZbV[:J/YZbV[02/YZbV
[:J/YZbV[00?e`030=OG00KG000Ee`<0B=L0BFEOIEn9GhUOREn9GhUOREn9PhV3RH>9PhV3RH>9PZf2
[H:]PZf2[H:]PZf2[H:]PZfV[JJ/YZbV[:J/YZbV[:J/YZbV[:J/YZ`01ZH02X:VPZJ2YX:VPZH2PP0=
O89lPWb2O89lPWb2O00:PP0PPh:WPZf2[H:]PZf2[H:]PZf2[H:]YZfV[:J/YZbV[:H;[0801j`00m3G
e`0>e`030=OG00KG00000mL0000200?G00<0emL00]L300OG0P19e`1]05mOGeiOGUmNGeiOGX=NPej9
GXUNREj9PXV2RH:9PXV2RH:9PXV2[H:/PZb2[8:/PZb2[8:/PZb2[8:VPZJ2YX6VPJJ1YX6VPJJ1YX6V
PJJ1YX6VNjIkPW^2Nh9kPUN2Eh9HPUR2F89HPWb2O00>PP0YYX:VPZJ2YX:/PZb2[8:/PZb2[8:/YZbV
[:J/YZbV[:J/YP2V[:J/YZ`04ML00`3Ge`06e`000mL00`3Ge`0:e`030=OG00KG0P19e`17IEmUGfEO
REn9GhUOREn9GhUORH>9PhV3RH>9PXV2[H:]PZf2[H:]PZf2[H:]PZf2[H:/YZbV[:J/YZbV[:J/YZbV
[:J/YZ`01:H05h:VPZJ2YX:VPZJ2YWb2O89lPWb2O89l00j2022VPZJ2[8:/PZb2[8:/PZb2[:J/YZbV
[:J/YZbV[:J/YPb/00@0[:b/5=L00`3Ge`05e`000mL00`3Ge`0:e`030=OG00SG0P19e`AO06ENGeiO
GUmNGej3GX=NREj9GXUNRH:9PXV2RH:9PXV2RH:/PZb2[8:/PZb2[8:/PZJ2YX:VPZJ2YX:VPJJ1YX6V
PJJ1YX6VPJJ1YX6VPJIkYW^2Nh9kPW^2Eh9HPUR2F89lPWb2O00<PP0WYX:VPZJ2YX:VPZb2[8:/PZb2
[8:/PZb2[:J/YZbV[:J/YZbV[:H001KG00<0emL01ML000?G00<0emL01mL300gG0P18e`14GfEOIEmU
GfEOREn9GhUOREn9PhV3RH>9PhV2RH:9PZf2[H:]PZf2[H:]PZf2[H:]PZb2[8:/YZbV[:J/YZbV[:J/
YZ`2YP0>PZJ2YX:VPZJ2YX:VPZH2PP09O89lPWb2O89l00j202:VPZJ2YX:/PZb2[8:/PZb2[8:/YZbV
[:J/YZbV[:J/YZbV2Z`2e`030=OG01?G00<0emL01ML000?G00<0emL01mL00`3Ge`0?e`80B=L0J00j
GeiOGUmNGeiOGUmNPej3GX=NPej3GXV2RH:9PXV2RH:9PXR2R8:/PZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ1
YX6VPJJ1YX6VPJJ1YX6VPJJ1YX62Nh9kPW^2Nh9kPWb2O89lPWb2O89l2X808jJ2YX:VPZJ2YX:VPZb2
[8:/PZb2[8:/YZbV[:J/YZbV[:J/00GG00<0emL04]L00`3Ge`05e`0000CG00002ML00`3Ge`0Ae`80
B=L0DUmUGfEOIEmUGfEOREn9GhUOREn9PhV2RH:9PXV2RH:]PZf2[H:]PZf2[H:]PZf2[8:/PZb2[8:/
PZb2[8:/PZb2YX:VPZJ2YX:VPZJ2YX:VPZHEPP0VYX:VPZJ2YX:VPZb2[8:/PZb2[:J/YZbV[:J/YZbV
[:J/YZbV[:H5[0OG0P0Be`030=OG00GG0003e`030=OG00OG100Be`80B=L08EljGcYO>UmNGeiOGUmN
Pej3GX=NPej3PX>2Ph:3PX>2P`05PP0nYX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ1YX6VPJJ1YX6VPJJ1
YX6VPJIkPW^2Nh9kPW^2O89lPWb2O89lPW`<PP0OYX:VPZJ2YX:VPZJ2[8:/PZb2[8:/YZbV[:J/YZbV
[00:e`030=OG013G00<0emL01=L002GG0P17e`03Gc]O00EO04UUGhUOREn9GhUOREn9PXV2RH:9PXV2
RH:]PZf2[H:]PZf2[H:]PZb2[8:/PZb2[8:/PZb2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:V01>202RVPZJ2
YX:VPZb2[8:/PZb2[8:/YZbV[:J/YZbV[:J/YZbV[:J/YZbV3ML00`3Ge`0?e`030=OG00CG000We`80
AmL083YO>UljGcYOGUmNGeiOGUmNPej3GX=NPej3PX>2Ph:32h80=ZJ2YX:VPZJ2YX:VPZJ2YX:VPJJ1
YX6VPJJ1YX6VPJJ1YW^2Nh9kPW^2Nh9kPW^2O89lPWb2O0Z201jVPZJ2YX:VPZJ2YX:VPZJ2[8:/PZb2
[8:/YZbV[:H?e`030=OG00kG00<0emL01=L002WG0P17e`04Gc]O>`QO0469GhUOREn9GhV2RH:9PXV2
RH:9PZf2[H:]PZf2[H:]PZb2[8:/PZb2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YP0APP0WYX:VPZJ2
YX:VPZJ2[8:/PZb2[8:/PZbV[:J/YZbV[:J/YZbV[:J/01;G00<0emL03ML00`3Ge`04e`00:mL204KG
01lk=3/jGcYO>UmNGeiOGUmNGej3GX=NPej3GX>2Ph:300n2032VPZJ2YX:VPZJ2YX6VPJJ1YX6VPJJ1
YX6VNjIkYW^2Nh9kPW^2Nh9kPW^2Nh9lPW`:PP0JYX:VPZJ2YX:VPZJ2YX:/PZb2[8:/PZbV[:HEe`03
0=OG00gG00<0emL00mL002gG0P16e`0505lkGc/02Ul0?H=OREn9GXV2RH:9PXV2RH:9PZf2[H:]PZf2
[8:/PZb2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH03H809JJ2YX:VPZJ2YX:VPZJ2YX:/PZb2
[8:/YZbV[:J/YZbV[:J/YZ`06=L200gG00<0emL00mL002oG0P16e`0M>c@k=5ldGcYO>UmNGeiOGUmN
Pej3GX=NPej3PX<04H80;:J2PX:VPZJ2YX:VPJJ1YX6VPJJ1YW^2NjIkPW^2Nh9kPW^2Nh9kPW^2O89l
28806:J2YX:VPZJ2YX:VPZJ2YX:VPZb2[8:/PQcG00<0emL02]L00`3Ge`03e`00<ML204KG0c/015lk
Gc/8G`0iPen3GX=NPh:9PXV2RH:9PXV2RH:9PZf2[8:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2
YX:V00^202>VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZb2[8:/YZbV[:J/YZbV[00Oe`030=OG00WG00<0emL0
0mL003?G0P15e`0L03/d>c@k=5ldGcYO>UmNGeiOGX=NPej3GX=NPa^202:VPH:1PX62PH9kPW^2Nh9k
PW^2Nh9kPW^2Nh9kPW^2Nh:11X805:J2YX:VPZJ2YX:VPZJ2YX:VPZJ28]L00`3Ge`08e`030=OG00?G
000ee`80AML013/@>cD2>`03Gc]O00EO03V3Gh=NPej3GX>2Ph:3PX>2Ph:3PX>2Yh:VPZJ2YX:VPZJ2
YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH02H807jJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2[8:/PZbV[:J/YZ`0
9ML00`3Ge`08e`030=OG00;G000ge`80AML06a0e43/d>cAO=5ldGcAOGUmNGej3GX=NPej3GP0IPP0g
PH:1PX62PH9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPX62PJJ2YX:VPZJ2YX:VPZJ2YX:VPP0Xe`03
0=OG00OG00<0emL00]L003WG0P15e`0:4A0k=3/eGc]O>`AO03F3GX=NPej3GX>2Ph:3PX>2Ph:3PX>2
Ph:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YP07PP0MYX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZb2
[8:/YZ`0:mL200OG00<0emL00]L003_G0P13e`0O0=OG4A0k43/d>cAO=5ldGeiOGUmNPej3GX=NPUj2
GP0EPP0aPH:1PW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh:1PX6VPJJ1YX:VPJJ2YX:VPP0_e`03
0=OG00CG00<0emL00]L003gG0P11e`030=OG00;G00D@>c@k=@02>`0KGc]OGUmNPej3GX=NPej3PX>2
Ph:3PX>2Ph:300>201^VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH01H806JJ2YX:VPZJ2YX:VPZJ2
YX:VPZJ2YX:VPZ`0<]L00`3Ge`03e`030=OG00;G000oe`80?mL00`3Ge`05e`0K43D@>c@k=5ldGeQO
F5mHGej3GX=NPUj2GX9N01>202]lPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh:1PX6VPJJ1YX6V
PJJ103GG00<0emL00mL00`3Ge`01e`00@ML203gG00<0emL02ML07C/dGcAO=5mNGej3GX=NPej3GX>2
Ph:3PX>2Ph:300N201FVPZJ2YX:VPZJ2YX:VPZJ2YX:VPZH01H805JJ2YX:VPZJ2YX:VPZJ2YX:VPZJ2
YP0he`030=OG00;G00<0emL00ML004?G0P0ke`030=OG00cG01Hk=3/dGcAOF5mHGeR3F89HPUR2GX9N
2h80:gb2O89lPWb2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPX62PJJ1YX40?ML01@3GemL000?G
0015e`80>ML00`3Ge`0@e`0F=5mNGeiOGUmNPej3GX=NPh:3PX>2P`n200nVPZJ2YX:VPZJ2YX:VPZH0
0h803jJ2YX:VPZJ2YX:VPZJ2YP10e`8000?G0=L00]L004OG0P0ge`030=OG01?G03ldGcAOF5mHGeR2
F89HPUR2F89HPUR2O89lPWb2O89lPWb2O89kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW/0A]L00`3G
0002e`00BML203GG00<0emL05mL04EmNGej3GX=NPej3PX>2Ph:300n201VVPZJ2YX:VPZJ2YX:VPZJ2
YX:VPZJ2YX:V04WG0P02e`00BmL203;G00<0emL07ML0<5mHGUQNF89HPUR2F89HPUR2F89lPWb2O89l
PWb2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nd_G1002e`00CML2033G00<0emL08ML02Uj3GX=NPej3PX<EPP07
YX:VPZJ2YP1;e`H01]L004oG0P0^e`030=OG02WG01V2F89HPUR2F89lPWb2O89lPW^2Nh9kPW^204[G
1P0<e`00DML202cG00<0emL0QML701;G001Ce`80:]L00`3Ge`1oe`H06ML005GG0P0Xe`030=OG07WG
1P0Oe`00EmL202KG00<0emL0L]L702GG001Ie`809=L00`3Ge`1/e`H0;=L005_G0P0Re`030=OG06GG
1`0be`00GML2023G00<0emL0GmL603WG001Oe`807]L00`3Ge`1Ie`H0?mL0067G0P0Le`030=OG05;G
1`15e`00HmL201[G00<0emL0C=L604cG001Ue`806=L00`3Ge`16e`H0D]L006OG0P0Fe`030=OG03oG
1`1He`00JML201CG00<0emL0>ML605oG001[e`804]L00`3Ge`0ce`H0IML006gG0P0?e`030=OG02gG
1`1[e`00KmL200gG00<0emL09mL607;G001ae`802mL00`3Ge`0Pe`L0N=L007?G0P09e`030=OG01[G
1P1oe`00MML200OG00<0emL05=L608GG001ge`801ML00`3Ge`0=e`L0RmL007WG0P03e`030=OG00OG
1P2Be`00NmL20003e`3G00;G1P2He`00OML509kG0000\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.0768164, 0.0016712, \
0.0036026, 0.00584438}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[PD3,ViewPoint->{0.,0.,2.},AspectRatio->0.5]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1 8.32667e-17 0.5 [
[0 -0.00625 -6 -9 ]
[0 -0.00625 6 0 ]
[.25 -0.00625 -6 -9 ]
[.25 -0.00625 6 0 ]
[.5 -0.00625 -3 -9 ]
[.5 -0.00625 3 0 ]
[.75 -0.00625 -3 -9 ]
[.75 -0.00625 3 0 ]
[1 -0.00625 -3 -9 ]
[1 -0.00625 3 0 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -6 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[.07841 .04545 -6 -4.5 ]
[.07841 .04545 0 4.5 ]
[.05202 .03226 -18 -4.5 ]
[.05202 .03226 0 4.5 ]
[.02198 .01724 -6 -4.5 ]
[.02198 .01724 0 4.5 ]
[-0.0125 0 -18 -4.5 ]
[-0.0125 0 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .00313 L
s
[(-4)] 0 -0.00625 0 1 Mshowa
.25 0 m
.25 .00313 L
s
[(-2)] .25 -0.00625 0 1 Mshowa
.5 0 m
.5 .00313 L
s
[(0)] .5 -0.00625 0 1 Mshowa
.75 0 m
.75 .00313 L
s
[(2)] .75 -0.00625 0 1 Mshowa
1 0 m
1 .00313 L
s
[(4)] 1 -0.00625 0 1 Mshowa
.125 Mabswid
.0625 0 m
.0625 .00188 L
s
.125 0 m
.125 .00188 L
s
.1875 0 m
.1875 .00188 L
s
.3125 0 m
.3125 .00188 L
s
.375 0 m
.375 .00188 L
s
.4375 0 m
.4375 .00188 L
s
.5625 0 m
.5625 .00188 L
s
.625 0 m
.625 .00188 L
s
.6875 0 m
.6875 .00188 L
s
.8125 0 m
.8125 .00188 L
s
.875 0 m
.875 .00188 L
s
.9375 0 m
.9375 .00188 L
s
.25 Mabswid
0 0 m
0 .5 L
s
0 0 m
.00625 0 L
s
[(-2)] -0.0125 0 1 0 Mshowa
0 .125 m
.00625 .125 L
s
[(-1)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(2)] -0.0125 .5 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
.25 Mabswid
.09091 .04545 m
0 0 L
s
.09091 .04545 m
.09716 .04545 L
s
[(0)] .07841 .04545 1 0 Mshowa
.06452 .03226 m
.07077 .03226 L
s
[(0.5)] .05202 .03226 1 0 Mshowa
.03448 .01724 m
.04073 .01724 L
s
[(1)] .02198 .01724 1 0 Mshowa
0 0 m
.00625 0 L
s
[(1.5)] -0.0125 0 1 0 Mshowa
.125 Mabswid
.08589 .04294 m
.08964 .04294 L
s
.08075 .04037 m
.0845 .04037 L
s
.07547 .03774 m
.07922 .03774 L
s
.07006 .03503 m
.07381 .03503 L
s
.05882 .02941 m
.06257 .02941 L
s
.05298 .02649 m
.05673 .02649 L
s
.04698 .02349 m
.05073 .02349 L
s
.04082 .02041 m
.04457 .02041 L
s
.02797 .01399 m
.03172 .01399 L
s
.02128 .01064 m
.02503 .01064 L
s
.01439 .00719 m
.01814 .00719 L
s
.0073 .00365 m
.01105 .00365 L
s
.25 Mabswid
.09091 .04545 m
0 0 L
s
0 0 m
0 .5 L
s
0 .5 m
.09091 .45455 L
s
.09091 .45455 m
.09091 .04545 L
s
.90909 .04545 m
.90909 .45455 L
s
.90909 .45455 m
1 .5 L
s
1 .5 m
1 0 L
s
1 0 m
.90909 .04545 L
s
.09091 .04545 m
0 0 L
s
0 0 m
1 0 L
s
1 0 m
.90909 .04545 L
s
.90909 .04545 m
.09091 .04545 L
s
.09091 .45455 m
.90909 .45455 L
s
.90909 .45455 m
1 .5 L
s
1 .5 m
0 .5 L
s
0 .5 m
.09091 .45455 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.338 .276 .64 r
.0909 .04545 .0909 .05063 .09937 .04968 .09932 .04446 Mtetra
.342 .285 .648 r
.09932 .04446 .09937 .04968 .10792 .04873 .10783 .04346 Mtetra
.345 .293 .656 r
.10783 .04346 .10792 .04873 .11657 .04778 .11643 .04245 Mtetra
.349 .302 .664 r
.11643 .04245 .11657 .04778 .1253 .04682 .12513 .04145 Mtetra
.354 .312 .672 r
.12513 .04145 .1253 .04682 .13414 .04586 .13392 .04043 Mtetra
.359 .322 .68 r
.13392 .04043 .13414 .04586 .14307 .0449 .14282 .03942 Mtetra
.365 .332 .689 r
.14282 .03942 .14307 .0449 .1521 .04394 .15181 .03841 Mtetra
.371 .343 .697 r
.15181 .03841 .1521 .04394 .16124 .04298 .16091 .0374 Mtetra
.378 .353 .705 r
.16091 .0374 .16124 .04298 .17048 .04202 .17012 .03639 Mtetra
.385 .365 .714 r
.17012 .03639 .17048 .04202 .17983 .04108 .17944 .03539 Mtetra
.392 .377 .722 r
.17944 .03539 .17983 .04108 .1893 .04014 .18888 .0344 Mtetra
.4 .389 .731 r
.18888 .0344 .1893 .04014 .19887 .03921 .19842 .03341 Mtetra
.409 .401 .74 r
.19842 .03341 .19887 .03921 .20856 .03829 .20808 .03244 Mtetra
.417 .414 .748 r
.20808 .03244 .20856 .03829 .21836 .03739 .21785 .03148 Mtetra
.426 .427 .757 r
.21785 .03148 .21836 .03739 .22827 .0365 .22775 .03053 Mtetra
.435 .441 .766 r
.22775 .03053 .22827 .0365 .2383 .03563 .23775 .0296 Mtetra
.445 .454 .775 r
.23775 .0296 .2383 .03563 .24845 .03478 .24787 .02869 Mtetra
.454 .469 .784 r
.24787 .02869 .24845 .03478 .2587 .03396 .25811 .0278 Mtetra
.464 .483 .793 r
.25811 .0278 .2587 .03396 .26907 .03315 .26846 .02693 Mtetra
.474 .498 .802 r
.26846 .02693 .26907 .03315 .27955 .03238 .27893 .02609 Mtetra
.484 .512 .811 r
.27893 .02609 .27955 .03238 .29014 .03163 .2895 .02528 Mtetra
.495 .527 .82 r
.2895 .02528 .29014 .03163 .30083 .03091 .30019 .0245 Mtetra
.505 .542 .828 r
.30019 .0245 .30083 .03091 .31163 .03023 .31098 .02375 Mtetra
.515 .557 .837 r
.31098 .02375 .31163 .03023 .32252 .02958 .32187 .02303 Mtetra
.525 .573 .846 r
.32187 .02303 .32252 .02958 .33351 .02897 .33286 .02235 Mtetra
.535 .587 .854 r
.33286 .02235 .33351 .02897 .34459 .02839 .34395 .0217 Mtetra
.545 .602 .862 r
.34395 .0217 .34459 .02839 .35575 .02786 .35512 .02109 Mtetra
.554 .617 .87 r
.35512 .02109 .35575 .02786 .367 .02736 .36638 .02053 Mtetra
.563 .631 .877 r
.36638 .02053 .367 .02736 .37832 .02691 .37772 .02 Mtetra
.571 .645 .885 r
.37772 .02 .37832 .02691 .3897 .0265 .38914 .01952 Mtetra
.58 .659 .892 r
.38914 .01952 .3897 .0265 .40115 .02613 .40062 .01908 Mtetra
.588 .672 .898 r
.40062 .01908 .40115 .02613 .41265 .02581 .41216 .01868 Mtetra
.596 .685 .904 r
.41216 .01868 .41265 .02581 .4242 .02553 .42375 .01833 Mtetra
.603 .698 .91 r
.42375 .01833 .4242 .02553 .4358 .02529 .4354 .01803 Mtetra
.611 .71 .915 r
.4354 .01803 .4358 .02529 .44743 .02511 .44709 .01778 Mtetra
.619 .723 .92 r
.44709 .01778 .44743 .02511 .45909 .02497 .45881 .01758 Mtetra
.628 .736 .925 r
.45881 .01758 .45909 .02497 .47077 .02489 .47056 .01745 Mtetra
.638 .749 .929 r
.47056 .01745 .47077 .02489 .48246 .02488 .48233 .01738 Mtetra
.649 .762 .932 r
.48233 .01738 .48246 .02488 .49415 .02493 .49411 .01739 Mtetra
.645 .764 .935 r
.49411 .01739 .49415 .02493 .50585 .02493 .50589 .01739 Mtetra
.94 .774 .648 r
.90068 .04446 .90063 .04968 .9091 .05063 .9091 .04545 Mtetra
.939 .778 .655 r
.89217 .04346 .89208 .04873 .90063 .04968 .90068 .04446 Mtetra
.937 .782 .663 r
.88357 .04245 .88343 .04778 .89208 .04873 .89217 .04346 Mtetra
.935 .786 .671 r
.87487 .04145 .8747 .04682 .88343 .04778 .88357 .04245 Mtetra
.933 .79 .679 r
.86608 .04043 .86586 .04586 .8747 .04682 .87487 .04145 Mtetra
.931 .794 .687 r
.85718 .03942 .85693 .0449 .86586 .04586 .86608 .04043 Mtetra
.928 .797 .695 r
.84819 .03841 .8479 .04394 .85693 .0449 .85718 .03942 Mtetra
.925 .8 .704 r
.83909 .0374 .83876 .04298 .8479 .04394 .84819 .03841 Mtetra
.921 .803 .712 r
.82988 .03639 .82952 .04202 .83876 .04298 .83909 .0374 Mtetra
.917 .805 .721 r
.82056 .03539 .82017 .04108 .82952 .04202 .82988 .03639 Mtetra
.913 .807 .729 r
.81112 .0344 .8107 .04014 .82017 .04108 .82056 .03539 Mtetra
.908 .809 .738 r
.80158 .03341 .80113 .03921 .8107 .04014 .81112 .0344 Mtetra
.903 .811 .746 r
.79192 .03244 .79144 .03829 .80113 .03921 .80158 .03341 Mtetra
.898 .812 .755 r
.78215 .03148 .78164 .03739 .79144 .03829 .79192 .03244 Mtetra
.892 .814 .764 r
.77225 .03053 .77173 .0365 .78164 .03739 .78215 .03148 Mtetra
.886 .815 .773 r
.76225 .0296 .7617 .03563 .77173 .0365 .77225 .03053 Mtetra
.879 .815 .782 r
.75213 .02869 .75155 .03478 .7617 .03563 .76225 .0296 Mtetra
.872 .816 .791 r
.74189 .0278 .7413 .03396 .75155 .03478 .75213 .02869 Mtetra
.865 .816 .8 r
.73154 .02693 .73093 .03315 .7413 .03396 .74189 .0278 Mtetra
.857 .816 .809 r
.72107 .02609 .72045 .03238 .73093 .03315 .73154 .02693 Mtetra
.848 .816 .818 r
.7105 .02528 .70986 .03163 .72045 .03238 .72107 .02609 Mtetra
.839 .815 .826 r
.69981 .0245 .69917 .03091 .70986 .03163 .7105 .02528 Mtetra
.83 .815 .835 r
.68902 .02375 .68837 .03023 .69917 .03091 .69981 .0245 Mtetra
.82 .814 .844 r
.67813 .02303 .67748 .02958 .68837 .03023 .68902 .02375 Mtetra
.81 .812 .852 r
.66714 .02235 .66649 .02897 .67748 .02958 .67813 .02303 Mtetra
.8 .811 .86 r
.65605 .0217 .65541 .02839 .66649 .02897 .66714 .02235 Mtetra
.789 .809 .868 r
.64488 .02109 .64425 .02786 .65541 .02839 .65605 .0217 Mtetra
.778 .807 .876 r
.63362 .02053 .633 .02736 .64425 .02786 .64488 .02109 Mtetra
.767 .805 .883 r
.62228 .02 .62168 .02691 .633 .02736 .63362 .02053 Mtetra
.756 .803 .89 r
.61086 .01952 .6103 .0265 .62168 .02691 .62228 .02 Mtetra
.745 .801 .897 r
.59938 .01908 .59885 .02613 .6103 .0265 .61086 .01952 Mtetra
.734 .798 .903 r
.58784 .01868 .58735 .02581 .59885 .02613 .59938 .01908 Mtetra
.722 .795 .909 r
.57625 .01833 .5758 .02553 .58735 .02581 .58784 .01868 Mtetra
.71 .791 .915 r
.5646 .01803 .5642 .02529 .5758 .02553 .57625 .01833 Mtetra
.698 .787 .92 r
.55291 .01778 .55257 .02511 .5642 .02529 .5646 .01803 Mtetra
.686 .783 .924 r
.54119 .01758 .54091 .02497 .55257 .02511 .55291 .01778 Mtetra
.673 .777 .928 r
.52944 .01745 .52923 .02489 .54091 .02497 .54119 .01758 Mtetra
.659 .771 .932 r
.51767 .01738 .51754 .02488 .52923 .02489 .52944 .01745 Mtetra
.643 .762 .935 r
.50589 .01739 .50585 .02493 .51754 .02488 .51767 .01738 Mtetra
.349 .285 .643 r
.0909 .05063 .0909 .05581 .09941 .05491 .09937 .04968 Mtetra
.352 .293 .651 r
.09937 .04968 .09941 .05491 .10801 .05401 .10792 .04873 Mtetra
.355 .301 .659 r
.10792 .04873 .10801 .05401 .1167 .0531 .11657 .04778 Mtetra
.36 .31 .667 r
.11657 .04778 .1167 .0531 .12547 .05219 .1253 .04682 Mtetra
.364 .32 .675 r
.1253 .04682 .12547 .05219 .13434 .05127 .13414 .04586 Mtetra
.369 .329 .683 r
.13414 .04586 .13434 .05127 .14331 .05036 .14307 .0449 Mtetra
.375 .339 .691 r
.14307 .0449 .14331 .05036 .15238 .04945 .1521 .04394 Mtetra
.381 .35 .699 r
.1521 .04394 .15238 .04945 .16155 .04854 .16124 .04298 Mtetra
.388 .361 .707 r
.16124 .04298 .16155 .04854 .17083 .04764 .17048 .04202 Mtetra
.395 .372 .716 r
.17048 .04202 .17083 .04764 .18021 .04675 .17983 .04108 Mtetra
.403 .384 .724 r
.17983 .04108 .18021 .04675 .18971 .04586 .1893 .04014 Mtetra
.41 .396 .733 r
.1893 .04014 .18971 .04586 .19931 .04498 .19887 .03921 Mtetra
.419 .409 .741 r
.19887 .03921 .19931 .04498 .20903 .04412 .20856 .03829 Mtetra
.428 .421 .75 r
.20856 .03829 .20903 .04412 .21885 .04327 .21836 .03739 Mtetra
.437 .435 .759 r
.21836 .03739 .21885 .04327 .22879 .04244 .22827 .0365 Mtetra
.446 .448 .768 r
.22827 .0365 .22879 .04244 .23884 .04163 .2383 .03563 Mtetra
.456 .462 .776 r
.2383 .03563 .23884 .04163 .24901 .04084 .24845 .03478 Mtetra
.466 .476 .785 r
.24845 .03478 .24901 .04084 .25928 .04007 .2587 .03396 Mtetra
.476 .491 .794 r
.2587 .03396 .25928 .04007 .26967 .03933 .26907 .03315 Mtetra
.486 .506 .803 r
.26907 .03315 .26967 .03933 .28016 .03862 .27955 .03238 Mtetra
.496 .521 .812 r
.27955 .03238 .28016 .03862 .29076 .03793 .29014 .03163 Mtetra
.507 .536 .821 r
.29014 .03163 .29076 .03793 .30146 .03728 .30083 .03091 Mtetra
.517 .551 .829 r
.30083 .03091 .30146 .03728 .31226 .03666 .31163 .03023 Mtetra
.528 .566 .838 r
.31163 .03023 .31226 .03666 .32316 .03608 .32252 .02958 Mtetra
.538 .581 .846 r
.32252 .02958 .32316 .03608 .33414 .03553 .33351 .02897 Mtetra
.548 .597 .855 r
.33351 .02897 .33414 .03553 .34522 .03502 .34459 .02839 Mtetra
.557 .611 .863 r
.34459 .02839 .34522 .03502 .35637 .03455 .35575 .02786 Mtetra
.567 .626 .87 r
.35575 .02786 .35637 .03455 .3676 .03413 .367 .02736 Mtetra
.576 .641 .878 r
.367 .02736 .3676 .03413 .3789 .03374 .37832 .02691 Mtetra
.584 .655 .885 r
.37832 .02691 .3789 .03374 .39026 .0334 .3897 .0265 Mtetra
.593 .668 .892 r
.3897 .0265 .39026 .0334 .40167 .0331 .40115 .02613 Mtetra
.6 .681 .898 r
.40115 .02613 .40167 .0331 .41314 .03284 .41265 .02581 Mtetra
.608 .694 .904 r
.41265 .02581 .41314 .03284 .42464 .03263 .4242 .02553 Mtetra
.615 .706 .91 r
.4242 .02553 .42464 .03263 .43619 .03245 .4358 .02529 Mtetra
.623 .719 .915 r
.4358 .02529 .43619 .03245 .44776 .03233 .44743 .02511 Mtetra
.63 .731 .92 r
.44743 .02511 .44776 .03233 .45935 .03225 .45909 .02497 Mtetra
.639 .743 .924 r
.45909 .02497 .45935 .03225 .47096 .03222 .47077 .02489 Mtetra
.648 .755 .928 r
.47077 .02489 .47096 .03222 .48258 .03225 .48246 .02488 Mtetra
.658 .768 .931 r
.48246 .02488 .48258 .03225 .4942 .03235 .49415 .02493 Mtetra
.646 .763 .934 r
.49415 .02493 .4942 .03235 .5058 .03235 .50585 .02493 Mtetra
.936 .77 .651 r
.90063 .04968 .90059 .05491 .9091 .05581 .9091 .05063 Mtetra
.935 .775 .658 r
.89208 .04873 .89199 .05401 .90059 .05491 .90063 .04968 Mtetra
.934 .779 .666 r
.88343 .04778 .8833 .0531 .89199 .05401 .89208 .04873 Mtetra
.932 .783 .674 r
.8747 .04682 .87453 .05219 .8833 .0531 .88343 .04778 Mtetra
.929 .787 .682 r
.86586 .04586 .86566 .05127 .87453 .05219 .8747 .04682 Mtetra
.927 .79 .69 r
.85693 .0449 .85669 .05036 .86566 .05127 .86586 .04586 Mtetra
.924 .793 .698 r
.8479 .04394 .84762 .04945 .85669 .05036 .85693 .0449 Mtetra
.921 .796 .706 r
.83876 .04298 .83845 .04854 .84762 .04945 .8479 .04394 Mtetra
.917 .798 .714 r
.82952 .04202 .82917 .04764 .83845 .04854 .83876 .04298 Mtetra
.913 .801 .722 r
.82017 .04108 .81979 .04675 .82917 .04764 .82952 .04202 Mtetra
.909 .803 .731 r
.8107 .04014 .81029 .04586 .81979 .04675 .82017 .04108 Mtetra
.904 .805 .739 r
.80113 .03921 .80069 .04498 .81029 .04586 .8107 .04014 Mtetra
.899 .806 .748 r
.79144 .03829 .79097 .04412 .80069 .04498 .80113 .03921 Mtetra
.893 .808 .757 r
.78164 .03739 .78115 .04327 .79097 .04412 .79144 .03829 Mtetra
.887 .809 .765 r
.77173 .0365 .77121 .04244 .78115 .04327 .78164 .03739 Mtetra
.881 .809 .774 r
.7617 .03563 .76116 .04163 .77121 .04244 .77173 .0365 Mtetra
.874 .81 .783 r
.75155 .03478 .75099 .04084 .76116 .04163 .7617 .03563 Mtetra
.867 .81 .792 r
.7413 .03396 .74072 .04007 .75099 .04084 .75155 .03478 Mtetra
.859 .81 .801 r
.73093 .03315 .73033 .03933 .74072 .04007 .7413 .03396 Mtetra
.851 .81 .81 r
.72045 .03238 .71984 .03862 .73033 .03933 .73093 .03315 Mtetra
.842 .809 .819 r
.70986 .03163 .70924 .03793 .71984 .03862 .72045 .03238 Mtetra
.833 .809 .827 r
.69917 .03091 .69854 .03728 .70924 .03793 .70986 .03163 Mtetra
.823 .808 .836 r
.68837 .03023 .68774 .03666 .69854 .03728 .69917 .03091 Mtetra
.813 .806 .845 r
.67748 .02958 .67684 .03608 .68774 .03666 .68837 .03023 Mtetra
.803 .805 .853 r
.66649 .02897 .66586 .03553 .67684 .03608 .67748 .02958 Mtetra
.792 .803 .861 r
.65541 .02839 .65478 .03502 .66586 .03553 .66649 .02897 Mtetra
.781 .801 .869 r
.64425 .02786 .64363 .03455 .65478 .03502 .65541 .02839 Mtetra
.77 .799 .876 r
.633 .02736 .6324 .03413 .64363 .03455 .64425 .02786 Mtetra
.759 .797 .884 r
.62168 .02691 .6211 .03374 .6324 .03413 .633 .02736 Mtetra
.747 .794 .891 r
.6103 .0265 .60974 .0334 .6211 .03374 .62168 .02691 Mtetra
.736 .792 .897 r
.59885 .02613 .59833 .0331 .60974 .0334 .6103 .0265 Mtetra
.724 .789 .903 r
.58735 .02581 .58686 .03284 .59833 .0331 .59885 .02613 Mtetra
.713 .786 .909 r
.5758 .02553 .57536 .03263 .58686 .03284 .58735 .02581 Mtetra
.701 .783 .915 r
.5642 .02529 .56381 .03245 .57536 .03263 .5758 .02553 Mtetra
.69 .779 .919 r
.55257 .02511 .55224 .03233 .56381 .03245 .5642 .02529 Mtetra
.677 .774 .924 r
.54091 .02497 .54065 .03225 .55224 .03233 .55257 .02511 Mtetra
.665 .769 .928 r
.52923 .02489 .52904 .03222 .54065 .03225 .54091 .02497 Mtetra
.651 .762 .931 r
.51754 .02488 .51742 .03225 .52904 .03222 .52923 .02489 Mtetra
.635 .754 .934 r
.50585 .02493 .5058 .03235 .51742 .03225 .51754 .02488 Mtetra
.359 .293 .646 r
.0909 .05581 .0909 .06099 .09946 .06013 .09941 .05491 Mtetra
.362 .301 .654 r
.09941 .05491 .09946 .06013 .1081 .05927 .10801 .05401 Mtetra
.365 .309 .662 r
.10801 .05401 .1081 .05927 .11682 .05841 .1167 .0531 Mtetra
.369 .318 .669 r
.1167 .0531 .11682 .05841 .12564 .05755 .12547 .05219 Mtetra
.374 .327 .677 r
.12547 .05219 .12564 .05755 .13455 .05668 .13434 .05127 Mtetra
.379 .337 .685 r
.13434 .05127 .13455 .05668 .14355 .05582 .14331 .05036 Mtetra
.385 .347 .693 r
.14331 .05036 .14355 .05582 .15266 .05495 .15238 .04945 Mtetra
.391 .357 .701 r
.15238 .04945 .15266 .05495 .16186 .0541 .16155 .04854 Mtetra
.398 .368 .709 r
.16155 .04854 .16186 .0541 .17117 .05324 .17083 .04764 Mtetra
.405 .379 .717 r
.17083 .04764 .17117 .05324 .18059 .0524 .18021 .04675 Mtetra
.412 .391 .726 r
.18021 .04675 .18059 .0524 .19011 .05156 .18971 .04586 Mtetra
.42 .403 .734 r
.18971 .04586 .19011 .05156 .19974 .05074 .19931 .04498 Mtetra
.429 .416 .743 r
.19931 .04498 .19974 .05074 .20948 .04993 .20903 .04412 Mtetra
.438 .429 .751 r
.20903 .04412 .20948 .04993 .21934 .04913 .21885 .04327 Mtetra
.447 .442 .76 r
.21885 .04327 .21934 .04913 .2293 .04836 .22879 .04244 Mtetra
.457 .456 .769 r
.22879 .04244 .2293 .04836 .23937 .0476 .23884 .04163 Mtetra
.466 .47 .778 r
.23884 .04163 .23937 .0476 .24956 .04686 .24901 .04084 Mtetra
.477 .484 .786 r
.24901 .04084 .24956 .04686 .25985 .04615 .25928 .04007 Mtetra
.487 .499 .795 r
.25928 .04007 .25985 .04615 .27025 .04547 .26967 .03933 Mtetra
.497 .514 .804 r
.26967 .03933 .27025 .04547 .28076 .04481 .28016 .03862 Mtetra
.508 .529 .813 r
.28016 .03862 .28076 .04481 .29137 .04419 .29076 .03793 Mtetra
.519 .544 .821 r
.29076 .03793 .29137 .04419 .30208 .04359 .30146 .03728 Mtetra
.529 .559 .83 r
.30146 .03728 .30208 .04359 .31288 .04304 .31226 .03666 Mtetra
.54 .575 .839 r
.31226 .03666 .31288 .04304 .32378 .04251 .32316 .03608 Mtetra
.55 .59 .847 r
.32316 .03608 .32378 .04251 .33476 .04203 .33414 .03553 Mtetra
.561 .605 .855 r
.33414 .03553 .33476 .04203 .34583 .04159 .34522 .03502 Mtetra
.57 .62 .863 r
.34522 .03502 .34583 .04159 .35697 .04118 .35637 .03455 Mtetra
.58 .635 .871 r
.35637 .03455 .35697 .04118 .36819 .04082 .3676 .03413 Mtetra
.589 .65 .878 r
.3676 .03413 .36819 .04082 .37947 .0405 .3789 .03374 Mtetra
.597 .664 .885 r
.3789 .03374 .37947 .0405 .3908 .04022 .39026 .0334 Mtetra
.605 .677 .892 r
.39026 .0334 .3908 .04022 .40218 .03998 .40167 .0331 Mtetra
.613 .69 .898 r
.40167 .0331 .40218 .03998 .41361 .03979 .41314 .03284 Mtetra
.62 .703 .904 r
.41314 .03284 .41361 .03979 .42507 .03963 .42464 .03263 Mtetra
.627 .715 .909 r
.42464 .03263 .42507 .03963 .43657 .03952 .43619 .03245 Mtetra
.634 .726 .914 r
.43619 .03245 .43657 .03952 .44808 .03945 .44776 .03233 Mtetra
.641 .738 .919 r
.44776 .03233 .44808 .03945 .45961 .03942 .45935 .03225 Mtetra
.649 .749 .923 r
.45935 .03225 .45961 .03942 .47116 .03944 .47096 .03222 Mtetra
.657 .761 .927 r
.47096 .03222 .47116 .03944 .4827 .03951 .48258 .03225 Mtetra
.667 .774 .929 r
.48258 .03225 .4827 .03951 .49424 .03964 .4942 .03235 Mtetra
.647 .761 .933 r
.4942 .03235 .49424 .03964 .50576 .03964 .5058 .03235 Mtetra
.933 .767 .654 r
.90059 .05491 .90054 .06013 .9091 .06099 .9091 .05581 Mtetra
.931 .771 .661 r
.89199 .05401 .8919 .05927 .90054 .06013 .90059 .05491 Mtetra
.93 .776 .669 r
.8833 .0531 .88318 .05841 .8919 .05927 .89199 .05401 Mtetra
.928 .779 .676 r
.87453 .05219 .87436 .05755 .88318 .05841 .8833 .0531 Mtetra
.926 .783 .684 r
.86566 .05127 .86545 .05668 .87436 .05755 .87453 .05219 Mtetra
.923 .786 .692 r
.85669 .05036 .85645 .05582 .86545 .05668 .86566 .05127 Mtetra
.92 .789 .7 r
.84762 .04945 .84734 .05495 .85645 .05582 .85669 .05036 Mtetra
.917 .792 .708 r
.83845 .04854 .83814 .0541 .84734 .05495 .84762 .04945 Mtetra
.913 .794 .716 r
.82917 .04764 .82883 .05324 .83814 .0541 .83845 .04854 Mtetra
.909 .797 .724 r
.81979 .04675 .81941 .0524 .82883 .05324 .82917 .04764 Mtetra
.905 .798 .732 r
.81029 .04586 .80989 .05156 .81941 .0524 .81979 .04675 Mtetra
.9 .8 .741 r
.80069 .04498 .80026 .05074 .80989 .05156 .81029 .04586 Mtetra
.894 .801 .749 r
.79097 .04412 .79052 .04993 .80026 .05074 .80069 .04498 Mtetra
.889 .803 .758 r
.78115 .04327 .78066 .04913 .79052 .04993 .79097 .04412 Mtetra
.883 .803 .767 r
.77121 .04244 .7707 .04836 .78066 .04913 .78115 .04327 Mtetra
.876 .804 .775 r
.76116 .04163 .76063 .0476 .7707 .04836 .77121 .04244 Mtetra
.869 .804 .784 r
.75099 .04084 .75044 .04686 .76063 .0476 .76116 .04163 Mtetra
.861 .804 .793 r
.74072 .04007 .74015 .04615 .75044 .04686 .75099 .04084 Mtetra
.853 .804 .802 r
.73033 .03933 .72975 .04547 .74015 .04615 .74072 .04007 Mtetra
.845 .804 .811 r
.71984 .03862 .71924 .04481 .72975 .04547 .73033 .03933 Mtetra
.836 .803 .819 r
.70924 .03793 .70863 .04419 .71924 .04481 .71984 .03862 Mtetra
.826 .802 .828 r
.69854 .03728 .69792 .04359 .70863 .04419 .70924 .03793 Mtetra
.816 .8 .837 r
.68774 .03666 .68712 .04304 .69792 .04359 .69854 .03728 Mtetra
.806 .799 .845 r
.67684 .03608 .67622 .04251 .68712 .04304 .68774 .03666 Mtetra
.795 .797 .853 r
.66586 .03553 .66524 .04203 .67622 .04251 .67684 .03608 Mtetra
.784 .795 .861 r
.65478 .03502 .65417 .04159 .66524 .04203 .66586 .03553 Mtetra
.773 .793 .869 r
.64363 .03455 .64303 .04118 .65417 .04159 .65478 .03502 Mtetra
.761 .791 .877 r
.6324 .03413 .63181 .04082 .64303 .04118 .64363 .03455 Mtetra
.75 .788 .884 r
.6211 .03374 .62053 .0405 .63181 .04082 .6324 .03413 Mtetra
.738 .786 .891 r
.60974 .0334 .6092 .04022 .62053 .0405 .6211 .03374 Mtetra
.727 .783 .897 r
.59833 .0331 .59782 .03998 .6092 .04022 .60974 .0334 Mtetra
.715 .78 .903 r
.58686 .03284 .58639 .03979 .59782 .03998 .59833 .0331 Mtetra
.704 .777 .909 r
.57536 .03263 .57493 .03963 .58639 .03979 .58686 .03284 Mtetra
.692 .774 .914 r
.56381 .03245 .56343 .03952 .57493 .03963 .57536 .03263 Mtetra
.681 .77 .919 r
.55224 .03233 .55192 .03945 .56343 .03952 .56381 .03245 Mtetra
.669 .766 .923 r
.54065 .03225 .54039 .03942 .55192 .03945 .55224 .03233 Mtetra
.656 .761 .927 r
.52904 .03222 .52884 .03944 .54039 .03942 .54065 .03225 Mtetra
.643 .754 .93 r
.51742 .03225 .5173 .03951 .52884 .03944 .52904 .03222 Mtetra
.628 .746 .932 r
.5058 .03235 .50576 .03964 .5173 .03951 .51742 .03225 Mtetra
.369 .301 .649 r
.0909 .06099 .0909 .06616 .0995 .06535 .09946 .06013 Mtetra
.372 .309 .657 r
.09946 .06013 .0995 .06535 .10818 .06454 .1081 .05927 Mtetra
.375 .317 .664 r
.1081 .05927 .10818 .06454 .11695 .06372 .11682 .05841 Mtetra
.379 .326 .672 r
.11682 .05841 .11695 .06372 .1258 .0629 .12564 .05755 Mtetra
.383 .335 .679 r
.12564 .05755 .1258 .0629 .13475 .06208 .13455 .05668 Mtetra
.389 .344 .687 r
.13455 .05668 .13475 .06208 .14379 .06126 .14355 .05582 Mtetra
.394 .354 .695 r
.14355 .05582 .14379 .06126 .15293 .06045 .15266 .05495 Mtetra
.4 .364 .703 r
.15266 .05495 .15293 .06045 .16217 .05963 .16186 .0541 Mtetra
.407 .375 .711 r
.16186 .0541 .16217 .05963 .17151 .05883 .17117 .05324 Mtetra
.414 .386 .719 r
.17117 .05324 .17151 .05883 .18095 .05803 .18059 .0524 Mtetra
.422 .398 .727 r
.18059 .0524 .18095 .05803 .19051 .05725 .19011 .05156 Mtetra
.43 .41 .736 r
.19011 .05156 .19051 .05725 .20017 .05647 .19974 .05074 Mtetra
.439 .423 .744 r
.19974 .05074 .20017 .05647 .20993 .05571 .20948 .04993 Mtetra
.448 .436 .753 r
.20948 .04993 .20993 .05571 .21981 .05497 .21934 .04913 Mtetra
.457 .449 .761 r
.21934 .04913 .21981 .05497 .2298 .05424 .2293 .04836 Mtetra
.467 .463 .77 r
.2293 .04836 .2298 .05424 .23989 .05354 .23937 .0476 Mtetra
.477 .477 .779 r
.23937 .0476 .23989 .05354 .2501 .05285 .24956 .04686 Mtetra
.487 .491 .787 r
.24956 .04686 .2501 .05285 .26041 .0522 .25985 .04615 Mtetra
.498 .506 .796 r
.25985 .04615 .26041 .0522 .27082 .05157 .27025 .04547 Mtetra
.509 .521 .805 r
.27025 .04547 .27082 .05157 .28134 .05097 .28076 .04481 Mtetra
.52 .537 .813 r
.28076 .04481 .28134 .05097 .29196 .0504 .29137 .04419 Mtetra
.53 .552 .822 r
.29137 .04419 .29196 .0504 .30268 .04986 .30208 .04359 Mtetra
.541 .568 .831 r
.30208 .04359 .30268 .04986 .31349 .04936 .31288 .04304 Mtetra
.552 .583 .839 r
.31288 .04304 .31349 .04936 .32439 .0489 .32378 .04251 Mtetra
.563 .599 .847 r
.32378 .04251 .32439 .0489 .33537 .04847 .33476 .04203 Mtetra
.573 .614 .855 r
.33476 .04203 .33537 .04847 .34643 .04809 .34583 .04159 Mtetra
.583 .629 .863 r
.34583 .04159 .34643 .04809 .35757 .04775 .35697 .04118 Mtetra
.593 .644 .871 r
.35697 .04118 .35757 .04775 .36877 .04744 .36819 .04082 Mtetra
.602 .659 .878 r
.36819 .04082 .36877 .04744 .38002 .04718 .37947 .0405 Mtetra
.61 .673 .885 r
.37947 .0405 .38002 .04718 .39133 .04696 .3908 .04022 Mtetra
.618 .686 .891 r
.3908 .04022 .39133 .04696 .40269 .04679 .40218 .03998 Mtetra
.626 .699 .898 r
.40218 .03998 .40269 .04679 .41408 .04665 .41361 .03979 Mtetra
.632 .711 .903 r
.41361 .03979 .41408 .04665 .4255 .04655 .42507 .03963 Mtetra
.639 .723 .909 r
.42507 .03963 .4255 .04655 .43694 .04649 .43657 .03952 Mtetra
.645 .734 .914 r
.43657 .03952 .43694 .04649 .4484 .04647 .44808 .03945 Mtetra
.651 .745 .918 r
.44808 .03945 .4484 .04647 .45987 .04649 .45961 .03942 Mtetra
.658 .756 .922 r
.45961 .03942 .45987 .04649 .47134 .04655 .47116 .03944 Mtetra
.666 .767 .925 r
.47116 .03944 .47134 .04655 .48282 .04665 .4827 .03951 Mtetra
.676 .779 .928 r
.4827 .03951 .48282 .04665 .49428 .04682 .49424 .03964 Mtetra
.648 .76 .931 r
.49424 .03964 .49428 .04682 .50572 .04682 .50576 .03964 Mtetra
.929 .764 .656 r
.90054 .06013 .9005 .06535 .9091 .06616 .9091 .06099 Mtetra
.928 .768 .664 r
.8919 .05927 .89182 .06454 .9005 .06535 .90054 .06013 Mtetra
.926 .772 .671 r
.88318 .05841 .88305 .06372 .89182 .06454 .8919 .05927 Mtetra
.924 .776 .678 r
.87436 .05755 .8742 .0629 .88305 .06372 .88318 .05841 Mtetra
.922 .779 .686 r
.86545 .05668 .86525 .06208 .8742 .0629 .87436 .05755 Mtetra
.919 .783 .694 r
.85645 .05582 .85621 .06126 .86525 .06208 .86545 .05668 Mtetra
.916 .785 .702 r
.84734 .05495 .84707 .06045 .85621 .06126 .85645 .05582 Mtetra
.913 .788 .709 r
.83814 .0541 .83783 .05963 .84707 .06045 .84734 .05495 Mtetra
.909 .79 .717 r
.82883 .05324 .82849 .05883 .83783 .05963 .83814 .0541 Mtetra
.905 .792 .726 r
.81941 .0524 .81905 .05803 .82849 .05883 .82883 .05324 Mtetra
.9 .794 .734 r
.80989 .05156 .80949 .05725 .81905 .05803 .81941 .0524 Mtetra
.895 .795 .742 r
.80026 .05074 .79983 .05647 .80949 .05725 .80989 .05156 Mtetra
.89 .797 .751 r
.79052 .04993 .79007 .05571 .79983 .05647 .80026 .05074 Mtetra
.884 .798 .759 r
.78066 .04913 .78019 .05497 .79007 .05571 .79052 .04993 Mtetra
.878 .798 .768 r
.7707 .04836 .7702 .05424 .78019 .05497 .78066 .04913 Mtetra
.871 .799 .776 r
.76063 .0476 .76011 .05354 .7702 .05424 .7707 .04836 Mtetra
.864 .799 .785 r
.75044 .04686 .7499 .05285 .76011 .05354 .76063 .0476 Mtetra
.856 .798 .794 r
.74015 .04615 .73959 .0522 .7499 .05285 .75044 .04686 Mtetra
.847 .798 .803 r
.72975 .04547 .72918 .05157 .73959 .0522 .74015 .04615 Mtetra
.839 .797 .811 r
.71924 .04481 .71866 .05097 .72918 .05157 .72975 .04547 Mtetra
.829 .796 .82 r
.70863 .04419 .70804 .0504 .71866 .05097 .71924 .04481 Mtetra
.82 .795 .829 r
.69792 .04359 .69732 .04986 .70804 .0504 .70863 .04419 Mtetra
.809 .793 .837 r
.68712 .04304 .68651 .04936 .69732 .04986 .69792 .04359 Mtetra
.799 .791 .845 r
.67622 .04251 .67561 .0489 .68651 .04936 .68712 .04304 Mtetra
.788 .789 .854 r
.66524 .04203 .66463 .04847 .67561 .0489 .67622 .04251 Mtetra
.776 .787 .862 r
.65417 .04159 .65357 .04809 .66463 .04847 .66524 .04203 Mtetra
.764 .784 .869 r
.64303 .04118 .64243 .04775 .65357 .04809 .65417 .04159 Mtetra
.753 .782 .877 r
.63181 .04082 .63123 .04744 .64243 .04775 .64303 .04118 Mtetra
.741 .779 .884 r
.62053 .0405 .61998 .04718 .63123 .04744 .63181 .04082 Mtetra
.729 .777 .891 r
.6092 .04022 .60867 .04696 .61998 .04718 .62053 .0405 Mtetra
.717 .774 .897 r
.59782 .03998 .59731 .04679 .60867 .04696 .6092 .04022 Mtetra
.705 .771 .903 r
.58639 .03979 .58592 .04665 .59731 .04679 .59782 .03998 Mtetra
.694 .768 .909 r
.57493 .03963 .5745 .04655 .58592 .04665 .58639 .03979 Mtetra
.683 .765 .914 r
.56343 .03952 .56306 .04649 .5745 .04655 .57493 .03963 Mtetra
.672 .762 .918 r
.55192 .03945 .5516 .04647 .56306 .04649 .56343 .03952 Mtetra
.66 .758 .922 r
.54039 .03942 .54013 .04649 .5516 .04647 .55192 .03945 Mtetra
.648 .753 .926 r
.52884 .03944 .52866 .04655 .54013 .04649 .54039 .03942 Mtetra
.636 .746 .928 r
.5173 .03951 .51718 .04665 .52866 .04655 .52884 .03944 Mtetra
.621 .738 .931 r
.50576 .03964 .50572 .04682 .51718 .04665 .5173 .03951 Mtetra
.379 .309 .652 r
.0909 .06616 .0909 .07134 .09954 .07057 .0995 .06535 Mtetra
.381 .317 .659 r
.0995 .06535 .09954 .07057 .10827 .0698 .10818 .06454 Mtetra
.385 .325 .667 r
.10818 .06454 .10827 .0698 .11707 .06903 .11695 .06372 Mtetra
.388 .333 .674 r
.11695 .06372 .11707 .06903 .12596 .06825 .1258 .0629 Mtetra
.393 .342 .682 r
.1258 .0629 .12596 .06825 .13494 .06747 .13475 .06208 Mtetra
.398 .351 .689 r
.13475 .06208 .13494 .06747 .14402 .0667 .14379 .06126 Mtetra
.404 .361 .697 r
.14379 .06126 .14402 .0667 .15319 .06593 .15293 .06045 Mtetra
.41 .371 .705 r
.15293 .06045 .15319 .06593 .16246 .06516 .16217 .05963 Mtetra
.417 .382 .713 r
.16217 .05963 .16246 .06516 .17184 .0644 .17151 .05883 Mtetra
.424 .393 .721 r
.17151 .05883 .17184 .0644 .18131 .06365 .18095 .05803 Mtetra
.432 .405 .729 r
.18095 .05803 .18131 .06365 .19089 .06291 .19051 .05725 Mtetra
.44 .417 .737 r
.19051 .05725 .19089 .06291 .20058 .06218 .20017 .05647 Mtetra
.449 .43 .745 r
.20017 .05647 .20058 .06218 .21037 .06147 .20993 .05571 Mtetra
.458 .443 .754 r
.20993 .05571 .21037 .06147 .22028 .06078 .21981 .05497 Mtetra
.467 .456 .762 r
.21981 .05497 .22028 .06078 .23029 .0601 .2298 .05424 Mtetra
.477 .47 .771 r
.2298 .05424 .23029 .0601 .2404 .05944 .23989 .05354 Mtetra
.487 .484 .779 r
.23989 .05354 .2404 .05944 .25062 .05881 .2501 .05285 Mtetra
.498 .499 .788 r
.2501 .05285 .25062 .05881 .26095 .05821 .26041 .0522 Mtetra
.509 .514 .797 r
.26041 .0522 .26095 .05821 .27138 .05763 .27082 .05157 Mtetra
.52 .529 .805 r
.27082 .05157 .27138 .05763 .28192 .05708 .28134 .05097 Mtetra
.531 .544 .814 r
.28134 .05097 .28192 .05708 .29255 .05656 .29196 .0504 Mtetra
.542 .56 .822 r
.29196 .0504 .29255 .05656 .30327 .05608 .30268 .04986 Mtetra
.553 .576 .831 r
.30268 .04986 .30327 .05608 .31409 .05564 .31349 .04936 Mtetra
.564 .591 .839 r
.31349 .04936 .31409 .05564 .32499 .05523 .32439 .0489 Mtetra
.575 .607 .847 r
.32439 .0489 .32499 .05523 .33597 .05486 .33537 .04847 Mtetra
.586 .623 .855 r
.33537 .04847 .33597 .05486 .34702 .05453 .34643 .04809 Mtetra
.596 .638 .863 r
.34643 .04809 .34702 .05453 .35815 .05424 .35757 .04775 Mtetra
.606 .653 .87 r
.35757 .04775 .35815 .05424 .36933 .054 .36877 .04744 Mtetra
.615 .667 .877 r
.36877 .04744 .36933 .054 .38057 .0538 .38002 .04718 Mtetra
.623 .681 .884 r
.38002 .04718 .38057 .0538 .39186 .05363 .39133 .04696 Mtetra
.631 .695 .891 r
.39133 .04696 .39186 .05363 .40318 .05351 .40269 .04679 Mtetra
.638 .708 .897 r
.40269 .04679 .40318 .05351 .41453 .05343 .41408 .04665 Mtetra
.644 .72 .903 r
.41408 .04665 .41453 .05343 .42591 .05338 .4255 .04655 Mtetra
.65 .731 .908 r
.4255 .04655 .42591 .05338 .43731 .05337 .43694 .04649 Mtetra
.656 .742 .913 r
.43694 .04649 .43731 .05337 .44871 .05339 .4484 .04647 Mtetra
.661 .752 .917 r
.4484 .04647 .44871 .05339 .46012 .05345 .45987 .04649 Mtetra
.668 .762 .921 r
.45987 .04649 .46012 .05345 .47153 .05355 .47134 .04655 Mtetra
.675 .773 .924 r
.47134 .04655 .47153 .05355 .48293 .05369 .48282 .04665 Mtetra
.684 .784 .926 r
.48282 .04665 .48293 .05369 .49432 .05388 .49428 .04682 Mtetra
.649 .759 .93 r
.49428 .04682 .49432 .05388 .50568 .05388 .50572 .04682 Mtetra
.925 .76 .659 r
.9005 .06535 .90046 .07057 .9091 .07134 .9091 .06616 Mtetra
.924 .765 .666 r
.89182 .06454 .89173 .0698 .90046 .07057 .9005 .06535 Mtetra
.922 .769 .673 r
.88305 .06372 .88293 .06903 .89173 .0698 .89182 .06454 Mtetra
.92 .772 .681 r
.8742 .0629 .87404 .06825 .88293 .06903 .88305 .06372 Mtetra
.918 .776 .688 r
.86525 .06208 .86506 .06747 .87404 .06825 .8742 .0629 Mtetra
.915 .779 .696 r
.85621 .06126 .85598 .0667 .86506 .06747 .86525 .06208 Mtetra
.912 .781 .703 r
.84707 .06045 .84681 .06593 .85598 .0667 .85621 .06126 Mtetra
.909 .784 .711 r
.83783 .05963 .83754 .06516 .84681 .06593 .84707 .06045 Mtetra
.905 .786 .719 r
.82849 .05883 .82816 .0644 .83754 .06516 .83783 .05963 Mtetra
.901 .788 .727 r
.81905 .05803 .81869 .06365 .82816 .0644 .82849 .05883 Mtetra
.896 .789 .735 r
.80949 .05725 .80911 .06291 .81869 .06365 .81905 .05803 Mtetra
.891 .791 .743 r
.79983 .05647 .79942 .06218 .80911 .06291 .80949 .05725 Mtetra
.885 .792 .752 r
.79007 .05571 .78963 .06147 .79942 .06218 .79983 .05647 Mtetra
.879 .792 .76 r
.78019 .05497 .77972 .06078 .78963 .06147 .79007 .05571 Mtetra
.873 .793 .769 r
.7702 .05424 .76971 .0601 .77972 .06078 .78019 .05497 Mtetra
.866 .793 .777 r
.76011 .05354 .7596 .05944 .76971 .0601 .7702 .05424 Mtetra
.858 .793 .786 r
.7499 .05285 .74938 .05881 .7596 .05944 .76011 .05354 Mtetra
.85 .792 .794 r
.73959 .0522 .73905 .05821 .74938 .05881 .7499 .05285 Mtetra
.842 .792 .803 r
.72918 .05157 .72862 .05763 .73905 .05821 .73959 .0522 Mtetra
.832 .79 .812 r
.71866 .05097 .71808 .05708 .72862 .05763 .72918 .05157 Mtetra
.823 .789 .82 r
.70804 .0504 .70745 .05656 .71808 .05708 .71866 .05097 Mtetra
.813 .787 .829 r
.69732 .04986 .69673 .05608 .70745 .05656 .70804 .0504 Mtetra
.802 .786 .837 r
.68651 .04936 .68591 .05564 .69673 .05608 .69732 .04986 Mtetra
.791 .783 .846 r
.67561 .0489 .67501 .05523 .68591 .05564 .68651 .04936 Mtetra
.78 .781 .854 r
.66463 .04847 .66403 .05486 .67501 .05523 .67561 .0489 Mtetra
.768 .778 .862 r
.65357 .04809 .65298 .05453 .66403 .05486 .66463 .04847 Mtetra
.756 .776 .869 r
.64243 .04775 .64185 .05424 .65298 .05453 .65357 .04809 Mtetra
.744 .773 .877 r
.63123 .04744 .63067 .054 .64185 .05424 .64243 .04775 Mtetra
.731 .77 .884 r
.61998 .04718 .61943 .0538 .63067 .054 .63123 .04744 Mtetra
.719 .767 .89 r
.60867 .04696 .60814 .05363 .61943 .0538 .61998 .04718 Mtetra
.707 .764 .897 r
.59731 .04679 .59682 .05351 .60814 .05363 .60867 .04696 Mtetra
.696 .762 .903 r
.58592 .04665 .58547 .05343 .59682 .05351 .59731 .04679 Mtetra
.684 .759 .908 r
.5745 .04655 .57409 .05338 .58547 .05343 .58592 .04665 Mtetra
.673 .756 .913 r
.56306 .04649 .56269 .05337 .57409 .05338 .5745 .04655 Mtetra
.662 .753 .917 r
.5516 .04647 .55129 .05339 .56269 .05337 .56306 .04649 Mtetra
.652 .749 .921 r
.54013 .04649 .53988 .05345 .55129 .05339 .5516 .04647 Mtetra
.64 .745 .924 r
.52866 .04655 .52847 .05355 .53988 .05345 .54013 .04649 Mtetra
.628 .739 .927 r
.51718 .04665 .51707 .05369 .52847 .05355 .52866 .04655 Mtetra
.615 .731 .929 r
.50572 .04682 .50568 .05388 .51707 .05369 .51718 .04665 Mtetra
.388 .317 .655 r
.0909 .07134 .0909 .07652 .09958 .07579 .09954 .07057 Mtetra
.391 .324 .662 r
.09954 .07057 .09958 .07579 .10835 .07506 .10827 .0698 Mtetra
.394 .332 .669 r
.10827 .0698 .10835 .07506 .11719 .07433 .11707 .06903 Mtetra
.398 .34 .676 r
.11707 .06903 .11719 .07433 .12612 .07359 .12596 .06825 Mtetra
.402 .349 .684 r
.12596 .06825 .12612 .07359 .13514 .07286 .13494 .06747 Mtetra
.407 .358 .691 r
.13494 .06747 .13514 .07286 .14425 .07212 .14402 .0667 Mtetra
.413 .368 .699 r
.14402 .0667 .14425 .07212 .15345 .07139 .15319 .06593 Mtetra
.419 .378 .706 r
.15319 .06593 .15345 .07139 .16276 .07067 .16246 .06516 Mtetra
.426 .389 .714 r
.16246 .06516 .16276 .07067 .17216 .06996 .17184 .0644 Mtetra
.433 .4 .722 r
.17184 .0644 .17216 .06996 .18166 .06925 .18131 .06365 Mtetra
.441 .411 .73 r
.18131 .06365 .18166 .06925 .19127 .06855 .19089 .06291 Mtetra
.449 .424 .738 r
.19089 .06291 .19127 .06855 .20099 .06787 .20058 .06218 Mtetra
.458 .436 .746 r
.20058 .06218 .20099 .06787 .2108 .06721 .21037 .06147 Mtetra
.467 .449 .755 r
.21037 .06147 .2108 .06721 .22073 .06656 .22028 .06078 Mtetra
.477 .463 .763 r
.22028 .06078 .22073 .06656 .23076 .06593 .23029 .0601 Mtetra
.487 .477 .771 r
.23029 .0601 .23076 .06593 .2409 .06532 .2404 .05944 Mtetra
.498 .491 .78 r
.2404 .05944 .2409 .06532 .25114 .06474 .25062 .05881 Mtetra
.509 .506 .788 r
.25062 .05881 .25114 .06474 .26148 .06418 .26095 .05821 Mtetra
.52 .521 .797 r
.26095 .05821 .26148 .06418 .27193 .06365 .27138 .05763 Mtetra
.531 .536 .805 r
.27138 .05763 .27193 .06365 .28248 .06315 .28192 .05708 Mtetra
.542 .552 .814 r
.28192 .05708 .28248 .06315 .29312 .06269 .29255 .05656 Mtetra
.554 .567 .822 r
.29255 .05656 .29312 .06269 .30385 .06226 .30327 .05608 Mtetra
.565 .583 .831 r
.30327 .05608 .30385 .06226 .31467 .06186 .31409 .05564 Mtetra
.576 .599 .839 r
.31409 .05564 .31467 .06186 .32557 .0615 .32499 .05523 Mtetra
.587 .615 .847 r
.32499 .05523 .32557 .0615 .33655 .06119 .33597 .05486 Mtetra
.598 .631 .855 r
.33597 .05486 .33655 .06119 .3476 .06091 .34702 .05453 Mtetra
.609 .646 .862 r
.34702 .05453 .3476 .06091 .35872 .06068 .35815 .05424 Mtetra
.618 .661 .87 r
.35815 .05424 .35872 .06068 .36989 .06049 .36933 .054 Mtetra
.628 .676 .877 r
.36933 .054 .36989 .06049 .38111 .06034 .38057 .0538 Mtetra
.636 .69 .884 r
.38057 .0538 .38111 .06034 .39237 .06023 .39186 .05363 Mtetra
.644 .703 .89 r
.39186 .05363 .39237 .06023 .40366 .06016 .40318 .05351 Mtetra
.65 .716 .896 r
.40318 .05351 .40366 .06016 .41498 .06012 .41453 .05343 Mtetra
.656 .728 .902 r
.41453 .05343 .41498 .06012 .42632 .06013 .42591 .05338 Mtetra
.662 .739 .907 r
.42591 .05338 .42632 .06013 .43767 .06016 .43731 .05337 Mtetra
.666 .749 .912 r
.43731 .05337 .43767 .06016 .44902 .06023 .44871 .05339 Mtetra
.671 .759 .916 r
.44871 .05339 .44902 .06023 .46037 .06033 .46012 .05345 Mtetra
.677 .768 .92 r
.46012 .05345 .46037 .06033 .47171 .06046 .47153 .05355 Mtetra
.683 .778 .923 r
.47153 .05355 .47171 .06046 .48304 .06062 .48293 .05369 Mtetra
.691 .788 .925 r
.48293 .05369 .48304 .06062 .49435 .06083 .49432 .05388 Mtetra
.65 .758 .929 r
.49432 .05388 .49435 .06083 .50565 .06083 .50568 .05388 Mtetra
.921 .757 .662 r
.90046 .07057 .90042 .07579 .9091 .07652 .9091 .07134 Mtetra
.92 .761 .668 r
.89173 .0698 .89165 .07506 .90042 .07579 .90046 .07057 Mtetra
.918 .765 .676 r
.88293 .06903 .88281 .07433 .89165 .07506 .89173 .0698 Mtetra
.916 .769 .683 r
.87404 .06825 .87388 .07359 .88281 .07433 .88293 .06903 Mtetra
.914 .772 .69 r
.86506 .06747 .86486 .07286 .87388 .07359 .87404 .06825 Mtetra
.911 .775 .697 r
.85598 .0667 .85575 .07212 .86486 .07286 .86506 .06747 Mtetra
.908 .777 .705 r
.84681 .06593 .84655 .07139 .85575 .07212 .85598 .0667 Mtetra
.905 .78 .713 r
.83754 .06516 .83724 .07067 .84655 .07139 .84681 .06593 Mtetra
.901 .782 .72 r
.82816 .0644 .82784 .06996 .83724 .07067 .83754 .06516 Mtetra
.897 .783 .728 r
.81869 .06365 .81834 .06925 .82784 .06996 .82816 .0644 Mtetra
.892 .785 .736 r
.80911 .06291 .80873 .06855 .81834 .06925 .81869 .06365 Mtetra
.887 .786 .744 r
.79942 .06218 .79901 .06787 .80873 .06855 .80911 .06291 Mtetra
.881 .787 .753 r
.78963 .06147 .7892 .06721 .79901 .06787 .79942 .06218 Mtetra
.875 .787 .761 r
.77972 .06078 .77927 .06656 .7892 .06721 .78963 .06147 Mtetra
.868 .787 .769 r
.76971 .0601 .76924 .06593 .77927 .06656 .77972 .06078 Mtetra
.861 .787 .778 r
.7596 .05944 .7591 .06532 .76924 .06593 .76971 .0601 Mtetra
.853 .787 .786 r
.74938 .05881 .74886 .06474 .7591 .06532 .7596 .05944 Mtetra
.845 .786 .795 r
.73905 .05821 .73852 .06418 .74886 .06474 .74938 .05881 Mtetra
.836 .785 .803 r
.72862 .05763 .72807 .06365 .73852 .06418 .73905 .05821 Mtetra
.826 .784 .812 r
.71808 .05708 .71752 .06315 .72807 .06365 .72862 .05763 Mtetra
.816 .782 .82 r
.70745 .05656 .70688 .06269 .71752 .06315 .71808 .05708 Mtetra
.806 .78 .829 r
.69673 .05608 .69615 .06226 .70688 .06269 .70745 .05656 Mtetra
.795 .778 .837 r
.68591 .05564 .68533 .06186 .69615 .06226 .69673 .05608 Mtetra
.783 .775 .845 r
.67501 .05523 .67443 .0615 .68533 .06186 .68591 .05564 Mtetra
.772 .773 .853 r
.66403 .05486 .66345 .06119 .67443 .0615 .67501 .05523 Mtetra
.759 .77 .861 r
.65298 .05453 .6524 .06091 .66345 .06119 .66403 .05486 Mtetra
.747 .767 .869 r
.64185 .05424 .64128 .06068 .6524 .06091 .65298 .05453 Mtetra
.734 .764 .876 r
.63067 .054 .63011 .06049 .64128 .06068 .64185 .05424 Mtetra
.722 .76 .883 r
.61943 .0538 .61889 .06034 .63011 .06049 .63067 .054 Mtetra
.709 .757 .89 r
.60814 .05363 .60763 .06023 .61889 .06034 .61943 .0538 Mtetra
.697 .755 .896 r
.59682 .05351 .59634 .06016 .60763 .06023 .60814 .05363 Mtetra
.686 .752 .902 r
.58547 .05343 .58502 .06012 .59634 .06016 .59682 .05351 Mtetra
.674 .749 .907 r
.57409 .05338 .57368 .06013 .58502 .06012 .58547 .05343 Mtetra
.663 .747 .912 r
.56269 .05337 .56233 .06016 .57368 .06013 .57409 .05338 Mtetra
.653 .744 .916 r
.55129 .05339 .55098 .06023 .56233 .06016 .56269 .05337 Mtetra
.643 .741 .92 r
.53988 .05345 .53963 .06033 .55098 .06023 .55129 .05339 Mtetra
.632 .737 .923 r
.52847 .05355 .52829 .06046 .53963 .06033 .53988 .05345 Mtetra
.621 .731 .925 r
.51707 .05369 .51696 .06062 .52829 .06046 .52847 .05355 Mtetra
.609 .724 .927 r
.50568 .05388 .50565 .06083 .51696 .06062 .51707 .05369 Mtetra
.398 .325 .657 r
.0909 .07652 .0909 .0817 .09962 .08101 .09958 .07579 Mtetra
.4 .331 .664 r
.09958 .07579 .09962 .08101 .10842 .08032 .10835 .07506 Mtetra
.403 .339 .671 r
.10835 .07506 .10842 .08032 .11731 .07962 .11719 .07433 Mtetra
.407 .347 .678 r
.11719 .07433 .11731 .07962 .12627 .07893 .12612 .07359 Mtetra
.411 .356 .685 r
.12612 .07359 .12627 .07893 .13532 .07823 .13514 .07286 Mtetra
.416 .365 .693 r
.13514 .07286 .13532 .07823 .14447 .07754 .14425 .07212 Mtetra
.422 .374 .7 r
.14425 .07212 .14447 .07754 .15371 .07685 .15345 .07139 Mtetra
.428 .384 .708 r
.15345 .07139 .15371 .07685 .16304 .07617 .16276 .07067 Mtetra
.435 .395 .715 r
.16276 .07067 .16304 .07617 .17247 .0755 .17216 .06996 Mtetra
.442 .406 .723 r
.17216 .06996 .17247 .0755 .18201 .07483 .18166 .06925 Mtetra
.45 .418 .731 r
.18166 .06925 .18201 .07483 .19164 .07418 .19127 .06855 Mtetra
.458 .43 .739 r
.19127 .06855 .19164 .07418 .20138 .07354 .20099 .06787 Mtetra
.467 .443 .747 r
.20099 .06787 .20138 .07354 .21123 .07292 .2108 .06721 Mtetra
.477 .456 .755 r
.2108 .06721 .21123 .07292 .22117 .07232 .22073 .06656 Mtetra
.487 .469 .764 r
.22073 .06656 .22117 .07232 .23123 .07173 .23076 .06593 Mtetra
.497 .483 .772 r
.23076 .06593 .23123 .07173 .24138 .07117 .2409 .06532 Mtetra
.508 .498 .78 r
.2409 .06532 .24138 .07117 .25164 .07063 .25114 .06474 Mtetra
.519 .512 .789 r
.25114 .06474 .25164 .07063 .262 .07012 .26148 .06418 Mtetra
.53 .528 .797 r
.26148 .06418 .262 .07012 .27247 .06964 .27193 .06365 Mtetra
.542 .543 .805 r
.27193 .06365 .27247 .06964 .28302 .06919 .28248 .06315 Mtetra
.553 .559 .814 r
.28248 .06315 .28302 .06919 .29367 .06877 .29312 .06269 Mtetra
.565 .575 .822 r
.29312 .06269 .29367 .06877 .30441 .06838 .30385 .06226 Mtetra
.577 .591 .83 r
.30385 .06226 .30441 .06838 .31524 .06804 .31467 .06186 Mtetra
.588 .607 .838 r
.31467 .06186 .31524 .06804 .32614 .06773 .32557 .0615 Mtetra
.599 .623 .846 r
.32557 .0615 .32614 .06773 .33712 .06746 .33655 .06119 Mtetra
.61 .639 .854 r
.33655 .06119 .33712 .06746 .34817 .06724 .3476 .06091 Mtetra
.621 .654 .862 r
.3476 .06091 .34817 .06724 .35927 .06705 .35872 .06068 Mtetra
.631 .67 .869 r
.35872 .06068 .35927 .06705 .37043 .06691 .36989 .06049 Mtetra
.64 .685 .876 r
.36989 .06049 .37043 .06691 .38163 .06681 .38111 .06034 Mtetra
.649 .699 .883 r
.38111 .06034 .38163 .06681 .39287 .06675 .39237 .06023 Mtetra
.656 .712 .889 r
.39237 .06023 .39287 .06675 .40414 .06673 .40366 .06016 Mtetra
.663 .724 .895 r
.40366 .06016 .40414 .06673 .41542 .06674 .41498 .06012 Mtetra
.668 .736 .901 r
.41498 .06012 .41542 .06674 .42672 .06679 .42632 .06013 Mtetra
.673 .747 .906 r
.42632 .06013 .42672 .06679 .43802 .06687 .43767 .06016 Mtetra
.677 .756 .911 r
.43767 .06016 .43802 .06687 .44932 .06698 .44902 .06023 Mtetra
.681 .765 .915 r
.44902 .06023 .44932 .06698 .46061 .06711 .46037 .06033 Mtetra
.685 .774 .918 r
.46037 .06033 .46061 .06711 .47189 .06726 .47171 .06046 Mtetra
.69 .782 .921 r
.47171 .06046 .47189 .06726 .48315 .06745 .48304 .06062 Mtetra
.697 .792 .923 r
.48304 .06062 .48315 .06745 .49439 .06767 .49435 .06083 Mtetra
.651 .757 .927 r
.49435 .06083 .49439 .06767 .50561 .06767 .50565 .06083 Mtetra
.917 .754 .664 r
.90042 .07579 .90038 .08101 .9091 .0817 .9091 .07652 Mtetra
.916 .758 .671 r
.89165 .07506 .89158 .08032 .90038 .08101 .90042 .07579 Mtetra
.914 .762 .678 r
.88281 .07433 .88269 .07962 .89158 .08032 .89165 .07506 Mtetra
.912 .765 .685 r
.87388 .07359 .87373 .07893 .88269 .07962 .88281 .07433 Mtetra
.91 .768 .692 r
.86486 .07286 .86468 .07823 .87373 .07893 .87388 .07359 Mtetra
.907 .771 .699 r
.85575 .07212 .85553 .07754 .86468 .07823 .86486 .07286 Mtetra
.904 .773 .706 r
.84655 .07139 .84629 .07685 .85553 .07754 .85575 .07212 Mtetra
.901 .776 .714 r
.83724 .07067 .83696 .07617 .84629 .07685 .84655 .07139 Mtetra
.897 .777 .722 r
.82784 .06996 .82753 .0755 .83696 .07617 .83724 .07067 Mtetra
.892 .779 .729 r
.81834 .06925 .81799 .07483 .82753 .0755 .82784 .06996 Mtetra
.887 .78 .737 r
.80873 .06855 .80836 .07418 .81799 .07483 .81834 .06925 Mtetra
.882 .781 .745 r
.79901 .06787 .79862 .07354 .80836 .07418 .80873 .06855 Mtetra
.876 .782 .753 r
.7892 .06721 .78877 .07292 .79862 .07354 .79901 .06787 Mtetra
.87 .782 .762 r
.77927 .06656 .77883 .07232 .78877 .07292 .7892 .06721 Mtetra
.863 .782 .77 r
.76924 .06593 .76877 .07173 .77883 .07232 .77927 .06656 Mtetra
.855 .782 .778 r
.7591 .06532 .75862 .07117 .76877 .07173 .76924 .06593 Mtetra
.847 .781 .787 r
.74886 .06474 .74836 .07063 .75862 .07117 .7591 .06532 Mtetra
.839 .78 .795 r
.73852 .06418 .738 .07012 .74836 .07063 .74886 .06474 Mtetra
.83 .778 .804 r
.72807 .06365 .72753 .06964 .738 .07012 .73852 .06418 Mtetra
.82 .777 .812 r
.71752 .06315 .71698 .06919 .72753 .06964 .72807 .06365 Mtetra
.81 .775 .82 r
.70688 .06269 .70633 .06877 .71698 .06919 .71752 .06315 Mtetra
.799 .772 .829 r
.69615 .06226 .69559 .06838 .70633 .06877 .70688 .06269 Mtetra
.788 .77 .837 r
.68533 .06186 .68476 .06804 .69559 .06838 .69615 .06226 Mtetra
.776 .767 .845 r
.67443 .0615 .67386 .06773 .68476 .06804 .68533 .06186 Mtetra
.763 .764 .853 r
.66345 .06119 .66288 .06746 .67386 .06773 .67443 .0615 Mtetra
.751 .761 .861 r
.6524 .06091 .65183 .06724 .66288 .06746 .66345 .06119 Mtetra
.738 .757 .868 r
.64128 .06068 .64073 .06705 .65183 .06724 .6524 .06091 Mtetra
.725 .754 .875 r
.63011 .06049 .62957 .06691 .64073 .06705 .64128 .06068 Mtetra
.712 .751 .882 r
.61889 .06034 .61837 .06681 .62957 .06691 .63011 .06049 Mtetra
.699 .748 .889 r
.60763 .06023 .60713 .06675 .61837 .06681 .61889 .06034 Mtetra
.687 .745 .895 r
.59634 .06016 .59586 .06673 .60713 .06675 .60763 .06023 Mtetra
.675 .742 .901 r
.58502 .06012 .58458 .06674 .59586 .06673 .59634 .06016 Mtetra
.664 .739 .906 r
.57368 .06013 .57328 .06679 .58458 .06674 .58502 .06012 Mtetra
.653 .737 .911 r
.56233 .06016 .56198 .06687 .57328 .06679 .57368 .06013 Mtetra
.644 .735 .915 r
.55098 .06023 .55068 .06698 .56198 .06687 .56233 .06016 Mtetra
.634 .732 .919 r
.53963 .06033 .53939 .06711 .55068 .06698 .55098 .06023 Mtetra
.625 .729 .922 r
.52829 .06046 .52811 .06726 .53939 .06711 .53963 .06033 Mtetra
.615 .725 .924 r
.51696 .06062 .51685 .06745 .52811 .06726 .52829 .06046 Mtetra
.603 .718 .925 r
.50565 .06083 .50561 .06767 .51685 .06745 .51696 .06062 Mtetra
.407 .332 .66 r
.0909 .0817 .0909 .08688 .09966 .08623 .09962 .08101 Mtetra
.409 .339 .667 r
.09962 .08101 .09966 .08623 .1085 .08557 .10842 .08032 Mtetra
.412 .346 .673 r
.10842 .08032 .1085 .08557 .11742 .08491 .11731 .07962 Mtetra
.415 .354 .68 r
.11731 .07962 .11742 .08491 .12642 .08426 .12627 .07893 Mtetra
.42 .362 .687 r
.12627 .07893 .12642 .08426 .13551 .0836 .13532 .07823 Mtetra
.425 .371 .694 r
.13532 .07823 .13551 .0836 .14468 .08295 .14447 .07754 Mtetra
.43 .381 .702 r
.14447 .07754 .14468 .08295 .15395 .0823 .15371 .07685 Mtetra
.436 .391 .709 r
.15371 .07685 .15395 .0823 .16332 .08166 .16304 .07617 Mtetra
.443 .401 .717 r
.16304 .07617 .16332 .08166 .17278 .08102 .17247 .0755 Mtetra
.451 .412 .724 r
.17247 .0755 .17278 .08102 .18234 .0804 .18201 .07483 Mtetra
.459 .424 .732 r
.18201 .07483 .18234 .0804 .192 .07979 .19164 .07418 Mtetra
.467 .436 .74 r
.19164 .07418 .192 .07979 .20177 .07919 .20138 .07354 Mtetra
.477 .449 .748 r
.20138 .07354 .20177 .07919 .21164 .07861 .21123 .07292 Mtetra
.486 .462 .756 r
.21123 .07292 .21164 .07861 .22161 .07805 .22117 .07232 Mtetra
.496 .475 .764 r
.22117 .07232 .22161 .07805 .23168 .07751 .23123 .07173 Mtetra
.507 .49 .772 r
.23123 .07173 .23168 .07751 .24186 .07699 .24138 .07117 Mtetra
.518 .504 .78 r
.24138 .07117 .24186 .07699 .25213 .07649 .25164 .07063 Mtetra
.529 .519 .789 r
.25164 .07063 .25213 .07649 .26251 .07603 .262 .07012 Mtetra
.54 .534 .797 r
.262 .07012 .26251 .07603 .27299 .07559 .27247 .06964 Mtetra
.552 .55 .805 r
.27247 .06964 .27299 .07559 .28356 .07518 .28302 .06919 Mtetra
.564 .566 .814 r
.28302 .06919 .28356 .07518 .29422 .07481 .29367 .06877 Mtetra
.576 .582 .822 r
.29367 .06877 .29422 .07481 .30496 .07447 .30441 .06838 Mtetra
.588 .598 .83 r
.30441 .06838 .30496 .07447 .31579 .07417 .31524 .06804 Mtetra
.6 .614 .838 r
.31524 .06804 .31579 .07417 .3267 .0739 .32614 .06773 Mtetra
.611 .631 .846 r
.32614 .06773 .3267 .0739 .33768 .07368 .33712 .06746 Mtetra
.623 .647 .853 r
.33712 .06746 .33768 .07368 .34872 .0735 .34817 .06724 Mtetra
.633 .663 .861 r
.34817 .06724 .34872 .0735 .35981 .07337 .35927 .06705 Mtetra
.644 .678 .868 r
.35927 .06705 .35981 .07337 .37096 .07327 .37043 .06691 Mtetra
.653 .693 .875 r
.37043 .06691 .37096 .07327 .38214 .07322 .38163 .06681 Mtetra
.661 .707 .881 r
.38163 .06681 .38214 .07322 .39336 .0732 .39287 .06675 Mtetra
.669 .72 .888 r
.39287 .06675 .39336 .0732 .4046 .07323 .40414 .06673 Mtetra
.675 .733 .894 r
.40414 .06673 .4046 .07323 .41585 .07329 .41542 .06674 Mtetra
.68 .744 .899 r
.41542 .06674 .41585 .07329 .42711 .07338 .42672 .06679 Mtetra
.684 .754 .905 r
.42672 .06679 .42711 .07338 .43836 .0735 .43802 .06687 Mtetra
.687 .763 .909 r
.43802 .06687 .43836 .0735 .44961 .07364 .44932 .06698 Mtetra
.69 .772 .914 r
.44932 .06698 .44961 .07364 .46084 .0738 .46061 .06711 Mtetra
.693 .779 .917 r
.46061 .06711 .46084 .0738 .47206 .07398 .47189 .06726 Mtetra
.697 .787 .92 r
.47189 .06726 .47206 .07398 .48326 .07419 .48315 .06745 Mtetra
.703 .795 .922 r
.48315 .06745 .48326 .07419 .49443 .07442 .49439 .06767 Mtetra
.651 .756 .926 r
.49439 .06767 .49443 .07442 .50557 .07442 .50561 .06767 Mtetra
.913 .75 .666 r
.90038 .08101 .90034 .08623 .9091 .08688 .9091 .0817 Mtetra
.912 .754 .673 r
.89158 .08032 .8915 .08557 .90034 .08623 .90038 .08101 Mtetra
.91 .758 .68 r
.88269 .07962 .88258 .08491 .8915 .08557 .89158 .08032 Mtetra
.909 .761 .686 r
.87373 .07893 .87358 .08426 .88258 .08491 .88269 .07962 Mtetra
.906 .764 .693 r
.86468 .07823 .86449 .0836 .87358 .08426 .87373 .07893 Mtetra
.904 .767 .7 r
.85553 .07754 .85532 .08295 .86449 .0836 .86468 .07823 Mtetra
.9 .769 .708 r
.84629 .07685 .84605 .0823 .85532 .08295 .85553 .07754 Mtetra
.897 .771 .715 r
.83696 .07617 .83668 .08166 .84605 .0823 .84629 .07685 Mtetra
.893 .773 .723 r
.82753 .0755 .82722 .08102 .83668 .08166 .83696 .07617 Mtetra
.888 .774 .73 r
.81799 .07483 .81766 .0804 .82722 .08102 .82753 .0755 Mtetra
.883 .776 .738 r
.80836 .07418 .808 .07979 .81766 .0804 .81799 .07483 Mtetra
.878 .776 .746 r
.79862 .07354 .79823 .07919 .808 .07979 .80836 .07418 Mtetra
.872 .777 .754 r
.78877 .07292 .78836 .07861 .79823 .07919 .79862 .07354 Mtetra
.865 .777 .762 r
.77883 .07232 .77839 .07805 .78836 .07861 .78877 .07292 Mtetra
.858 .776 .77 r
.76877 .07173 .76832 .07751 .77839 .07805 .77883 .07232 Mtetra
.85 .776 .778 r
.75862 .07117 .75814 .07699 .76832 .07751 .76877 .07173 Mtetra
.842 .775 .787 r
.74836 .07063 .74787 .07649 .75814 .07699 .75862 .07117 Mtetra
.833 .773 .795 r
.738 .07012 .73749 .07603 .74787 .07649 .74836 .07063 Mtetra
.824 .772 .803 r
.72753 .06964 .72701 .07559 .73749 .07603 .738 .07012 Mtetra
.814 .77 .812 r
.71698 .06919 .71644 .07518 .72701 .07559 .72753 .06964 Mtetra
.803 .767 .82 r
.70633 .06877 .70578 .07481 .71644 .07518 .71698 .06919 Mtetra
.792 .765 .828 r
.69559 .06838 .69504 .07447 .70578 .07481 .70633 .06877 Mtetra
.78 .762 .836 r
.68476 .06804 .68421 .07417 .69504 .07447 .69559 .06838 Mtetra
.768 .758 .844 r
.67386 .06773 .6733 .0739 .68421 .07417 .68476 .06804 Mtetra
.755 .755 .852 r
.66288 .06746 .66232 .07368 .6733 .0739 .67386 .06773 Mtetra
.742 .751 .86 r
.65183 .06724 .65128 .0735 .66232 .07368 .66288 .06746 Mtetra
.729 .748 .867 r
.64073 .06705 .64019 .07337 .65128 .0735 .65183 .06724 Mtetra
.715 .744 .874 r
.62957 .06691 .62904 .07327 .64019 .07337 .64073 .06705 Mtetra
.702 .741 .881 r
.61837 .06681 .61786 .07322 .62904 .07327 .62957 .06691 Mtetra
.689 .737 .888 r
.60713 .06675 .60664 .0732 .61786 .07322 .61837 .06681 Mtetra
.676 .734 .894 r
.59586 .06673 .5954 .07323 .60664 .0732 .60713 .06675 Mtetra
.664 .732 .9 r
.58458 .06674 .58415 .07329 .5954 .07323 .59586 .06673 Mtetra
.653 .729 .905 r
.57328 .06679 .57289 .07338 .58415 .07329 .58458 .06674 Mtetra
.643 .727 .91 r
.56198 .06687 .56164 .0735 .57289 .07338 .57328 .06679 Mtetra
.634 .726 .914 r
.55068 .06698 .55039 .07364 .56164 .0735 .56198 .06687 Mtetra
.625 .724 .918 r
.53939 .06711 .53916 .0738 .55039 .07364 .55068 .06698 Mtetra
.617 .722 .921 r
.52811 .06726 .52794 .07398 .53916 .0738 .53939 .06711 Mtetra
.608 .718 .923 r
.51685 .06745 .51674 .07419 .52794 .07398 .52811 .06726 Mtetra
.598 .712 .924 r
.50561 .06767 .50557 .07442 .51674 .07419 .51685 .06745 Mtetra
.415 .339 .662 r
.0909 .08688 .0909 .09205 .0997 .09144 .09966 .08623 Mtetra
.417 .346 .669 r
.09966 .08623 .0997 .09144 .10857 .09082 .1085 .08557 Mtetra
.42 .353 .675 r
.1085 .08557 .10857 .09082 .11753 .0902 .11742 .08491 Mtetra
.424 .36 .682 r
.11742 .08491 .11753 .0902 .12656 .08958 .12642 .08426 Mtetra
.428 .369 .689 r
.12642 .08426 .12656 .08958 .13568 .08896 .13551 .0836 Mtetra
.433 .377 .696 r
.13551 .0836 .13568 .08896 .14489 .08835 .14468 .08295 Mtetra
.439 .387 .703 r
.14468 .08295 .14489 .08835 .15419 .08774 .15395 .0823 Mtetra
.445 .397 .71 r
.15395 .0823 .15419 .08774 .16359 .08713 .16332 .08166 Mtetra
.452 .407 .718 r
.16332 .08166 .16359 .08713 .17308 .08654 .17278 .08102 Mtetra
.459 .418 .725 r
.17278 .08102 .17308 .08654 .18267 .08595 .18234 .0804 Mtetra
.468 .43 .733 r
.18234 .0804 .18267 .08595 .19235 .08538 .192 .07979 Mtetra
.476 .442 .74 r
.192 .07979 .19235 .08538 .20214 .08483 .20177 .07919 Mtetra
.486 .455 .748 r
.20177 .07919 .20214 .08483 .21203 .08428 .21164 .07861 Mtetra
.495 .468 .756 r
.21164 .07861 .21203 .08428 .22203 .08376 .22161 .07805 Mtetra
.506 .482 .764 r
.22161 .07805 .22203 .08376 .23212 .08326 .23168 .07751 Mtetra
.516 .496 .772 r
.23168 .07751 .23212 .08326 .24232 .08278 .24186 .07699 Mtetra
.527 .51 .78 r
.24186 .07699 .24232 .08278 .25261 .08233 .25213 .07649 Mtetra
.539 .525 .789 r
.25213 .07649 .25261 .08233 .26301 .0819 .26251 .07603 Mtetra
.551 .541 .797 r
.26251 .07603 .26301 .0819 .27349 .0815 .27299 .07559 Mtetra
.563 .556 .805 r
.27299 .07559 .27349 .0815 .28408 .08114 .28356 .07518 Mtetra
.575 .572 .813 r
.28356 .07518 .28408 .08114 .29475 .0808 .29422 .07481 Mtetra
.587 .589 .821 r
.29422 .07481 .29475 .0808 .3055 .08051 .30496 .07447 Mtetra
.599 .605 .829 r
.30496 .07447 .3055 .08051 .31634 .08025 .31579 .07417 Mtetra
.611 .622 .837 r
.31579 .07417 .31634 .08025 .32724 .08003 .3267 .0739 Mtetra
.623 .638 .844 r
.3267 .0739 .32724 .08003 .33822 .07985 .33768 .07368 Mtetra
.635 .654 .852 r
.33768 .07368 .33822 .07985 .34926 .07972 .34872 .0735 Mtetra
.646 .67 .859 r
.34872 .0735 .34926 .07972 .36034 .07962 .35981 .07337 Mtetra
.656 .686 .866 r
.35981 .07337 .36034 .07962 .37148 .07957 .37096 .07327 Mtetra
.666 .701 .873 r
.37096 .07327 .37148 .07957 .38265 .07956 .38214 .07322 Mtetra
.674 .715 .88 r
.38214 .07322 .38265 .07956 .39384 .07959 .39336 .0732 Mtetra
.681 .729 .886 r
.39336 .0732 .39384 .07959 .40505 .07966 .4046 .07323 Mtetra
.687 .741 .892 r
.4046 .07323 .40505 .07966 .41627 .07976 .41585 .07329 Mtetra
.692 .752 .898 r
.41585 .07329 .41627 .07976 .42749 .07989 .42711 .07338 Mtetra
.695 .762 .903 r
.42711 .07338 .42749 .07989 .4387 .08004 .43836 .0735 Mtetra
.698 .771 .908 r
.43836 .0735 .4387 .08004 .4499 .08022 .44961 .07364 Mtetra
.699 .778 .912 r
.44961 .07364 .4499 .08022 .46108 .08041 .46084 .0738 Mtetra
.701 .785 .916 r
.46084 .0738 .46108 .08041 .47223 .08061 .47206 .07398 Mtetra
.703 .791 .919 r
.47206 .07398 .47223 .08061 .48336 .08083 .48326 .07419 Mtetra
.708 .798 .921 r
.48326 .07419 .48336 .08083 .49446 .08107 .49443 .07442 Mtetra
.652 .756 .925 r
.49443 .07442 .49446 .08107 .50554 .08107 .50557 .07442 Mtetra
.909 .747 .669 r
.90034 .08623 .9003 .09144 .9091 .09205 .9091 .08688 Mtetra
.908 .751 .675 r
.8915 .08557 .89143 .09082 .9003 .09144 .90034 .08623 Mtetra
.907 .755 .681 r
.88258 .08491 .88247 .0902 .89143 .09082 .8915 .08557 Mtetra
.905 .758 .688 r
.87358 .08426 .87344 .08958 .88247 .0902 .88258 .08491 Mtetra
.902 .761 .695 r
.86449 .0836 .86432 .08896 .87344 .08958 .87358 .08426 Mtetra
.9 .763 .702 r
.85532 .08295 .85511 .08835 .86432 .08896 .86449 .0836 Mtetra
.896 .765 .709 r
.84605 .0823 .84581 .08774 .85511 .08835 .85532 .08295 Mtetra
.893 .767 .716 r
.83668 .08166 .83641 .08713 .84581 .08774 .84605 .0823 Mtetra
.889 .769 .723 r
.82722 .08102 .82692 .08654 .83641 .08713 .83668 .08166 Mtetra
.884 .77 .731 r
.81766 .0804 .81733 .08595 .82692 .08654 .82722 .08102 Mtetra
.879 .771 .739 r
.808 .07979 .80765 .08538 .81733 .08595 .81766 .0804 Mtetra
.873 .771 .746 r
.79823 .07919 .79786 .08483 .80765 .08538 .808 .07979 Mtetra
.867 .771 .754 r
.78836 .07861 .78797 .08428 .79786 .08483 .79823 .07919 Mtetra
.86 .771 .762 r
.77839 .07805 .77797 .08376 .78797 .08428 .78836 .07861 Mtetra
.853 .771 .77 r
.76832 .07751 .76788 .08326 .77797 .08376 .77839 .07805 Mtetra
.845 .77 .778 r
.75814 .07699 .75768 .08278 .76788 .08326 .76832 .07751 Mtetra
.837 .769 .787 r
.74787 .07649 .74739 .08233 .75768 .08278 .75814 .07699 Mtetra
.828 .767 .795 r
.73749 .07603 .73699 .0819 .74739 .08233 .74787 .07649 Mtetra
.818 .765 .803 r
.72701 .07559 .72651 .0815 .73699 .0819 .73749 .07603 Mtetra
.807 .763 .811 r
.71644 .07518 .71592 .08114 .72651 .0815 .72701 .07559 Mtetra
.796 .76 .819 r
.70578 .07481 .70525 .0808 .71592 .08114 .71644 .07518 Mtetra
.785 .757 .828 r
.69504 .07447 .6945 .08051 .70525 .0808 .70578 .07481 Mtetra
.773 .753 .836 r
.68421 .07417 .68366 .08025 .6945 .08051 .69504 .07447 Mtetra
.76 .75 .843 r
.6733 .0739 .67276 .08003 .68366 .08025 .68421 .07417 Mtetra
.747 .746 .851 r
.66232 .07368 .66178 .07985 .67276 .08003 .6733 .0739 Mtetra
.733 .742 .859 r
.65128 .0735 .65074 .07972 .66178 .07985 .66232 .07368 Mtetra
.719 .738 .866 r
.64019 .07337 .63966 .07962 .65074 .07972 .65128 .0735 Mtetra
.706 .734 .873 r
.62904 .07327 .62852 .07957 .63966 .07962 .64019 .07337 Mtetra
.692 .73 .88 r
.61786 .07322 .61735 .07956 .62852 .07957 .62904 .07327 Mtetra
.678 .727 .886 r
.60664 .0732 .60616 .07959 .61735 .07956 .61786 .07322 Mtetra
.665 .723 .892 r
.5954 .07323 .59495 .07966 .60616 .07959 .60664 .0732 Mtetra
.653 .721 .898 r
.58415 .07329 .58373 .07976 .59495 .07966 .5954 .07323 Mtetra
.642 .719 .904 r
.57289 .07338 .57251 .07989 .58373 .07976 .58415 .07329 Mtetra
.632 .718 .908 r
.56164 .0735 .5613 .08004 .57251 .07989 .57289 .07338 Mtetra
.624 .717 .913 r
.55039 .07364 .5501 .08022 .5613 .08004 .56164 .0735 Mtetra
.616 .716 .917 r
.53916 .0738 .53892 .08041 .5501 .08022 .55039 .07364 Mtetra
.609 .714 .919 r
.52794 .07398 .52777 .08061 .53892 .08041 .53916 .0738 Mtetra
.602 .712 .921 r
.51674 .07419 .51664 .08083 .52777 .08061 .52794 .07398 Mtetra
.594 .707 .922 r
.50557 .07442 .50554 .08107 .51664 .08083 .51674 .07419 Mtetra
.424 .346 .665 r
.0909 .09205 .09089 .09723 .09973 .09665 .0997 .09144 Mtetra
.426 .352 .671 r
.0997 .09144 .09973 .09665 .10865 .09607 .10857 .09082 Mtetra
.429 .359 .677 r
.10857 .09082 .10865 .09607 .11764 .09548 .11753 .0902 Mtetra
.432 .367 .684 r
.11753 .0902 .11764 .09548 .1267 .0949 .12656 .08958 Mtetra
.436 .375 .69 r
.12656 .08958 .1267 .0949 .13586 .09432 .13568 .08896 Mtetra
.441 .383 .697 r
.13568 .08896 .13586 .09432 .1451 .09374 .14489 .08835 Mtetra
.447 .393 .704 r
.14489 .08835 .1451 .09374 .15443 .09316 .15419 .08774 Mtetra
.453 .403 .711 r
.15419 .08774 .15443 .09316 .16385 .0926 .16359 .08713 Mtetra
.46 .413 .719 r
.16359 .08713 .16385 .0926 .17337 .09204 .17308 .08654 Mtetra
.468 .424 .726 r
.17308 .08654 .17337 .09204 .18298 .09149 .18267 .08595 Mtetra
.476 .436 .733 r
.18267 .08595 .18298 .09149 .1927 .09096 .19235 .08538 Mtetra
.485 .448 .741 r
.19235 .08538 .1927 .09096 .20251 .09044 .20214 .08483 Mtetra
.494 .46 .749 r
.20214 .08483 .20251 .09044 .21242 .08993 .21203 .08428 Mtetra
.504 .474 .756 r
.21203 .08428 .21242 .08993 .22244 .08945 .22203 .08376 Mtetra
.515 .487 .764 r
.22203 .08376 .22244 .08945 .23255 .08899 .23212 .08326 Mtetra
.525 .502 .772 r
.23212 .08326 .23255 .08899 .24277 .08854 .24232 .08278 Mtetra
.537 .516 .78 r
.24232 .08278 .24277 .08854 .25308 .08813 .25261 .08233 Mtetra
.548 .531 .788 r
.25261 .08233 .25308 .08813 .26349 .08774 .26301 .0819 Mtetra
.56 .547 .796 r
.26301 .0819 .26349 .08774 .27399 .08738 .27349 .0815 Mtetra
.573 .563 .804 r
.27349 .0815 .27399 .08738 .28458 .08706 .28408 .08114 Mtetra
.585 .579 .812 r
.28408 .08114 .28458 .08706 .29526 .08676 .29475 .0808 Mtetra
.598 .595 .82 r
.29475 .0808 .29526 .08676 .30602 .08651 .3055 .08051 Mtetra
.61 .612 .828 r
.3055 .08051 .30602 .08651 .31686 .08629 .31634 .08025 Mtetra
.623 .628 .836 r
.31634 .08025 .31686 .08629 .32777 .08611 .32724 .08003 Mtetra
.635 .645 .843 r
.32724 .08003 .32777 .08611 .33875 .08597 .33822 .07985 Mtetra
.647 .662 .85 r
.33822 .07985 .33875 .08597 .34978 .08587 .34926 .07972 Mtetra
.658 .678 .858 r
.34926 .07972 .34978 .08587 .36086 .08582 .36034 .07962 Mtetra
.669 .694 .864 r
.36034 .07962 .36086 .08582 .37198 .08581 .37148 .07957 Mtetra
.678 .709 .871 r
.37148 .07957 .37198 .08581 .38314 .08584 .38265 .07956 Mtetra
.687 .723 .878 r
.38265 .07956 .38314 .08584 .39431 .08591 .39384 .07959 Mtetra
.694 .737 .884 r
.39384 .07959 .39431 .08591 .4055 .08601 .40505 .07966 Mtetra
.7 .749 .89 r
.40505 .07966 .4055 .08601 .41669 .08615 .41627 .07976 Mtetra
.704 .76 .896 r
.41627 .07976 .41669 .08615 .42787 .08632 .42749 .07989 Mtetra
.706 .77 .901 r
.42749 .07989 .42787 .08632 .43904 .08651 .4387 .08004 Mtetra
.708 .778 .907 r
.4387 .08004 .43904 .08651 .45019 .08672 .4499 .08022 Mtetra
.708 .784 .911 r
.4499 .08022 .45019 .08672 .46131 .08694 .46108 .08041 Mtetra
.708 .79 .915 r
.46108 .08041 .46131 .08694 .4724 .08716 .47223 .08061 Mtetra
.709 .795 .918 r
.47223 .08061 .4724 .08716 .48346 .08739 .48336 .08083 Mtetra
.712 .8 .92 r
.48336 .08083 .48346 .08739 .4945 .08762 .49446 .08107 Mtetra
.653 .755 .925 r
.49446 .08107 .4945 .08762 .5055 .08762 .50554 .08107 Mtetra
.905 .744 .671 r
.9003 .09144 .90027 .09665 .90911 .09723 .9091 .09205 Mtetra
.904 .748 .677 r
.89143 .09082 .89135 .09607 .90027 .09665 .9003 .09144 Mtetra
.903 .751 .683 r
.88247 .0902 .88236 .09548 .89135 .09607 .89143 .09082 Mtetra
.901 .754 .69 r
.87344 .08958 .8733 .0949 .88236 .09548 .88247 .0902 Mtetra
.899 .757 .696 r
.86432 .08896 .86414 .09432 .8733 .0949 .87344 .08958 Mtetra
.896 .759 .703 r
.85511 .08835 .8549 .09374 .86414 .09432 .86432 .08896 Mtetra
.892 .761 .71 r
.84581 .08774 .84557 .09316 .8549 .09374 .85511 .08835 Mtetra
.889 .763 .717 r
.83641 .08713 .83615 .0926 .84557 .09316 .84581 .08774 Mtetra
.885 .764 .724 r
.82692 .08654 .82663 .09204 .83615 .0926 .83641 .08713 Mtetra
.88 .765 .732 r
.81733 .08595 .81702 .09149 .82663 .09204 .82692 .08654 Mtetra
.875 .766 .739 r
.80765 .08538 .8073 .09096 .81702 .09149 .81733 .08595 Mtetra
.869 .766 .747 r
.79786 .08483 .79749 .09044 .8073 .09096 .80765 .08538 Mtetra
.862 .766 .754 r
.78797 .08428 .78758 .08993 .79749 .09044 .79786 .08483 Mtetra
.856 .766 .762 r
.77797 .08376 .77756 .08945 .78758 .08993 .78797 .08428 Mtetra
.848 .765 .77 r
.76788 .08326 .76745 .08899 .77756 .08945 .77797 .08376 Mtetra
.84 .764 .778 r
.75768 .08278 .75723 .08854 .76745 .08899 .76788 .08326 Mtetra
.831 .762 .786 r
.74739 .08233 .74692 .08813 .75723 .08854 .75768 .08278 Mtetra
.822 .76 .794 r
.73699 .0819 .73651 .08774 .74692 .08813 .74739 .08233 Mtetra
.812 .758 .803 r
.72651 .0815 .72601 .08738 .73651 .08774 .73699 .0819 Mtetra
.801 .755 .811 r
.71592 .08114 .71542 .08706 .72601 .08738 .72651 .0815 Mtetra
.79 .752 .819 r
.70525 .0808 .70474 .08676 .71542 .08706 .71592 .08114 Mtetra
.778 .749 .827 r
.6945 .08051 .69398 .08651 .70474 .08676 .70525 .0808 Mtetra
.765 .745 .834 r
.68366 .08025 .68314 .08629 .69398 .08651 .6945 .08051 Mtetra
.752 .741 .842 r
.67276 .08003 .67223 .08611 .68314 .08629 .68366 .08025 Mtetra
.738 .737 .85 r
.66178 .07985 .66125 .08597 .67223 .08611 .67276 .08003 Mtetra
.724 .732 .857 r
.65074 .07972 .65022 .08587 .66125 .08597 .66178 .07985 Mtetra
.71 .728 .864 r
.63966 .07962 .63914 .08582 .65022 .08587 .65074 .07972 Mtetra
.695 .723 .871 r
.62852 .07957 .62802 .08581 .63914 .08582 .63966 .07962 Mtetra
.681 .719 .878 r
.61735 .07956 .61686 .08584 .62802 .08581 .62852 .07957 Mtetra
.667 .716 .884 r
.60616 .07959 .60569 .08591 .61686 .08584 .61735 .07956 Mtetra
.654 .712 .891 r
.59495 .07966 .5945 .08601 .60569 .08591 .60616 .07959 Mtetra
.642 .71 .897 r
.58373 .07976 .58331 .08615 .5945 .08601 .59495 .07966 Mtetra
.631 .708 .902 r
.57251 .07989 .57213 .08632 .58331 .08615 .58373 .07976 Mtetra
.621 .707 .907 r
.5613 .08004 .56096 .08651 .57213 .08632 .57251 .07989 Mtetra
.613 .707 .912 r
.5501 .08022 .54981 .08672 .56096 .08651 .5613 .08004 Mtetra
.607 .707 .915 r
.53892 .08041 .53869 .08694 .54981 .08672 .5501 .08022 Mtetra
.602 .707 .918 r
.52777 .08061 .5276 .08716 .53869 .08694 .53892 .08041 Mtetra
.596 .706 .92 r
.51664 .08083 .51654 .08739 .5276 .08716 .52777 .08061 Mtetra
.59 .703 .921 r
.50554 .08107 .5055 .08762 .51654 .08739 .51664 .08083 Mtetra
.432 .353 .667 r
.09089 .09723 .09089 .10241 .09977 .10186 .09973 .09665 Mtetra
.434 .359 .673 r
.09973 .09665 .09977 .10186 .10872 .10131 .10865 .09607 Mtetra
.437 .365 .679 r
.10865 .09607 .10872 .10131 .11774 .10076 .11764 .09548 Mtetra
.44 .373 .685 r
.11764 .09548 .11774 .10076 .12684 .10021 .1267 .0949 Mtetra
.444 .381 .692 r
.1267 .0949 .12684 .10021 .13603 .09966 .13586 .09432 Mtetra
.449 .389 .699 r
.13586 .09432 .13603 .09966 .1453 .09912 .1451 .09374 Mtetra
.455 .399 .705 r
.1451 .09374 .1453 .09912 .15465 .09858 .15443 .09316 Mtetra
.461 .408 .712 r
.15443 .09316 .15465 .09858 .16411 .09805 .16385 .0926 Mtetra
.468 .419 .719 r
.16385 .0926 .16411 .09805 .17365 .09753 .17337 .09204 Mtetra
.476 .43 .727 r
.17337 .09204 .17365 .09753 .18329 .09701 .18298 .09149 Mtetra
.484 .441 .734 r
.18298 .09149 .18329 .09701 .19303 .09651 .1927 .09096 Mtetra
.493 .453 .741 r
.1927 .09096 .19303 .09651 .20287 .09603 .20251 .09044 Mtetra
.503 .466 .749 r
.20251 .09044 .20287 .09603 .2128 .09556 .21242 .08993 Mtetra
.513 .479 .756 r
.21242 .08993 .2128 .09556 .22284 .09511 .22244 .08945 Mtetra
.523 .493 .764 r
.22244 .08945 .22284 .09511 .23297 .09469 .23255 .08899 Mtetra
.534 .507 .772 r
.23255 .08899 .23297 .09469 .2432 .09428 .24277 .08854 Mtetra
.546 .522 .78 r
.24277 .08854 .2432 .09428 .25353 .0939 .25308 .08813 Mtetra
.558 .537 .788 r
.25308 .08813 .25353 .0939 .26396 .09355 .26349 .08774 Mtetra
.57 .553 .796 r
.26349 .08774 .26396 .09355 .27447 .09323 .27399 .08738 Mtetra
.583 .569 .803 r
.27399 .08738 .27447 .09323 .28507 .09294 .28458 .08706 Mtetra
.595 .585 .811 r
.28458 .08706 .28507 .09294 .29576 .09268 .29526 .08676 Mtetra
.608 .602 .819 r
.29526 .08676 .29576 .09268 .30653 .09246 .30602 .08651 Mtetra
.621 .618 .827 r
.30602 .08651 .30653 .09246 .31738 .09228 .31686 .08629 Mtetra
.634 .635 .834 r
.31686 .08629 .31738 .09228 .32829 .09214 .32777 .08611 Mtetra
.646 .652 .841 r
.32777 .08611 .32829 .09214 .33926 .09204 .33875 .08597 Mtetra
.659 .669 .849 r
.33875 .08597 .33926 .09204 .35029 .09198 .34978 .08587 Mtetra
.67 .685 .856 r
.34978 .08587 .35029 .09198 .36137 .09196 .36086 .08582 Mtetra
.681 .701 .862 r
.36086 .08582 .36137 .09196 .37248 .09199 .37198 .08581 Mtetra
.691 .717 .869 r
.37198 .08581 .37248 .09199 .38362 .09205 .38314 .08584 Mtetra
.699 .731 .875 r
.38314 .08584 .38362 .09205 .39477 .09216 .39431 .08591 Mtetra
.706 .745 .882 r
.39431 .08591 .39477 .09216 .40594 .09231 .4055 .08601 Mtetra
.712 .757 .888 r
.4055 .08601 .40594 .09231 .4171 .09248 .41669 .08615 Mtetra
.716 .768 .894 r
.41669 .08615 .4171 .09248 .42824 .09269 .42787 .08632 Mtetra
.718 .777 .899 r
.42787 .08632 .42824 .09269 .43937 .09291 .43904 .08651 Mtetra
.718 .785 .905 r
.43904 .08651 .43937 .09291 .45047 .09314 .45019 .08672 Mtetra
.717 .791 .91 r
.45019 .08672 .45047 .09314 .46153 .09338 .46131 .08694 Mtetra
.715 .795 .914 r
.46131 .08694 .46153 .09338 .47257 .09362 .4724 .08716 Mtetra
.714 .799 .917 r
.4724 .08716 .47257 .09362 .48356 .09386 .48346 .08739 Mtetra
.715 .803 .919 r
.48346 .08739 .48356 .09386 .49453 .0941 .4945 .08762 Mtetra
.653 .754 .924 r
.4945 .08762 .49453 .0941 .50547 .0941 .5055 .08762 Mtetra
.901 .74 .673 r
.90027 .09665 .90023 .10186 .90911 .10241 .90911 .09723 Mtetra
.9 .744 .679 r
.89135 .09607 .89128 .10131 .90023 .10186 .90027 .09665 Mtetra
.899 .747 .685 r
.88236 .09548 .88226 .10076 .89128 .10131 .89135 .09607 Mtetra
.897 .75 .691 r
.8733 .0949 .87316 .10021 .88226 .10076 .88236 .09548 Mtetra
.895 .753 .698 r
.86414 .09432 .86397 .09966 .87316 .10021 .8733 .0949 Mtetra
.892 .755 .704 r
.8549 .09374 .8547 .09912 .86397 .09966 .86414 .09432 Mtetra
.889 .757 .711 r
.84557 .09316 .84535 .09858 .8547 .09912 .8549 .09374 Mtetra
.885 .759 .718 r
.83615 .0926 .83589 .09805 .84535 .09858 .84557 .09316 Mtetra
.88 .76 .725 r
.82663 .09204 .82635 .09753 .83589 .09805 .83615 .0926 Mtetra
.876 .761 .732 r
.81702 .09149 .81671 .09701 .82635 .09753 .82663 .09204 Mtetra
.87 .761 .739 r
.8073 .09096 .80697 .09651 .81671 .09701 .81702 .09149 Mtetra
.864 .761 .747 r
.79749 .09044 .79713 .09603 .80697 .09651 .8073 .09096 Mtetra
.858 .761 .755 r
.78758 .08993 .7872 .09556 .79713 .09603 .79749 .09044 Mtetra
.851 .76 .762 r
.77756 .08945 .77716 .09511 .7872 .09556 .78758 .08993 Mtetra
.843 .759 .77 r
.76745 .08899 .76703 .09469 .77716 .09511 .77756 .08945 Mtetra
.835 .758 .778 r
.75723 .08854 .7568 .09428 .76703 .09469 .76745 .08899 Mtetra
.826 .756 .786 r
.74692 .08813 .74647 .0939 .7568 .09428 .75723 .08854 Mtetra
.816 .754 .794 r
.73651 .08774 .73604 .09355 .74647 .0939 .74692 .08813 Mtetra
.806 .751 .802 r
.72601 .08738 .72553 .09323 .73604 .09355 .73651 .08774 Mtetra
.795 .748 .81 r
.71542 .08706 .71493 .09294 .72553 .09323 .72601 .08738 Mtetra
.783 .744 .818 r
.70474 .08676 .70424 .09268 .71493 .09294 .71542 .08706 Mtetra
.771 .741 .825 r
.69398 .08651 .69347 .09246 .70424 .09268 .70474 .08676 Mtetra
.758 .736 .833 r
.68314 .08629 .68262 .09228 .69347 .09246 .69398 .08651 Mtetra
.744 .732 .841 r
.67223 .08611 .67171 .09214 .68262 .09228 .68314 .08629 Mtetra
.73 .727 .848 r
.66125 .08597 .66074 .09204 .67171 .09214 .67223 .08611 Mtetra
.715 .722 .855 r
.65022 .08587 .64971 .09198 .66074 .09204 .66125 .08597 Mtetra
.7 .717 .862 r
.63914 .08582 .63863 .09196 .64971 .09198 .65022 .08587 Mtetra
.685 .713 .869 r
.62802 .08581 .62752 .09199 .63863 .09196 .63914 .08582 Mtetra
.67 .708 .876 r
.61686 .08584 .61638 .09205 .62752 .09199 .62802 .08581 Mtetra
.656 .704 .882 r
.60569 .08591 .60523 .09216 .61638 .09205 .61686 .08584 Mtetra
.642 .701 .889 r
.5945 .08601 .59406 .09231 .60523 .09216 .60569 .08591 Mtetra
.63 .698 .895 r
.58331 .08615 .5829 .09248 .59406 .09231 .5945 .08601 Mtetra
.619 .697 .9 r
.57213 .08632 .57176 .09269 .5829 .09248 .58331 .08615 Mtetra
.61 .697 .905 r
.56096 .08651 .56063 .09291 .57176 .09269 .57213 .08632 Mtetra
.603 .697 .91 r
.54981 .08672 .54953 .09314 .56063 .09291 .56096 .08651 Mtetra
.597 .699 .914 r
.53869 .08694 .53847 .09338 .54953 .09314 .54981 .08672 Mtetra
.594 .7 .917 r
.5276 .08716 .52743 .09362 .53847 .09338 .53869 .08694 Mtetra
.591 .701 .919 r
.51654 .08739 .51644 .09386 .52743 .09362 .5276 .08716 Mtetra
.587 .699 .92 r
.5055 .08762 .50547 .0941 .51644 .09386 .51654 .08739 Mtetra
.44 .359 .669 r
.09089 .10241 .09089 .10759 .0998 .10707 .09977 .10186 Mtetra
.442 .365 .675 r
.09977 .10186 .0998 .10707 .10879 .10655 .10872 .10131 Mtetra
.444 .372 .681 r
.10872 .10131 .10879 .10655 .11784 .10604 .11774 .10076 Mtetra
.448 .379 .687 r
.11774 .10076 .11784 .10604 .12697 .10552 .12684 .10021 Mtetra
.452 .387 .693 r
.12684 .10021 .12697 .10552 .13619 .105 .13603 .09966 Mtetra
.457 .395 .7 r
.13603 .09966 .13619 .105 .14549 .10449 .1453 .09912 Mtetra
.463 .404 .706 r
.1453 .09912 .14549 .10449 .15488 .10399 .15465 .09858 Mtetra
.469 .414 .713 r
.15465 .09858 .15488 .10399 .16435 .10349 .16411 .09805 Mtetra
.476 .424 .72 r
.16411 .09805 .16435 .10349 .17392 .103 .17365 .09753 Mtetra
.484 .435 .727 r
.17365 .09753 .17392 .103 .18359 .10252 .18329 .09701 Mtetra
.492 .446 .734 r
.18329 .09701 .18359 .10252 .19335 .10206 .19303 .09651 Mtetra
.501 .459 .741 r
.19303 .09651 .19335 .10206 .20321 .10161 .20287 .09603 Mtetra
.511 .471 .749 r
.20287 .09603 .20321 .10161 .21317 .10117 .2128 .09556 Mtetra
.521 .484 .756 r
.2128 .09556 .21317 .10117 .22322 .10076 .22284 .09511 Mtetra
.532 .498 .764 r
.22284 .09511 .22322 .10076 .23338 .10036 .23297 .09469 Mtetra
.543 .512 .772 r
.23297 .09469 .23338 .10036 .24363 .09999 .2432 .09428 Mtetra
.555 .527 .779 r
.2432 .09428 .24363 .09999 .25397 .09965 .25353 .0939 Mtetra
.567 .543 .787 r
.25353 .0939 .25397 .09965 .26441 .09933 .26396 .09355 Mtetra
.58 .558 .795 r
.26396 .09355 .26441 .09933 .27494 .09904 .27447 .09323 Mtetra
.592 .574 .802 r
.27447 .09323 .27494 .09904 .28555 .09879 .28507 .09294 Mtetra
.606 .591 .81 r
.28507 .09294 .28555 .09879 .29625 .09857 .29576 .09268 Mtetra
.619 .608 .817 r
.29576 .09268 .29625 .09857 .30703 .09838 .30653 .09246 Mtetra
.632 .625 .825 r
.30653 .09246 .30703 .09838 .31788 .09823 .31738 .09228 Mtetra
.645 .642 .832 r
.31738 .09228 .31788 .09823 .32879 .09812 .32829 .09214 Mtetra
.658 .659 .839 r
.32829 .09214 .32879 .09812 .33977 .09805 .33926 .09204 Mtetra
.67 .676 .846 r
.33926 .09204 .33977 .09805 .35079 .09803 .35029 .09198 Mtetra
.682 .692 .853 r
.35029 .09198 .35079 .09803 .36186 .09805 .36137 .09196 Mtetra
.693 .709 .86 r
.36137 .09196 .36186 .09805 .37296 .09811 .37248 .09199 Mtetra
.703 .724 .866 r
.37248 .09199 .37296 .09811 .38409 .09821 .38362 .09205 Mtetra
.712 .739 .873 r
.38362 .09205 .38409 .09821 .39522 .09835 .39477 .09216 Mtetra
.719 .753 .879 r
.39477 .09216 .39522 .09835 .40636 .09853 .40594 .09231 Mtetra
.725 .765 .885 r
.40594 .09231 .40636 .09853 .4175 .09874 .4171 .09248 Mtetra
.728 .776 .891 r
.4171 .09248 .4175 .09874 .42861 .09898 .42824 .09269 Mtetra
.729 .785 .897 r
.42824 .09269 .42861 .09898 .43969 .09923 .43937 .09291 Mtetra
.728 .792 .903 r
.43937 .09291 .43969 .09923 .45074 .0995 .45047 .09314 Mtetra
.726 .797 .908 r
.45047 .09314 .45074 .0995 .46176 .09976 .46153 .09338 Mtetra
.722 .801 .913 r
.46153 .09338 .46176 .09976 .47273 .10001 .47257 .09362 Mtetra
.719 .803 .917 r
.47257 .09362 .47273 .10001 .48366 .10026 .48356 .09386 Mtetra
.718 .804 .919 r
.48356 .09386 .48366 .10026 .49456 .10049 .49453 .0941 Mtetra
.653 .754 .924 r
.49453 .0941 .49456 .10049 .50544 .10049 .50547 .0941 Mtetra
.898 .737 .674 r
.90023 .10186 .9002 .10707 .90911 .10759 .90911 .10241 Mtetra
.897 .741 .68 r
.89128 .10131 .89121 .10655 .9002 .10707 .90023 .10186 Mtetra
.895 .744 .686 r
.88226 .10076 .88216 .10604 .89121 .10655 .89128 .10131 Mtetra
.893 .747 .692 r
.87316 .10021 .87303 .10552 .88216 .10604 .88226 .10076 Mtetra
.891 .749 .699 r
.86397 .09966 .86381 .105 .87303 .10552 .87316 .10021 Mtetra
.888 .751 .705 r
.8547 .09912 .85451 .10449 .86381 .105 .86397 .09966 Mtetra
.885 .753 .712 r
.84535 .09858 .84512 .10399 .85451 .10449 .8547 .09912 Mtetra
.881 .755 .718 r
.83589 .09805 .83565 .10349 .84512 .10399 .84535 .09858 Mtetra
.876 .756 .725 r
.82635 .09753 .82608 .103 .83565 .10349 .83589 .09805 Mtetra
.872 .756 .732 r
.81671 .09701 .81641 .10252 .82608 .103 .82635 .09753 Mtetra
.866 .756 .74 r
.80697 .09651 .80665 .10206 .81641 .10252 .81671 .09701 Mtetra
.86 .756 .747 r
.79713 .09603 .79679 .10161 .80665 .10206 .80697 .09651 Mtetra
.853 .756 .754 r
.7872 .09556 .78683 .10117 .79679 .10161 .79713 .09603 Mtetra
.846 .755 .762 r
.77716 .09511 .77678 .10076 .78683 .10117 .7872 .09556 Mtetra
.838 .753 .77 r
.76703 .09469 .76662 .10036 .77678 .10076 .77716 .09511 Mtetra
.83 .752 .777 r
.7568 .09428 .75637 .09999 .76662 .10036 .76703 .09469 Mtetra
.82 .749 .785 r
.74647 .0939 .74603 .09965 .75637 .09999 .7568 .09428 Mtetra
.81 .747 .793 r
.73604 .09355 .73559 .09933 .74603 .09965 .74647 .0939 Mtetra
.8 .744 .801 r
.72553 .09323 .72506 .09904 .73559 .09933 .73604 .09355 Mtetra
.788 .74 .809 r
.71493 .09294 .71445 .09879 .72506 .09904 .72553 .09323 Mtetra
.776 .737 .816 r
.70424 .09268 .70375 .09857 .71445 .09879 .71493 .09294 Mtetra
.763 .732 .824 r
.69347 .09246 .69297 .09838 .70375 .09857 .70424 .09268 Mtetra
.75 .728 .831 r
.68262 .09228 .68212 .09823 .69297 .09838 .69347 .09246 Mtetra
.736 .723 .839 r
.67171 .09214 .67121 .09812 .68212 .09823 .68262 .09228 Mtetra
.721 .717 .846 r
.66074 .09204 .66023 .09805 .67121 .09812 .67171 .09214 Mtetra
.706 .712 .853 r
.64971 .09198 .64921 .09803 .66023 .09805 .66074 .09204 Mtetra
.69 .707 .86 r
.63863 .09196 .63814 .09805 .64921 .09803 .64971 .09198 Mtetra
.675 .701 .867 r
.62752 .09199 .62704 .09811 .63814 .09805 .63863 .09196 Mtetra
.659 .697 .874 r
.61638 .09205 .61591 .09821 .62704 .09811 .62752 .09199 Mtetra
.644 .692 .88 r
.60523 .09216 .60478 .09835 .61591 .09821 .61638 .09205 Mtetra
.63 .689 .886 r
.59406 .09231 .59364 .09853 .60478 .09835 .60523 .09216 Mtetra
.617 .686 .892 r
.5829 .09248 .5825 .09874 .59364 .09853 .59406 .09231 Mtetra
.606 .685 .898 r
.57176 .09269 .57139 .09898 .5825 .09874 .5829 .09248 Mtetra
.597 .686 .904 r
.56063 .09291 .56031 .09923 .57139 .09898 .57176 .09269 Mtetra
.591 .687 .909 r
.54953 .09314 .54926 .0995 .56031 .09923 .56063 .09291 Mtetra
.587 .69 .913 r
.53847 .09338 .53824 .09976 .54926 .0995 .54953 .09314 Mtetra
.586 .694 .916 r
.52743 .09362 .52727 .10001 .53824 .09976 .53847 .09338 Mtetra
.585 .696 .919 r
.51644 .09386 .51634 .10026 .52727 .10001 .52743 .09362 Mtetra
.584 .697 .92 r
.50547 .0941 .50544 .10049 .51634 .10026 .51644 .09386 Mtetra
.448 .365 .671 r
.09089 .10759 .09089 .11277 .09984 .11228 .0998 .10707 Mtetra
.45 .371 .676 r
.0998 .10707 .09984 .11228 .10885 .11179 .10879 .10655 Mtetra
.452 .377 .682 r
.10879 .10655 .10885 .11179 .11794 .11131 .11784 .10604 Mtetra
.455 .384 .688 r
.11784 .10604 .11794 .11131 .1271 .11082 .12697 .10552 Mtetra
.459 .392 .694 r
.12697 .10552 .1271 .11082 .13635 .11034 .13619 .105 Mtetra
.464 .4 .701 r
.13619 .105 .13635 .11034 .14568 .10986 .14549 .10449 Mtetra
.47 .409 .707 r
.14549 .10449 .14568 .10986 .15509 .10938 .15488 .10399 Mtetra
.476 .419 .714 r
.15488 .10399 .15509 .10938 .16459 .10892 .16435 .10349 Mtetra
.484 .429 .72 r
.16435 .10349 .16459 .10892 .17419 .10846 .17392 .103 Mtetra
.491 .44 .727 r
.17392 .103 .17419 .10846 .18388 .10801 .18359 .10252 Mtetra
.5 .451 .734 r
.18359 .10252 .18388 .10801 .19367 .10758 .19335 .10206 Mtetra
.509 .464 .742 r
.19335 .10206 .19367 .10758 .20355 .10716 .20321 .10161 Mtetra
.519 .476 .749 r
.20321 .10161 .20355 .10716 .21352 .10676 .21317 .10117 Mtetra
.529 .489 .756 r
.21317 .10117 .21352 .10676 .2236 .10638 .22322 .10076 Mtetra
.54 .503 .763 r
.22322 .10076 .2236 .10638 .23377 .10602 .23338 .10036 Mtetra
.552 .518 .771 r
.23338 .10036 .23377 .10602 .24404 .10568 .24363 .09999 Mtetra
.564 .532 .778 r
.24363 .09999 .24404 .10568 .2544 .10537 .25397 .09965 Mtetra
.576 .548 .786 r
.25397 .09965 .2544 .10537 .26485 .10508 .26441 .09933 Mtetra
.589 .564 .794 r
.26441 .09933 .26485 .10508 .27539 .10483 .27494 .09904 Mtetra
.602 .58 .801 r
.27494 .09904 .27539 .10483 .28602 .1046 .28555 .09879 Mtetra
.615 .596 .808 r
.28555 .09879 .28602 .1046 .29672 .10441 .29625 .09857 Mtetra
.629 .613 .816 r
.29625 .09857 .29672 .10441 .30751 .10426 .30703 .09838 Mtetra
.642 .63 .823 r
.30703 .09838 .30751 .10426 .31836 .10414 .31788 .09823 Mtetra
.656 .648 .83 r
.31788 .09823 .31836 .10414 .32928 .10406 .32879 .09812 Mtetra
.669 .665 .837 r
.32879 .09812 .32928 .10406 .34025 .10402 .33977 .09805 Mtetra
.682 .682 .844 r
.33977 .09805 .34025 .10402 .35128 .10403 .35079 .09803 Mtetra
.694 .699 .851 r
.35079 .09803 .35128 .10403 .36234 .10408 .36186 .09805 Mtetra
.705 .716 .857 r
.36186 .09805 .36234 .10408 .37343 .10417 .37296 .09811 Mtetra
.716 .732 .863 r
.37296 .09811 .37343 .10417 .38454 .10431 .38409 .09821 Mtetra
.725 .747 .87 r
.38409 .09821 .38454 .10431 .39566 .10448 .39522 .09835 Mtetra
.732 .761 .876 r
.39522 .09835 .39566 .10448 .40678 .10469 .40636 .09853 Mtetra
.737 .774 .882 r
.40636 .09853 .40678 .10469 .41789 .10493 .4175 .09874 Mtetra
.74 .785 .888 r
.4175 .09874 .41789 .10493 .42897 .1052 .42861 .09898 Mtetra
.741 .793 .895 r
.42861 .09898 .42897 .1052 .44001 .10549 .43969 .09923 Mtetra
.739 .8 .901 r
.43969 .09923 .44001 .10549 .45102 .10578 .45074 .0995 Mtetra
.735 .804 .907 r
.45074 .0995 .45102 .10578 .46198 .10606 .46176 .09976 Mtetra
.729 .806 .912 r
.46176 .09976 .46198 .10606 .47289 .10633 .47273 .10001 Mtetra
.723 .806 .916 r
.47273 .10001 .47289 .10633 .48376 .10658 .48366 .10026 Mtetra
.719 .806 .919 r
.48366 .10026 .48376 .10658 .4946 .1068 .49456 .10049 Mtetra
.653 .754 .924 r
.49456 .10049 .4946 .1068 .5054 .1068 .50544 .10049 Mtetra
.894 .734 .676 r
.9002 .10707 .90016 .11228 .90911 .11277 .90911 .10759 Mtetra
.893 .737 .682 r
.89121 .10655 .89115 .11179 .90016 .11228 .9002 .10707 Mtetra
.891 .741 .688 r
.88216 .10604 .88206 .11131 .89115 .11179 .89121 .10655 Mtetra
.89 .743 .694 r
.87303 .10552 .8729 .11082 .88206 .11131 .88216 .10604 Mtetra
.887 .746 .7 r
.86381 .105 .86365 .11034 .8729 .11082 .87303 .10552 Mtetra
.884 .748 .706 r
.85451 .10449 .85432 .10986 .86365 .11034 .86381 .105 Mtetra
.881 .749 .712 r
.84512 .10399 .84491 .10938 .85432 .10986 .85451 .10449 Mtetra
.877 .75 .719 r
.83565 .10349 .83541 .10892 .84491 .10938 .84512 .10399 Mtetra
.872 .751 .726 r
.82608 .103 .82581 .10846 .83541 .10892 .83565 .10349 Mtetra
.867 .752 .733 r
.81641 .10252 .81612 .10801 .82581 .10846 .82608 .103 Mtetra
.862 .752 .74 r
.80665 .10206 .80633 .10758 .81612 .10801 .81641 .10252 Mtetra
.856 .751 .747 r
.79679 .10161 .79645 .10716 .80633 .10758 .80665 .10206 Mtetra
.849 .75 .754 r
.78683 .10117 .78648 .10676 .79645 .10716 .79679 .10161 Mtetra
.841 .749 .762 r
.77678 .10076 .7764 .10638 .78648 .10676 .78683 .10117 Mtetra
.833 .748 .769 r
.76662 .10036 .76623 .10602 .7764 .10638 .77678 .10076 Mtetra
.825 .746 .777 r
.75637 .09999 .75596 .10568 .76623 .10602 .76662 .10036 Mtetra
.815 .743 .784 r
.74603 .09965 .7456 .10537 .75596 .10568 .75637 .09999 Mtetra
.805 .74 .792 r
.73559 .09933 .73515 .10508 .7456 .10537 .74603 .09965 Mtetra
.794 .737 .8 r
.72506 .09904 .72461 .10483 .73515 .10508 .73559 .09933 Mtetra
.782 .733 .807 r
.71445 .09879 .71398 .1046 .72461 .10483 .72506 .09904 Mtetra
.77 .729 .815 r
.70375 .09857 .70328 .10441 .71398 .1046 .71445 .09879 Mtetra
.756 .724 .822 r
.69297 .09838 .69249 .10426 .70328 .10441 .70375 .09857 Mtetra
.742 .719 .83 r
.68212 .09823 .68164 .10414 .69249 .10426 .69297 .09838 Mtetra
.728 .713 .837 r
.67121 .09812 .67072 .10406 .68164 .10414 .68212 .09823 Mtetra
.712 .708 .844 r
.66023 .09805 .65975 .10402 .67072 .10406 .67121 .09812 Mtetra
.696 .702 .851 r
.64921 .09803 .64872 .10403 .65975 .10402 .66023 .09805 Mtetra
.68 .696 .858 r
.63814 .09805 .63766 .10408 .64872 .10403 .64921 .09803 Mtetra
.664 .69 .864 r
.62704 .09811 .62657 .10417 .63766 .10408 .63814 .09805 Mtetra
.648 .685 .871 r
.61591 .09821 .61546 .10431 .62657 .10417 .62704 .09811 Mtetra
.632 .68 .877 r
.60478 .09835 .60434 .10448 .61546 .10431 .61591 .09821 Mtetra
.617 .676 .883 r
.59364 .09853 .59322 .10469 .60434 .10448 .60478 .09835 Mtetra
.604 .674 .89 r
.5825 .09874 .58211 .10493 .59322 .10469 .59364 .09853 Mtetra
.593 .673 .896 r
.57139 .09898 .57103 .1052 .58211 .10493 .5825 .09874 Mtetra
.584 .674 .901 r
.56031 .09923 .55999 .10549 .57103 .1052 .57139 .09898 Mtetra
.579 .677 .907 r
.54926 .0995 .54898 .10578 .55999 .10549 .56031 .09923 Mtetra
.577 .681 .912 r
.53824 .09976 .53802 .10606 .54898 .10578 .54926 .0995 Mtetra
.577 .687 .916 r
.52727 .10001 .52711 .10633 .53802 .10606 .53824 .09976 Mtetra
.58 .692 .918 r
.51634 .10026 .51624 .10658 .52711 .10633 .52727 .10001 Mtetra
.582 .695 .919 r
.50544 .10049 .5054 .1068 .51624 .10658 .51634 .10026 Mtetra
.455 .371 .673 r
.09089 .11277 .09089 .11794 .09987 .11749 .09984 .11228 Mtetra
.457 .377 .678 r
.09984 .11228 .09987 .11749 .10891 .11703 .10885 .11179 Mtetra
.459 .383 .684 r
.10885 .11179 .10891 .11703 .11803 .11657 .11794 .11131 Mtetra
.463 .39 .69 r
.11794 .11131 .11803 .11657 .12723 .11612 .1271 .11082 Mtetra
.467 .398 .695 r
.1271 .11082 .12723 .11612 .1365 .11566 .13635 .11034 Mtetra
.472 .406 .702 r
.13635 .11034 .1365 .11566 .14586 .11521 .14568 .10986 Mtetra
.477 .415 .708 r
.14568 .10986 .14586 .11521 .1553 .11477 .15509 .10938 Mtetra
.484 .424 .714 r
.15509 .10938 .1553 .11477 .16483 .11433 .16459 .10892 Mtetra
.491 .434 .721 r
.16459 .10892 .16483 .11433 .17445 .11391 .17419 .10846 Mtetra
.499 .445 .728 r
.17419 .10846 .17445 .11391 .18416 .11349 .18388 .10801 Mtetra
.507 .456 .734 r
.18388 .10801 .18416 .11349 .19397 .11309 .19367 .10758 Mtetra
.517 .468 .741 r
.19367 .10758 .19397 .11309 .20387 .1127 .20355 .10716 Mtetra
.527 .481 .748 r
.20355 .10716 .20387 .1127 .21387 .11233 .21352 .10676 Mtetra
.537 .494 .756 r
.21352 .10676 .21387 .11233 .22396 .11198 .2236 .10638 Mtetra
.548 .508 .763 r
.2236 .10638 .22396 .11198 .23415 .11165 .23377 .10602 Mtetra
.56 .522 .77 r
.23377 .10602 .23415 .11165 .24444 .11134 .24404 .10568 Mtetra
.572 .537 .778 r
.24404 .10568 .24444 .11134 .25481 .11106 .2544 .10537 Mtetra
.585 .553 .785 r
.2544 .10537 .25481 .11106 .26528 .1108 .26485 .10508 Mtetra
.598 .569 .792 r
.26485 .10508 .26528 .1108 .27583 .11058 .27539 .10483 Mtetra
.611 .585 .8 r
.27539 .10483 .27583 .11058 .28647 .11038 .28602 .1046 Mtetra
.625 .602 .807 r
.28602 .1046 .28647 .11038 .29718 .11022 .29672 .10441 Mtetra
.639 .619 .814 r
.29672 .10441 .29718 .11022 .30797 .11009 .30751 .10426 Mtetra
.652 .636 .821 r
.30751 .10426 .30797 .11009 .31883 .11001 .31836 .10414 Mtetra
.666 .653 .828 r
.31836 .10414 .31883 .11001 .32975 .10996 .32928 .10406 Mtetra
.68 .671 .835 r
.32928 .10406 .32975 .10996 .34073 .10995 .34025 .10402 Mtetra
.693 .688 .841 r
.34025 .10402 .34073 .10995 .35175 .10998 .35128 .10403 Mtetra
.706 .706 .848 r
.35128 .10403 .35175 .10998 .3628 .11006 .36234 .10408 Mtetra
.717 .723 .854 r
.36234 .10408 .3628 .11006 .37389 .11018 .37343 .10417 Mtetra
.728 .739 .86 r
.37343 .10417 .37389 .11018 .38499 .11034 .38454 .10431 Mtetra
.737 .754 .866 r
.38454 .10431 .38499 .11034 .39609 .11055 .39566 .10448 Mtetra
.745 .769 .872 r
.39566 .10448 .39609 .11055 .40719 .11079 .40678 .10469 Mtetra
.75 .782 .879 r
.40678 .10469 .40719 .11079 .41827 .11106 .41789 .10493 Mtetra
.753 .793 .885 r
.41789 .10493 .41827 .11106 .42932 .11136 .42897 .1052 Mtetra
.753 .802 .892 r
.42897 .1052 .42932 .11136 .44033 .11167 .44001 .10549 Mtetra
.75 .808 .899 r
.44001 .10549 .44033 .11167 .45129 .11199 .45102 .10578 Mtetra
.744 .811 .905 r
.45102 .10578 .45129 .11199 .4622 .11229 .46198 .10606 Mtetra
.736 .812 .911 r
.46198 .10606 .4622 .11229 .47305 .11258 .47289 .10633 Mtetra
.727 .81 .916 r
.47289 .10633 .47305 .11258 .48386 .11282 .48376 .10658 Mtetra
.719 .807 .919 r
.48376 .10658 .48386 .11282 .49463 .11304 .4946 .1068 Mtetra
.653 .755 .924 r
.4946 .1068 .49463 .11304 .50537 .11304 .5054 .1068 Mtetra
.89 .731 .678 r
.90016 .11228 .90013 .11749 .90911 .11794 .90911 .11277 Mtetra
.889 .734 .683 r
.89115 .11179 .89109 .11703 .90013 .11749 .90016 .11228 Mtetra
.888 .737 .689 r
.88206 .11131 .88197 .11657 .89109 .11703 .89115 .11179 Mtetra
.886 .74 .695 r
.8729 .11082 .87277 .11612 .88197 .11657 .88206 .11131 Mtetra
.883 .742 .701 r
.86365 .11034 .8635 .11566 .87277 .11612 .8729 .11082 Mtetra
.88 .744 .707 r
.85432 .10986 .85414 .11521 .8635 .11566 .86365 .11034 Mtetra
.877 .745 .713 r
.84491 .10938 .8447 .11477 .85414 .11521 .85432 .10986 Mtetra
.873 .746 .719 r
.83541 .10892 .83517 .11433 .8447 .11477 .84491 .10938 Mtetra
.869 .747 .726 r
.82581 .10846 .82555 .11391 .83517 .11433 .83541 .10892 Mtetra
.863 .747 .733 r
.81612 .10801 .81584 .11349 .82555 .11391 .82581 .10846 Mtetra
.858 .747 .74 r
.80633 .10758 .80603 .11309 .81584 .11349 .81612 .10801 Mtetra
.851 .746 .747 r
.79645 .10716 .79613 .1127 .80603 .11309 .80633 .10758 Mtetra
.844 .745 .754 r
.78648 .10676 .78613 .11233 .79613 .1127 .79645 .10716 Mtetra
.837 .744 .761 r
.7764 .10638 .77604 .11198 .78613 .11233 .78648 .10676 Mtetra
.829 .742 .768 r
.76623 .10602 .76585 .11165 .77604 .11198 .7764 .10638 Mtetra
.82 .739 .776 r
.75596 .10568 .75556 .11134 .76585 .11165 .76623 .10602 Mtetra
.81 .737 .783 r
.7456 .10537 .74519 .11106 .75556 .11134 .75596 .10568 Mtetra
.799 .733 .791 r
.73515 .10508 .73472 .1108 .74519 .11106 .7456 .10537 Mtetra
.788 .729 .798 r
.72461 .10483 .72417 .11058 .73472 .1108 .73515 .10508 Mtetra
.776 .725 .806 r
.71398 .1046 .71353 .11038 .72417 .11058 .72461 .10483 Mtetra
.763 .72 .813 r
.70328 .10441 .70282 .11022 .71353 .11038 .71398 .1046 Mtetra
.749 .715 .82 r
.69249 .10426 .69203 .11009 .70282 .11022 .70328 .10441 Mtetra
.735 .71 .827 r
.68164 .10414 .68117 .11001 .69203 .11009 .69249 .10426 Mtetra
.719 .704 .835 r
.67072 .10406 .67025 .10996 .68117 .11001 .68164 .10414 Mtetra
.703 .697 .841 r
.65975 .10402 .65927 .10995 .67025 .10996 .67072 .10406 Mtetra
.687 .691 .848 r
.64872 .10403 .64825 .10998 .65927 .10995 .65975 .10402 Mtetra
.67 .684 .855 r
.63766 .10408 .6372 .11006 .64825 .10998 .64872 .10403 Mtetra
.653 .678 .861 r
.62657 .10417 .62611 .11018 .6372 .11006 .63766 .10408 Mtetra
.636 .672 .868 r
.61546 .10431 .61501 .11034 .62611 .11018 .62657 .10417 Mtetra
.619 .667 .874 r
.60434 .10448 .60391 .11055 .61501 .11034 .61546 .10431 Mtetra
.604 .663 .88 r
.59322 .10469 .59281 .11079 .60391 .11055 .60434 .10448 Mtetra
.59 .66 .886 r
.58211 .10493 .58173 .11106 .59281 .11079 .59322 .10469 Mtetra
.579 .66 .893 r
.57103 .1052 .57068 .11136 .58173 .11106 .58211 .10493 Mtetra
.57 .662 .899 r
.55999 .10549 .55967 .11167 .57068 .11136 .57103 .1052 Mtetra
.566 .666 .905 r
.54898 .10578 .54871 .11199 .55967 .11167 .55999 .10549 Mtetra
.565 .672 .911 r
.53802 .10606 .5378 .11229 .54871 .11199 .54898 .10578 Mtetra
.568 .68 .915 r
.52711 .10633 .52695 .11258 .5378 .11229 .53802 .10606 Mtetra
.574 .688 .919 r
.51624 .10658 .51614 .11282 .52695 .11258 .52711 .10633 Mtetra
.581 .694 .92 r
.5054 .1068 .50537 .11304 .51614 .11282 .51624 .10658 Mtetra
.462 .377 .674 r
.09089 .11794 .09088 .12312 .0999 .12269 .09987 .11749 Mtetra
.464 .383 .68 r
.09987 .11749 .0999 .12269 .10898 .12227 .10891 .11703 Mtetra
.466 .389 .685 r
.10891 .11703 .10898 .12227 .11813 .12184 .11803 .11657 Mtetra
.47 .395 .691 r
.11803 .11657 .11813 .12184 .12735 .12141 .12723 .11612 Mtetra
.474 .403 .696 r
.12723 .11612 .12735 .12141 .13665 .12098 .1365 .11566 Mtetra
.479 .411 .702 r
.1365 .11566 .13665 .12098 .14603 .12056 .14586 .11521 Mtetra
.484 .419 .708 r
.14586 .11521 .14603 .12056 .1555 .12015 .1553 .11477 Mtetra
.491 .429 .715 r
.1553 .11477 .1555 .12015 .16505 .11974 .16483 .11433 Mtetra
.498 .439 .721 r
.16483 .11433 .16505 .11974 .1747 .11935 .17445 .11391 Mtetra
.506 .45 .728 r
.17445 .11391 .1747 .11935 .18443 .11896 .18416 .11349 Mtetra
.515 .461 .734 r
.18416 .11349 .18443 .11896 .19426 .11859 .19397 .11309 Mtetra
.524 .473 .741 r
.19397 .11309 .19426 .11859 .20419 .11823 .20387 .1127 Mtetra
.534 .486 .748 r
.20387 .1127 .20419 .11823 .2142 .11789 .21387 .11233 Mtetra
.545 .499 .755 r
.21387 .11233 .2142 .11789 .22431 .11756 .22396 .11198 Mtetra
.556 .513 .762 r
.22396 .11198 .22431 .11756 .23452 .11726 .23415 .11165 Mtetra
.568 .527 .769 r
.23415 .11165 .23452 .11726 .24482 .11698 .24444 .11134 Mtetra
.58 .542 .776 r
.24444 .11134 .24482 .11698 .25521 .11673 .25481 .11106 Mtetra
.593 .557 .784 r
.25481 .11106 .25521 .11673 .26569 .1165 .26528 .1108 Mtetra
.607 .573 .791 r
.26528 .1108 .26569 .1165 .27625 .1163 .27583 .11058 Mtetra
.62 .59 .798 r
.27583 .11058 .27625 .1163 .2869 .11613 .28647 .11038 Mtetra
.634 .607 .805 r
.28647 .11038 .2869 .11613 .29763 .116 .29718 .11022 Mtetra
.648 .624 .812 r
.29718 .11022 .29763 .116 .30842 .1159 .30797 .11009 Mtetra
.662 .641 .819 r
.30797 .11009 .30842 .1159 .31929 .11583 .31883 .11001 Mtetra
.677 .659 .825 r
.31883 .11001 .31929 .11583 .33021 .11581 .32975 .10996 Mtetra
.691 .677 .832 r
.32975 .10996 .33021 .11581 .34118 .11583 .34073 .10995 Mtetra
.704 .694 .838 r
.34073 .10995 .34118 .11583 .3522 .11589 .35175 .10998 Mtetra
.717 .712 .844 r
.35175 .10998 .3522 .11589 .36326 .11599 .3628 .11006 Mtetra
.729 .729 .85 r
.3628 .11006 .36326 .11599 .37433 .11614 .37389 .11018 Mtetra
.74 .746 .856 r
.37389 .11018 .37433 .11614 .38542 .11633 .38499 .11034 Mtetra
.75 .762 .862 r
.38499 .11034 .38542 .11633 .39651 .11656 .39609 .11055 Mtetra
.758 .776 .868 r
.39609 .11055 .39651 .11656 .40759 .11683 .40719 .11079 Mtetra
.763 .79 .875 r
.40719 .11079 .40759 .11683 .41865 .11713 .41827 .11106 Mtetra
.766 .801 .881 r
.41827 .11106 .41865 .11713 .42967 .11745 .42932 .11136 Mtetra
.765 .81 .889 r
.42932 .11136 .42967 .11745 .44064 .1178 .44033 .11167 Mtetra
.761 .816 .896 r
.44033 .11167 .44064 .1178 .45156 .11814 .45129 .11199 Mtetra
.753 .819 .904 r
.45129 .11199 .45156 .11814 .46242 .11846 .4622 .11229 Mtetra
.743 .818 .911 r
.4622 .11229 .46242 .11846 .47322 .11876 .47305 .11258 Mtetra
.73 .814 .917 r
.47305 .11258 .47322 .11876 .48396 .11901 .48386 .11282 Mtetra
.719 .808 .921 r
.48386 .11282 .48396 .11901 .49466 .11921 .49463 .11304 Mtetra
.652 .755 .925 r
.49463 .11304 .49466 .11921 .50534 .11921 .50537 .11304 Mtetra
.886 .728 .679 r
.90013 .11749 .9001 .12269 .90912 .12312 .90911 .11794 Mtetra
.885 .731 .685 r
.89109 .11703 .89102 .12227 .9001 .12269 .90013 .11749 Mtetra
.884 .734 .69 r
.88197 .11657 .88187 .12184 .89102 .12227 .89109 .11703 Mtetra
.882 .736 .696 r
.87277 .11612 .87265 .12141 .88187 .12184 .88197 .11657 Mtetra
.88 .738 .701 r
.8635 .11566 .86335 .12098 .87265 .12141 .87277 .11612 Mtetra
.877 .74 .707 r
.85414 .11521 .85397 .12056 .86335 .12098 .8635 .11566 Mtetra
.873 .741 .713 r
.8447 .11477 .8445 .12015 .85397 .12056 .85414 .11521 Mtetra
.869 .742 .72 r
.83517 .11433 .83495 .11974 .8445 .12015 .8447 .11477 Mtetra
.865 .742 .726 r
.82555 .11391 .8253 .11935 .83495 .11974 .83517 .11433 Mtetra
.859 .742 .733 r
.81584 .11349 .81557 .11896 .8253 .11935 .82555 .11391 Mtetra
.854 .742 .739 r
.80603 .11309 .80574 .11859 .81557 .11896 .81584 .11349 Mtetra
.847 .741 .746 r
.79613 .1127 .79581 .11823 .80574 .11859 .80603 .11309 Mtetra
.84 .74 .753 r
.78613 .11233 .7858 .11789 .79581 .11823 .79613 .1127 Mtetra
.832 .738 .76 r
.77604 .11198 .77569 .11756 .7858 .11789 .78613 .11233 Mtetra
.824 .736 .767 r
.76585 .11165 .76548 .11726 .77569 .11756 .77604 .11198 Mtetra
.815 .733 .775 r
.75556 .11134 .75518 .11698 .76548 .11726 .76585 .11165 Mtetra
.805 .73 .782 r
.74519 .11106 .74479 .11673 .75518 .11698 .75556 .11134 Mtetra
.794 .726 .789 r
.73472 .1108 .73431 .1165 .74479 .11673 .74519 .11106 Mtetra
.782 .722 .797 r
.72417 .11058 .72375 .1163 .73431 .1165 .73472 .1108 Mtetra
.77 .717 .804 r
.71353 .11038 .7131 .11613 .72375 .1163 .72417 .11058 Mtetra
.756 .712 .811 r
.70282 .11022 .70237 .116 .7131 .11613 .71353 .11038 Mtetra
.742 .707 .818 r
.69203 .11009 .69158 .1159 .70237 .116 .70282 .11022 Mtetra
.727 .7 .825 r
.68117 .11001 .68071 .11583 .69158 .1159 .69203 .11009 Mtetra
.711 .694 .832 r
.67025 .10996 .66979 .11581 .68071 .11583 .68117 .11001 Mtetra
.695 .687 .839 r
.65927 .10995 .65882 .11583 .66979 .11581 .67025 .10996 Mtetra
.677 .68 .845 r
.64825 .10998 .6478 .11589 .65882 .11583 .65927 .10995 Mtetra
.66 .673 .852 r
.6372 .11006 .63674 .11599 .6478 .11589 .64825 .10998 Mtetra
.642 .666 .858 r
.62611 .11018 .62567 .11614 .63674 .11599 .6372 .11006 Mtetra
.624 .659 .864 r
.61501 .11034 .61458 .11633 .62567 .11614 .62611 .11018 Mtetra
.607 .654 .87 r
.60391 .11055 .60349 .11656 .61458 .11633 .61501 .11034 Mtetra
.59 .649 .877 r
.59281 .11079 .59241 .11683 .60349 .11656 .60391 .11055 Mtetra
.576 .646 .883 r
.58173 .11106 .58135 .11713 .59241 .11683 .59281 .11079 Mtetra
.564 .646 .89 r
.57068 .11136 .57033 .11745 .58135 .11713 .58173 .11106 Mtetra
.555 .648 .896 r
.55967 .11167 .55936 .1178 .57033 .11745 .57068 .11136 Mtetra
.552 .654 .903 r
.54871 .11199 .54844 .11814 .55936 .1178 .55967 .11167 Mtetra
.553 .663 .91 r
.5378 .11229 .53758 .11846 .54844 .11814 .54871 .11199 Mtetra
.558 .673 .915 r
.52695 .11258 .52678 .11876 .53758 .11846 .5378 .11229 Mtetra
.568 .685 .919 r
.51614 .11282 .51604 .11901 .52678 .11876 .52695 .11258 Mtetra
.58 .695 .92 r
.50537 .11304 .50534 .11921 .51604 .11901 .51614 .11282 Mtetra
.469 .383 .676 r
.09088 .12312 .09088 .1283 .09993 .1279 .0999 .12269 Mtetra
.471 .388 .681 r
.0999 .12269 .09993 .1279 .10904 .1275 .10898 .12227 Mtetra
.473 .394 .686 r
.10898 .12227 .10904 .1275 .11821 .1271 .11813 .12184 Mtetra
.476 .4 .692 r
.11813 .12184 .11821 .1271 .12746 .1267 .12735 .12141 Mtetra
.48 .408 .697 r
.12735 .12141 .12746 .1267 .13679 .1263 .13665 .12098 Mtetra
.485 .415 .703 r
.13665 .12098 .13679 .1263 .1462 .12591 .14603 .12056 Mtetra
.491 .424 .709 r
.14603 .12056 .1462 .12591 .15569 .12552 .1555 .12015 Mtetra
.498 .433 .715 r
.1555 .12015 .15569 .12552 .16527 .12514 .16505 .11974 Mtetra
.505 .443 .721 r
.16505 .11974 .16527 .12514 .17494 .12477 .1747 .11935 Mtetra
.513 .454 .728 r
.1747 .11935 .17494 .12477 .1847 .12441 .18443 .11896 Mtetra
.522 .465 .734 r
.18443 .11896 .1847 .12441 .19454 .12407 .19426 .11859 Mtetra
.531 .477 .741 r
.19426 .11859 .19454 .12407 .20449 .12374 .20419 .11823 Mtetra
.541 .49 .747 r
.20419 .11823 .20449 .12374 .21452 .12342 .2142 .11789 Mtetra
.552 .503 .754 r
.2142 .11789 .21452 .12342 .22465 .12312 .22431 .11756 Mtetra
.564 .517 .761 r
.22431 .11756 .22465 .12312 .23488 .12285 .23452 .11726 Mtetra
.576 .531 .768 r
.23452 .11726 .23488 .12285 .24519 .1226 .24482 .11698 Mtetra
.588 .546 .775 r
.24482 .11698 .24519 .1226 .2556 .12237 .25521 .11673 Mtetra
.602 .562 .782 r
.25521 .11673 .2556 .12237 .26609 .12216 .26569 .1165 Mtetra
.615 .578 .789 r
.26569 .1165 .26609 .12216 .27666 .12199 .27625 .1163 Mtetra
.629 .594 .796 r
.27625 .1163 .27666 .12199 .28732 .12185 .2869 .11613 Mtetra
.643 .611 .803 r
.2869 .11613 .28732 .12185 .29805 .12174 .29763 .116 Mtetra
.658 .629 .809 r
.29763 .116 .29805 .12174 .30886 .12166 .30842 .1159 Mtetra
.672 .646 .816 r
.30842 .1159 .30886 .12166 .31973 .12162 .31929 .11583 Mtetra
.687 .664 .822 r
.31929 .11583 .31973 .12162 .33065 .12162 .33021 .11581 Mtetra
.701 .682 .829 r
.33021 .11581 .33065 .12162 .34163 .12166 .34118 .11583 Mtetra
.715 .7 .835 r
.34118 .11583 .34163 .12166 .35264 .12175 .3522 .11589 Mtetra
.728 .718 .84 r
.3522 .11589 .35264 .12175 .36369 .12187 .36326 .11599 Mtetra
.741 .735 .846 r
.36326 .11599 .36369 .12187 .37476 .12204 .37433 .11614 Mtetra
.753 .752 .852 r
.37433 .11614 .37476 .12204 .38584 .12226 .38542 .11633 Mtetra
.763 .769 .858 r
.38542 .11633 .38584 .12226 .39692 .12251 .39651 .11656 Mtetra
.771 .784 .864 r
.39651 .11656 .39692 .12251 .40799 .1228 .40759 .11683 Mtetra
.777 .798 .87 r
.40759 .11683 .40799 .1228 .41902 .12313 .41865 .11713 Mtetra
.779 .809 .877 r
.41865 .11713 .41902 .12313 .43001 .12348 .42967 .11745 Mtetra
.778 .819 .885 r
.42967 .11745 .43001 .12348 .44095 .12385 .44064 .1178 Mtetra
.773 .825 .893 r
.44064 .1178 .44095 .12385 .45183 .12422 .45156 .11814 Mtetra
.763 .827 .902 r
.45156 .11814 .45183 .12422 .46264 .12456 .46242 .11846 Mtetra
.75 .825 .91 r
.46242 .11846 .46264 .12456 .47338 .12487 .47322 .11876 Mtetra
.733 .819 .918 r
.47322 .11876 .47338 .12487 .48406 .12512 .48396 .11901 Mtetra
.717 .809 .922 r
.48396 .11901 .48406 .12512 .49469 .12532 .49466 .11921 Mtetra
.651 .757 .927 r
.49466 .11921 .49469 .12532 .50531 .12532 .50534 .11921 Mtetra
.883 .724 .681 r
.9001 .12269 .90007 .1279 .90912 .1283 .90912 .12312 Mtetra
.882 .728 .686 r
.89102 .12227 .89096 .1275 .90007 .1279 .9001 .12269 Mtetra
.881 .73 .691 r
.88187 .12184 .88179 .1271 .89096 .1275 .89102 .12227 Mtetra
.879 .733 .696 r
.87265 .12141 .87254 .1267 .88179 .1271 .88187 .12184 Mtetra
.876 .735 .702 r
.86335 .12098 .86321 .1263 .87254 .1267 .87265 .12141 Mtetra
.873 .736 .708 r
.85397 .12056 .8538 .12591 .86321 .1263 .86335 .12098 Mtetra
.87 .737 .714 r
.8445 .12015 .84431 .12552 .8538 .12591 .85397 .12056 Mtetra
.866 .738 .72 r
.83495 .11974 .83473 .12514 .84431 .12552 .8445 .12015 Mtetra
.861 .738 .726 r
.8253 .11935 .82506 .12477 .83473 .12514 .83495 .11974 Mtetra
.856 .738 .733 r
.81557 .11896 .8153 .12441 .82506 .12477 .8253 .11935 Mtetra
.85 .737 .739 r
.80574 .11859 .80546 .12407 .8153 .12441 .81557 .11896 Mtetra
.843 .736 .746 r
.79581 .11823 .79551 .12374 .80546 .12407 .80574 .11859 Mtetra
.836 .735 .753 r
.7858 .11789 .78548 .12342 .79551 .12374 .79581 .11823 Mtetra
.828 .733 .759 r
.77569 .11756 .77535 .12312 .78548 .12342 .7858 .11789 Mtetra
.819 .73 .766 r
.76548 .11726 .76512 .12285 .77535 .12312 .77569 .11756 Mtetra
.81 .727 .773 r
.75518 .11698 .75481 .1226 .76512 .12285 .76548 .11726 Mtetra
.799 .724 .781 r
.74479 .11673 .7444 .12237 .75481 .1226 .75518 .11698 Mtetra
.788 .719 .788 r
.73431 .1165 .73391 .12216 .7444 .12237 .74479 .11673 Mtetra
.776 .715 .795 r
.72375 .1163 .72334 .12199 .73391 .12216 .73431 .1165 Mtetra
.763 .71 .802 r
.7131 .11613 .71268 .12185 .72334 .12199 .72375 .1163 Mtetra
.75 .704 .809 r
.70237 .116 .70195 .12174 .71268 .12185 .7131 .11613 Mtetra
.735 .698 .816 r
.69158 .1159 .69114 .12166 .70195 .12174 .70237 .116 Mtetra
.719 .691 .822 r
.68071 .11583 .68027 .12162 .69114 .12166 .69158 .1159 Mtetra
.703 .684 .829 r
.66979 .11581 .66935 .12162 .68027 .12162 .68071 .11583 Mtetra
.686 .677 .835 r
.65882 .11583 .65837 .12166 .66935 .12162 .66979 .11581 Mtetra
.668 .669 .842 r
.6478 .11589 .64736 .12175 .65837 .12166 .65882 .11583 Mtetra
.649 .661 .848 r
.63674 .11599 .63631 .12187 .64736 .12175 .6478 .11589 Mtetra
.63 .653 .854 r
.62567 .11614 .62524 .12204 .63631 .12187 .63674 .11599 Mtetra
.612 .646 .86 r
.61458 .11633 .61416 .12226 .62524 .12204 .62567 .11614 Mtetra
.593 .64 .866 r
.60349 .11656 .60308 .12251 .61416 .12226 .61458 .11633 Mtetra
.576 .635 .872 r
.59241 .11683 .59201 .1228 .60308 .12251 .60349 .11656 Mtetra
.56 .631 .879 r
.58135 .11713 .58098 .12313 .59201 .1228 .59241 .11683 Mtetra
.548 .631 .886 r
.57033 .11745 .56999 .12348 .58098 .12313 .58135 .11713 Mtetra
.539 .634 .893 r
.55936 .1178 .55905 .12385 .56999 .12348 .57033 .11745 Mtetra
.536 .641 .901 r
.54844 .11814 .54817 .12422 .55905 .12385 .55936 .1178 Mtetra
.539 .652 .908 r
.53758 .11846 .53736 .12456 .54817 .12422 .54844 .11814 Mtetra
.548 .666 .915 r
.52678 .11876 .52662 .12487 .53736 .12456 .53758 .11846 Mtetra
.562 .682 .92 r
.51604 .11901 .51594 .12512 .52662 .12487 .52678 .11876 Mtetra
.579 .696 .922 r
.50534 .11921 .50531 .12532 .51594 .12512 .51604 .11901 Mtetra
.476 .388 .677 r
.09088 .1283 .09088 .13348 .09996 .1331 .09993 .1279 Mtetra
.477 .393 .682 r
.09993 .1279 .09996 .1331 .10909 .13273 .10904 .1275 Mtetra
.48 .399 .687 r
.10904 .1275 .10909 .13273 .1183 .13235 .11821 .1271 Mtetra
.483 .405 .693 r
.11821 .1271 .1183 .13235 .12758 .13198 .12746 .1267 Mtetra
.487 .412 .698 r
.12746 .1267 .12758 .13198 .13693 .13161 .13679 .1263 Mtetra
.492 .42 .704 r
.13679 .1263 .13693 .13161 .14636 .13124 .1462 .12591 Mtetra
.498 .429 .709 r
.1462 .12591 .14636 .13124 .15588 .13088 .15569 .12552 Mtetra
.504 .438 .715 r
.15569 .12552 .15588 .13088 .16548 .13053 .16527 .12514 Mtetra
.511 .448 .721 r
.16527 .12514 .16548 .13053 .17517 .13019 .17494 .12477 Mtetra
.52 .458 .728 r
.17494 .12477 .17517 .13019 .18495 .12985 .1847 .12441 Mtetra
.528 .469 .734 r
.1847 .12441 .18495 .12985 .19482 .12953 .19454 .12407 Mtetra
.538 .481 .74 r
.19454 .12407 .19482 .12953 .20478 .12923 .20449 .12374 Mtetra
.548 .494 .747 r
.20449 .12374 .20478 .12923 .21483 .12894 .21452 .12342 Mtetra
.559 .507 .753 r
.21452 .12342 .21483 .12894 .22498 .12867 .22465 .12312 Mtetra
.571 .521 .76 r
.22465 .12312 .22498 .12867 .23522 .12842 .23488 .12285 Mtetra
.583 .535 .767 r
.23488 .12285 .23522 .12842 .24555 .12819 .24519 .1226 Mtetra
.596 .55 .774 r
.24519 .1226 .24555 .12819 .25597 .12798 .2556 .12237 Mtetra
.61 .566 .78 r
.2556 .12237 .25597 .12798 .26647 .1278 .26609 .12216 Mtetra
.623 .582 .787 r
.26609 .12216 .26647 .1278 .27706 .12765 .27666 .12199 Mtetra
.637 .599 .794 r
.27666 .12199 .27706 .12765 .28772 .12753 .28732 .12185 Mtetra
.652 .616 .8 r
.28732 .12185 .28772 .12753 .29847 .12745 .29805 .12174 Mtetra
.667 .633 .807 r
.29805 .12174 .29847 .12745 .30928 .12739 .30886 .12166 Mtetra
.682 .651 .813 r
.30886 .12166 .30928 .12739 .32015 .12737 .31973 .12162 Mtetra
.696 .669 .819 r
.31973 .12162 .32015 .12737 .33108 .1274 .33065 .12162 Mtetra
.711 .687 .825 r
.33065 .12162 .33108 .1274 .34206 .12746 .34163 .12166 Mtetra
.726 .705 .831 r
.34163 .12166 .34206 .12746 .35307 .12756 .35264 .12175 Mtetra
.74 .723 .836 r
.35264 .12175 .35307 .12756 .36412 .12771 .36369 .12187 Mtetra
.753 .741 .842 r
.36369 .12187 .36412 .12771 .37518 .1279 .37476 .12204 Mtetra
.765 .759 .847 r
.37476 .12204 .37518 .1279 .38625 .12813 .38584 .12226 Mtetra
.775 .775 .853 r
.38584 .12226 .38625 .12813 .39732 .12841 .39692 .12251 Mtetra
.784 .791 .858 r
.39692 .12251 .39732 .12841 .40837 .12872 .40799 .1228 Mtetra
.79 .805 .865 r
.40799 .1228 .40837 .12872 .41938 .12907 .41902 .12313 Mtetra
.793 .818 .872 r
.41902 .12313 .41938 .12907 .43035 .12945 .43001 .12348 Mtetra
.791 .828 .88 r
.43001 .12348 .43035 .12945 .44126 .12985 .44095 .12385 Mtetra
.785 .834 .889 r
.44095 .12385 .44126 .12985 .45209 .13024 .45183 .12422 Mtetra
.774 .836 .9 r
.45183 .12422 .45209 .13024 .46285 .1306 .46264 .12456 Mtetra
.757 .832 .91 r
.46264 .12456 .46285 .1306 .47354 .13093 .47338 .12487 Mtetra
.736 .824 .919 r
.47338 .12487 .47354 .13093 .48416 .13118 .48406 .12512 Mtetra
.714 .811 .925 r
.48406 .12512 .48416 .13118 .49473 .13136 .49469 .12532 Mtetra
.65 .758 .929 r
.49469 .12532 .49473 .13136 .50527 .13136 .50531 .12532 Mtetra
.879 .721 .682 r
.90007 .1279 .90004 .1331 .90912 .13348 .90912 .1283 Mtetra
.878 .725 .687 r
.89096 .1275 .89091 .13273 .90004 .1331 .90007 .1279 Mtetra
.877 .727 .692 r
.88179 .1271 .8817 .13235 .89091 .13273 .89096 .1275 Mtetra
.875 .729 .697 r
.87254 .1267 .87242 .13198 .8817 .13235 .88179 .1271 Mtetra
.873 .731 .703 r
.86321 .1263 .86307 .13161 .87242 .13198 .87254 .1267 Mtetra
.87 .732 .708 r
.8538 .12591 .85364 .13124 .86307 .13161 .86321 .1263 Mtetra
.866 .733 .714 r
.84431 .12552 .84412 .13088 .85364 .13124 .8538 .12591 Mtetra
.862 .734 .72 r
.83473 .12514 .83452 .13053 .84412 .13088 .84431 .12552 Mtetra
.857 .734 .726 r
.82506 .12477 .82483 .13019 .83452 .13053 .83473 .12514 Mtetra
.852 .733 .732 r
.8153 .12441 .81505 .12985 .82483 .13019 .82506 .12477 Mtetra
.846 .733 .739 r
.80546 .12407 .80518 .12953 .81505 .12985 .8153 .12441 Mtetra
.839 .731 .745 r
.79551 .12374 .79522 .12923 .80518 .12953 .80546 .12407 Mtetra
.832 .729 .752 r
.78548 .12342 .78517 .12894 .79522 .12923 .79551 .12374 Mtetra
.823 .727 .758 r
.77535 .12312 .77502 .12867 .78517 .12894 .78548 .12342 Mtetra
.815 .724 .765 r
.76512 .12285 .76478 .12842 .77502 .12867 .77535 .12312 Mtetra
.805 .721 .772 r
.75481 .1226 .75445 .12819 .76478 .12842 .76512 .12285 Mtetra
.794 .717 .779 r
.7444 .12237 .74403 .12798 .75445 .12819 .75481 .1226 Mtetra
.783 .713 .786 r
.73391 .12216 .73353 .1278 .74403 .12798 .7444 .12237 Mtetra
.771 .708 .793 r
.72334 .12199 .72294 .12765 .73353 .1278 .73391 .12216 Mtetra
.757 .702 .8 r
.71268 .12185 .71228 .12753 .72294 .12765 .72334 .12199 Mtetra
.743 .696 .806 r
.70195 .12174 .70153 .12745 .71228 .12753 .71268 .12185 Mtetra
.728 .689 .813 r
.69114 .12166 .69072 .12739 .70153 .12745 .70195 .12174 Mtetra
.712 .682 .819 r
.68027 .12162 .67985 .12737 .69072 .12739 .69114 .12166 Mtetra
.695 .674 .826 r
.66935 .12162 .66892 .1274 .67985 .12737 .68027 .12162 Mtetra
.677 .666 .832 r
.65837 .12166 .65794 .12746 .66892 .1274 .66935 .12162 Mtetra
.658 .658 .838 r
.64736 .12175 .64693 .12756 .65794 .12746 .65837 .12166 Mtetra
.639 .649 .844 r
.63631 .12187 .63588 .12771 .64693 .12756 .64736 .12175 Mtetra
.619 .64 .85 r
.62524 .12204 .62482 .1279 .63588 .12771 .63631 .12187 Mtetra
.599 .632 .856 r
.61416 .12226 .61375 .12813 .62482 .1279 .62524 .12204 Mtetra
.579 .625 .861 r
.60308 .12251 .60268 .12841 .61375 .12813 .61416 .12226 Mtetra
.561 .619 .868 r
.59201 .1228 .59163 .12872 .60268 .12841 .60308 .12251 Mtetra
.544 .616 .874 r
.58098 .12313 .58062 .12907 .59163 .12872 .59201 .1228 Mtetra
.531 .615 .881 r
.56999 .12348 .56965 .12945 .58062 .12907 .58098 .12313 Mtetra
.522 .619 .889 r
.55905 .12385 .55874 .12985 .56965 .12945 .56999 .12348 Mtetra
.519 .627 .898 r
.54817 .12422 .54791 .13024 .55874 .12985 .55905 .12385 Mtetra
.523 .641 .907 r
.53736 .12456 .53715 .1306 .54791 .13024 .54817 .12422 Mtetra
.535 .659 .915 r
.52662 .12487 .52646 .13093 .53715 .1306 .53736 .12456 Mtetra
.555 .679 .922 r
.51594 .12512 .51584 .13118 .52646 .13093 .52662 .12487 Mtetra
.579 .699 .924 r
.50531 .12532 .50527 .13136 .51584 .13118 .51594 .12512 Mtetra
.482 .393 .679 r
.09088 .13348 .09088 .13866 .09998 .13831 .09996 .1331 Mtetra
.483 .398 .684 r
.09996 .1331 .09998 .13831 .10915 .13796 .10909 .13273 Mtetra
.486 .404 .688 r
.10909 .13273 .10915 .13796 .11838 .13761 .1183 .13235 Mtetra
.489 .41 .693 r
.1183 .13235 .11838 .13761 .12768 .13726 .12758 .13198 Mtetra
.493 .417 .699 r
.12758 .13198 .12768 .13726 .13706 .13691 .13693 .13161 Mtetra
.498 .424 .704 r
.13693 .13161 .13706 .13691 .14652 .13657 .14636 .13124 Mtetra
.504 .433 .71 r
.14636 .13124 .14652 .13657 .15606 .13623 .15588 .13088 Mtetra
.51 .442 .715 r
.15588 .13088 .15606 .13623 .16568 .13591 .16548 .13053 Mtetra
.518 .452 .721 r
.16548 .13053 .16568 .13591 .17539 .13559 .17517 .13019 Mtetra
.526 .462 .727 r
.17517 .13019 .17539 .13559 .18519 .13528 .18495 .12985 Mtetra
.535 .473 .733 r
.18495 .12985 .18519 .13528 .19508 .13499 .19482 .12953 Mtetra
.545 .485 .74 r
.19482 .12953 .19508 .13499 .20506 .1347 .20478 .12923 Mtetra
.555 .498 .746 r
.20478 .12923 .20506 .1347 .21513 .13444 .21483 .12894 Mtetra
.566 .511 .752 r
.21483 .12894 .21513 .13444 .22529 .13419 .22498 .12867 Mtetra
.578 .525 .759 r
.22498 .12867 .22529 .13419 .23555 .13397 .23522 .12842 Mtetra
.591 .539 .765 r
.23522 .12842 .23555 .13397 .24589 .13376 .24555 .12819 Mtetra
.604 .554 .772 r
.24555 .12819 .24589 .13376 .25632 .13358 .25597 .12798 Mtetra
.617 .57 .779 r
.25597 .12798 .25632 .13358 .26684 .13342 .26647 .1278 Mtetra
.631 .586 .785 r
.26647 .1278 .26684 .13342 .27744 .13329 .27706 .12765 Mtetra
.646 .603 .791 r
.27706 .12765 .27744 .13329 .28811 .13319 .28772 .12753 Mtetra
.66 .62 .798 r
.28772 .12753 .28811 .13319 .29886 .13312 .29847 .12745 Mtetra
.676 .637 .804 r
.29847 .12745 .29886 .13312 .30968 .13309 .30928 .12739 Mtetra
.691 .655 .81 r
.30928 .12739 .30968 .13309 .32056 .13309 .32015 .12737 Mtetra
.706 .673 .816 r
.32015 .12737 .32056 .13309 .33149 .13313 .33108 .1274 Mtetra
.721 .692 .821 r
.33108 .1274 .33149 .13313 .34247 .13321 .34206 .12746 Mtetra
.736 .71 .827 r
.34206 .12746 .34247 .13321 .35348 .13333 .35307 .12756 Mtetra
.75 .728 .832 r
.35307 .12756 .35348 .13333 .36453 .13349 .36412 .12771 Mtetra
.764 .747 .837 r
.36412 .12771 .36453 .13349 .37559 .1337 .37518 .1279 Mtetra
.777 .765 .842 r
.37518 .1279 .37559 .1337 .38665 .13395 .38625 .12813 Mtetra
.788 .782 .847 r
.38625 .12813 .38665 .13395 .39771 .13425 .39732 .12841 Mtetra
.797 .798 .853 r
.39732 .12841 .39771 .13425 .40874 .13458 .40837 .12872 Mtetra
.804 .813 .859 r
.40837 .12872 .40874 .13458 .41974 .13496 .41938 .12907 Mtetra
.807 .826 .866 r
.41938 .12907 .41974 .13496 .43068 .13536 .43035 .12945 Mtetra
.805 .837 .875 r
.43035 .12945 .43068 .13536 .44156 .13578 .44126 .12985 Mtetra
.798 .843 .885 r
.44126 .12985 .44156 .13578 .45236 .13619 .45209 .13024 Mtetra
.785 .845 .897 r
.45209 .13024 .45236 .13619 .46307 .13659 .46285 .1306 Mtetra
.765 .841 .909 r
.46285 .1306 .46307 .13659 .4737 .13693 .47354 .13093 Mtetra
.739 .83 .921 r
.47354 .13093 .4737 .13693 .48426 .13719 .48416 .13118 Mtetra
.71 .812 .928 r
.48416 .13118 .48426 .13719 .49476 .13735 .49473 .13136 Mtetra
.647 .761 .932 r
.49473 .13136 .49476 .13735 .50524 .13735 .50527 .13136 Mtetra
.876 .719 .683 r
.90004 .1331 .90002 .13831 .90912 .13866 .90912 .13348 Mtetra
.875 .721 .688 r
.89091 .13273 .89085 .13796 .90002 .13831 .90004 .1331 Mtetra
.874 .724 .693 r
.8817 .13235 .88162 .13761 .89085 .13796 .89091 .13273 Mtetra
.872 .726 .698 r
.87242 .13198 .87232 .13726 .88162 .13761 .8817 .13235 Mtetra
.869 .728 .703 r
.86307 .13161 .86294 .13691 .87232 .13726 .87242 .13198 Mtetra
.866 .729 .709 r
.85364 .13124 .85348 .13657 .86294 .13691 .86307 .13161 Mtetra
.863 .729 .714 r
.84412 .13088 .84394 .13623 .85348 .13657 .85364 .13124 Mtetra
.858 .73 .72 r
.83452 .13053 .83432 .13591 .84394 .13623 .84412 .13088 Mtetra
.854 .73 .726 r
.82483 .13019 .82461 .13559 .83432 .13591 .83452 .13053 Mtetra
.848 .729 .732 r
.81505 .12985 .81481 .13528 .82461 .13559 .82483 .13019 Mtetra
.842 .728 .738 r
.80518 .12953 .80492 .13499 .81481 .13528 .81505 .12985 Mtetra
.835 .726 .744 r
.79522 .12923 .79494 .1347 .80492 .13499 .80518 .12953 Mtetra
.827 .724 .751 r
.78517 .12894 .78487 .13444 .79494 .1347 .79522 .12923 Mtetra
.819 .722 .757 r
.77502 .12867 .77471 .13419 .78487 .13444 .78517 .12894 Mtetra
.81 .718 .764 r
.76478 .12842 .76445 .13397 .77471 .13419 .77502 .12867 Mtetra
.8 .715 .77 r
.75445 .12819 .75411 .13376 .76445 .13397 .76478 .12842 Mtetra
.789 .71 .777 r
.74403 .12798 .74368 .13358 .75411 .13376 .75445 .12819 Mtetra
.778 .706 .784 r
.73353 .1278 .73316 .13342 .74368 .13358 .74403 .12798 Mtetra
.765 .7 .79 r
.72294 .12765 .72256 .13329 .73316 .13342 .73353 .1278 Mtetra
.751 .694 .797 r
.71228 .12753 .71189 .13319 .72256 .13329 .72294 .12765 Mtetra
.737 .688 .804 r
.70153 .12745 .70114 .13312 .71189 .13319 .71228 .12753 Mtetra
.721 .68 .81 r
.69072 .12739 .69032 .13309 .70114 .13312 .70153 .12745 Mtetra
.704 .672 .816 r
.67985 .12737 .67944 .13309 .69032 .13309 .69072 .12739 Mtetra
.687 .664 .822 r
.66892 .1274 .66851 .13313 .67944 .13309 .67985 .12737 Mtetra
.668 .655 .828 r
.65794 .12746 .65753 .13321 .66851 .13313 .66892 .1274 Mtetra
.649 .646 .834 r
.64693 .12756 .64652 .13333 .65753 .13321 .65794 .12746 Mtetra
.628 .637 .839 r
.63588 .12771 .63547 .13349 .64652 .13333 .64693 .12756 Mtetra
.607 .627 .845 r
.62482 .1279 .62441 .1337 .63547 .13349 .63588 .12771 Mtetra
.586 .618 .85 r
.61375 .12813 .61335 .13395 .62441 .1337 .62482 .1279 Mtetra
.565 .61 .856 r
.60268 .12841 .60229 .13425 .61335 .13395 .61375 .12813 Mtetra
.545 .603 .862 r
.59163 .12872 .59126 .13458 .60229 .13425 .60268 .12841 Mtetra
.527 .599 .869 r
.58062 .12907 .58026 .13496 .59126 .13458 .59163 .12872 Mtetra
.513 .598 .876 r
.56965 .12945 .56932 .13536 .58026 .13496 .58062 .12907 Mtetra
.503 .602 .885 r
.55874 .12985 .55844 .13578 .56932 .13536 .56965 .12945 Mtetra
.5 .612 .895 r
.54791 .13024 .54764 .13619 .55844 .13578 .55874 .12985 Mtetra
.506 .628 .905 r
.53715 .1306 .53693 .13659 .54764 .13619 .54791 .13024 Mtetra
.521 .65 .916 r
.52646 .13093 .5263 .13693 .53693 .13659 .53715 .1306 Mtetra
.546 .677 .924 r
.51584 .13118 .51574 .13719 .5263 .13693 .52646 .13093 Mtetra
.578 .703 .928 r
.50527 .13136 .50524 .13735 .51574 .13719 .51584 .13118 Mtetra
.488 .398 .68 r
.09088 .13866 .09088 .14384 .10001 .14351 .09998 .13831 Mtetra
.489 .403 .685 r
.09998 .13831 .10001 .14351 .1092 .14318 .10915 .13796 Mtetra
.492 .408 .689 r
.10915 .13796 .1092 .14318 .11846 .14285 .11838 .13761 Mtetra
.495 .414 .694 r
.11838 .13761 .11846 .14285 .12779 .14253 .12768 .13726 Mtetra
.499 .421 .699 r
.12768 .13726 .12779 .14253 .13719 .14221 .13706 .13691 Mtetra
.504 .428 .704 r
.13706 .13691 .13719 .14221 .14667 .14189 .14652 .13657 Mtetra
.51 .437 .71 r
.14652 .13657 .14667 .14189 .15623 .14158 .15606 .13623 Mtetra
.516 .446 .715 r
.15606 .13623 .15623 .14158 .16587 .14128 .16568 .13591 Mtetra
.524 .455 .721 r
.16568 .13591 .16587 .14128 .1756 .14098 .17539 .13559 Mtetra
.532 .466 .727 r
.17539 .13559 .1756 .14098 .18542 .1407 .18519 .13528 Mtetra
.541 .477 .733 r
.18519 .13528 .18542 .1407 .19533 .14043 .19508 .13499 Mtetra
.551 .489 .739 r
.19508 .13499 .19533 .14043 .20533 .14017 .20506 .1347 Mtetra
.562 .501 .745 r
.20506 .1347 .20533 .14017 .21542 .13993 .21513 .13444 Mtetra
.573 .514 .751 r
.21513 .13444 .21542 .13993 .2256 .1397 .22529 .13419 Mtetra
.585 .528 .758 r
.22529 .13419 .2256 .1397 .23586 .13949 .23555 .13397 Mtetra
.598 .543 .764 r
.23555 .13397 .23586 .13949 .24622 .13931 .24589 .13376 Mtetra
.611 .558 .77 r
.24589 .13376 .24622 .13931 .25666 .13915 .25632 .13358 Mtetra
.625 .573 .776 r
.25632 .13358 .25666 .13915 .26719 .13901 .26684 .13342 Mtetra
.639 .59 .783 r
.26684 .13342 .26719 .13901 .2778 .1389 .27744 .13329 Mtetra
.654 .606 .789 r
.27744 .13329 .2778 .1389 .28849 .13882 .28811 .13319 Mtetra
.669 .623 .795 r
.28811 .13319 .28849 .13882 .29924 .13877 .29886 .13312 Mtetra
.684 .641 .801 r
.29886 .13312 .29924 .13877 .31007 .13875 .30968 .13309 Mtetra
.7 .659 .807 r
.30968 .13309 .31007 .13875 .32095 .13877 .32056 .13309 Mtetra
.715 .677 .812 r
.32056 .13309 .32095 .13877 .33188 .13883 .33149 .13313 Mtetra
.731 .696 .817 r
.33149 .13313 .33188 .13883 .34286 .13892 .34247 .13321 Mtetra
.746 .715 .822 r
.34247 .13321 .34286 .13892 .35388 .13906 .35348 .13333 Mtetra
.761 .733 .827 r
.35348 .13333 .35388 .13906 .36492 .13923 .36453 .13349 Mtetra
.775 .752 .832 r
.36453 .13349 .36492 .13923 .37597 .13946 .37559 .1337 Mtetra
.789 .77 .836 r
.37559 .1337 .37597 .13946 .38703 .13972 .38665 .13395 Mtetra
.8 .788 .841 r
.38665 .13395 .38703 .13972 .39808 .14003 .39771 .13425 Mtetra
.81 .805 .846 r
.39771 .13425 .39808 .14003 .4091 .14039 .40874 .13458 Mtetra
.817 .82 .852 r
.40874 .13458 .4091 .14039 .42008 .14078 .41974 .13496 Mtetra
.821 .834 .859 r
.41974 .13496 .42008 .14078 .43101 .1412 .43068 .13536 Mtetra
.82 .846 .868 r
.43068 .13536 .43101 .1412 .44186 .14165 .44156 .13578 Mtetra
.813 .853 .879 r
.44156 .13578 .44186 .14165 .45263 .14209 .45236 .13619 Mtetra
.798 .856 .893 r
.45236 .13619 .45263 .14209 .4633 .14251 .46307 .13659 Mtetra
.774 .851 .908 r
.46307 .13659 .4633 .14251 .47387 .14287 .4737 .13693 Mtetra
.743 .837 .922 r
.4737 .13693 .47387 .14287 .48436 .14314 .48426 .13719 Mtetra
.705 .814 .932 r
.48426 .13719 .48436 .14314 .49479 .14329 .49476 .13735 Mtetra
.644 .764 .936 r
.49476 .13735 .49479 .14329 .50521 .14329 .50524 .13735 Mtetra
.873 .716 .684 r
.90002 .13831 .89999 .14351 .90912 .14384 .90912 .13866 Mtetra
.872 .718 .689 r
.89085 .13796 .8908 .14318 .89999 .14351 .90002 .13831 Mtetra
.87 .721 .694 r
.88162 .13761 .88154 .14285 .8908 .14318 .89085 .13796 Mtetra
.868 .723 .698 r
.87232 .13726 .87221 .14253 .88154 .14285 .88162 .13761 Mtetra
.866 .724 .704 r
.86294 .13691 .86281 .14221 .87221 .14253 .87232 .13726 Mtetra
.863 .725 .709 r
.85348 .13657 .85333 .14189 .86281 .14221 .86294 .13691 Mtetra
.859 .726 .714 r
.84394 .13623 .84377 .14158 .85333 .14189 .85348 .13657 Mtetra
.855 .726 .72 r
.83432 .13591 .83413 .14128 .84377 .14158 .84394 .13623 Mtetra
.85 .725 .725 r
.82461 .13559 .8244 .14098 .83413 .14128 .83432 .13591 Mtetra
.844 .724 .731 r
.81481 .13528 .81458 .1407 .8244 .14098 .82461 .13559 Mtetra
.838 .723 .737 r
.80492 .13499 .80467 .14043 .81458 .1407 .81481 .13528 Mtetra
.831 .721 .743 r
.79494 .1347 .79467 .14017 .80467 .14043 .80492 .13499 Mtetra
.823 .719 .75 r
.78487 .13444 .78458 .13993 .79467 .14017 .79494 .1347 Mtetra
.815 .716 .756 r
.77471 .13419 .7744 .1397 .78458 .13993 .78487 .13444 Mtetra
.806 .713 .762 r
.76445 .13397 .76414 .13949 .7744 .1397 .77471 .13419 Mtetra
.795 .709 .769 r
.75411 .13376 .75378 .13931 .76414 .13949 .76445 .13397 Mtetra
.784 .704 .775 r
.74368 .13358 .74334 .13915 .75378 .13931 .75411 .13376 Mtetra
.772 .699 .782 r
.73316 .13342 .73281 .13901 .74334 .13915 .74368 .13358 Mtetra
.759 .693 .788 r
.72256 .13329 .7222 .1389 .73281 .13901 .73316 .13342 Mtetra
.745 .686 .794 r
.71189 .13319 .71151 .13882 .7222 .1389 .72256 .13329 Mtetra
.73 .679 .801 r
.70114 .13312 .70076 .13877 .71151 .13882 .71189 .13319 Mtetra
.714 .671 .807 r
.69032 .13309 .68993 .13875 .70076 .13877 .70114 .13312 Mtetra
.697 .663 .813 r
.67944 .13309 .67905 .13877 .68993 .13875 .69032 .13309 Mtetra
.679 .654 .818 r
.66851 .13313 .66812 .13883 .67905 .13877 .67944 .13309 Mtetra
.659 .644 .824 r
.65753 .13321 .65714 .13892 .66812 .13883 .66851 .13313 Mtetra
.639 .634 .829 r
.64652 .13333 .64612 .13906 .65714 .13892 .65753 .13321 Mtetra
.618 .624 .835 r
.63547 .13349 .63508 .13923 .64612 .13906 .64652 .13333 Mtetra
.596 .614 .84 r
.62441 .1337 .62403 .13946 .63508 .13923 .63547 .13349 Mtetra
.573 .603 .845 r
.61335 .13395 .61297 .13972 .62403 .13946 .62441 .1337 Mtetra
.551 .594 .85 r
.60229 .13425 .60192 .14003 .61297 .13972 .61335 .13395 Mtetra
.529 .586 .856 r
.59126 .13458 .5909 .14039 .60192 .14003 .60229 .13425 Mtetra
.51 .581 .863 r
.58026 .13496 .57992 .14078 .5909 .14039 .59126 .13458 Mtetra
.493 .579 .87 r
.56932 .13536 .56899 .1412 .57992 .14078 .58026 .13496 Mtetra
.482 .583 .88 r
.55844 .13578 .55814 .14165 .56899 .1412 .56932 .13536 Mtetra
.479 .594 .891 r
.54764 .13619 .54737 .14209 .55814 .14165 .55844 .13578 Mtetra
.485 .613 .903 r
.53693 .13659 .5367 .14251 .54737 .14209 .54764 .13619 Mtetra
.504 .64 .916 r
.5263 .13693 .52613 .14287 .5367 .14251 .53693 .13659 Mtetra
.536 .674 .926 r
.51574 .13719 .51564 .14314 .52613 .14287 .5263 .13693 Mtetra
.577 .708 .932 r
.50524 .13735 .50521 .14329 .51564 .14314 .51574 .13719 Mtetra
.494 .403 .681 r
.09088 .14384 .09087 .14901 .10003 .14871 .10001 .14351 Mtetra
.495 .407 .686 r
.10001 .14351 .10003 .14871 .10925 .14841 .1092 .14318 Mtetra
.497 .413 .69 r
.1092 .14318 .10925 .14841 .11853 .1481 .11846 .14285 Mtetra
.501 .418 .695 r
.11846 .14285 .11853 .1481 .12789 .1478 .12779 .14253 Mtetra
.505 .425 .7 r
.12779 .14253 .12789 .1478 .13731 .1475 .13719 .14221 Mtetra
.51 .432 .705 r
.13719 .14221 .13731 .1475 .14681 .14721 .14667 .14189 Mtetra
.515 .44 .71 r
.14667 .14189 .14681 .14721 .15639 .14692 .15623 .14158 Mtetra
.522 .449 .715 r
.15623 .14158 .15639 .14692 .16606 .14664 .16587 .14128 Mtetra
.53 .459 .721 r
.16587 .14128 .16606 .14664 .17581 .14636 .1756 .14098 Mtetra
.538 .469 .726 r
.1756 .14098 .17581 .14636 .18564 .1461 .18542 .1407 Mtetra
.547 .48 .732 r
.18542 .1407 .18564 .1461 .19557 .14585 .19533 .14043 Mtetra
.557 .492 .738 r
.19533 .14043 .19557 .14585 .20558 .14562 .20533 .14017 Mtetra
.568 .504 .744 r
.20533 .14017 .20558 .14562 .21569 .1454 .21542 .13993 Mtetra
.579 .518 .75 r
.21542 .13993 .21569 .1454 .22588 .14519 .2256 .1397 Mtetra
.591 .531 .756 r
.2256 .1397 .22588 .14519 .23617 .145 .23586 .13949 Mtetra
.604 .546 .762 r
.23586 .13949 .23617 .145 .24654 .14484 .24622 .13931 Mtetra
.618 .561 .768 r
.24622 .13931 .24654 .14484 .25699 .1447 .25666 .13915 Mtetra
.632 .576 .774 r
.25666 .13915 .25699 .1447 .26753 .14458 .26719 .13901 Mtetra
.646 .593 .78 r
.26719 .13901 .26753 .14458 .27815 .14449 .2778 .1389 Mtetra
.661 .61 .786 r
.2778 .1389 .27815 .14449 .28884 .14442 .28849 .13882 Mtetra
.677 .627 .792 r
.28849 .13882 .28884 .14442 .29961 .14439 .29924 .13877 Mtetra
.692 .645 .798 r
.29924 .13877 .29961 .14439 .31044 .14439 .31007 .13875 Mtetra
.708 .663 .803 r
.31007 .13875 .31044 .14439 .32132 .14442 .32095 .13877 Mtetra
.724 .681 .808 r
.32095 .13877 .32132 .14442 .33226 .14449 .33188 .13883 Mtetra
.74 .7 .813 r
.33188 .13883 .33226 .14449 .34324 .14459 .34286 .13892 Mtetra
.756 .719 .817 r
.34286 .13892 .34324 .14459 .35426 .14474 .35388 .13906 Mtetra
.771 .737 .822 r
.35388 .13906 .35426 .14474 .3653 .14493 .36492 .13923 Mtetra
.786 .756 .826 r
.36492 .13923 .3653 .14493 .37635 .14516 .37597 .13946 Mtetra
.8 .775 .83 r
.37597 .13946 .37635 .14516 .3874 .14544 .38703 .13972 Mtetra
.813 .793 .834 r
.38703 .13972 .3874 .14544 .39844 .14577 .39808 .14003 Mtetra
.823 .811 .839 r
.39808 .14003 .39844 .14577 .40945 .14613 .4091 .14039 Mtetra
.831 .827 .844 r
.4091 .14039 .40945 .14613 .42042 .14654 .42008 .14078 Mtetra
.836 .842 .851 r
.42008 .14078 .42042 .14654 .43133 .14699 .43101 .1412 Mtetra
.835 .855 .86 r
.43101 .1412 .43133 .14699 .44215 .14746 .44186 .14165 Mtetra
.828 .864 .872 r
.44186 .14165 .44215 .14746 .45289 .14793 .45263 .14209 Mtetra
.812 .867 .888 r
.45263 .14209 .45289 .14793 .46352 .14837 .4633 .14251 Mtetra
.785 .861 .907 r
.4633 .14251 .46352 .14837 .47404 .14876 .47387 .14287 Mtetra
.869 .713 .686 r
.89999 .14351 .89997 .14871 .90913 .14901 .90912 .14384 Mtetra
.869 .716 .69 r
.8908 .14318 .89075 .14841 .89997 .14871 .89999 .14351 Mtetra
.867 .718 .694 r
.88154 .14285 .88147 .1481 .89075 .14841 .8908 .14318 Mtetra
.865 .72 .699 r
.87221 .14253 .87211 .1478 .88147 .1481 .88154 .14285 Mtetra
.863 .721 .704 r
.86281 .14221 .86269 .1475 .87211 .1478 .87221 .14253 Mtetra
.86 .722 .709 r
.85333 .14189 .85319 .14721 .86269 .1475 .86281 .14221 Mtetra
.856 .722 .714 r
.84377 .14158 .84361 .14692 .85319 .14721 .85333 .14189 Mtetra
.852 .722 .719 r
.83413 .14128 .83394 .14664 .84361 .14692 .84377 .14158 Mtetra
.847 .721 .725 r
.8244 .14098 .82419 .14636 .83394 .14664 .83413 .14128 Mtetra
.841 .72 .731 r
.81458 .1407 .81436 .1461 .82419 .14636 .8244 .14098 Mtetra
.835 .719 .736 r
.80467 .14043 .80443 .14585 .81436 .1461 .81458 .1407 Mtetra
.827 .716 .742 r
.79467 .14017 .79442 .14562 .80443 .14585 .80467 .14043 Mtetra
.82 .714 .748 r
.78458 .13993 .78431 .1454 .79442 .14562 .79467 .14017 Mtetra
.811 .711 .754 r
.7744 .1397 .77412 .14519 .78431 .1454 .78458 .13993 Mtetra
.801 .707 .761 r
.76414 .13949 .76383 .145 .77412 .14519 .7744 .1397 Mtetra
.791 .702 .767 r
.75378 .13931 .75346 .14484 .76383 .145 .76414 .13949 Mtetra
.78 .697 .773 r
.74334 .13915 .74301 .1447 .75346 .14484 .75378 .13931 Mtetra
.767 .692 .779 r
.73281 .13901 .73247 .14458 .74301 .1447 .74334 .13915 Mtetra
.754 .686 .786 r
.7222 .1389 .72185 .14449 .73247 .14458 .73281 .13901 Mtetra
.74 .679 .792 r
.71151 .13882 .71116 .14442 .72185 .14449 .7222 .1389 Mtetra
.724 .671 .798 r
.70076 .13877 .70039 .14439 .71116 .14442 .71151 .13882 Mtetra
.707 .663 .803 r
.68993 .13875 .68956 .14439 .70039 .14439 .70076 .13877 Mtetra
.69 .653 .809 r
.67905 .13877 .67868 .14442 .68956 .14439 .68993 .13875 Mtetra
.671 .644 .814 r
.66812 .13883 .66774 .14449 .67868 .14442 .67905 .13877 Mtetra
.651 .633 .82 r
.65714 .13892 .65676 .14459 .66774 .14449 .66812 .13883 Mtetra
.629 .622 .825 r
.64612 .13906 .64574 .14474 .65676 .14459 .65714 .13892 Mtetra
.607 .611 .829 r
.63508 .13923 .6347 .14493 .64574 .14474 .64612 .13906 Mtetra
.584 .6 .834 r
.62403 .13946 .62365 .14516 .6347 .14493 .63508 .13923 Mtetra
.56 .588 .839 r
.61297 .13972 .6126 .14544 .62365 .14516 .62403 .13946 Mtetra
.536 .578 .844 r
.60192 .14003 .60156 .14577 .6126 .14544 .61297 .13972 Mtetra
.513 .568 .849 r
.5909 .14039 .59055 .14613 .60156 .14577 .60192 .14003 Mtetra
.491 .562 .855 r
.57992 .14078 .57958 .14654 .59055 .14613 .5909 .14039 Mtetra
.472 .559 .863 r
.56899 .1412 .56867 .14699 .57958 .14654 .57992 .14078 Mtetra
.459 .563 .873 r
.55814 .14165 .55785 .14746 .56867 .14699 .56899 .1412 Mtetra
.455 .575 .885 r
.54737 .14209 .54711 .14793 .55785 .14746 .55814 .14165 Mtetra
.462 .596 .9 r
.5367 .14251 .53648 .14837 .54711 .14793 .54737 .14209 Mtetra
.485 .629 .916 r
.52613 .14287 .52596 .14876 .53648 .14837 .5367 .14251 Mtetra
.499 .408 .683 r
.09087 .14901 .09087 .15419 .10006 .15391 .10003 .14871 Mtetra
.501 .412 .687 r
.10003 .14871 .10006 .15391 .1093 .15363 .10925 .14841 Mtetra
.503 .417 .691 r
.10925 .14841 .1093 .15363 .11861 .15335 .11853 .1481 Mtetra
.506 .422 .695 r
.11853 .1481 .11861 .15335 .12798 .15307 .12789 .1478 Mtetra
.51 .429 .7 r
.12789 .1478 .12798 .15307 .13743 .15279 .13731 .1475 Mtetra
.515 .436 .705 r
.13731 .1475 .13743 .15279 .14695 .15252 .14681 .14721 Mtetra
.521 .444 .71 r
.14681 .14721 .14695 .15252 .15655 .15225 .15639 .14692 Mtetra
.528 .453 .715 r
.15639 .14692 .15655 .15225 .16623 .15199 .16606 .14664 Mtetra
.535 .462 .72 r
.16606 .14664 .16623 .15199 .176 .15174 .17581 .14636 Mtetra
.544 .472 .726 r
.17581 .14636 .176 .15174 .18586 .1515 .18564 .1461 Mtetra
.553 .483 .731 r
.18564 .1461 .18586 .1515 .1958 .15127 .19557 .14585 Mtetra
.563 .495 .737 r
.19557 .14585 .1958 .15127 .20583 .15105 .20558 .14562 Mtetra
.574 .507 .743 r
.20558 .14562 .20583 .15105 .21595 .15085 .21569 .1454 Mtetra
.585 .52 .749 r
.21569 .1454 .21595 .15085 .22616 .15067 .22588 .14519 Mtetra
.598 .534 .754 r
.22588 .14519 .22616 .15067 .23645 .1505 .23617 .145 Mtetra
.611 .549 .76 r
.23617 .145 .23645 .1505 .24684 .15035 .24654 .14484 Mtetra
.624 .564 .766 r
.24654 .14484 .24684 .15035 .2573 .15023 .25699 .1447 Mtetra
.638 .579 .772 r
.25699 .1447 .2573 .15023 .26785 .15012 .26753 .14458 Mtetra
.653 .596 .778 r
.26753 .14458 .26785 .15012 .27848 .15005 .27815 .14449 Mtetra
.668 .612 .783 r
.27815 .14449 .27848 .15005 .28918 .15 .28884 .14442 Mtetra
.684 .63 .789 r
.28884 .14442 .28918 .15 .29995 .14998 .29961 .14439 Mtetra
.7 .648 .794 r
.29961 .14439 .29995 .14998 .31079 .14999 .31044 .14439 Mtetra
.716 .666 .799 r
.31044 .14439 .31079 .14999 .32168 .15003 .32132 .14442 Mtetra
.733 .684 .804 r
.32132 .14442 .32168 .15003 .33262 .15011 .33226 .14449 Mtetra
.749 .703 .808 r
.33226 .14449 .33262 .15011 .3436 .15023 .34324 .14459 Mtetra
.765 .722 .812 r
.34324 .14459 .3436 .15023 .35462 .15039 .35426 .14474 Mtetra
.781 .741 .816 r
.35426 .14474 .35462 .15039 .36566 .15059 .3653 .14493 Mtetra
.797 .76 .82 r
.3653 .14493 .36566 .15059 .37671 .15083 .37635 .14516 Mtetra
.811 .779 .823 r
.37635 .14516 .37671 .15083 .38775 .15112 .3874 .14544 Mtetra
.825 .798 .827 r
.3874 .14544 .38775 .15112 .39878 .15145 .39844 .14577 Mtetra
.836 .816 .83 r
.39844 .14577 .39878 .15145 .40979 .15183 .40945 .14613 Mtetra
.845 .834 .835 r
.40945 .14613 .40979 .15183 .42074 .15225 .42042 .14654 Mtetra
.851 .85 .841 r
.42042 .14654 .42074 .15225 .43164 .15271 .43133 .14699 Mtetra
.851 .864 .85 r
.43133 .14699 .43164 .15271 .44245 .1532 .44215 .14746 Mtetra
.844 .874 .864 r
.44215 .14746 .44245 .1532 .45315 .1537 .45289 .14793 Mtetra
.827 .879 .882 r
.45289 .14793 .45315 .1537 .46374 .15418 .46352 .14837 Mtetra
.866 .71 .687 r
.89997 .14871 .89994 .15391 .90913 .15419 .90913 .14901 Mtetra
.865 .713 .691 r
.89075 .14841 .8907 .15363 .89994 .15391 .89997 .14871 Mtetra
.864 .715 .695 r
.88147 .1481 .88139 .15335 .8907 .15363 .89075 .14841 Mtetra
.862 .716 .699 r
.87211 .1478 .87202 .15307 .88139 .15335 .88147 .1481 Mtetra
.86 .717 .704 r
.86269 .1475 .86257 .15279 .87202 .15307 .87211 .1478 Mtetra
.856 .718 .709 r
.85319 .14721 .85305 .15252 .86257 .15279 .86269 .1475 Mtetra
.853 .718 .714 r
.84361 .14692 .84345 .15225 .85305 .15252 .85319 .14721 Mtetra
.848 .718 .719 r
.83394 .14664 .83377 .15199 .84345 .15225 .84361 .14692 Mtetra
.843 .717 .724 r
.82419 .14636 .824 .15174 .83377 .15199 .83394 .14664 Mtetra
.837 .716 .73 r
.81436 .1461 .81414 .1515 .824 .15174 .82419 .14636 Mtetra
.831 .714 .735 r
.80443 .14585 .8042 .15127 .81414 .1515 .81436 .1461 Mtetra
.824 .712 .741 r
.79442 .14562 .79417 .15105 .8042 .15127 .80443 .14585 Mtetra
.816 .709 .747 r
.78431 .1454 .78405 .15085 .79417 .15105 .79442 .14562 Mtetra
.807 .705 .753 r
.77412 .14519 .77384 .15067 .78405 .15085 .78431 .1454 Mtetra
.797 .701 .759 r
.76383 .145 .76355 .1505 .77384 .15067 .77412 .14519 Mtetra
.787 .696 .765 r
.75346 .14484 .75316 .15035 .76355 .1505 .76383 .145 Mtetra
.775 .691 .771 r
.74301 .1447 .7427 .15023 .75316 .15035 .75346 .14484 Mtetra
.762 .685 .777 r
.73247 .14458 .73215 .15012 .7427 .15023 .74301 .1447 Mtetra
.749 .678 .783 r
.72185 .14449 .72152 .15005 .73215 .15012 .73247 .14458 Mtetra
.734 .671 .789 r
.71116 .14442 .71082 .15 .72152 .15005 .72185 .14449 Mtetra
.718 .663 .794 r
.70039 .14439 .70005 .14998 .71082 .15 .71116 .14442 Mtetra
.701 .654 .8 r
.68956 .14439 .68921 .14999 .70005 .14998 .70039 .14439 Mtetra
.683 .644 .805 r
.67868 .14442 .67832 .15003 .68921 .14999 .68956 .14439 Mtetra
.663 .634 .81 r
.66774 .14449 .66738 .15011 .67832 .15003 .67868 .14442 Mtetra
.642 .622 .815 r
.65676 .14459 .6564 .15023 .66738 .15011 .66774 .14449 Mtetra
.62 .611 .819 r
.64574 .14474 .64538 .15039 .6564 .15023 .65676 .14459 Mtetra
.597 .598 .824 r
.6347 .14493 .63434 .15059 .64538 .15039 .64574 .14474 Mtetra
.572 .586 .828 r
.62365 .14516 .62329 .15083 .63434 .15059 .6347 .14493 Mtetra
.547 .573 .832 r
.6126 .14544 .61225 .15112 .62329 .15083 .62365 .14516 Mtetra
.521 .561 .836 r
.60156 .14577 .60122 .15145 .61225 .15112 .6126 .14544 Mtetra
.496 .55 .841 r
.59055 .14613 .59021 .15183 .60122 .15145 .60156 .14577 Mtetra
.471 .541 .847 r
.57958 .14654 .57926 .15225 .59021 .15183 .59055 .14613 Mtetra
.45 .537 .855 r
.56867 .14699 .56836 .15271 .57926 .15225 .57958 .14654 Mtetra
.434 .54 .865 r
.55785 .14746 .55755 .1532 .56836 .15271 .56867 .14699 Mtetra
.428 .552 .878 r
.54711 .14793 .54685 .1537 .55755 .1532 .55785 .14746 Mtetra
.435 .576 .896 r
.53648 .14837 .53626 .15418 .54685 .1537 .54711 .14793 Mtetra
.505 .412 .684 r
.09087 .15419 .09087 .15937 .10008 .15911 .10006 .15391 Mtetra
.506 .416 .688 r
.10006 .15391 .10008 .15911 .10935 .15885 .1093 .15363 Mtetra
.508 .421 .692 r
.1093 .15363 .10935 .15885 .11867 .15859 .11861 .15335 Mtetra
.511 .426 .696 r
.11861 .15335 .11867 .15859 .12807 .15833 .12798 .15307 Mtetra
.515 .432 .7 r
.12798 .15307 .12807 .15833 .13754 .15807 .13743 .15279 Mtetra
.52 .439 .705 r
.13743 .15279 .13754 .15807 .14708 .15782 .14695 .15252 Mtetra
.526 .447 .71 r
.14695 .15252 .14708 .15782 .1567 .15757 .15655 .15225 Mtetra
.533 .456 .715 r
.15655 .15225 .1567 .15757 .1664 .15733 .16623 .15199 Mtetra
.54 .465 .72 r
.16623 .15199 .1664 .15733 .17619 .1571 .176 .15174 Mtetra
.549 .475 .725 r
.176 .15174 .17619 .1571 .18606 .15688 .18586 .1515 Mtetra
.558 .486 .73 r
.18586 .1515 .18606 .15688 .19602 .15667 .1958 .15127 Mtetra
.568 .498 .736 r
.1958 .15127 .19602 .15667 .20606 .15647 .20583 .15105 Mtetra
.579 .51 .741 r
.20583 .15105 .20606 .15647 .2162 .15629 .21595 .15085 Mtetra
.591 .523 .747 r
.21595 .15085 .2162 .15629 .22642 .15612 .22616 .15067 Mtetra
.604 .537 .753 r
.22616 .15067 .22642 .15612 .23673 .15597 .23645 .1505 Mtetra
.617 .551 .758 r
.23645 .1505 .23673 .15597 .24712 .15584 .24684 .15035 Mtetra
.63 .566 .764 r
.24684 .15035 .24712 .15584 .2576 .15573 .2573 .15023 Mtetra
.645 .582 .769 r
.2573 .15023 .2576 .15573 .26816 .15565 .26785 .15012 Mtetra
.66 .598 .775 r
.26785 .15012 .26816 .15565 .2788 .15558 .27848 .15005 Mtetra
.675 .615 .78 r
.27848 .15005 .2788 .15558 .28951 .15555 .28918 .15 Mtetra
.691 .632 .785 r
.28918 .15 .28951 .15555 .30028 .15554 .29995 .14998 Mtetra
.708 .65 .79 r
.29995 .14998 .30028 .15554 .31112 .15556 .31079 .14999 Mtetra
.724 .669 .795 r
.31079 .14999 .31112 .15556 .32202 .15562 .32168 .15003 Mtetra
.741 .687 .799 r
.32168 .15003 .32202 .15562 .33297 .15571 .33262 .15011 Mtetra
.758 .706 .803 r
.33262 .15011 .33297 .15571 .34395 .15583 .3436 .15023 Mtetra
.774 .725 .807 r
.3436 .15023 .34395 .15583 .35497 .156 .35462 .15039 Mtetra
.791 .745 .81 r
.35462 .15039 .35497 .156 .366 .1562 .36566 .15059 Mtetra
.807 .764 .813 r
.36566 .15059 .366 .1562 .37705 .15645 .37671 .15083 Mtetra
.822 .783 .816 r
.37671 .15083 .37705 .15645 .38809 .15674 .38775 .15112 Mtetra
.836 .803 .818 r
.38775 .15112 .38809 .15674 .39912 .15708 .39878 .15145 Mtetra
.849 .821 .821 r
.39878 .15145 .39912 .15708 .41011 .15747 .40979 .15183 Mtetra
.859 .84 .825 r
.40979 .15183 .41011 .15747 .42106 .1579 .42074 .15225 Mtetra
.866 .857 .83 r
.42074 .15225 .42106 .1579 .43194 .15838 .43164 .15271 Mtetra
.867 .872 .839 r
.43164 .15271 .43194 .15838 .44273 .15889 .44245 .1532 Mtetra
.863 .708 .687 r
.89994 .15391 .89992 .15911 .90913 .15937 .90913 .15419 Mtetra
.862 .71 .691 r
.8907 .15363 .89065 .15885 .89992 .15911 .89994 .15391 Mtetra
.861 .712 .695 r
.88139 .15335 .88133 .15859 .89065 .15885 .8907 .15363 Mtetra
.859 .713 .7 r
.87202 .15307 .87193 .15833 .88133 .15859 .88139 .15335 Mtetra
.857 .714 .704 r
.86257 .15279 .86246 .15807 .87193 .15833 .87202 .15307 Mtetra
.853 .715 .709 r
.85305 .15252 .85292 .15782 .86246 .15807 .86257 .15279 Mtetra
.85 .715 .714 r
.84345 .15225 .8433 .15757 .85292 .15782 .85305 .15252 Mtetra
.845 .714 .719 r
.83377 .15199 .8336 .15733 .8433 .15757 .84345 .15225 Mtetra
.84 .713 .724 r
.824 .15174 .82381 .1571 .8336 .15733 .83377 .15199 Mtetra
.834 .712 .729 r
.81414 .1515 .81394 .15688 .82381 .1571 .824 .15174 Mtetra
.828 .71 .734 r
.8042 .15127 .80398 .15667 .81394 .15688 .81414 .1515 Mtetra
.82 .707 .74 r
.79417 .15105 .79394 .15647 .80398 .15667 .8042 .15127 Mtetra
.812 .704 .745 r
.78405 .15085 .7838 .15629 .79394 .15647 .79417 .15105 Mtetra
.803 .7 .751 r
.77384 .15067 .77358 .15612 .7838 .15629 .78405 .15085 Mtetra
.793 .696 .757 r
.76355 .1505 .76327 .15597 .77358 .15612 .77384 .15067 Mtetra
.782 .69 .763 r
.75316 .15035 .75288 .15584 .76327 .15597 .76355 .1505 Mtetra
.77 .685 .768 r
.7427 .15023 .7424 .15573 .75288 .15584 .75316 .15035 Mtetra
.758 .678 .774 r
.73215 .15012 .73184 .15565 .7424 .15573 .7427 .15023 Mtetra
.744 .671 .78 r
.72152 .15005 .7212 .15558 .73184 .15565 .73215 .15012 Mtetra
.728 .663 .785 r
.71082 .15 .71049 .15555 .7212 .15558 .72152 .15005 Mtetra
.712 .654 .791 r
.70005 .14998 .69972 .15554 .71049 .15555 .71082 .15 Mtetra
.695 .645 .796 r
.68921 .14999 .68888 .15556 .69972 .15554 .70005 .14998 Mtetra
.676 .635 .801 r
.67832 .15003 .67798 .15562 .68888 .15556 .68921 .14999 Mtetra
.656 .623 .805 r
.66738 .15011 .66703 .15571 .67798 .15562 .67832 .15003 Mtetra
.634 .611 .81 r
.6564 .15023 .65605 .15583 .66703 .15571 .66738 .15011 Mtetra
.611 .599 .814 r
.64538 .15039 .64503 .156 .65605 .15583 .6564 .15023 Mtetra
.587 .585 .818 r
.63434 .15059 .634 .1562 .64503 .156 .64538 .15039 Mtetra
.561 .571 .821 r
.62329 .15083 .62295 .15645 .634 .1562 .63434 .15059 Mtetra
.534 .557 .825 r
.61225 .15112 .61191 .15674 .62295 .15645 .62329 .15083 Mtetra
.506 .543 .828 r
.60122 .15145 .60088 .15708 .61191 .15674 .61225 .15112 Mtetra
.478 .53 .832 r
.59021 .15183 .58989 .15747 .60088 .15708 .60122 .15145 Mtetra
.451 .52 .838 r
.57926 .15225 .57894 .1579 .58989 .15747 .59021 .15183 Mtetra
.427 .514 .845 r
.56836 .15271 .56806 .15838 .57894 .1579 .57926 .15225 Mtetra
.407 .515 .855 r
.55755 .1532 .55727 .15889 .56806 .15838 .56836 .15271 Mtetra
.509 .416 .685 r
.09087 .15937 .09087 .16455 .1001 .16431 .10008 .15911 Mtetra
.511 .42 .688 r
.10008 .15911 .1001 .16431 .10939 .16407 .10935 .15885 Mtetra
.513 .424 .692 r
.10935 .15885 .10939 .16407 .11874 .16382 .11867 .15859 Mtetra
.516 .43 .696 r
.11867 .15859 .11874 .16382 .12815 .16359 .12807 .15833 Mtetra
.52 .436 .701 r
.12807 .15833 .12815 .16359 .13764 .16335 .13754 .15807 Mtetra
.525 .443 .705 r
.13754 .15807 .13764 .16335 .1472 .16312 .14708 .15782 Mtetra
.531 .45 .71 r
.14708 .15782 .1472 .16312 .15684 .16289 .1567 .15757 Mtetra
.538 .459 .714 r
.1567 .15757 .15684 .16289 .16656 .16267 .1664 .15733 Mtetra
.545 .468 .719 r
.1664 .15733 .16656 .16267 .17636 .16246 .17619 .1571 Mtetra
.554 .478 .724 r
.17619 .1571 .17636 .16246 .18625 .16226 .18606 .15688 Mtetra
.563 .489 .729 r
.18606 .15688 .18625 .16226 .19622 .16206 .19602 .15667 Mtetra
.574 .5 .735 r
.19602 .15667 .19622 .16206 .20628 .16189 .20606 .15647 Mtetra
.585 .513 .74 r
.20606 .15647 .20628 .16189 .21643 .16172 .2162 .15629 Mtetra
.597 .526 .745 r
.2162 .15629 .21643 .16172 .22667 .16157 .22642 .15612 Mtetra
.609 .539 .751 r
.22642 .15612 .22667 .16157 .23699 .16143 .23673 .15597 Mtetra
.622 .554 .756 r
.23673 .15597 .23699 .16143 .24739 .16132 .24712 .15584 Mtetra
.636 .569 .762 r
.24712 .15584 .24739 .16132 .25788 .16122 .2576 .15573 Mtetra
.651 .584 .767 r
.2576 .15573 .25788 .16122 .26845 .16115 .26816 .15565 Mtetra
.666 .601 .772 r
.26816 .15565 .26845 .16115 .2791 .1611 .2788 .15558 Mtetra
.682 .617 .777 r
.2788 .15558 .2791 .1611 .28981 .16107 .28951 .15555 Mtetra
.698 .635 .782 r
.28951 .15555 .28981 .16107 .3006 .16108 .30028 .15554 Mtetra
.715 .653 .786 r
.30028 .15554 .3006 .16108 .31144 .16111 .31112 .15556 Mtetra
.732 .671 .791 r
.31112 .15556 .31144 .16111 .32234 .16117 .32202 .15562 Mtetra
.749 .69 .795 r
.32202 .15562 .32234 .16117 .33329 .16127 .33297 .15571 Mtetra
.766 .709 .798 r
.33297 .15571 .33329 .16127 .34428 .1614 .34395 .15583 Mtetra
.783 .728 .801 r
.34395 .15583 .34428 .1614 .35529 .16157 .35497 .156 Mtetra
.8 .747 .804 r
.35497 .156 .35529 .16157 .36633 .16178 .366 .1562 Mtetra
.817 .767 .806 r
.366 .1562 .36633 .16178 .37737 .16203 .37705 .15645 Mtetra
.833 .787 .808 r
.37705 .15645 .37737 .16203 .38841 .16232 .38809 .15674 Mtetra
.848 .806 .81 r
.38809 .15674 .38841 .16232 .39943 .16266 .39912 .15708 Mtetra
.861 .826 .811 r
.39912 .15708 .39943 .16266 .41042 .16306 .41011 .15747 Mtetra
.873 .845 .814 r
.41011 .15747 .41042 .16306 .42136 .1635 .42106 .1579 Mtetra
.881 .863 .818 r
.42106 .1579 .42136 .1635 .43223 .16399 .43194 .15838 Mtetra
.884 .88 .825 r
.43194 .15838 .43223 .16399 .44301 .16452 .44273 .15889 Mtetra
.86 .705 .688 r
.89992 .15911 .8999 .16431 .90913 .16455 .90913 .15937 Mtetra
.86 .707 .692 r
.89065 .15885 .89061 .16407 .8999 .16431 .89992 .15911 Mtetra
.858 .709 .696 r
.88133 .15859 .88126 .16382 .89061 .16407 .89065 .15885 Mtetra
.856 .71 .7 r
.87193 .15833 .87185 .16359 .88126 .16382 .88133 .15859 Mtetra
.854 .711 .704 r
.86246 .15807 .86236 .16335 .87185 .16359 .87193 .15833 Mtetra
.851 .711 .709 r
.85292 .15782 .8528 .16312 .86236 .16335 .86246 .15807 Mtetra
.847 .711 .713 r
.8433 .15757 .84316 .16289 .8528 .16312 .85292 .15782 Mtetra
.842 .71 .718 r
.8336 .15733 .83344 .16267 .84316 .16289 .8433 .15757 Mtetra
.837 .709 .723 r
.82381 .1571 .82364 .16246 .83344 .16267 .8336 .15733 Mtetra
.831 .707 .728 r
.81394 .15688 .81375 .16226 .82364 .16246 .82381 .1571 Mtetra
.824 .705 .733 r
.80398 .15667 .80378 .16206 .81375 .16226 .81394 .15688 Mtetra
.817 .702 .738 r
.79394 .15647 .79372 .16189 .80378 .16206 .80398 .15667 Mtetra
.809 .699 .744 r
.7838 .15629 .78357 .16172 .79372 .16189 .79394 .15647 Mtetra
.799 .695 .749 r
.77358 .15612 .77333 .16157 .78357 .16172 .7838 .15629 Mtetra
.789 .69 .755 r
.76327 .15597 .76301 .16143 .77333 .16157 .77358 .15612 Mtetra
.778 .685 .76 r
.75288 .15584 .75261 .16132 .76301 .16143 .76327 .15597 Mtetra
.766 .678 .766 r
.7424 .15573 .74212 .16122 .75261 .16132 .75288 .15584 Mtetra
.753 .672 .771 r
.73184 .15565 .73155 .16115 .74212 .16122 .7424 .15573 Mtetra
.739 .664 .777 r
.7212 .15558 .7209 .1611 .73155 .16115 .73184 .15565 Mtetra
.723 .655 .782 r
.71049 .15555 .71019 .16107 .7209 .1611 .7212 .15558 Mtetra
.706 .646 .787 r
.69972 .15554 .6994 .16108 .71019 .16107 .71049 .15555 Mtetra
.688 .636 .792 r
.68888 .15556 .68856 .16111 .6994 .16108 .69972 .15554 Mtetra
.669 .625 .796 r
.67798 .15562 .67766 .16117 .68856 .16111 .68888 .15556 Mtetra
.648 .613 .801 r
.66703 .15571 .66671 .16127 .67766 .16117 .67798 .15562 Mtetra
.626 .6 .805 r
.65605 .15583 .65572 .1614 .66671 .16127 .66703 .15571 Mtetra
.602 .587 .808 r
.64503 .156 .64471 .16157 .65572 .1614 .65605 .15583 Mtetra
.577 .572 .811 r
.634 .1562 .63367 .16178 .64471 .16157 .64503 .156 Mtetra
.55 .557 .814 r
.62295 .15645 .62263 .16203 .63367 .16178 .634 .1562 Mtetra
.521 .541 .817 r
.61191 .15674 .61159 .16232 .62263 .16203 .62295 .15645 Mtetra
.492 .525 .82 r
.60088 .15708 .60057 .16266 .61159 .16232 .61191 .15674 Mtetra
.461 .51 .823 r
.58989 .15747 .58958 .16306 .60057 .16266 .60088 .15708 Mtetra
.431 .497 .827 r
.57894 .1579 .57864 .1635 .58958 .16306 .58989 .15747 Mtetra
.402 .488 .833 r
.56806 .15838 .56777 .16399 .57864 .1635 .57894 .1579 Mtetra
.378 .486 .843 r
.55727 .15889 .55699 .16452 .56777 .16399 .56806 .15838 Mtetra
.514 .42 .686 r
.09087 .16455 .09087 .16973 .10012 .1695 .1001 .16431 Mtetra
.515 .423 .689 r
.1001 .16431 .10012 .1695 .10943 .16928 .10939 .16407 Mtetra
.517 .428 .693 r
.10939 .16407 .10943 .16928 .1188 .16906 .11874 .16382 Mtetra
.52 .433 .697 r
.11874 .16382 .1188 .16906 .12823 .16884 .12815 .16359 Mtetra
.525 .439 .701 r
.12815 .16359 .12823 .16884 .13774 .16862 .13764 .16335 Mtetra
.53 .446 .705 r
.13764 .16335 .13774 .16862 .14732 .16841 .1472 .16312 Mtetra
.535 .453 .709 r
.1472 .16312 .14732 .16841 .15697 .1682 .15684 .16289 Mtetra
.542 .462 .714 r
.15684 .16289 .15697 .1682 .16671 .168 .16656 .16267 Mtetra
.55 .471 .719 r
.16656 .16267 .16671 .168 .17653 .16781 .17636 .16246 Mtetra
.559 .481 .723 r
.17636 .16246 .17653 .16781 .18643 .16762 .18625 .16226 Mtetra
.568 .491 .728 r
.18625 .16226 .18643 .16762 .19642 .16745 .19622 .16206 Mtetra
.579 .503 .733 r
.19622 .16206 .19642 .16745 .20649 .16728 .20628 .16189 Mtetra
.59 .515 .738 r
.20628 .16189 .20649 .16728 .21665 .16713 .21643 .16172 Mtetra
.602 .528 .744 r
.21643 .16172 .21665 .16713 .2269 .167 .22667 .16157 Mtetra
.614 .541 .749 r
.22667 .16157 .2269 .167 .23723 .16688 .23699 .16143 Mtetra
.628 .556 .754 r
.23699 .16143 .23723 .16688 .24765 .16678 .24739 .16132 Mtetra
.642 .571 .759 r
.24739 .16132 .24765 .16678 .25815 .1667 .25788 .16122 Mtetra
.657 .586 .764 r
.25788 .16122 .25815 .1667 .26873 .16663 .26845 .16115 Mtetra
.672 .602 .769 r
.26845 .16115 .26873 .16663 .27938 .16659 .2791 .1611 Mtetra
.688 .619 .774 r
.2791 .1611 .27938 .16659 .2901 .16658 .28981 .16107 Mtetra
.705 .637 .778 r
.28981 .16107 .2901 .16658 .30089 .16659 .3006 .16108 Mtetra
.721 .654 .782 r
.3006 .16108 .30089 .16659 .31175 .16663 .31144 .16111 Mtetra
.739 .673 .786 r
.31144 .16111 .31175 .16663 .32265 .1667 .32234 .16117 Mtetra
.756 .691 .79 r
.32234 .16117 .32265 .1667 .3336 .1668 .33329 .16127 Mtetra
.774 .711 .793 r
.33329 .16127 .3336 .1668 .34459 .16693 .34428 .1614 Mtetra
.791 .73 .795 r
.34428 .1614 .34459 .16693 .3556 .16711 .35529 .16157 Mtetra
.809 .749 .797 r
.35529 .16157 .3556 .16711 .36664 .16731 .36633 .16178 Mtetra
.826 .769 .799 r
.36633 .16178 .36664 .16731 .37768 .16757 .37737 .16203 Mtetra
.842 .789 .8 r
.37737 .16203 .37768 .16757 .38871 .16786 .38841 .16232 Mtetra
.858 .809 .8 r
.38841 .16232 .38871 .16786 .39973 .1682 .39943 .16266 Mtetra
.873 .829 .801 r
.39943 .16266 .39973 .1682 .41071 .16859 .41042 .16306 Mtetra
.886 .848 .801 r
.41042 .16306 .41071 .16859 .42165 .16904 .42136 .1635 Mtetra
.896 .868 .803 r
.42136 .1635 .42165 .16904 .43251 .16953 .43223 .16399 Mtetra
.858 .703 .689 r
.8999 .16431 .89988 .1695 .90913 .16973 .90913 .16455 Mtetra
.857 .705 .692 r
.89061 .16407 .89057 .16928 .89988 .1695 .8999 .16431 Mtetra
.856 .706 .696 r
.88126 .16382 .8812 .16906 .89057 .16928 .89061 .16407 Mtetra
.854 .708 .7 r
.87185 .16359 .87177 .16884 .8812 .16906 .88126 .16382 Mtetra
.851 .708 .704 r
.86236 .16335 .86226 .16862 .87177 .16884 .87185 .16359 Mtetra
.848 .708 .708 r
.8528 .16312 .85268 .16841 .86226 .16862 .86236 .16335 Mtetra
.844 .708 .713 r
.84316 .16289 .84303 .1682 .85268 .16841 .8528 .16312 Mtetra
.839 .707 .717 r
.83344 .16267 .83329 .168 .84303 .1682 .84316 .16289 Mtetra
.834 .705 .722 r
.82364 .16246 .82347 .16781 .83329 .168 .83344 .16267 Mtetra
.828 .703 .727 r
.81375 .16226 .81357 .16762 .82347 .16781 .82364 .16246 Mtetra
.821 .701 .732 r
.80378 .16206 .80358 .16745 .81357 .16762 .81375 .16226 Mtetra
.814 .698 .737 r
.79372 .16189 .79351 .16728 .80358 .16745 .80378 .16206 Mtetra
.805 .694 .742 r
.78357 .16172 .78335 .16713 .79351 .16728 .79372 .16189 Mtetra
.796 .69 .747 r
.77333 .16157 .7731 .167 .78335 .16713 .78357 .16172 Mtetra
.786 .684 .753 r
.76301 .16143 .76277 .16688 .7731 .167 .77333 .16157 Mtetra
.774 .679 .758 r
.75261 .16132 .75235 .16678 .76277 .16688 .76301 .16143 Mtetra
.762 .672 .763 r
.74212 .16122 .74185 .1667 .75235 .16678 .75261 .16132 Mtetra
.749 .665 .768 r
.73155 .16115 .73127 .16663 .74185 .1667 .74212 .16122 Mtetra
.734 .657 .773 r
.7209 .1611 .72062 .16659 .73127 .16663 .73155 .16115 Mtetra
.718 .648 .778 r
.71019 .16107 .7099 .16658 .72062 .16659 .7209 .1611 Mtetra
.701 .638 .783 r
.6994 .16108 .69911 .16659 .7099 .16658 .71019 .16107 Mtetra
.682 .627 .788 r
.68856 .16111 .68825 .16663 .69911 .16659 .6994 .16108 Mtetra
.663 .616 .792 r
.67766 .16117 .67735 .1667 .68825 .16663 .68856 .16111 Mtetra
.641 .603 .796 r
.66671 .16127 .6664 .1668 .67735 .1667 .67766 .16117 Mtetra
.618 .589 .799 r
.65572 .1614 .65541 .16693 .6664 .1668 .66671 .16127 Mtetra
.593 .575 .802 r
.64471 .16157 .6444 .16711 .65541 .16693 .65572 .1614 Mtetra
.567 .559 .805 r
.63367 .16178 .63336 .16731 .6444 .16711 .64471 .16157 Mtetra
.539 .542 .807 r
.62263 .16203 .62232 .16757 .63336 .16731 .63367 .16178 Mtetra
.509 .525 .809 r
.61159 .16232 .61129 .16786 .62232 .16757 .62263 .16203 Mtetra
.477 .507 .81 r
.60057 .16266 .60027 .1682 .61129 .16786 .61159 .16232 Mtetra
.444 .49 .812 r
.58958 .16306 .58929 .16859 .60027 .1682 .60057 .16266 Mtetra
.41 .473 .815 r
.57864 .1635 .57835 .16904 .58929 .16859 .58958 .16306 Mtetra
.376 .461 .82 r
.56777 .16399 .56749 .16953 .57835 .16904 .57864 .1635 Mtetra
.518 .423 .687 r
.09087 .16973 .09087 .17491 .10014 .1747 .10012 .1695 Mtetra
.52 .427 .69 r
.10012 .1695 .10014 .1747 .10947 .1745 .10943 .16928 Mtetra
.522 .431 .693 r
.10943 .16928 .10947 .1745 .11886 .17429 .1188 .16906 Mtetra
.525 .436 .697 r
.1188 .16906 .11886 .17429 .12831 .17409 .12823 .16884 Mtetra
.529 .442 .701 r
.12823 .16884 .12831 .17409 .13783 .17389 .13774 .16862 Mtetra
.534 .448 .705 r
.13774 .16862 .13783 .17389 .14743 .1737 .14732 .16841 Mtetra
.54 .456 .709 r
.14732 .16841 .14743 .1737 .1571 .17351 .15697 .1682 Mtetra
.547 .464 .713 r
.15697 .1682 .1571 .17351 .16685 .17332 .16671 .168 Mtetra
.555 .473 .718 r
.16671 .168 .16685 .17332 .17668 .17315 .17653 .16781 Mtetra
.563 .483 .722 r
.17653 .16781 .17668 .17315 .1866 .17298 .18643 .16762 Mtetra
.573 .493 .727 r
.18643 .16762 .1866 .17298 .1966 .17282 .19642 .16745 Mtetra
.583 .505 .732 r
.19642 .16745 .1966 .17282 .20669 .17267 .20649 .16728 Mtetra
.595 .517 .737 r
.20649 .16728 .20669 .17267 .21686 .17254 .21665 .16713 Mtetra
.607 .53 .742 r
.21665 .16713 .21686 .17254 .22712 .17242 .2269 .167 Mtetra
.619 .543 .747 r
.2269 .167 .22712 .17242 .23746 .17231 .23723 .16688 Mtetra
.633 .557 .752 r
.23723 .16688 .23746 .17231 .24789 .17222 .24765 .16678 Mtetra
.647 .572 .756 r
.24765 .16678 .24789 .17222 .2584 .17215 .25815 .1667 Mtetra
.662 .588 .761 r
.25815 .1667 .2584 .17215 .26898 .1721 .26873 .16663 Mtetra
.678 .604 .766 r
.26873 .16663 .26898 .1721 .27965 .17207 .27938 .16659 Mtetra
.694 .621 .77 r
.27938 .16659 .27965 .17207 .29038 .17206 .2901 .16658 Mtetra
.711 .638 .774 r
.2901 .16658 .29038 .17206 .30117 .17208 .30089 .16659 Mtetra
.728 .656 .778 r
.30089 .16659 .30117 .17208 .31203 .17213 .31175 .16663 Mtetra
.745 .674 .782 r
.31175 .16663 .31203 .17213 .32294 .1722 .32265 .1667 Mtetra
.763 .693 .785 r
.32265 .1667 .32294 .1722 .33389 .1723 .3336 .1668 Mtetra
.781 .712 .787 r
.3336 .1668 .33389 .1723 .34488 .17244 .34459 .16693 Mtetra
.799 .731 .789 r
.34459 .16693 .34488 .17244 .35589 .17261 .3556 .16711 Mtetra
.817 .751 .791 r
.3556 .16711 .35589 .17261 .36693 .17282 .36664 .16731 Mtetra
.834 .771 .791 r
.36664 .16731 .36693 .17282 .37797 .17307 .37768 .16757 Mtetra
.852 .791 .791 r
.37768 .16757 .37797 .17307 .389 .17336 .38871 .16786 Mtetra
.868 .811 .791 r
.38871 .16786 .389 .17336 .40001 .17369 .39973 .1682 Mtetra
.884 .831 .789 r
.39973 .1682 .40001 .17369 .41099 .17408 .41071 .16859 Mtetra
.898 .851 .788 r
.41071 .16859 .41099 .17408 .42192 .17452 .42165 .16904 Mtetra
.855 .7 .69 r
.89988 .1695 .89986 .1747 .90913 .17491 .90913 .16973 Mtetra
.854 .702 .693 r
.89057 .16928 .89053 .1745 .89986 .1747 .89988 .1695 Mtetra
.853 .704 .696 r
.8812 .16906 .88114 .17429 .89053 .1745 .89057 .16928 Mtetra
.851 .705 .7 r
.87177 .16884 .87169 .17409 .88114 .17429 .8812 .16906 Mtetra
.848 .705 .704 r
.86226 .16862 .86217 .17389 .87169 .17409 .87177 .16884 Mtetra
.845 .705 .708 r
.85268 .16841 .85257 .1737 .86217 .17389 .86226 .16862 Mtetra
.841 .704 .712 r
.84303 .1682 .8429 .17351 .85257 .1737 .85268 .16841 Mtetra
.837 .703 .717 r
.83329 .168 .83315 .17332 .8429 .17351 .84303 .1682 Mtetra
.831 .702 .721 r
.82347 .16781 .82332 .17315 .83315 .17332 .83329 .168 Mtetra
.825 .699 .726 r
.81357 .16762 .8134 .17298 .82332 .17315 .82347 .16781 Mtetra
.818 .697 .731 r
.80358 .16745 .8034 .17282 .8134 .17298 .81357 .16762 Mtetra
.81 .693 .735 r
.79351 .16728 .79331 .17267 .8034 .17282 .80358 .16745 Mtetra
.802 .689 .74 r
.78335 .16713 .78314 .17254 .79331 .17267 .79351 .16728 Mtetra
.792 .684 .745 r
.7731 .167 .77288 .17242 .78314 .17254 .78335 .16713 Mtetra
.782 .679 .75 r
.76277 .16688 .76254 .17231 .77288 .17242 .7731 .167 Mtetra
.77 .673 .755 r
.75235 .16678 .75211 .17222 .76254 .17231 .76277 .16688 Mtetra
.758 .666 .76 r
.74185 .1667 .7416 .17215 .75211 .17222 .75235 .16678 Mtetra
.744 .658 .765 r
.73127 .16663 .73102 .1721 .7416 .17215 .74185 .1667 Mtetra
.729 .65 .77 r
.72062 .16659 .72035 .17207 .73102 .1721 .73127 .16663 Mtetra
.713 .64 .775 r
.7099 .16658 .70962 .17206 .72035 .17207 .72062 .16659 Mtetra
.696 .63 .779 r
.69911 .16659 .69883 .17208 .70962 .17206 .7099 .16658 Mtetra
.677 .619 .783 r
.68825 .16663 .68797 .17213 .69883 .17208 .69911 .16659 Mtetra
.656 .606 .787 r
.67735 .1667 .67706 .1722 .68797 .17213 .68825 .16663 Mtetra
.634 .593 .79 r
.6664 .1668 .66611 .1723 .67706 .1722 .67735 .1667 Mtetra
.611 .579 .793 r
.65541 .16693 .65512 .17244 .66611 .1723 .6664 .1668 Mtetra
.585 .563 .796 r
.6444 .16711 .64411 .17261 .65512 .17244 .65541 .16693 Mtetra
.558 .546 .797 r
.63336 .16731 .63307 .17282 .64411 .17261 .6444 .16711 Mtetra
.528 .528 .799 r
.62232 .16757 .62203 .17307 .63307 .17282 .63336 .16731 Mtetra
.497 .509 .8 r
.61129 .16786 .611 .17336 .62203 .17307 .62232 .16757 Mtetra
.463 .489 .8 r
.60027 .1682 .59999 .17369 .611 .17336 .61129 .16786 Mtetra
.427 .468 .8 r
.58929 .16859 .58901 .17408 .59999 .17369 .60027 .1682 Mtetra
.389 .448 .801 r
.57835 .16904 .57808 .17452 .58901 .17408 .58929 .16859 Mtetra
.522 .426 .687 r
.09087 .17491 .09087 .18008 .10016 .1799 .10014 .1747 Mtetra
.524 .43 .69 r
.10014 .1747 .10016 .1799 .1095 .17971 .10947 .1745 Mtetra
.526 .434 .694 r
.10947 .1745 .1095 .17971 .11891 .17952 .11886 .17429 Mtetra
.529 .439 .697 r
.11886 .17429 .11891 .17952 .12838 .17934 .12831 .17409 Mtetra
.533 .444 .701 r
.12831 .17409 .12838 .17934 .13792 .17916 .13783 .17389 Mtetra
.538 .451 .705 r
.13783 .17389 .13792 .17916 .14753 .17898 .14743 .1737 Mtetra
.544 .458 .709 r
.14743 .1737 .14753 .17898 .15722 .17881 .1571 .17351 Mtetra
.551 .466 .713 r
.1571 .17351 .15722 .17881 .16698 .17864 .16685 .17332 Mtetra
.559 .475 .717 r
.16685 .17332 .16698 .17864 .17683 .17848 .17668 .17315 Mtetra
.567 .485 .721 r
.17668 .17315 .17683 .17848 .18676 .17833 .1866 .17298 Mtetra
.577 .495 .726 r
.1866 .17298 .18676 .17833 .19677 .17818 .1966 .17282 Mtetra
.588 .507 .73 r
.1966 .17282 .19677 .17818 .20687 .17805 .20669 .17267 Mtetra
.599 .519 .735 r
.20669 .17267 .20687 .17805 .21706 .17793 .21686 .17254 Mtetra
.611 .531 .74 r
.21686 .17254 .21706 .17793 .22733 .17782 .22712 .17242 Mtetra
.624 .545 .744 r
.22712 .17242 .22733 .17782 .23768 .17773 .23746 .17231 Mtetra
.638 .559 .749 r
.23746 .17231 .23768 .17773 .24812 .17765 .24789 .17222 Mtetra
.652 .574 .754 r
.24789 .17222 .24812 .17765 .25863 .17759 .2584 .17215 Mtetra
.668 .589 .758 r
.2584 .17215 .25863 .17759 .26923 .17755 .26898 .1721 Mtetra
.683 .605 .762 r
.26898 .1721 .26923 .17755 .27989 .17753 .27965 .17207 Mtetra
.7 .622 .766 r
.27965 .17207 .27989 .17753 .29063 .17753 .29038 .17206 Mtetra
.717 .639 .77 r
.29038 .17206 .29063 .17753 .30143 .17755 .30117 .17208 Mtetra
.734 .657 .774 r
.30117 .17208 .30143 .17755 .31229 .1776 .31203 .17213 Mtetra
.752 .675 .777 r
.31203 .17213 .31229 .1776 .32321 .17768 .32294 .1722 Mtetra
.77 .694 .779 r
.32294 .1722 .32321 .17768 .33416 .17778 .33389 .1723 Mtetra
.788 .713 .781 r
.33389 .1723 .33416 .17778 .34515 .17792 .34488 .17244 Mtetra
.806 .732 .783 r
.34488 .17244 .34515 .17792 .35617 .17808 .35589 .17261 Mtetra
.824 .752 .784 r
.35589 .17261 .35617 .17808 .3672 .17829 .36693 .17282 Mtetra
.842 .772 .783 r
.36693 .17282 .3672 .17829 .37824 .17853 .37797 .17307 Mtetra
.86 .792 .782 r
.37797 .17307 .37824 .17853 .38926 .17881 .389 .17336 Mtetra
.878 .812 .78 r
.389 .17336 .38926 .17881 .40027 .17914 .40001 .17369 Mtetra
.895 .832 .777 r
.40001 .17369 .40027 .17914 .41125 .17952 .41099 .17408 Mtetra
.91 .852 .773 r
.41099 .17408 .41125 .17952 .42217 .17995 .42192 .17452 Mtetra
.853 .698 .69 r
.89986 .1747 .89984 .1799 .90913 .18008 .90913 .17491 Mtetra
.852 .7 .693 r
.89053 .1745 .8905 .17971 .89984 .1799 .89986 .1747 Mtetra
.851 .701 .697 r
.88114 .17429 .88109 .17952 .8905 .17971 .89053 .1745 Mtetra
.849 .702 .7 r
.87169 .17409 .87162 .17934 .88109 .17952 .88114 .17429 Mtetra
.846 .702 .704 r
.86217 .17389 .86208 .17916 .87162 .17934 .87169 .17409 Mtetra
.843 .702 .708 r
.85257 .1737 .85247 .17898 .86208 .17916 .86217 .17389 Mtetra
.839 .701 .712 r
.8429 .17351 .84278 .17881 .85247 .17898 .85257 .1737 Mtetra
.834 .7 .716 r
.83315 .17332 .83302 .17864 .84278 .17881 .8429 .17351 Mtetra
.828 .698 .72 r
.82332 .17315 .82317 .17848 .83302 .17864 .83315 .17332 Mtetra
.822 .696 .724 r
.8134 .17298 .81324 .17833 .82317 .17848 .82332 .17315 Mtetra
.815 .693 .729 r
.8034 .17282 .80323 .17818 .81324 .17833 .8134 .17298 Mtetra
.808 .689 .734 r
.79331 .17267 .79313 .17805 .80323 .17818 .8034 .17282 Mtetra
.799 .685 .738 r
.78314 .17254 .78294 .17793 .79313 .17805 .79331 .17267 Mtetra
.789 .679 .743 r
.77288 .17242 .77267 .17782 .78294 .17793 .78314 .17254 Mtetra
.779 .674 .748 r
.76254 .17231 .76232 .17773 .77267 .17782 .77288 .17242 Mtetra
.767 .667 .753 r
.75211 .17222 .75188 .17765 .76232 .17773 .76254 .17231 Mtetra
.754 .66 .757 r
.7416 .17215 .74137 .17759 .75188 .17765 .75211 .17222 Mtetra
.74 .652 .762 r
.73102 .1721 .73077 .17755 .74137 .17759 .7416 .17215 Mtetra
.725 .643 .766 r
.72035 .17207 .72011 .17753 .73077 .17755 .73102 .1721 Mtetra
.709 .633 .771 r
.70962 .17206 .70937 .17753 .72011 .17753 .72035 .17207 Mtetra
.691 .622 .775 r
.69883 .17208 .69857 .17755 .70937 .17753 .70962 .17206 Mtetra
.671 .61 .778 r
.68797 .17213 .68771 .1776 .69857 .17755 .69883 .17208 Mtetra
.65 .597 .782 r
.67706 .1722 .67679 .17768 .68771 .1776 .68797 .17213 Mtetra
.628 .583 .785 r
.66611 .1723 .66584 .17778 .67679 .17768 .67706 .1722 Mtetra
.604 .568 .787 r
.65512 .17244 .65485 .17792 .66584 .17778 .66611 .1723 Mtetra
.577 .551 .789 r
.64411 .17261 .64383 .17808 .65485 .17792 .65512 .17244 Mtetra
.549 .533 .79 r
.63307 .17282 .6328 .17829 .64383 .17808 .64411 .17261 Mtetra
.518 .514 .791 r
.62203 .17307 .62176 .17853 .6328 .17829 .63307 .17282 Mtetra
.485 .493 .79 r
.611 .17336 .61074 .17881 .62176 .17853 .62203 .17307 Mtetra
.449 .471 .789 r
.59999 .17369 .59973 .17914 .61074 .17881 .611 .17336 Mtetra
.41 .447 .788 r
.58901 .17408 .58875 .17952 .59973 .17914 .59999 .17369 Mtetra
.369 .423 .787 r
.57808 .17452 .57783 .17995 .58875 .17952 .58901 .17408 Mtetra
.526 .43 .688 r
.09087 .18008 .09086 .18526 .10017 .18509 .10016 .1799 Mtetra
.527 .433 .691 r
.10016 .1799 .10017 .18509 .10954 .18492 .1095 .17971 Mtetra
.529 .437 .694 r
.1095 .17971 .10954 .18492 .11896 .18475 .11891 .17952 Mtetra
.533 .441 .697 r
.11891 .17952 .11896 .18475 .12845 .18459 .12838 .17934 Mtetra
.537 .447 .701 r
.12838 .17934 .12845 .18459 .138 .18442 .13792 .17916 Mtetra
.542 .453 .704 r
.13792 .17916 .138 .18442 .14763 .18426 .14753 .17898 Mtetra
.548 .46 .708 r
.14753 .17898 .14763 .18426 .15733 .1841 .15722 .17881 Mtetra
.555 .468 .712 r
.15722 .17881 .15733 .1841 .16711 .18395 .16698 .17864 Mtetra
.563 .477 .716 r
.16698 .17864 .16711 .18395 .17697 .1838 .17683 .17848 Mtetra
.571 .487 .72 r
.17683 .17848 .17697 .1838 .18691 .18367 .18676 .17833 Mtetra
.581 .497 .725 r
.18676 .17833 .18691 .18367 .19693 .18354 .19677 .17818 Mtetra
.592 .508 .729 r
.19677 .17818 .19693 .18354 .20704 .18342 .20687 .17805 Mtetra
.603 .52 .733 r
.20687 .17805 .20704 .18342 .21724 .18331 .21706 .17793 Mtetra
.616 .533 .738 r
.21706 .17793 .21724 .18331 .22752 .18322 .22733 .17782 Mtetra
.629 .546 .742 r
.22733 .17782 .22752 .18322 .23788 .18313 .23768 .17773 Mtetra
.642 .56 .746 r
.23768 .17773 .23788 .18313 .24833 .18307 .24812 .17765 Mtetra
.657 .575 .751 r
.24812 .17765 .24833 .18307 .25885 .18301 .25863 .17759 Mtetra
.672 .59 .755 r
.25863 .17759 .25885 .18301 .26945 .18298 .26923 .17755 Mtetra
.688 .606 .759 r
.26923 .17755 .26945 .18298 .28013 .18297 .27989 .17753 Mtetra
.705 .623 .763 r
.27989 .17753 .28013 .18297 .29087 .18297 .29063 .17753 Mtetra
.722 .64 .766 r
.29063 .17753 .29087 .18297 .30168 .183 .30143 .17755 Mtetra
.74 .658 .769 r
.30143 .17755 .30168 .183 .31254 .18305 .31229 .1776 Mtetra
.757 .676 .772 r
.31229 .1776 .31254 .18305 .32346 .18313 .32321 .17768 Mtetra
.776 .695 .774 r
.32321 .17768 .32346 .18313 .33441 .18323 .33416 .17778 Mtetra
.794 .714 .776 r
.33416 .17778 .33441 .18323 .34541 .18336 .34515 .17792 Mtetra
.813 .733 .776 r
.34515 .17792 .34541 .18336 .35642 .18353 .35617 .17808 Mtetra
.831 .752 .776 r
.35617 .17808 .35642 .18353 .36745 .18373 .3672 .17829 Mtetra
.85 .772 .775 r
.3672 .17829 .36745 .18373 .37848 .18396 .37824 .17853 Mtetra
.868 .792 .773 r
.37824 .17853 .37848 .18396 .38951 .18423 .38926 .17881 Mtetra
.886 .812 .77 r
.38926 .17881 .38951 .18423 .40051 .18455 .40027 .17914 Mtetra
.904 .832 .765 r
.40027 .17914 .40051 .18455 .41148 .18491 .41125 .17952 Mtetra
.85 .696 .691 r
.89984 .1799 .89983 .18509 .90914 .18526 .90913 .18008 Mtetra
.85 .698 .694 r
.8905 .17971 .89046 .18492 .89983 .18509 .89984 .1799 Mtetra
.848 .699 .697 r
.88109 .17952 .88104 .18475 .89046 .18492 .8905 .17971 Mtetra
.846 .7 .7 r
.87162 .17934 .87155 .18459 .88104 .18475 .88109 .17952 Mtetra
.844 .7 .703 r
.86208 .17916 .862 .18442 .87155 .18459 .87162 .17934 Mtetra
.84 .699 .707 r
.85247 .17898 .85237 .18426 .862 .18442 .86208 .17916 Mtetra
.836 .698 .711 r
.84278 .17881 .84267 .1841 .85237 .18426 .85247 .17898 Mtetra
.831 .697 .715 r
.83302 .17864 .83289 .18395 .84267 .1841 .84278 .17881 Mtetra
.826 .695 .719 r
.82317 .17848 .82303 .1838 .83289 .18395 .83302 .17864 Mtetra
.82 .692 .723 r
.81324 .17833 .81309 .18367 .82303 .1838 .82317 .17848 Mtetra
.813 .688 .727 r
.80323 .17818 .80307 .18354 .81309 .18367 .81324 .17833 Mtetra
.805 .685 .732 r
.79313 .17805 .79296 .18342 .80307 .18354 .80323 .17818 Mtetra
.796 .68 .736 r
.78294 .17793 .78276 .18331 .79296 .18342 .79313 .17805 Mtetra
.786 .675 .741 r
.77267 .17782 .77248 .18322 .78276 .18331 .78294 .17793 Mtetra
.775 .669 .745 r
.76232 .17773 .76212 .18313 .77248 .18322 .77267 .17782 Mtetra
.764 .662 .75 r
.75188 .17765 .75167 .18307 .76212 .18313 .76232 .17773 Mtetra
.751 .654 .754 r
.74137 .17759 .74115 .18301 .75167 .18307 .75188 .17765 Mtetra
.736 .646 .759 r
.73077 .17755 .73055 .18298 .74115 .18301 .74137 .17759 Mtetra
.721 .636 .763 r
.72011 .17753 .71987 .18297 .73055 .18298 .73077 .17755 Mtetra
.704 .626 .767 r
.70937 .17753 .70913 .18297 .71987 .18297 .72011 .17753 Mtetra
.686 .614 .77 r
.69857 .17755 .69832 .183 .70913 .18297 .70937 .17753 Mtetra
.666 .602 .774 r
.68771 .1776 .68746 .18305 .69832 .183 .69857 .17755 Mtetra
.645 .588 .777 r
.67679 .17768 .67654 .18313 .68746 .18305 .68771 .1776 Mtetra
.622 .574 .779 r
.66584 .17778 .66559 .18323 .67654 .18313 .67679 .17768 Mtetra
.597 .557 .781 r
.65485 .17792 .65459 .18336 .66559 .18323 .66584 .17778 Mtetra
.57 .54 .782 r
.64383 .17808 .64358 .18353 .65459 .18336 .65485 .17792 Mtetra
.541 .521 .782 r
.6328 .17829 .63255 .18373 .64358 .18353 .64383 .17808 Mtetra
.509 .5 .782 r
.62176 .17853 .62152 .18396 .63255 .18373 .6328 .17829 Mtetra
.475 .477 .781 r
.61074 .17881 .61049 .18423 .62152 .18396 .62176 .17853 Mtetra
.437 .453 .778 r
.59973 .17914 .59949 .18455 .61049 .18423 .61074 .17881 Mtetra
.395 .426 .775 r
.58875 .17952 .58852 .18491 .59949 .18455 .59973 .17914 Mtetra
.53 .432 .689 r
.09086 .18526 .09086 .19044 .10019 .19029 .10017 .18509 Mtetra
.531 .435 .691 r
.10017 .18509 .10019 .19029 .10957 .19013 .10954 .18492 Mtetra
.533 .439 .694 r
.10954 .18492 .10957 .19013 .11901 .18998 .11896 .18475 Mtetra
.536 .444 .697 r
.11896 .18475 .11901 .18998 .12851 .18983 .12845 .18459 Mtetra
.54 .449 .701 r
.12845 .18459 .12851 .18983 .13808 .18968 .138 .18442 Mtetra
.545 .455 .704 r
.138 .18442 .13808 .18968 .14772 .18953 .14763 .18426 Mtetra
.551 .462 .708 r
.14763 .18426 .14772 .18953 .15743 .18939 .15733 .1841 Mtetra
.558 .47 .711 r
.15733 .1841 .15743 .18939 .16722 .18925 .16711 .18395 Mtetra
.566 .479 .715 r
.16711 .18395 .16722 .18925 .17709 .18912 .17697 .1838 Mtetra
.575 .488 .719 r
.17697 .1838 .17709 .18912 .18705 .189 .18691 .18367 Mtetra
.585 .498 .723 r
.18691 .18367 .18705 .189 .19708 .18888 .19693 .18354 Mtetra
.596 .509 .727 r
.19693 .18354 .19708 .18888 .2072 .18878 .20704 .18342 Mtetra
.607 .521 .731 r
.20704 .18342 .2072 .18878 .21741 .18868 .21724 .18331 Mtetra
.62 .534 .736 r
.21724 .18331 .21741 .18868 .2277 .1886 .22752 .18322 Mtetra
.633 .547 .74 r
.22752 .18322 .2277 .1886 .23807 .18853 .23788 .18313 Mtetra
.647 .561 .744 r
.23788 .18313 .23807 .18853 .24852 .18847 .24833 .18307 Mtetra
.661 .576 .748 r
.24833 .18307 .24852 .18847 .25905 .18842 .25885 .18301 Mtetra
.677 .591 .752 r
.25885 .18301 .25905 .18842 .26966 .1884 .26945 .18298 Mtetra
.693 .607 .755 r
.26945 .18298 .26966 .1884 .28034 .18839 .28013 .18297 Mtetra
.71 .623 .759 r
.28013 .18297 .28034 .18839 .29109 .1884 .29087 .18297 Mtetra
.727 .641 .762 r
.29087 .18297 .29109 .1884 .3019 .18843 .30168 .183 Mtetra
.745 .658 .765 r
.30168 .183 .3019 .18843 .31277 .18848 .31254 .18305 Mtetra
.763 .676 .767 r
.31254 .18305 .31277 .18848 .32369 .18856 .32346 .18313 Mtetra
.781 .695 .768 r
.32346 .18313 .32369 .18856 .33465 .18866 .33441 .18323 Mtetra
.8 .714 .769 r
.33441 .18323 .33465 .18866 .34564 .18879 .34541 .18336 Mtetra
.819 .733 .77 r
.34541 .18336 .34564 .18879 .35666 .18895 .35642 .18353 Mtetra
.838 .752 .769 r
.35642 .18353 .35666 .18895 .36768 .18913 .36745 .18373 Mtetra
.856 .772 .767 r
.36745 .18373 .36768 .18913 .37871 .18936 .37848 .18396 Mtetra
.875 .791 .764 r
.37848 .18396 .37871 .18936 .38974 .18962 .38951 .18423 Mtetra
.894 .811 .759 r
.38951 .18423 .38974 .18962 .40073 .18992 .40051 .18455 Mtetra
.912 .831 .752 r
.40051 .18455 .40073 .18992 .4117 .19027 .41148 .18491 Mtetra
.848 .694 .691 r
.89983 .18509 .89981 .19029 .90914 .19044 .90914 .18526 Mtetra
.847 .696 .694 r
.89046 .18492 .89043 .19013 .89981 .19029 .89983 .18509 Mtetra
.846 .697 .697 r
.88104 .18475 .88099 .18998 .89043 .19013 .89046 .18492 Mtetra
.844 .697 .7 r
.87155 .18459 .87149 .18983 .88099 .18998 .88104 .18475 Mtetra
.841 .697 .703 r
.862 .18442 .86192 .18968 .87149 .18983 .87155 .18459 Mtetra
.838 .696 .707 r
.85237 .18426 .85228 .18953 .86192 .18968 .862 .18442 Mtetra
.834 .695 .71 r
.84267 .1841 .84257 .18939 .85228 .18953 .85237 .18426 Mtetra
.829 .693 .714 r
.83289 .18395 .83278 .18925 .84257 .18939 .84267 .1841 Mtetra
.824 .691 .718 r
.82303 .1838 .82291 .18912 .83278 .18925 .83289 .18395 Mtetra
.817 .688 .722 r
.81309 .18367 .81295 .189 .82291 .18912 .82303 .1838 Mtetra
.81 .685 .726 r
.80307 .18354 .80292 .18888 .81295 .189 .81309 .18367 Mtetra
.802 .68 .73 r
.79296 .18342 .7928 .18878 .80292 .18888 .80307 .18354 Mtetra
.793 .676 .734 r
.78276 .18331 .78259 .18868 .7928 .18878 .79296 .18342 Mtetra
.783 .67 .739 r
.77248 .18322 .7723 .1886 .78259 .18868 .78276 .18331 Mtetra
.772 .664 .743 r
.76212 .18313 .76193 .18853 .7723 .1886 .77248 .18322 Mtetra
.76 .656 .747 r
.75167 .18307 .75148 .18847 .76193 .18853 .76212 .18313 Mtetra
.747 .648 .751 r
.74115 .18301 .74095 .18842 .75148 .18847 .75167 .18307 Mtetra
.733 .639 .755 r
.73055 .18298 .73034 .1884 .74095 .18842 .74115 .18301 Mtetra
.717 .63 .759 r
.71987 .18297 .71966 .18839 .73034 .1884 .73055 .18298 Mtetra
.7 .619 .763 r
.70913 .18297 .70891 .1884 .71966 .18839 .71987 .18297 Mtetra
.681 .607 .766 r
.69832 .183 .6981 .18843 .70891 .1884 .70913 .18297 Mtetra
.661 .594 .769 r
.68746 .18305 .68723 .18848 .6981 .18843 .69832 .183 Mtetra
.64 .58 .771 r
.67654 .18313 .67631 .18856 .68723 .18848 .68746 .18305 Mtetra
.616 .564 .773 r
.66559 .18323 .66535 .18866 .67631 .18856 .67654 .18313 Mtetra
.591 .547 .774 r
.65459 .18336 .65436 .18879 .66535 .18866 .66559 .18323 Mtetra
.563 .529 .775 r
.64358 .18353 .64334 .18895 .65436 .18879 .65459 .18336 Mtetra
.533 .509 .775 r
.63255 .18373 .63232 .18913 .64334 .18895 .64358 .18353 Mtetra
.501 .487 .773 r
.62152 .18396 .62129 .18936 .63232 .18913 .63255 .18373 Mtetra
.465 .462 .771 r
.61049 .18423 .61026 .18962 .62129 .18936 .62152 .18396 Mtetra
.425 .435 .766 r
.59949 .18455 .59927 .18992 .61026 .18962 .61049 .18423 Mtetra
.381 .405 .761 r
.58852 .18491 .5883 .19027 .59927 .18992 .59949 .18455 Mtetra
.533 .435 .689 r
.09086 .19044 .09086 .19562 .1002 .19548 .10019 .19029 Mtetra
.534 .438 .692 r
.10019 .19029 .1002 .19548 .1096 .19534 .10957 .19013 Mtetra
.536 .441 .695 r
.10957 .19013 .1096 .19534 .11905 .19521 .11901 .18998 Mtetra
.539 .446 .697 r
.11901 .18998 .11905 .19521 .12856 .19507 .12851 .18983 Mtetra
.543 .451 .7 r
.12851 .18983 .12856 .19507 .13814 .19494 .13808 .18968 Mtetra
.548 .457 .704 r
.13808 .18968 .13814 .19494 .1478 .1948 .14772 .18953 Mtetra
.555 .464 .707 r
.14772 .18953 .1478 .1948 .15752 .19468 .15743 .18939 Mtetra
.562 .472 .71 r
.15743 .18939 .15752 .19468 .16733 .19455 .16722 .18925 Mtetra
.57 .48 .714 r
.16722 .18925 .16733 .19455 .17721 .19444 .17709 .18912 Mtetra
.578 .489 .718 r
.17709 .18912 .17721 .19444 .18717 .19433 .18705 .189 Mtetra
.588 .499 .722 r
.18705 .189 .18717 .19433 .19722 .19422 .19708 .18888 Mtetra
.599 .51 .725 r
.19708 .18888 .19722 .19422 .20735 .19413 .2072 .18878 Mtetra
.611 .522 .729 r
.2072 .18878 .20735 .19413 .21756 .19405 .21741 .18868 Mtetra
.623 .534 .733 r
.21741 .18868 .21756 .19405 .22786 .19397 .2277 .1886 Mtetra
.637 .548 .737 r
.2277 .1886 .22786 .19397 .23824 .19391 .23807 .18853 Mtetra
.651 .561 .741 r
.23807 .18853 .23824 .19391 .2487 .19386 .24852 .18847 Mtetra
.666 .576 .745 r
.24852 .18847 .2487 .19386 .25924 .19382 .25905 .18842 Mtetra
.681 .591 .748 r
.25905 .18842 .25924 .19382 .26985 .1938 .26966 .1884 Mtetra
.697 .607 .752 r
.26966 .1884 .26985 .1938 .28054 .1938 .28034 .18839 Mtetra
.714 .624 .755 r
.28034 .18839 .28054 .1938 .29129 .19381 .29109 .1884 Mtetra
.732 .641 .758 r
.29109 .1884 .29129 .19381 .30211 .19384 .3019 .18843 Mtetra
.75 .658 .76 r
.3019 .18843 .30211 .19384 .31298 .19389 .31277 .18848 Mtetra
.768 .676 .762 r
.31277 .18848 .31298 .19389 .3239 .19397 .32369 .18856 Mtetra
.786 .694 .763 r
.32369 .18856 .3239 .19397 .33486 .19407 .33465 .18866 Mtetra
.805 .713 .763 r
.33465 .18866 .33486 .19407 .34585 .19419 .34564 .18879 Mtetra
.824 .732 .763 r
.34564 .18879 .34585 .19419 .35687 .19434 .35666 .18895 Mtetra
.843 .751 .761 r
.35666 .18895 .35687 .19434 .3679 .19452 .36768 .18913 Mtetra
.862 .77 .759 r
.36768 .18913 .3679 .19452 .37892 .19473 .37871 .18936 Mtetra
.882 .79 .755 r
.37871 .18936 .37892 .19473 .38994 .19497 .38974 .18962 Mtetra
.901 .809 .748 r
.38974 .18962 .38994 .19497 .40093 .19525 .40073 .18992 Mtetra
.92 .828 .739 r
.40073 .18992 .40093 .19525 .41189 .19558 .4117 .19027 Mtetra
.846 .693 .692 r
.89981 .19029 .8998 .19548 .90914 .19562 .90914 .19044 Mtetra
.845 .694 .694 r
.89043 .19013 .8904 .19534 .8998 .19548 .89981 .19029 Mtetra
.844 .695 .697 r
.88099 .18998 .88095 .19521 .8904 .19534 .89043 .19013 Mtetra
.842 .695 .7 r
.87149 .18983 .87144 .19507 .88095 .19521 .88099 .18998 Mtetra
.839 .695 .703 r
.86192 .18968 .86186 .19494 .87144 .19507 .87149 .18983 Mtetra
.836 .694 .706 r
.85228 .18953 .8522 .1948 .86186 .19494 .86192 .18968 Mtetra
.832 .692 .709 r
.84257 .18939 .84248 .19468 .8522 .1948 .85228 .18953 Mtetra
.827 .69 .713 r
.83278 .18925 .83267 .19455 .84248 .19468 .84257 .18939 Mtetra
.821 .688 .716 r
.82291 .18912 .82279 .19444 .83267 .19455 .83278 .18925 Mtetra
.815 .685 .72 r
.81295 .189 .81283 .19433 .82279 .19444 .82291 .18912 Mtetra
.808 .681 .724 r
.80292 .18888 .80278 .19422 .81283 .19433 .81295 .189 Mtetra
.8 .676 .728 r
.7928 .18878 .79265 .19413 .80278 .19422 .80292 .18888 Mtetra
.791 .671 .732 r
.78259 .18868 .78244 .19405 .79265 .19413 .7928 .18878 Mtetra
.781 .665 .736 r
.7723 .1886 .77214 .19397 .78244 .19405 .78259 .18868 Mtetra
.77 .659 .74 r
.76193 .18853 .76176 .19391 .77214 .19397 .7723 .1886 Mtetra
.757 .651 .744 r
.75148 .18847 .7513 .19386 .76176 .19391 .76193 .18853 Mtetra
.744 .643 .748 r
.74095 .18842 .74076 .19382 .7513 .19386 .75148 .18847 Mtetra
.729 .633 .752 r
.73034 .1884 .73015 .1938 .74076 .19382 .74095 .18842 Mtetra
.713 .623 .755 r
.71966 .18839 .71946 .1938 .73015 .1938 .73034 .1884 Mtetra
.696 .612 .758 r
.70891 .1884 .70871 .19381 .71946 .1938 .71966 .18839 Mtetra
.677 .599 .761 r
.6981 .18843 .69789 .19384 .70871 .19381 .70891 .1884 Mtetra
.657 .586 .764 r
.68723 .18848 .68702 .19389 .69789 .19384 .6981 .18843 Mtetra
.635 .571 .766 r
.67631 .18856 .6761 .19397 .68702 .19389 .68723 .18848 Mtetra
.611 .555 .767 r
.66535 .18866 .66514 .19407 .6761 .19397 .67631 .18856 Mtetra
.585 .537 .768 r
.65436 .18879 .65415 .19419 .66514 .19407 .66535 .18866 Mtetra
.557 .518 .768 r
.64334 .18895 .64313 .19434 .65415 .19419 .65436 .18879 Mtetra
.526 .497 .767 r
.63232 .18913 .6321 .19452 .64313 .19434 .64334 .18895 Mtetra
.493 .474 .764 r
.62129 .18936 .62108 .19473 .6321 .19452 .63232 .18913 Mtetra
.456 .448 .76 r
.61026 .18962 .61006 .19497 .62108 .19473 .62129 .18936 Mtetra
.415 .419 .755 r
.59927 .18992 .59907 .19525 .61006 .19497 .61026 .18962 Mtetra
.369 .386 .747 r
.5883 .19027 .58811 .19558 .59907 .19525 .59927 .18992 Mtetra
.536 .438 .69 r
.09086 .19562 .09086 .2008 .10022 .20068 .1002 .19548 Mtetra
.537 .44 .692 r
.1002 .19548 .10022 .20068 .10962 .20055 .1096 .19534 Mtetra
.539 .443 .695 r
.1096 .19534 .10962 .20055 .11909 .20043 .11905 .19521 Mtetra
.542 .448 .697 r
.11905 .19521 .11909 .20043 .12861 .20031 .12856 .19507 Mtetra
.546 .453 .7 r
.12856 .19507 .12861 .20031 .13821 .20019 .13814 .19494 Mtetra
.551 .459 .703 r
.13814 .19494 .13821 .20019 .14787 .20007 .1478 .1948 Mtetra
.558 .465 .706 r
.1478 .1948 .14787 .20007 .15761 .19996 .15752 .19468 Mtetra
.565 .473 .709 r
.15752 .19468 .15761 .19996 .16742 .19985 .16733 .19455 Mtetra
.573 .481 .713 r
.16733 .19455 .16742 .19985 .17731 .19975 .17721 .19444 Mtetra
.582 .49 .716 r
.17721 .19444 .17731 .19975 .18729 .19965 .18717 .19433 Mtetra
.591 .5 .72 r
.18717 .19433 .18729 .19965 .19734 .19956 .19722 .19422 Mtetra
.602 .511 .724 r
.19722 .19422 .19734 .19956 .20748 .19947 .20735 .19413 Mtetra
.614 .523 .727 r
.20735 .19413 .20748 .19947 .2177 .1994 .21756 .19405 Mtetra
.627 .535 .731 r
.21756 .19405 .2177 .1994 .22801 .19933 .22786 .19397 Mtetra
.64 .548 .735 r
.22786 .19397 .22801 .19933 .23839 .19928 .23824 .19391 Mtetra
.654 .562 .738 r
.23824 .19391 .23839 .19928 .24886 .19924 .2487 .19386 Mtetra
.669 .576 .742 r
.2487 .19386 .24886 .19924 .25941 .19921 .25924 .19382 Mtetra
.685 .591 .745 r
.25924 .19382 .25941 .19921 .27003 .19919 .26985 .1938 Mtetra
.701 .607 .748 r
.26985 .1938 .27003 .19919 .28072 .19919 .28054 .1938 Mtetra
.718 .623 .751 r
.28054 .1938 .28072 .19919 .29148 .19921 .29129 .19381 Mtetra
.736 .64 .753 r
.29129 .19381 .29148 .19921 .3023 .19924 .30211 .19384 Mtetra
.754 .658 .755 r
.30211 .19384 .3023 .19924 .31317 .19929 .31298 .19389 Mtetra
.772 .676 .756 r
.31298 .19389 .31317 .19929 .3241 .19936 .3239 .19397 Mtetra
.791 .694 .757 r
.3239 .19397 .3241 .19936 .33506 .19945 .33486 .19407 Mtetra
.81 .712 .757 r
.33486 .19407 .33506 .19945 .34605 .19957 .34585 .19419 Mtetra
.829 .731 .756 r
.34585 .19419 .34605 .19957 .35706 .19971 .35687 .19434 Mtetra
.849 .75 .754 r
.35687 .19434 .35706 .19971 .36809 .19987 .3679 .19452 Mtetra
.868 .769 .75 r
.3679 .19452 .36809 .19987 .37911 .20007 .37892 .19473 Mtetra
.887 .787 .745 r
.37892 .19473 .37911 .20007 .39012 .20029 .38994 .19497 Mtetra
.906 .806 .738 r
.38994 .19497 .39012 .20029 .40111 .20056 .40093 .19525 Mtetra
.844 .691 .692 r
.8998 .19548 .89978 .20068 .90914 .2008 .90914 .19562 Mtetra
.844 .692 .694 r
.8904 .19534 .89038 .20055 .89978 .20068 .8998 .19548 Mtetra
.842 .693 .697 r
.88095 .19521 .88091 .20043 .89038 .20055 .8904 .19534 Mtetra
.84 .693 .699 r
.87144 .19507 .87139 .20031 .88091 .20043 .88095 .19521 Mtetra
.837 .692 .702 r
.86186 .19494 .86179 .20019 .87139 .20031 .87144 .19507 Mtetra
.834 .691 .705 r
.8522 .1948 .85213 .20007 .86179 .20019 .86186 .19494 Mtetra
.83 .69 .708 r
.84248 .19468 .84239 .19996 .85213 .20007 .8522 .1948 Mtetra
.825 .687 .712 r
.83267 .19455 .83258 .19985 .84239 .19996 .84248 .19468 Mtetra
.819 .685 .715 r
.82279 .19444 .82269 .19975 .83258 .19985 .83267 .19455 Mtetra
.813 .681 .719 r
.81283 .19433 .81271 .19965 .82269 .19975 .82279 .19444 Mtetra
.806 .677 .722 r
.80278 .19422 .80266 .19956 .81271 .19965 .81283 .19433 Mtetra
.797 .672 .726 r
.79265 .19413 .79252 .19947 .80266 .19956 .80278 .19422 Mtetra
.788 .667 .73 r
.78244 .19405 .7823 .1994 .79252 .19947 .79265 .19413 Mtetra
.778 .661 .734 r
.77214 .19397 .77199 .19933 .7823 .1994 .78244 .19405 Mtetra
.767 .654 .737 r
.76176 .19391 .76161 .19928 .77199 .19933 .77214 .19397 Mtetra
.755 .646 .741 r
.7513 .19386 .75114 .19924 .76161 .19928 .76176 .19391 Mtetra
.741 .637 .745 r
.74076 .19382 .74059 .19921 .75114 .19924 .7513 .19386 Mtetra
.726 .628 .748 r
.73015 .1938 .72997 .19919 .74059 .19921 .74076 .19382 Mtetra
.71 .617 .751 r
.71946 .1938 .71928 .19919 .72997 .19919 .73015 .1938 Mtetra
.693 .605 .754 r
.70871 .19381 .70852 .19921 .71928 .19919 .71946 .1938 Mtetra
.673 .592 .756 r
.69789 .19384 .6977 .19924 .70852 .19921 .70871 .19381 Mtetra
.653 .578 .759 r
.68702 .19389 .68683 .19929 .6977 .19924 .69789 .19384 Mtetra
.63 .563 .76 r
.6761 .19397 .6759 .19936 .68683 .19929 .68702 .19389 Mtetra
.606 .546 .761 r
.66514 .19407 .66494 .19945 .6759 .19936 .6761 .19397 Mtetra
.579 .528 .761 r
.65415 .19419 .65395 .19957 .66494 .19945 .66514 .19407 Mtetra
.551 .507 .76 r
.64313 .19434 .64294 .19971 .65395 .19957 .65415 .19419 Mtetra
.52 .485 .759 r
.6321 .19452 .63191 .19987 .64294 .19971 .64313 .19434 Mtetra
.486 .461 .755 r
.62108 .19473 .62089 .20007 .63191 .19987 .6321 .19452 Mtetra
.449 .434 .75 r
.61006 .19497 .60988 .20029 .62089 .20007 .62108 .19473 Mtetra
.407 .403 .743 r
.59907 .19525 .59889 .20056 .60988 .20029 .61006 .19497 Mtetra
.539 .44 .69 r
.09086 .2008 .09086 .20598 .10023 .20587 .10022 .20068 Mtetra
.54 .442 .693 r
.10022 .20068 .10023 .20587 .10965 .20576 .10962 .20055 Mtetra
.542 .445 .695 r
.10962 .20055 .10965 .20576 .11912 .20565 .11909 .20043 Mtetra
.545 .449 .697 r
.11909 .20043 .11912 .20565 .12866 .20554 .12861 .20031 Mtetra
.549 .454 .7 r
.12861 .20031 .12866 .20554 .13826 .20544 .13821 .20019 Mtetra
.554 .46 .703 r
.13821 .20019 .13826 .20544 .14794 .20534 .14787 .20007 Mtetra
.56 .467 .705 r
.14787 .20007 .14794 .20534 .15768 .20524 .15761 .19996 Mtetra
.567 .474 .708 r
.15761 .19996 .15768 .20524 .16751 .20514 .16742 .19985 Mtetra
.575 .482 .712 r
.16742 .19985 .16751 .20514 .17741 .20505 .17731 .19975 Mtetra
.584 .491 .715 r
.17731 .19975 .17741 .20505 .18739 .20496 .18729 .19965 Mtetra
.594 .501 .718 r
.18729 .19965 .18739 .20496 .19745 .20488 .19734 .19956 Mtetra
.605 .512 .722 r
.19734 .19956 .19745 .20488 .2076 .20481 .20748 .19947 Mtetra
.617 .523 .725 r
.20748 .19947 .2076 .20481 .21783 .20475 .2177 .1994 Mtetra
.63 .535 .729 r
.2177 .1994 .21783 .20475 .22814 .20469 .22801 .19933 Mtetra
.643 .548 .732 r
.22801 .19933 .22814 .20469 .23853 .20464 .23839 .19928 Mtetra
.657 .562 .735 r
.23839 .19928 .23853 .20464 .24901 .20461 .24886 .19924 Mtetra
.673 .576 .738 r
.24886 .19924 .24901 .20461 .25956 .20458 .25941 .19921 Mtetra
.688 .591 .741 r
.25941 .19921 .25956 .20458 .27019 .20457 .27003 .19919 Mtetra
.705 .607 .744 r
.27003 .19919 .27019 .20457 .28088 .20457 .28072 .19919 Mtetra
.722 .623 .747 r
.28072 .19919 .28088 .20457 .29164 .20459 .29148 .19921 Mtetra
.74 .64 .749 r
.29148 .19921 .29164 .20459 .30247 .20462 .3023 .19924 Mtetra
.758 .657 .75 r
.3023 .19924 .30247 .20462 .31335 .20467 .31317 .19929 Mtetra
.777 .675 .751 r
.31317 .19929 .31335 .20467 .32427 .20474 .3241 .19936 Mtetra
.795 .693 .751 r
.3241 .19936 .32427 .20474 .33523 .20482 .33506 .19945 Mtetra
.815 .711 .751 r
.33506 .19945 .33523 .20482 .34623 .20493 .34605 .19957 Mtetra
.834 .729 .749 r
.34605 .19957 .34623 .20493 .35724 .20506 .35706 .19971 Mtetra
.853 .748 .746 r
.35706 .19971 .35724 .20506 .36826 .20521 .36809 .19987 Mtetra
.872 .766 .742 r
.36809 .19987 .36826 .20521 .37928 .20539 .37911 .20007 Mtetra
.892 .784 .736 r
.37911 .20007 .37928 .20539 .39029 .20559 .39012 .20029 Mtetra
.911 .802 .727 r
.39012 .20029 .39029 .20559 .40126 .20583 .40111 .20056 Mtetra
.842 .689 .692 r
.89978 .20068 .89977 .20587 .90914 .20598 .90914 .2008 Mtetra
.842 .69 .694 r
.89038 .20055 .89035 .20576 .89977 .20587 .89978 .20068 Mtetra
.84 .691 .697 r
.88091 .20043 .88088 .20565 .89035 .20576 .89038 .20055 Mtetra
.838 .691 .699 r
.87139 .20031 .87134 .20554 .88088 .20565 .88091 .20043 Mtetra
.836 .69 .702 r
.86179 .20019 .86174 .20544 .87134 .20554 .87139 .20031 Mtetra
.832 .689 .704 r
.85213 .20007 .85206 .20534 .86174 .20544 .86179 .20019 Mtetra
.828 .687 .707 r
.84239 .19996 .84232 .20524 .85206 .20534 .85213 .20007 Mtetra
.823 .685 .71 r
.83258 .19985 .83249 .20514 .84232 .20524 .84239 .19996 Mtetra
.818 .682 .714 r
.82269 .19975 .82259 .20505 .83249 .20514 .83258 .19985 Mtetra
.811 .678 .717 r
.81271 .19965 .81261 .20496 .82259 .20505 .82269 .19975 Mtetra
.804 .674 .72 r
.80266 .19956 .80255 .20488 .81261 .20496 .81271 .19965 Mtetra
.795 .669 .724 r
.79252 .19947 .7924 .20481 .80255 .20488 .80266 .19956 Mtetra
.786 .663 .727 r
.7823 .1994 .78217 .20475 .7924 .20481 .79252 .19947 Mtetra
.776 .656 .731 r
.77199 .19933 .77186 .20469 .78217 .20475 .7823 .1994 Mtetra
.765 .649 .734 r
.76161 .19928 .76147 .20464 .77186 .20469 .77199 .19933 Mtetra
.752 .641 .738 r
.75114 .19924 .75099 .20461 .76147 .20464 .76161 .19928 Mtetra
.738 .632 .741 r
.74059 .19921 .74044 .20458 .75099 .20461 .75114 .19924 Mtetra
.723 .622 .744 r
.72997 .19919 .72981 .20457 .74044 .20458 .74059 .19921 Mtetra
.707 .611 .747 r
.71928 .19919 .71912 .20457 .72981 .20457 .72997 .19919 Mtetra
.689 .599 .749 r
.70852 .19921 .70836 .20459 .71912 .20457 .71928 .19919 Mtetra
.67 .585 .752 r
.6977 .19924 .69753 .20462 .70836 .20459 .70852 .19921 Mtetra
.649 .571 .753 r
.68683 .19929 .68665 .20467 .69753 .20462 .6977 .19924 Mtetra
.626 .555 .754 r
.6759 .19936 .67573 .20474 .68665 .20467 .68683 .19929 Mtetra
.601 .537 .755 r
.66494 .19945 .66477 .20482 .67573 .20474 .6759 .19936 Mtetra
.574 .518 .754 r
.65395 .19957 .65377 .20493 .66477 .20482 .66494 .19945 Mtetra
.546 .497 .753 r
.64294 .19971 .64276 .20506 .65377 .20493 .65395 .19957 Mtetra
.514 .475 .75 r
.63191 .19987 .63174 .20521 .64276 .20506 .64294 .19971 Mtetra
.48 .449 .746 r
.62089 .20007 .62072 .20539 .63174 .20521 .63191 .19987 Mtetra
.442 .421 .74 r
.60988 .20029 .60971 .20559 .62072 .20539 .62089 .20007 Mtetra
.4 .389 .731 r
.59889 .20056 .59874 .20583 .60971 .20559 .60988 .20029 Mtetra
.541 .442 .691 r
.09086 .20598 .09086 .21116 .10024 .21106 .10023 .20587 Mtetra
.542 .444 .693 r
.10023 .20587 .10024 .21106 .10967 .21097 .10965 .20576 Mtetra
.544 .447 .695 r
.10965 .20576 .10967 .21097 .11915 .21087 .11912 .20565 Mtetra
.547 .451 .697 r
.11912 .20565 .11915 .21087 .1287 .21078 .12866 .20554 Mtetra
.551 .456 .699 r
.12866 .20554 .1287 .21078 .13831 .21069 .13826 .20544 Mtetra
.557 .461 .702 r
.13826 .20544 .13831 .21069 .148 .2106 .14794 .20534 Mtetra
.563 .468 .705 r
.14794 .20534 .148 .2106 .15775 .21051 .15768 .20524 Mtetra
.57 .475 .707 r
.15768 .20524 .15775 .21051 .16758 .21043 .16751 .20514 Mtetra
.578 .483 .71 r
.16751 .20514 .16758 .21043 .17749 .21035 .17741 .20505 Mtetra
.587 .492 .713 r
.17741 .20505 .17749 .21035 .18748 .21027 .18739 .20496 Mtetra
.597 .501 .717 r
.18739 .20496 .18748 .21027 .19755 .2102 .19745 .20488 Mtetra
.608 .512 .72 r
.19745 .20488 .19755 .2102 .20771 .21014 .2076 .20481 Mtetra
.62 .523 .723 r
.2076 .20481 .20771 .21014 .21794 .21009 .21783 .20475 Mtetra
.632 .535 .726 r
.21783 .20475 .21794 .21009 .22826 .21004 .22814 .20469 Mtetra
.646 .548 .729 r
.22814 .20469 .22826 .21004 .23866 .21 .23853 .20464 Mtetra
.66 .561 .732 r
.23853 .20464 .23866 .21 .24914 .20997 .24901 .20461 Mtetra
.676 .576 .735 r
.24901 .20461 .24914 .20997 .2597 .20995 .25956 .20458 Mtetra
.692 .59 .738 r
.25956 .20458 .2597 .20995 .27033 .20994 .27019 .20457 Mtetra
.708 .606 .74 r
.27019 .20457 .27033 .20994 .28103 .20994 .28088 .20457 Mtetra
.725 .622 .742 r
.28088 .20457 .28103 .20994 .29179 .20996 .29164 .20459 Mtetra
.743 .639 .744 r
.29164 .20459 .29179 .20996 .30262 .20999 .30247 .20462 Mtetra
.762 .656 .745 r
.30247 .20462 .30262 .20999 .3135 .21004 .31335 .20467 Mtetra
.78 .673 .746 r
.31335 .20467 .3135 .21004 .32443 .2101 .32427 .20474 Mtetra
.799 .691 .745 r
.32427 .20474 .32443 .2101 .33539 .21017 .33523 .20482 Mtetra
.818 .709 .744 r
.33523 .20482 .33539 .21017 .34638 .21027 .34623 .20493 Mtetra
.838 .727 .742 r
.34623 .20493 .34638 .21027 .3574 .21039 .35724 .20506 Mtetra
.857 .745 .739 r
.35724 .20506 .3574 .21039 .36842 .21052 .36826 .20521 Mtetra
.876 .763 .734 r
.36826 .20521 .36842 .21052 .37943 .21068 .37928 .20539 Mtetra
.895 .781 .727 r
.37928 .20539 .37943 .21068 .39043 .21087 .39029 .20559 Mtetra
.914 .798 .718 r
.39029 .20559 .39043 .21087 .4014 .21108 .40126 .20583 Mtetra
.841 .688 .693 r
.89977 .20587 .89976 .21106 .90914 .21116 .90914 .20598 Mtetra
.84 .689 .694 r
.89035 .20576 .89033 .21097 .89976 .21106 .89977 .20587 Mtetra
.839 .689 .696 r
.88088 .20565 .88085 .21087 .89033 .21097 .89035 .20576 Mtetra
.837 .689 .699 r
.87134 .20554 .8713 .21078 .88085 .21087 .88088 .20565 Mtetra
.834 .688 .701 r
.86174 .20544 .86169 .21069 .8713 .21078 .87134 .20554 Mtetra
.831 .686 .704 r
.85206 .20534 .852 .2106 .86169 .21069 .86174 .20544 Mtetra
.826 .684 .706 r
.84232 .20524 .84225 .21051 .852 .2106 .85206 .20534 Mtetra
.822 .682 .709 r
.83249 .20514 .83242 .21043 .84225 .21051 .84232 .20524 Mtetra
.816 .679 .712 r
.82259 .20505 .82251 .21035 .83242 .21043 .83249 .20514 Mtetra
.809 .675 .715 r
.81261 .20496 .81252 .21027 .82251 .21035 .82259 .20505 Mtetra
.802 .67 .718 r
.80255 .20488 .80245 .2102 .81252 .21027 .81261 .20496 Mtetra
.793 .665 .722 r
.7924 .20481 .79229 .21014 .80245 .2102 .80255 .20488 Mtetra
.784 .659 .725 r
.78217 .20475 .78206 .21009 .79229 .21014 .7924 .20481 Mtetra
.774 .652 .728 r
.77186 .20469 .77174 .21004 .78206 .21009 .78217 .20475 Mtetra
.762 .645 .731 r
.76147 .20464 .76134 .21 .77174 .21004 .77186 .20469 Mtetra
.75 .636 .735 r
.75099 .20461 .75086 .20997 .76134 .21 .76147 .20464 Mtetra
.736 .627 .737 r
.74044 .20458 .7403 .20995 .75086 .20997 .75099 .20461 Mtetra
.721 .616 .74 r
.72981 .20457 .72967 .20994 .7403 .20995 .74044 .20458 Mtetra
.704 .605 .743 r
.71912 .20457 .71897 .20994 .72967 .20994 .72981 .20457 Mtetra
.686 .592 .745 r
.70836 .20459 .70821 .20996 .71897 .20994 .71912 .20457 Mtetra
.667 .578 .747 r
.69753 .20462 .69738 .20999 .70821 .20996 .70836 .20459 Mtetra
.645 .563 .748 r
.68665 .20467 .6865 .21004 .69738 .20999 .69753 .20462 Mtetra
.622 .547 .749 r
.67573 .20474 .67557 .2101 .6865 .21004 .68665 .20467 Mtetra
.597 .529 .749 r
.66477 .20482 .66461 .21017 .67557 .2101 .67573 .20474 Mtetra
.57 .509 .748 r
.65377 .20493 .65362 .21027 .66461 .21017 .66477 .20482 Mtetra
.541 .488 .746 r
.64276 .20506 .6426 .21039 .65362 .21027 .65377 .20493 Mtetra
.509 .464 .742 r
.63174 .20521 .63158 .21052 .6426 .21039 .64276 .20506 Mtetra
.475 .438 .737 r
.62072 .20539 .62057 .21068 .63158 .21052 .63174 .20521 Mtetra
.437 .41 .73 r
.60971 .20559 .60957 .21087 .62057 .21068 .62072 .20539 Mtetra
.395 .376 .72 r
.59874 .20583 .5986 .21108 .60957 .21087 .60971 .20559 Mtetra
.543 .443 .691 r
.09086 .21116 .09086 .21634 .10025 .21625 .10024 .21106 Mtetra
.544 .446 .693 r
.10024 .21106 .10025 .21625 .10969 .21617 .10967 .21097 Mtetra
.546 .448 .695 r
.10967 .21097 .10969 .21617 .11918 .21609 .11915 .21087 Mtetra
.549 .452 .697 r
.11915 .21087 .11918 .21609 .12874 .21601 .1287 .21078 Mtetra
.554 .457 .699 r
.1287 .21078 .12874 .21601 .13836 .21593 .13831 .21069 Mtetra
.559 .462 .701 r
.13831 .21069 .13836 .21593 .14805 .21586 .148 .2106 Mtetra
.565 .468 .704 r
.148 .2106 .14805 .21586 .15781 .21578 .15775 .21051 Mtetra
.572 .475 .706 r
.15775 .21051 .15781 .21578 .16765 .21571 .16758 .21043 Mtetra
.58 .483 .709 r
.16758 .21043 .16765 .21571 .17757 .21564 .17749 .21035 Mtetra
.589 .492 .712 r
.17749 .21035 .17757 .21564 .18756 .21558 .18748 .21027 Mtetra
.599 .502 .715 r
.18748 .21027 .18756 .21558 .19764 .21552 .19755 .2102 Mtetra
.61 .512 .718 r
.19755 .2102 .19764 .21552 .2078 .21547 .20771 .21014 Mtetra
.622 .523 .721 r
.20771 .21014 .2078 .21547 .21804 .21542 .21794 .21009 Mtetra
.635 .535 .724 r
.21794 .21009 .21804 .21542 .22837 .21538 .22826 .21004 Mtetra
.649 .547 .726 r
.22826 .21004 .22837 .21538 .23877 .21535 .23866 .21 Mtetra
.663 .561 .729 r
.23866 .21 .23877 .21535 .24925 .21532 .24914 .20997 Mtetra
.678 .575 .732 r
.24914 .20997 .24925 .21532 .25981 .21531 .2597 .20995 Mtetra
.694 .59 .734 r
.2597 .20995 .25981 .21531 .27045 .2153 .27033 .20994 Mtetra
.711 .605 .736 r
.27033 .20994 .27045 .2153 .28115 .2153 .28103 .20994 Mtetra
.728 .621 .738 r
.28103 .20994 .28115 .2153 .29192 .21532 .29179 .20996 Mtetra
.746 .637 .739 r
.29179 .20996 .29192 .21532 .30275 .21535 .30262 .20999 Mtetra
.765 .654 .74 r
.30262 .20999 .30275 .21535 .31363 .21539 .3135 .21004 Mtetra
.783 .671 .74 r
.3135 .21004 .31363 .21539 .32456 .21544 .32443 .2101 Mtetra
.803 .689 .739 r
.32443 .2101 .32456 .21544 .33553 .21551 .33539 .21017 Mtetra
.822 .707 .738 r
.33539 .21017 .33553 .21551 .34652 .2156 .34638 .21027 Mtetra
.841 .724 .735 r
.34638 .21027 .34652 .2156 .35753 .2157 .3574 .21039 Mtetra
.86 .742 .731 r
.3574 .21039 .35753 .2157 .36855 .21582 .36842 .21052 Mtetra
.879 .76 .726 r
.36842 .21052 .36855 .21582 .37956 .21596 .37943 .21068 Mtetra
.898 .776 .719 r
.37943 .21068 .37956 .21596 .39055 .21612 .39043 .21087 Mtetra
.917 .793 .708 r
.39043 .21087 .39055 .21612 .40151 .21631 .4014 .21108 Mtetra
.84 .687 .693 r
.89976 .21106 .89975 .21625 .90914 .21634 .90914 .21116 Mtetra
.839 .687 .694 r
.89033 .21097 .89031 .21617 .89975 .21625 .89976 .21106 Mtetra
.838 .687 .696 r
.88085 .21087 .88082 .21609 .89031 .21617 .89033 .21097 Mtetra
.835 .687 .698 r
.8713 .21078 .87126 .21601 .88082 .21609 .88085 .21087 Mtetra
.833 .686 .7 r
.86169 .21069 .86164 .21593 .87126 .21601 .8713 .21078 Mtetra
.829 .684 .703 r
.852 .2106 .85195 .21586 .86164 .21593 .86169 .21069 Mtetra
.825 .682 .705 r
.84225 .21051 .84219 .21578 .85195 .21586 .852 .2106 Mtetra
.82 .679 .708 r
.83242 .21043 .83235 .21571 .84219 .21578 .84225 .21051 Mtetra
.814 .676 .711 r
.82251 .21035 .82243 .21564 .83235 .21571 .83242 .21043 Mtetra
.808 .672 .714 r
.81252 .21027 .81244 .21558 .82243 .21564 .82251 .21035 Mtetra
.8 .667 .716 r
.80245 .2102 .80236 .21552 .81244 .21558 .81252 .21027 Mtetra
.792 .662 .719 r
.79229 .21014 .7922 .21547 .80236 .21552 .80245 .2102 Mtetra
.782 .655 .722 r
.78206 .21009 .78196 .21542 .7922 .21547 .79229 .21014 Mtetra
.772 .648 .725 r
.77174 .21004 .77163 .21538 .78196 .21542 .78206 .21009 Mtetra
.76 .64 .728 r
.76134 .21 .76123 .21535 .77163 .21538 .77174 .21004 Mtetra
.748 .632 .731 r
.75086 .20997 .75075 .21532 .76123 .21535 .76134 .21 Mtetra
.734 .622 .734 r
.7403 .20995 .74019 .21531 .75075 .21532 .75086 .20997 Mtetra
.718 .611 .736 r
.72967 .20994 .72955 .2153 .74019 .21531 .7403 .20995 Mtetra
.702 .599 .738 r
.71897 .20994 .71885 .2153 .72955 .2153 .72967 .20994 Mtetra
.684 .586 .74 r
.70821 .20996 .70808 .21532 .71885 .2153 .71897 .20994 Mtetra
.664 .572 .742 r
.69738 .20999 .69725 .21535 .70808 .21532 .70821 .20996 Mtetra
.642 .556 .743 r
.6865 .21004 .68637 .21539 .69725 .21535 .69738 .20999 Mtetra
.619 .539 .743 r
.67557 .2101 .67544 .21544 .68637 .21539 .6865 .21004 Mtetra
.594 .521 .742 r
.66461 .21017 .66447 .21551 .67544 .21544 .67557 .2101 Mtetra
.566 .501 .741 r
.65362 .21027 .65348 .2156 .66447 .21551 .66461 .21017 Mtetra
.537 .479 .738 r
.6426 .21039 .64247 .2157 .65348 .2156 .65362 .21027 Mtetra
.505 .455 .734 r
.63158 .21052 .63145 .21582 .64247 .2157 .6426 .21039 Mtetra
.471 .428 .729 r
.62057 .21068 .62044 .21596 .63145 .21582 .63158 .21052 Mtetra
.433 .399 .721 r
.60957 .21087 .60945 .21612 .62044 .21596 .62057 .21068 Mtetra
.392 .365 .71 r
.5986 .21108 .59849 .21631 .60945 .21612 .60957 .21087 Mtetra
.545 .445 .692 r
.09086 .21634 .09086 .22152 .10026 .22145 .10025 .21625 Mtetra
.546 .447 .693 r
.10025 .21625 .10026 .22145 .1097 .22138 .10969 .21617 Mtetra
.548 .45 .695 r
.10969 .21617 .1097 .22138 .1192 .22131 .11918 .21609 Mtetra
.551 .453 .696 r
.11918 .21609 .1192 .22131 .12877 .22124 .12874 .21601 Mtetra
.555 .458 .698 r
.12874 .21601 .12877 .22124 .1384 .22118 .13836 .21593 Mtetra
.561 .463 .701 r
.13836 .21593 .1384 .22118 .14809 .22111 .14805 .21586 Mtetra
.567 .469 .703 r
.14805 .21586 .14809 .22111 .15786 .22105 .15781 .21578 Mtetra
.574 .476 .705 r
.15781 .21578 .15786 .22105 .16771 .22099 .16765 .21571 Mtetra
.582 .484 .708 r
.16765 .21571 .16771 .22099 .17763 .22093 .17757 .21564 Mtetra
.591 .492 .71 r
.17757 .21564 .17763 .22093 .18763 .22088 .18756 .21558 Mtetra
.601 .501 .713 r
.18756 .21558 .18763 .22088 .19772 .22083 .19764 .21552 Mtetra
.612 .512 .716 r
.19764 .21552 .19772 .22083 .20788 .22079 .2078 .21547 Mtetra
.624 .523 .718 r
.2078 .21547 .20788 .22079 .21813 .22075 .21804 .21542 Mtetra
.637 .534 .721 r
.21804 .21542 .21813 .22075 .22845 .22072 .22837 .21538 Mtetra
.651 .547 .724 r
.22837 .21538 .22845 .22072 .23886 .22069 .23877 .21535 Mtetra
.665 .56 .726 r
.23877 .21535 .23886 .22069 .24935 .22067 .24925 .21532 Mtetra
.681 .574 .728 r
.24925 .21532 .24935 .22067 .25992 .22066 .25981 .21531 Mtetra
.697 .588 .73 r
.25981 .21531 .25992 .22066 .27055 .22065 .27045 .2153 Mtetra
.714 .604 .732 r
.27045 .2153 .27055 .22065 .28126 .22066 .28115 .2153 Mtetra
.731 .619 .734 r
.28115 .2153 .28126 .22066 .29203 .22067 .29192 .21532 Mtetra
.749 .635 .734 r
.29192 .21532 .29203 .22067 .30287 .2207 .30275 .21535 Mtetra
.767 .652 .735 r
.30275 .21535 .30287 .2207 .31375 .22073 .31363 .21539 Mtetra
.786 .669 .734 r
.31363 .21539 .31375 .22073 .32468 .22078 .32456 .21544 Mtetra
.805 .687 .733 r
.32456 .21544 .32468 .22078 .33564 .22084 .33553 .21551 Mtetra
.825 .704 .731 r
.33553 .21551 .33564 .22084 .34664 .22091 .34652 .2156 Mtetra
.844 .721 .728 r
.34652 .2156 .34664 .22091 .35765 .221 .35753 .2157 Mtetra
.863 .739 .724 r
.35753 .2157 .35765 .221 .36866 .22111 .36855 .21582 Mtetra
.882 .756 .718 r
.36855 .21582 .36866 .22111 .37967 .22123 .37956 .21596 Mtetra
.9 .772 .71 r
.37956 .21596 .37967 .22123 .39065 .22136 .39055 .21612 Mtetra
.918 .787 .7 r
.39055 .21612 .39065 .22136 .4016 .22152 .40151 .21631 Mtetra
.838 .685 .693 r
.89975 .21625 .89974 .22145 .90914 .22152 .90914 .21634 Mtetra
.838 .686 .694 r
.89031 .21617 .8903 .22138 .89974 .22145 .89975 .21625 Mtetra
.836 .686 .696 r
.88082 .21609 .8808 .22131 .8903 .22138 .89031 .21617 Mtetra
.834 .685 .698 r
.87126 .21601 .87123 .22124 .8808 .22131 .88082 .21609 Mtetra
.832 .684 .7 r
.86164 .21593 .8616 .22118 .87123 .22124 .87126 .21601 Mtetra
.828 .682 .702 r
.85195 .21586 .85191 .22111 .8616 .22118 .86164 .21593 Mtetra
.824 .68 .704 r
.84219 .21578 .84214 .22105 .85191 .22111 .85195 .21586 Mtetra
.819 .677 .707 r
.83235 .21571 .83229 .22099 .84214 .22105 .84219 .21578 Mtetra
.813 .673 .709 r
.82243 .21564 .82237 .22093 .83229 .22099 .83235 .21571 Mtetra
.806 .669 .712 r
.81244 .21558 .81237 .22088 .82237 .22093 .82243 .21564 Mtetra
.799 .664 .714 r
.80236 .21552 .80228 .22083 .81237 .22088 .81244 .21558 Mtetra
.79 .658 .717 r
.7922 .21547 .79212 .22079 .80228 .22083 .80236 .21552 Mtetra
.781 .652 .72 r
.78196 .21542 .78187 .22075 .79212 .22079 .7922 .21547 Mtetra
.77 .644 .723 r
.77163 .21538 .77155 .22072 .78187 .22075 .78196 .21542 Mtetra
.759 .636 .725 r
.76123 .21535 .76114 .22069 .77155 .22072 .77163 .21538 Mtetra
.746 .627 .728 r
.75075 .21532 .75065 .22067 .76114 .22069 .76123 .21535 Mtetra
.732 .617 .73 r
.74019 .21531 .74008 .22066 .75065 .22067 .75075 .21532 Mtetra
.716 .606 .732 r
.72955 .2153 .72945 .22065 .74008 .22066 .74019 .21531 Mtetra
.7 .594 .734 r
.71885 .2153 .71874 .22066 .72945 .22065 .72955 .2153 Mtetra
.681 .58 .736 r
.70808 .21532 .70797 .22067 .71874 .22066 .71885 .2153 Mtetra
.661 .566 .737 r
.69725 .21535 .69713 .2207 .70797 .22067 .70808 .21532 Mtetra
.639 .55 .737 r
.68637 .21539 .68625 .22073 .69713 .2207 .69725 .21535 Mtetra
.616 .532 .737 r
.67544 .21544 .67532 .22078 .68625 .22073 .68637 .21539 Mtetra
.59 .513 .736 r
.66447 .21551 .66436 .22084 .67532 .22078 .67544 .21544 Mtetra
.563 .493 .734 r
.65348 .2156 .65336 .22091 .66436 .22084 .66447 .21551 Mtetra
.533 .47 .731 r
.64247 .2157 .64235 .221 .65336 .22091 .65348 .2156 Mtetra
.502 .446 .726 r
.63145 .21582 .63134 .22111 .64235 .221 .64247 .2157 Mtetra
.467 .419 .72 r
.62044 .21596 .62033 .22123 .63134 .22111 .63145 .21582 Mtetra
.43 .389 .712 r
.60945 .21612 .60935 .22136 .62033 .22123 .62044 .21596 Mtetra
.39 .356 .7 r
.59849 .21631 .5984 .22152 .60935 .22136 .60945 .21612 Mtetra
.547 .446 .692 r
.09086 .22152 .09086 .22669 .10026 .22664 .10026 .22145 Mtetra
.548 .448 .693 r
.10026 .22145 .10026 .22664 .10972 .22658 .1097 .22138 Mtetra
.55 .451 .695 r
.1097 .22138 .10972 .22658 .11922 .22653 .1192 .22131 Mtetra
.553 .454 .696 r
.1192 .22131 .11922 .22653 .12879 .22647 .12877 .22124 Mtetra
.557 .458 .698 r
.12877 .22124 .12879 .22647 .13843 .22642 .1384 .22118 Mtetra
.562 .463 .7 r
.1384 .22118 .13843 .22642 .14813 .22637 .14809 .22111 Mtetra
.568 .469 .702 r
.14809 .22111 .14813 .22637 .15791 .22632 .15786 .22105 Mtetra
.576 .476 .704 r
.15786 .22105 .15791 .22632 .16776 .22627 .16771 .22099 Mtetra
.584 .484 .706 r
.16771 .22099 .16776 .22627 .17768 .22622 .17763 .22093 Mtetra
.593 .492 .709 r
.17763 .22093 .17768 .22622 .18769 .22618 .18763 .22088 Mtetra
.603 .501 .711 r
.18763 .22088 .18769 .22618 .19778 .22614 .19772 .22083 Mtetra
.614 .511 .714 r
.19772 .22083 .19778 .22614 .20795 .2261 .20788 .22079 Mtetra
.626 .522 .716 r
.20788 .22079 .20795 .2261 .2182 .22607 .21813 .22075 Mtetra
.639 .533 .718 r
.21813 .22075 .2182 .22607 .22853 .22605 .22845 .22072 Mtetra
.653 .546 .721 r
.22845 .22072 .22853 .22605 .23894 .22603 .23886 .22069 Mtetra
.667 .559 .723 r
.23886 .22069 .23894 .22603 .24943 .22601 .24935 .22067 Mtetra
.683 .572 .725 r
.24935 .22067 .24943 .22601 .26 .226 .25992 .22066 Mtetra
.699 .587 .727 r
.25992 .22066 .26 .226 .27064 .226 .27055 .22065 Mtetra
.716 .602 .728 r
.27055 .22065 .27064 .226 .28135 .226 .28126 .22066 Mtetra
.733 .617 .729 r
.28126 .22066 .28135 .226 .29213 .22601 .29203 .22067 Mtetra
.751 .633 .73 r
.29203 .22067 .29213 .22601 .30296 .22604 .30287 .2207 Mtetra
.77 .65 .73 r
.30287 .2207 .30296 .22604 .31385 .22607 .31375 .22073 Mtetra
.789 .667 .729 r
.31375 .22073 .31385 .22607 .32478 .22611 .32468 .22078 Mtetra
.808 .684 .727 r
.32468 .22078 .32478 .22611 .33574 .22616 .33564 .22084 Mtetra
.827 .701 .725 r
.33564 .22084 .33574 .22616 .34673 .22622 .34664 .22091 Mtetra
.846 .718 .721 r
.34664 .22091 .34673 .22622 .35774 .22629 .35765 .221 Mtetra
.865 .735 .717 r
.35765 .221 .35774 .22629 .36876 .22638 .36866 .22111 Mtetra
.884 .751 .71 r
.36866 .22111 .36876 .22638 .37976 .22647 .37967 .22123 Mtetra
.902 .767 .702 r
.37967 .22123 .37976 .22647 .39074 .22659 .39065 .22136 Mtetra
.837 .684 .693 r
.89974 .22145 .89974 .22664 .90914 .22669 .90914 .22152 Mtetra
.837 .685 .694 r
.8903 .22138 .89028 .22658 .89974 .22664 .89974 .22145 Mtetra
.835 .685 .696 r
.8808 .22131 .88078 .22653 .89028 .22658 .8903 .22138 Mtetra
.833 .684 .697 r
.87123 .22124 .87121 .22647 .88078 .22653 .8808 .22131 Mtetra
.83 .682 .699 r
.8616 .22118 .86157 .22642 .87121 .22647 .87123 .22124 Mtetra
.827 .68 .701 r
.85191 .22111 .85187 .22637 .86157 .22642 .8616 .22118 Mtetra
.823 .678 .703 r
.84214 .22105 .84209 .22632 .85187 .22637 .85191 .22111 Mtetra
.818 .675 .705 r
.83229 .22099 .83224 .22627 .84209 .22632 .84214 .22105 Mtetra
.812 .671 .707 r
.82237 .22093 .82232 .22622 .83224 .22627 .83229 .22099 Mtetra
.805 .666 .71 r
.81237 .22088 .81231 .22618 .82232 .22622 .82237 .22093 Mtetra
.798 .661 .712 r
.80228 .22083 .80222 .22614 .81231 .22618 .81237 .22088 Mtetra
.789 .655 .715 r
.79212 .22079 .79205 .2261 .80222 .22614 .80228 .22083 Mtetra
.78 .648 .717 r
.78187 .22075 .7818 .22607 .79205 .2261 .79212 .22079 Mtetra
.769 .641 .72 r
.77155 .22072 .77147 .22605 .7818 .22607 .78187 .22075 Mtetra
.757 .632 .722 r
.76114 .22069 .76106 .22603 .77147 .22605 .77155 .22072 Mtetra
.744 .623 .724 r
.75065 .22067 .75057 .22601 .76106 .22603 .76114 .22069 Mtetra
.73 .612 .726 r
.74008 .22066 .74 .226 .75057 .22601 .75065 .22067 Mtetra
.715 .601 .728 r
.72945 .22065 .72936 .226 .74 .226 .74008 .22066 Mtetra
.698 .588 .73 r
.71874 .22066 .71865 .226 .72936 .226 .72945 .22065 Mtetra
.679 .575 .731 r
.70797 .22067 .70787 .22601 .71865 .226 .71874 .22066 Mtetra
.659 .56 .731 r
.69713 .2207 .69704 .22604 .70787 .22601 .70797 .22067 Mtetra
.637 .543 .732 r
.68625 .22073 .68615 .22607 .69704 .22604 .69713 .2207 Mtetra
.613 .525 .731 r
.67532 .22078 .67522 .22611 .68615 .22607 .68625 .22073 Mtetra
.588 .506 .729 r
.66436 .22084 .66426 .22616 .67522 .22611 .67532 .22078 Mtetra
.56 .485 .727 r
.65336 .22091 .65327 .22622 .66426 .22616 .66436 .22084 Mtetra
.531 .462 .724 r
.64235 .221 .64226 .22629 .65327 .22622 .65336 .22091 Mtetra
.499 .437 .719 r
.63134 .22111 .63124 .22638 .64226 .22629 .64235 .221 Mtetra
.465 .41 .712 r
.62033 .22123 .62024 .22647 .63124 .22638 .63134 .22111 Mtetra
.429 .381 .703 r
.60935 .22136 .60926 .22659 .62024 .22647 .62033 .22123 Mtetra
.548 .447 .692 r
.09086 .22669 .09086 .23187 .10027 .23183 .10026 .22664 Mtetra
.549 .449 .693 r
.10026 .22664 .10027 .23183 .10973 .23179 .10972 .22658 Mtetra
.551 .451 .694 r
.10972 .22658 .10973 .23179 .11924 .23174 .11922 .22653 Mtetra
.554 .455 .696 r
.11922 .22653 .11924 .23174 .12881 .2317 .12879 .22647 Mtetra
.558 .459 .697 r
.12879 .22647 .12881 .2317 .13845 .23166 .13843 .22642 Mtetra
.564 .464 .699 r
.13843 .22642 .13845 .23166 .14816 .23162 .14813 .22637 Mtetra
.57 .469 .701 r
.14813 .22637 .14816 .23162 .15794 .23158 .15791 .22632 Mtetra
.577 .476 .703 r
.15791 .22632 .15794 .23158 .16779 .23154 .16776 .22627 Mtetra
.585 .483 .705 r
.16776 .22627 .16779 .23154 .17773 .23151 .17768 .22622 Mtetra
.594 .492 .707 r
.17768 .22622 .17773 .23151 .18774 .23148 .18769 .22618 Mtetra
.604 .501 .709 r
.18769 .22618 .18774 .23148 .19783 .23145 .19778 .22614 Mtetra
.616 .51 .711 r
.19778 .22614 .19783 .23145 .208 .23142 .20795 .2261 Mtetra
.628 .521 .714 r
.20795 .2261 .208 .23142 .21825 .23139 .2182 .22607 Mtetra
.64 .532 .716 r
.2182 .22607 .21825 .23139 .22859 .23137 .22853 .22605 Mtetra
.654 .545 .718 r
.22853 .22605 .22859 .23137 .23901 .23136 .23894 .22603 Mtetra
.669 .557 .72 r
.23894 .22603 .23901 .23136 .2495 .23135 .24943 .22601 Mtetra
.684 .571 .721 r
.24943 .22601 .2495 .23135 .26007 .23134 .26 .226 Mtetra
.701 .585 .723 r
.26 .226 .26007 .23134 .27071 .23134 .27064 .226 Mtetra
.718 .6 .724 r
.27064 .226 .27071 .23134 .28143 .23134 .28135 .226 Mtetra
.735 .615 .725 r
.28135 .226 .28143 .23134 .2922 .23135 .29213 .22601 Mtetra
.753 .631 .725 r
.29213 .22601 .2922 .23135 .30304 .23137 .30296 .22604 Mtetra
.772 .647 .724 r
.30296 .22604 .30304 .23137 .31392 .23139 .31385 .22607 Mtetra
.791 .664 .723 r
.31385 .22607 .31392 .23139 .32485 .23142 .32478 .22611 Mtetra
.81 .681 .721 r
.32478 .22611 .32485 .23142 .33582 .23146 .33574 .22616 Mtetra
.829 .697 .719 r
.33574 .22616 .33582 .23146 .34681 .23151 .34673 .22622 Mtetra
.848 .714 .715 r
.34673 .22622 .34681 .23151 .35782 .23157 .35774 .22629 Mtetra
.867 .731 .709 r
.35774 .22629 .35782 .23157 .36883 .23164 .36876 .22638 Mtetra
.885 .746 .703 r
.36876 .22638 .36883 .23164 .37983 .23171 .37976 .22647 Mtetra
.903 .761 .695 r
.37976 .22647 .37983 .23171 .3908 .2318 .39074 .22659 Mtetra
.836 .684 .693 r
.89974 .22664 .89973 .23183 .90914 .23187 .90914 .22669 Mtetra
.836 .684 .694 r
.89028 .22658 .89027 .23179 .89973 .23183 .89974 .22664 Mtetra
.834 .683 .695 r
.88078 .22653 .88076 .23174 .89027 .23179 .89028 .22658 Mtetra
.832 .682 .697 r
.87121 .22647 .87119 .2317 .88076 .23174 .88078 .22653 Mtetra
.83 .681 .698 r
.86157 .22642 .86155 .23166 .87119 .2317 .87121 .22647 Mtetra
.826 .679 .7 r
.85187 .22637 .85184 .23162 .86155 .23166 .86157 .22642 Mtetra
.822 .676 .702 r
.84209 .22632 .84206 .23158 .85184 .23162 .85187 .22637 Mtetra
.817 .672 .704 r
.83224 .22627 .83221 .23154 .84206 .23158 .84209 .22632 Mtetra
.811 .668 .706 r
.82232 .22622 .82227 .23151 .83221 .23154 .83224 .22627 Mtetra
.804 .664 .708 r
.81231 .22618 .81226 .23148 .82227 .23151 .82232 .22622 Mtetra
.797 .658 .71 r
.80222 .22614 .80217 .23145 .81226 .23148 .81231 .22618 Mtetra
.788 .652 .712 r
.79205 .2261 .792 .23142 .80217 .23145 .80222 .22614 Mtetra
.778 .645 .715 r
.7818 .22607 .78175 .23139 .792 .23142 .79205 .2261 Mtetra
.768 .637 .717 r
.77147 .22605 .77141 .23137 .78175 .23139 .7818 .22607 Mtetra
.756 .628 .719 r
.76106 .22603 .76099 .23136 .77141 .23137 .77147 .22605 Mtetra
.743 .619 .721 r
.75057 .22601 .7505 .23135 .76099 .23136 .76106 .22603 Mtetra
.729 .608 .723 r
.74 .226 .73993 .23134 .7505 .23135 .75057 .22601 Mtetra
.713 .596 .724 r
.72936 .226 .72929 .23134 .73993 .23134 .74 .226 Mtetra
.696 .583 .725 r
.71865 .226 .71857 .23134 .72929 .23134 .72936 .226 Mtetra
.677 .569 .726 r
.70787 .22601 .7078 .23135 .71857 .23134 .71865 .226 Mtetra
.657 .554 .726 r
.69704 .22604 .69696 .23137 .7078 .23135 .70787 .22601 Mtetra
.635 .537 .726 r
.68615 .22607 .68608 .23139 .69696 .23137 .69704 .22604 Mtetra
.611 .519 .725 r
.67522 .22611 .67515 .23142 .68608 .23139 .68615 .22607 Mtetra
.586 .499 .723 r
.66426 .22616 .66418 .23146 .67515 .23142 .67522 .22611 Mtetra
.558 .477 .72 r
.65327 .22622 .65319 .23151 .66418 .23146 .66426 .22616 Mtetra
.528 .454 .716 r
.64226 .22629 .64218 .23157 .65319 .23151 .65327 .22622 Mtetra
.497 .429 .711 r
.63124 .22638 .63117 .23164 .64218 .23157 .64226 .22629 Mtetra
.463 .402 .704 r
.62024 .22647 .62017 .23171 .63117 .23164 .63124 .22638 Mtetra
.427 .373 .695 r
.60926 .22659 .6092 .2318 .62017 .23171 .62024 .22647 Mtetra
.549 .448 .692 r
.09086 .23187 .09086 .23705 .10027 .23702 .10027 .23183 Mtetra
.55 .45 .693 r
.10027 .23183 .10027 .23702 .10973 .23699 .10973 .23179 Mtetra
.552 .452 .694 r
.10973 .23179 .10973 .23699 .11925 .23696 .11924 .23174 Mtetra
.555 .455 .695 r
.11924 .23174 .11925 .23696 .12883 .23693 .12881 .2317 Mtetra
.559 .459 .697 r
.12881 .2317 .12883 .23693 .13847 .2369 .13845 .23166 Mtetra
.565 .464 .698 r
.13845 .23166 .13847 .2369 .14818 .23687 .14816 .23162 Mtetra
.571 .469 .7 r
.14816 .23162 .14818 .23687 .15797 .23684 .15794 .23158 Mtetra
.578 .476 .701 r
.15794 .23158 .15797 .23684 .16782 .23682 .16779 .23154 Mtetra
.586 .483 .703 r
.16779 .23154 .16782 .23682 .17776 .23679 .17773 .23151 Mtetra
.595 .491 .705 r
.17773 .23151 .17776 .23679 .18777 .23677 .18774 .23148 Mtetra
.606 .5 .707 r
.18774 .23148 .18777 .23677 .19787 .23675 .19783 .23145 Mtetra
.617 .509 .709 r
.19783 .23145 .19787 .23675 .20804 .23673 .208 .23142 Mtetra
.629 .52 .711 r
.208 .23142 .20804 .23673 .2183 .23671 .21825 .23139 Mtetra
.642 .531 .713 r
.21825 .23139 .2183 .23671 .22863 .2367 .22859 .23137 Mtetra
.656 .543 .715 r
.22859 .23137 .22863 .2367 .23905 .23669 .23901 .23136 Mtetra
.67 .556 .716 r
.23901 .23136 .23905 .23669 .24955 .23668 .2495 .23135 Mtetra
.686 .569 .718 r
.2495 .23135 .24955 .23668 .26012 .23667 .26007 .23134 Mtetra
.702 .583 .719 r
.26007 .23134 .26012 .23667 .27077 .23667 .27071 .23134 Mtetra
.719 .598 .72 r
.27071 .23134 .27077 .23667 .28148 .23668 .28143 .23134 Mtetra
.737 .613 .72 r
.28143 .23134 .28148 .23668 .29226 .23668 .2922 .23135 Mtetra
.755 .628 .72 r
.2922 .23135 .29226 .23668 .30309 .2367 .30304 .23137 Mtetra
.773 .644 .719 r
.30304 .23137 .30309 .2367 .31398 .23671 .31392 .23139 Mtetra
.792 .661 .718 r
.31392 .23139 .31398 .23671 .32491 .23674 .32485 .23142 Mtetra
.811 .677 .715 r
.32485 .23142 .32491 .23674 .33588 .23676 .33582 .23146 Mtetra
.831 .694 .712 r
.33582 .23146 .33588 .23676 .34687 .2368 .34681 .23151 Mtetra
.85 .71 .708 r
.34681 .23151 .34687 .2368 .35788 .23684 .35782 .23157 Mtetra
.869 .726 .702 r
.35782 .23157 .35788 .23684 .36889 .23689 .36883 .23164 Mtetra
.887 .741 .696 r
.36883 .23164 .36889 .23689 .37988 .23694 .37983 .23171 Mtetra
.904 .756 .687 r
.37983 .23171 .37988 .23694 .39085 .23701 .3908 .2318 Mtetra
.836 .683 .693 r
.89973 .23183 .89973 .23702 .90914 .23705 .90914 .23187 Mtetra
.835 .683 .694 r
.89027 .23179 .89027 .23699 .89973 .23702 .89973 .23183 Mtetra
.834 .682 .695 r
.88076 .23174 .88075 .23696 .89027 .23699 .89027 .23179 Mtetra
.832 .681 .696 r
.87119 .2317 .87117 .23693 .88075 .23696 .88076 .23174 Mtetra
.829 .679 .697 r
.86155 .23166 .86153 .2369 .87117 .23693 .87119 .2317 Mtetra
.825 .677 .699 r
.85184 .23162 .85182 .23687 .86153 .2369 .86155 .23166 Mtetra
.821 .674 .7 r
.84206 .23158 .84203 .23684 .85182 .23687 .85184 .23162 Mtetra
.816 .67 .702 r
.83221 .23154 .83218 .23682 .84203 .23684 .84206 .23158 Mtetra
.81 .666 .704 r
.82227 .23151 .82224 .23679 .83218 .23682 .83221 .23154 Mtetra
.803 .661 .706 r
.81226 .23148 .81223 .23677 .82224 .23679 .82227 .23151 Mtetra
.796 .656 .708 r
.80217 .23145 .80213 .23675 .81223 .23677 .81226 .23148 Mtetra
.787 .649 .71 r
.792 .23142 .79196 .23673 .80213 .23675 .80217 .23145 Mtetra
.777 .642 .712 r
.78175 .23139 .7817 .23671 .79196 .23673 .792 .23142 Mtetra
.767 .634 .714 r
.77141 .23137 .77137 .2367 .7817 .23671 .78175 .23139 Mtetra
.755 .625 .716 r
.76099 .23136 .76095 .23669 .77137 .2367 .77141 .23137 Mtetra
.742 .615 .717 r
.7505 .23135 .75045 .23668 .76095 .23669 .76099 .23136 Mtetra
.728 .604 .719 r
.73993 .23134 .73988 .23667 .75045 .23668 .7505 .23135 Mtetra
.712 .592 .72 r
.72929 .23134 .72923 .23667 .73988 .23667 .73993 .23134 Mtetra
.695 .579 .721 r
.71857 .23134 .71852 .23668 .72923 .23667 .72929 .23134 Mtetra
.676 .564 .721 r
.7078 .23135 .70774 .23668 .71852 .23668 .71857 .23134 Mtetra
.656 .548 .721 r
.69696 .23137 .69691 .2367 .70774 .23668 .7078 .23135 Mtetra
.634 .531 .72 r
.68608 .23139 .68602 .23671 .69691 .2367 .69696 .23137 Mtetra
.61 .512 .719 r
.67515 .23142 .67509 .23674 .68602 .23671 .68608 .23139 Mtetra
.584 .492 .717 r
.66418 .23146 .66412 .23676 .67509 .23674 .67515 .23142 Mtetra
.556 .47 .713 r
.65319 .23151 .65313 .2368 .66412 .23676 .66418 .23146 Mtetra
.526 .447 .709 r
.64218 .23157 .64212 .23684 .65313 .2368 .65319 .23151 Mtetra
.495 .422 .703 r
.63117 .23164 .63111 .23689 .64212 .23684 .64218 .23157 Mtetra
.462 .395 .696 r
.62017 .23171 .62012 .23694 .63111 .23689 .63117 .23164 Mtetra
.427 .367 .687 r
.6092 .2318 .60915 .23701 .62012 .23694 .62017 .23171 Mtetra
.55 .449 .693 r
.09086 .23705 .09086 .24223 .10027 .24221 .10027 .23702 Mtetra
.551 .45 .693 r
.10027 .23702 .10027 .24221 .10974 .24219 .10973 .23699 Mtetra
.553 .452 .694 r
.10973 .23699 .10974 .24219 .11926 .24218 .11925 .23696 Mtetra
.556 .455 .695 r
.11925 .23696 .11926 .24218 .12884 .24216 .12883 .23693 Mtetra
.56 .459 .696 r
.12883 .23693 .12884 .24216 .13849 .24214 .13847 .2369 Mtetra
.565 .463 .697 r
.13847 .2369 .13849 .24214 .1482 .24212 .14818 .23687 Mtetra
.572 .469 .699 r
.14818 .23687 .1482 .24212 .15798 .24211 .15797 .23684 Mtetra
.579 .475 .7 r
.15797 .23684 .15798 .24211 .16784 .24209 .16782 .23682 Mtetra
.587 .482 .702 r
.16782 .23682 .16784 .24209 .17778 .24208 .17776 .23679 Mtetra
.596 .49 .703 r
.17776 .23679 .17778 .24208 .18779 .24206 .18777 .23677 Mtetra
.606 .499 .705 r
.18777 .23677 .18779 .24206 .19789 .24205 .19787 .23675 Mtetra
.618 .508 .707 r
.19787 .23675 .19789 .24205 .20807 .24204 .20804 .23673 Mtetra
.63 .518 .709 r
.20804 .23673 .20807 .24204 .21833 .24203 .2183 .23671 Mtetra
.643 .529 .71 r
.2183 .23671 .21833 .24203 .22867 .24202 .22863 .2367 Mtetra
.657 .541 .712 r
.22863 .2367 .22867 .24202 .23908 .24201 .23905 .23669 Mtetra
.671 .554 .713 r
.23905 .23669 .23908 .24201 .24958 .24201 .24955 .23668 Mtetra
.687 .567 .714 r
.24955 .23668 .24958 .24201 .26016 .24201 .26012 .23667 Mtetra
.703 .581 .715 r
.26012 .23667 .26016 .24201 .2708 .242 .27077 .23667 Mtetra
.72 .595 .715 r
.27077 .23667 .2708 .242 .28152 .24201 .28148 .23668 Mtetra
.738 .61 .716 r
.28148 .23668 .28152 .24201 .29229 .24201 .29226 .23668 Mtetra
.756 .625 .715 r
.29226 .23668 .29229 .24201 .30313 .24202 .30309 .2367 Mtetra
.775 .641 .714 r
.30309 .2367 .30313 .24202 .31402 .24203 .31398 .23671 Mtetra
.793 .657 .712 r
.31398 .23671 .31402 .24203 .32495 .24204 .32491 .23674 Mtetra
.813 .673 .709 r
.32491 .23674 .32495 .24204 .33592 .24206 .33588 .23676 Mtetra
.832 .689 .706 r
.33588 .23676 .33592 .24206 .34691 .24208 .34687 .2368 Mtetra
.851 .706 .701 r
.34687 .2368 .34691 .24208 .35792 .24211 .35788 .23684 Mtetra
.869 .721 .695 r
.35788 .23684 .35792 .24211 .36892 .24214 .36889 .23689 Mtetra
.887 .736 .688 r
.36889 .23689 .36892 .24214 .37992 .24217 .37988 .23694 Mtetra
.904 .75 .68 r
.37988 .23694 .37992 .24217 .39088 .24221 .39085 .23701 Mtetra
.835 .682 .693 r
.89973 .23702 .89973 .24221 .90914 .24223 .90914 .23705 Mtetra
.835 .682 .694 r
.89027 .23699 .89026 .24219 .89973 .24221 .89973 .23702 Mtetra
.833 .681 .694 r
.88075 .23696 .88074 .24218 .89026 .24219 .89027 .23699 Mtetra
.831 .68 .695 r
.87117 .23693 .87116 .24216 .88074 .24218 .88075 .23696 Mtetra
.828 .678 .696 r
.86153 .2369 .86151 .24214 .87116 .24216 .87117 .23693 Mtetra
.825 .675 .698 r
.85182 .23687 .8518 .24212 .86151 .24214 .86153 .2369 Mtetra
.82 .672 .699 r
.84203 .23684 .84202 .24211 .8518 .24212 .85182 .23687 Mtetra
.815 .669 .701 r
.83218 .23682 .83216 .24209 .84202 .24211 .84203 .23684 Mtetra
.809 .664 .702 r
.82224 .23679 .82222 .24208 .83216 .24209 .83218 .23682 Mtetra
.803 .659 .704 r
.81223 .23677 .81221 .24206 .82222 .24208 .82224 .23679 Mtetra
.795 .653 .706 r
.80213 .23675 .80211 .24205 .81221 .24206 .81223 .23677 Mtetra
.786 .646 .707 r
.79196 .23673 .79193 .24204 .80211 .24205 .80213 .23675 Mtetra
.777 .639 .709 r
.7817 .23671 .78167 .24203 .79193 .24204 .79196 .23673 Mtetra
.766 .631 .711 r
.77137 .2367 .77133 .24202 .78167 .24203 .7817 .23671 Mtetra
.754 .621 .712 r
.76095 .23669 .76092 .24201 .77133 .24202 .77137 .2367 Mtetra
.741 .611 .714 r
.75045 .23668 .75042 .24201 .76092 .24201 .76095 .23669 Mtetra
.727 .6 .715 r
.73988 .23667 .73984 .24201 .75042 .24201 .75045 .23668 Mtetra
.711 .588 .716 r
.72923 .23667 .7292 .242 .73984 .24201 .73988 .23667 Mtetra
.694 .574 .716 r
.71852 .23668 .71848 .24201 .7292 .242 .72923 .23667 Mtetra
.675 .559 .716 r
.70774 .23668 .70771 .24201 .71848 .24201 .71852 .23668 Mtetra
.655 .543 .716 r
.69691 .2367 .69687 .24202 .70771 .24201 .70774 .23668 Mtetra
.632 .526 .715 r
.68602 .23671 .68598 .24203 .69687 .24202 .69691 .2367 Mtetra
.608 .507 .713 r
.67509 .23674 .67505 .24204 .68598 .24203 .68602 .23671 Mtetra
.582 .486 .71 r
.66412 .23676 .66408 .24206 .67505 .24204 .67509 .23674 Mtetra
.555 .464 .707 r
.65313 .2368 .65309 .24208 .66408 .24206 .66412 .23676 Mtetra
.525 .44 .702 r
.64212 .23684 .64208 .24211 .65309 .24208 .65313 .2368 Mtetra
.494 .415 .696 r
.63111 .23689 .63108 .24214 .64208 .24211 .64212 .23684 Mtetra
.461 .388 .689 r
.62012 .23694 .62008 .24217 .63108 .24214 .63111 .23689 Mtetra
.427 .36 .68 r
.60915 .23701 .60912 .24221 .62008 .24217 .62012 .23694 Mtetra
.55 .449 .693 r
.09086 .24223 .09086 .24741 .10027 .2474 .10027 .24221 Mtetra
.551 .45 .693 r
.10027 .24221 .10027 .2474 .10974 .2474 .10974 .24219 Mtetra
.554 .452 .694 r
.10974 .24219 .10974 .2474 .11926 .24739 .11926 .24218 Mtetra
.557 .455 .694 r
.11926 .24218 .11926 .24739 .12885 .24739 .12884 .24216 Mtetra
.561 .459 .695 r
.12884 .24216 .12885 .24739 .13849 .24738 .13849 .24214 Mtetra
.566 .463 .696 r
.13849 .24214 .13849 .24738 .14821 .24737 .1482 .24212 Mtetra
.572 .468 .697 r
.1482 .24212 .14821 .24737 .15799 .24737 .15798 .24211 Mtetra
.579 .474 .699 r
.15798 .24211 .15799 .24737 .16785 .24736 .16784 .24209 Mtetra
.588 .481 .7 r
.16784 .24209 .16785 .24736 .17779 .24736 .17778 .24208 Mtetra
.597 .489 .702 r
.17778 .24208 .17779 .24736 .18781 .24735 .18779 .24206 Mtetra
.607 .497 .703 r
.18779 .24206 .18781 .24735 .1979 .24735 .19789 .24205 Mtetra
.618 .507 .705 r
.19789 .24205 .1979 .24735 .20808 .24735 .20807 .24204 Mtetra
.63 .517 .706 r
.20807 .24204 .20808 .24735 .21834 .24734 .21833 .24203 Mtetra
.643 .528 .707 r
.21833 .24203 .21834 .24734 .22868 .24734 .22867 .24202 Mtetra
.657 .539 .709 r
.22867 .24202 .22868 .24734 .2391 .24734 .23908 .24201 Mtetra
.672 .551 .71 r
.23908 .24201 .2391 .24734 .2496 .24734 .24958 .24201 Mtetra
.687 .564 .711 r
.24958 .24201 .2496 .24734 .26017 .24734 .26016 .24201 Mtetra
.704 .578 .711 r
.26016 .24201 .26017 .24734 .27082 .24734 .2708 .242 Mtetra
.721 .592 .711 r
.2708 .242 .27082 .24734 .28153 .24734 .28152 .24201 Mtetra
.738 .607 .711 r
.28152 .24201 .28153 .24734 .29231 .24734 .29229 .24201 Mtetra
.757 .622 .71 r
.29229 .24201 .29231 .24734 .30315 .24734 .30313 .24202 Mtetra
.775 .637 .709 r
.30313 .24202 .30315 .24734 .31404 .24734 .31402 .24203 Mtetra
.794 .653 .706 r
.31402 .24203 .31404 .24734 .32497 .24735 .32495 .24204 Mtetra
.813 .669 .703 r
.32495 .24204 .32497 .24735 .33594 .24735 .33592 .24206 Mtetra
.833 .685 .699 r
.33592 .24206 .33594 .24735 .34693 .24736 .34691 .24208 Mtetra
.852 .701 .694 r
.34691 .24208 .34693 .24736 .35793 .24737 .35792 .24211 Mtetra
.87 .716 .688 r
.35792 .24211 .35793 .24737 .36894 .24738 .36892 .24214 Mtetra
.888 .731 .681 r
.36892 .24214 .36894 .24738 .37993 .24739 .37992 .24217 Mtetra
.904 .744 .673 r
.37992 .24217 .37993 .24739 .3909 .2474 .39088 .24221 Mtetra
.835 .682 .693 r
.89973 .24221 .89973 .2474 .90914 .24741 .90914 .24223 Mtetra
.834 .681 .693 r
.89026 .24219 .89026 .2474 .89973 .2474 .89973 .24221 Mtetra
.833 .681 .694 r
.88074 .24218 .88074 .24739 .89026 .2474 .89026 .24219 Mtetra
.831 .679 .695 r
.87116 .24216 .87115 .24739 .88074 .24739 .88074 .24218 Mtetra
.828 .677 .695 r
.86151 .24214 .86151 .24738 .87115 .24739 .87116 .24216 Mtetra
.824 .674 .696 r
.8518 .24212 .85179 .24737 .86151 .24738 .86151 .24214 Mtetra
.82 .671 .698 r
.84202 .24211 .84201 .24737 .85179 .24737 .8518 .24212 Mtetra
.815 .667 .699 r
.83216 .24209 .83215 .24736 .84201 .24737 .84202 .24211 Mtetra
.809 .662 .7 r
.82222 .24208 .82221 .24736 .83215 .24736 .83216 .24209 Mtetra
.802 .657 .702 r
.81221 .24206 .81219 .24735 .82221 .24736 .82222 .24208 Mtetra
.795 .651 .703 r
.80211 .24205 .8021 .24735 .81219 .24735 .81221 .24206 Mtetra
.786 .644 .705 r
.79193 .24204 .79192 .24735 .8021 .24735 .80211 .24205 Mtetra
.776 .636 .706 r
.78167 .24203 .78166 .24734 .79192 .24735 .79193 .24204 Mtetra
.766 .628 .708 r
.77133 .24202 .77132 .24734 .78166 .24734 .78167 .24203 Mtetra
.754 .618 .709 r
.76092 .24201 .7609 .24734 .77132 .24734 .77133 .24202 Mtetra
.741 .608 .71 r
.75042 .24201 .7504 .24734 .7609 .24734 .76092 .24201 Mtetra
.726 .596 .711 r
.73984 .24201 .73983 .24734 .7504 .24734 .75042 .24201 Mtetra
.71 .584 .711 r
.7292 .242 .72918 .24734 .73983 .24734 .73984 .24201 Mtetra
.693 .57 .712 r
.71848 .24201 .71847 .24734 .72918 .24734 .7292 .242 Mtetra
.674 .555 .711 r
.70771 .24201 .70769 .24734 .71847 .24734 .71848 .24201 Mtetra
.654 .538 .711 r
.69687 .24202 .69685 .24734 .70769 .24734 .70771 .24201 Mtetra
.632 .52 .709 r
.68598 .24203 .68596 .24734 .69685 .24734 .69687 .24202 Mtetra
.608 .501 .707 r
.67505 .24204 .67503 .24735 .68596 .24734 .68598 .24203 Mtetra
.582 .48 .704 r
.66408 .24206 .66406 .24735 .67503 .24735 .67505 .24204 Mtetra
.554 .458 .7 r
.65309 .24208 .65307 .24736 .66406 .24735 .66408 .24206 Mtetra
.524 .434 .695 r
.64208 .24211 .64207 .24737 .65307 .24736 .65309 .24208 Mtetra
.493 .408 .689 r
.63108 .24214 .63106 .24738 .64207 .24737 .64208 .24211 Mtetra
.46 .382 .681 r
.62008 .24217 .62007 .24739 .63106 .24738 .63108 .24214 Mtetra
.427 .354 .673 r
.60912 .24221 .6091 .2474 .62007 .24739 .62008 .24217 Mtetra
.551 .45 .693 r
.09086 .24741 .09086 .25259 .10027 .2526 .10027 .2474 Mtetra
.552 .45 .693 r
.10027 .2474 .10027 .2526 .10974 .2526 .10974 .2474 Mtetra
.554 .452 .693 r
.10974 .2474 .10974 .2526 .11926 .25261 .11926 .24739 Mtetra
.557 .455 .694 r
.11926 .24739 .11926 .25261 .12885 .25261 .12885 .24739 Mtetra
.561 .458 .694 r
.12885 .24739 .12885 .25261 .13849 .25262 .13849 .24738 Mtetra
.566 .462 .695 r
.13849 .24738 .13849 .25262 .14821 .25263 .14821 .24737 Mtetra
.572 .467 .696 r
.14821 .24737 .14821 .25263 .15799 .25263 .15799 .24737 Mtetra
.58 .473 .697 r
.15799 .24737 .15799 .25263 .16785 .25264 .16785 .24736 Mtetra
.588 .48 .698 r
.16785 .24736 .16785 .25264 .17779 .25264 .17779 .24736 Mtetra
.597 .488 .7 r
.17779 .24736 .17779 .25264 .18781 .25265 .18781 .24735 Mtetra
.607 .496 .701 r
.18781 .24735 .18781 .25265 .1979 .25265 .1979 .24735 Mtetra
.618 .505 .702 r
.1979 .24735 .1979 .25265 .20808 .25265 .20808 .24735 Mtetra
.631 .515 .703 r
.20808 .24735 .20808 .25265 .21834 .25266 .21834 .24734 Mtetra
.644 .525 .704 r
.21834 .24734 .21834 .25266 .22868 .25266 .22868 .24734 Mtetra
.657 .537 .705 r
.22868 .24734 .22868 .25266 .2391 .25266 .2391 .24734 Mtetra
.672 .549 .706 r
.2391 .24734 .2391 .25266 .2496 .25266 .2496 .24734 Mtetra
.688 .562 .707 r
.2496 .24734 .2496 .25266 .26017 .25266 .26017 .24734 Mtetra
.704 .575 .707 r
.26017 .24734 .26017 .25266 .27082 .25266 .27082 .24734 Mtetra
.721 .589 .707 r
.27082 .24734 .27082 .25266 .28153 .25266 .28153 .24734 Mtetra
.739 .603 .706 r
.28153 .24734 .28153 .25266 .29231 .25266 .29231 .24734 Mtetra
.757 .618 .705 r
.29231 .24734 .29231 .25266 .30315 .25266 .30315 .24734 Mtetra
.776 .633 .703 r
.30315 .24734 .30315 .25266 .31404 .25266 .31404 .24734 Mtetra
.795 .649 .701 r
.31404 .24734 .31404 .25266 .32497 .25265 .32497 .24735 Mtetra
.814 .664 .697 r
.32497 .24735 .32497 .25265 .33594 .25265 .33594 .24735 Mtetra
.833 .68 .693 r
.33594 .24735 .33594 .25265 .34693 .25264 .34693 .24736 Mtetra
.852 .696 .688 r
.34693 .24736 .34693 .25264 .35793 .25263 .35793 .24737 Mtetra
.87 .711 .681 r
.35793 .24737 .35793 .25263 .36894 .25262 .36894 .24738 Mtetra
.888 .725 .674 r
.36894 .24738 .36894 .25262 .37993 .25261 .37993 .24739 Mtetra
.904 .738 .666 r
.37993 .24739 .37993 .25261 .3909 .2526 .3909 .2474 Mtetra
.835 .682 .693 r
.89973 .2474 .89973 .2526 .90914 .25259 .90914 .24741 Mtetra
.834 .681 .693 r
.89026 .2474 .89026 .2526 .89973 .2526 .89973 .2474 Mtetra
.833 .68 .693 r
.88074 .24739 .88074 .25261 .89026 .2526 .89026 .2474 Mtetra
.831 .678 .694 r
.87115 .24739 .87115 .25261 .88074 .25261 .88074 .24739 Mtetra
.828 .676 .694 r
.86151 .24738 .86151 .25262 .87115 .25261 .87115 .24739 Mtetra
.824 .673 .695 r
.85179 .24737 .85179 .25263 .86151 .25262 .86151 .24738 Mtetra
.82 .669 .696 r
.84201 .24737 .84201 .25263 .85179 .25263 .85179 .24737 Mtetra
.815 .665 .697 r
.83215 .24736 .83215 .25264 .84201 .25263 .84201 .24737 Mtetra
.809 .66 .698 r
.82221 .24736 .82221 .25264 .83215 .25264 .83215 .24736 Mtetra
.802 .655 .7 r
.81219 .24735 .81219 .25265 .82221 .25264 .82221 .24736 Mtetra
.794 .649 .701 r
.8021 .24735 .8021 .25265 .81219 .25265 .81219 .24735 Mtetra
.786 .642 .702 r
.79192 .24735 .79192 .25265 .8021 .25265 .8021 .24735 Mtetra
.776 .634 .703 r
.78166 .24734 .78166 .25266 .79192 .25265 .79192 .24735 Mtetra
.765 .625 .704 r
.77132 .24734 .77132 .25266 .78166 .25266 .78166 .24734 Mtetra
.753 .615 .705 r
.7609 .24734 .7609 .25266 .77132 .25266 .77132 .24734 Mtetra
.74 .605 .706 r
.7504 .24734 .7504 .25266 .7609 .25266 .7609 .24734 Mtetra
.726 .593 .707 r
.73983 .24734 .73983 .25266 .7504 .25266 .7504 .24734 Mtetra
.71 .58 .707 r
.72918 .24734 .72918 .25266 .73983 .25266 .73983 .24734 Mtetra
.693 .566 .707 r
.71847 .24734 .71847 .25266 .72918 .25266 .72918 .24734 Mtetra
.674 .55 .706 r
.70769 .24734 .70769 .25266 .71847 .25266 .71847 .24734 Mtetra
.653 .534 .705 r
.69685 .24734 .69685 .25266 .70769 .25266 .70769 .24734 Mtetra
.631 .515 .703 r
.68596 .24734 .68596 .25266 .69685 .25266 .69685 .24734 Mtetra
.607 .496 .701 r
.67503 .24735 .67503 .25265 .68596 .25266 .68596 .24734 Mtetra
.581 .474 .697 r
.66406 .24735 .66406 .25265 .67503 .25265 .67503 .24735 Mtetra
.553 .452 .693 r
.65307 .24736 .65307 .25264 .66406 .25265 .66406 .24735 Mtetra
.524 .428 .688 r
.64207 .24737 .64207 .25263 .65307 .25264 .65307 .24736 Mtetra
.492 .402 .681 r
.63106 .24738 .63106 .25262 .64207 .25263 .64207 .24737 Mtetra
.46 .375 .674 r
.62007 .24739 .62007 .25261 .63106 .25262 .63106 .24738 Mtetra
.427 .349 .666 r
.6091 .2474 .6091 .2526 .62007 .25261 .62007 .24739 Mtetra
.349 .285 .643 r
.0909 .44937 .0909 .45455 .09932 .45554 .09937 .45032 Mtetra
.352 .281 .637 r
.09937 .45032 .09932 .45554 .10783 .45654 .10792 .45127 Mtetra
.355 .279 .631 r
.10792 .45127 .10783 .45654 .11643 .45755 .11657 .45222 Mtetra
.36 .277 .625 r
.11657 .45222 .11643 .45755 .12513 .45855 .1253 .45318 Mtetra
.364 .275 .62 r
.1253 .45318 .12513 .45855 .13392 .45957 .13414 .45414 Mtetra
.369 .273 .614 r
.13414 .45414 .13392 .45957 .14282 .46058 .14307 .4551 Mtetra
.375 .273 .609 r
.14307 .4551 .14282 .46058 .15181 .46159 .1521 .45606 Mtetra
.381 .272 .603 r
.1521 .45606 .15181 .46159 .16091 .4626 .16124 .45702 Mtetra
.388 .272 .598 r
.16124 .45702 .16091 .4626 .17012 .46361 .17048 .45798 Mtetra
.395 .272 .593 r
.17048 .45798 .17012 .46361 .17944 .46461 .17983 .45892 Mtetra
.403 .273 .588 r
.17983 .45892 .17944 .46461 .18888 .4656 .1893 .45986 Mtetra
.411 .274 .582 r
.1893 .45986 .18888 .4656 .19842 .46659 .19887 .46079 Mtetra
.419 .275 .577 r
.19887 .46079 .19842 .46659 .20808 .46756 .20856 .46171 Mtetra
.428 .276 .571 r
.20856 .46171 .20808 .46756 .21785 .46852 .21836 .46261 Mtetra
.437 .277 .566 r
.21836 .46261 .21785 .46852 .22775 .46947 .22827 .4635 Mtetra
.446 .279 .56 r
.22827 .4635 .22775 .46947 .23775 .4704 .2383 .46437 Mtetra
.456 .281 .554 r
.2383 .46437 .23775 .4704 .24787 .47131 .24845 .46522 Mtetra
.466 .283 .548 r
.24845 .46522 .24787 .47131 .25811 .4722 .2587 .46604 Mtetra
.476 .285 .541 r
.2587 .46604 .25811 .4722 .26846 .47307 .26907 .46685 Mtetra
.486 .287 .534 r
.26907 .46685 .26846 .47307 .27893 .47391 .27955 .46762 Mtetra
.496 .288 .527 r
.27955 .46762 .27893 .47391 .2895 .47472 .29014 .46837 Mtetra
.507 .29 .52 r
.29014 .46837 .2895 .47472 .30019 .4755 .30083 .46909 Mtetra
.517 .292 .512 r
.30083 .46909 .30019 .4755 .31098 .47625 .31163 .46977 Mtetra
.527 .294 .504 r
.31163 .46977 .31098 .47625 .32187 .47697 .32252 .47042 Mtetra
.538 .295 .495 r
.32252 .47042 .32187 .47697 .33286 .47765 .33351 .47103 Mtetra
.548 .296 .487 r
.33351 .47103 .33286 .47765 .34395 .4783 .34459 .47161 Mtetra
.557 .297 .477 r
.34459 .47161 .34395 .4783 .35512 .47891 .35575 .47214 Mtetra
.567 .298 .468 r
.35575 .47214 .35512 .47891 .36638 .47947 .367 .47264 Mtetra
.576 .298 .458 r
.367 .47264 .36638 .47947 .37772 .48 .37832 .47309 Mtetra
.584 .298 .448 r
.37832 .47309 .37772 .48 .38914 .48048 .3897 .4735 Mtetra
.592 .298 .438 r
.3897 .4735 .38914 .48048 .40062 .48092 .40115 .47387 Mtetra
.6 .298 .428 r
.40115 .47387 .40062 .48092 .41216 .48132 .41265 .47419 Mtetra
.608 .297 .418 r
.41265 .47419 .41216 .48132 .42375 .48167 .4242 .47447 Mtetra
.615 .297 .408 r
.4242 .47447 .42375 .48167 .4354 .48197 .4358 .47471 Mtetra
.622 .297 .398 r
.4358 .47471 .4354 .48197 .44709 .48222 .44743 .47489 Mtetra
.63 .297 .389 r
.44743 .47489 .44709 .48222 .45881 .48242 .45909 .47503 Mtetra
.638 .298 .379 r
.45909 .47503 .45881 .48242 .47056 .48255 .47077 .47511 Mtetra
.647 .3 .371 r
.47077 .47511 .47056 .48255 .48233 .48262 .48246 .47512 Mtetra
.657 .304 .362 r
.48246 .47512 .48233 .48262 .49411 .48261 .49415 .47507 Mtetra
.645 .289 .354 r
.49415 .47507 .49411 .48261 .50589 .48261 .50585 .47507 Mtetra
.936 .759 .636 r
.90063 .45032 .90068 .45554 .9091 .45455 .9091 .44937 Mtetra
.935 .752 .63 r
.89208 .45127 .89217 .45654 .90068 .45554 .90063 .45032 Mtetra
.934 .745 .624 r
.88343 .45222 .88357 .45755 .89217 .45654 .89208 .45127 Mtetra
.932 .738 .619 r
.8747 .45318 .87487 .45855 .88357 .45755 .88343 .45222 Mtetra
.929 .731 .613 r
.86586 .45414 .86608 .45957 .87487 .45855 .8747 .45318 Mtetra
.927 .723 .608 r
.85693 .4551 .85718 .46058 .86608 .45957 .86586 .45414 Mtetra
.924 .715 .602 r
.8479 .45606 .84819 .46159 .85718 .46058 .85693 .4551 Mtetra
.921 .707 .597 r
.83876 .45702 .83909 .4626 .84819 .46159 .8479 .45606 Mtetra
.917 .698 .591 r
.82952 .45798 .82988 .46361 .83909 .4626 .83876 .45702 Mtetra
.913 .689 .586 r
.82017 .45892 .82056 .46461 .82988 .46361 .82952 .45798 Mtetra
.908 .68 .581 r
.8107 .45986 .81112 .4656 .82056 .46461 .82017 .45892 Mtetra
.904 .67 .575 r
.80113 .46079 .80158 .46659 .81112 .4656 .8107 .45986 Mtetra
.899 .66 .569 r
.79144 .46171 .79192 .46756 .80158 .46659 .80113 .46079 Mtetra
.893 .65 .564 r
.78164 .46261 .78215 .46852 .79192 .46756 .79144 .46171 Mtetra
.887 .639 .558 r
.77173 .4635 .77225 .46947 .78215 .46852 .78164 .46261 Mtetra
.88 .628 .552 r
.7617 .46437 .76225 .4704 .77225 .46947 .77173 .4635 Mtetra
.874 .616 .546 r
.75155 .46522 .75213 .47131 .76225 .4704 .7617 .46437 Mtetra
.866 .603 .539 r
.7413 .46604 .74189 .4722 .75213 .47131 .75155 .46522 Mtetra
.858 .591 .532 r
.73093 .46685 .73154 .47307 .74189 .4722 .7413 .46604 Mtetra
.85 .577 .525 r
.72045 .46762 .72107 .47391 .73154 .47307 .73093 .46685 Mtetra
.841 .564 .518 r
.70986 .46837 .7105 .47472 .72107 .47391 .72045 .46762 Mtetra
.832 .549 .51 r
.69917 .46909 .69981 .4755 .7105 .47472 .70986 .46837 Mtetra
.823 .535 .502 r
.68837 .46977 .68902 .47625 .69981 .4755 .69917 .46909 Mtetra
.813 .52 .494 r
.67748 .47042 .67813 .47697 .68902 .47625 .68837 .46977 Mtetra
.802 .504 .485 r
.66649 .47103 .66714 .47765 .67813 .47697 .67748 .47042 Mtetra
.791 .488 .476 r
.65541 .47161 .65605 .4783 .66714 .47765 .66649 .47103 Mtetra
.78 .472 .467 r
.64425 .47214 .64488 .47891 .65605 .4783 .65541 .47161 Mtetra
.769 .456 .457 r
.633 .47264 .63362 .47947 .64488 .47891 .64425 .47214 Mtetra
.758 .44 .447 r
.62168 .47309 .62228 .48 .63362 .47947 .633 .47264 Mtetra
.747 .424 .437 r
.6103 .4735 .61086 .48048 .62228 .48 .62168 .47309 Mtetra
.735 .408 .427 r
.59885 .47387 .59938 .48092 .61086 .48048 .6103 .4735 Mtetra
.724 .392 .417 r
.58735 .47419 .58784 .48132 .59938 .48092 .59885 .47387 Mtetra
.712 .376 .407 r
.5758 .47447 .57625 .48167 .58784 .48132 .58735 .47419 Mtetra
.701 .361 .398 r
.5642 .47471 .5646 .48197 .57625 .48167 .5758 .47447 Mtetra
.689 .345 .388 r
.55257 .47489 .55291 .48222 .5646 .48197 .5642 .47471 Mtetra
.677 .33 .379 r
.54091 .47503 .54119 .48242 .55291 .48222 .55257 .47489 Mtetra
.664 .314 .37 r
.52923 .47511 .52944 .48255 .54119 .48242 .54091 .47503 Mtetra
.65 .298 .362 r
.51754 .47512 .51767 .48262 .52944 .48255 .52923 .47511 Mtetra
.634 .281 .354 r
.50585 .47507 .50589 .48261 .51767 .48262 .51754 .47512 Mtetra
.359 .293 .646 r
.0909 .44419 .0909 .44937 .09937 .45032 .09941 .44509 Mtetra
.362 .29 .64 r
.09941 .44509 .09937 .45032 .10792 .45127 .10801 .44599 Mtetra
.365 .287 .634 r
.10801 .44599 .10792 .45127 .11657 .45222 .1167 .4469 Mtetra
.369 .285 .629 r
.1167 .4469 .11657 .45222 .1253 .45318 .12547 .44781 Mtetra
.374 .283 .623 r
.12547 .44781 .1253 .45318 .13414 .45414 .13434 .44873 Mtetra
.379 .282 .618 r
.13434 .44873 .13414 .45414 .14307 .4551 .14331 .44964 Mtetra
.385 .281 .612 r
.14331 .44964 .14307 .4551 .1521 .45606 .15238 .45055 Mtetra
.391 .281 .607 r
.15238 .45055 .1521 .45606 .16124 .45702 .16155 .45146 Mtetra
.398 .281 .602 r
.16155 .45146 .16124 .45702 .17048 .45798 .17083 .45236 Mtetra
.405 .281 .597 r
.17083 .45236 .17048 .45798 .17983 .45892 .18021 .45325 Mtetra
.413 .282 .592 r
.18021 .45325 .17983 .45892 .1893 .45986 .18971 .45414 Mtetra
.421 .283 .586 r
.18971 .45414 .1893 .45986 .19887 .46079 .19931 .45502 Mtetra
.429 .284 .581 r
.19931 .45502 .19887 .46079 .20856 .46171 .20903 .45588 Mtetra
.438 .285 .576 r
.20903 .45588 .20856 .46171 .21836 .46261 .21885 .45673 Mtetra
.447 .287 .57 r
.21885 .45673 .21836 .46261 .22827 .4635 .22879 .45756 Mtetra
.457 .289 .564 r
.22879 .45756 .22827 .4635 .2383 .46437 .23884 .45837 Mtetra
.467 .291 .558 r
.23884 .45837 .2383 .46437 .24845 .46522 .24901 .45916 Mtetra
.477 .293 .552 r
.24901 .45916 .24845 .46522 .2587 .46604 .25928 .45993 Mtetra
.487 .295 .545 r
.25928 .45993 .2587 .46604 .26907 .46685 .26967 .46067 Mtetra
.497 .297 .539 r
.26967 .46067 .26907 .46685 .27955 .46762 .28016 .46138 Mtetra
.508 .299 .532 r
.28016 .46138 .27955 .46762 .29014 .46837 .29076 .46207 Mtetra
.519 .301 .524 r
.29076 .46207 .29014 .46837 .30083 .46909 .30146 .46272 Mtetra
.529 .303 .516 r
.30146 .46272 .30083 .46909 .31163 .46977 .31226 .46334 Mtetra
.54 .305 .508 r
.31226 .46334 .31163 .46977 .32252 .47042 .32316 .46392 Mtetra
.55 .307 .5 r
.32316 .46392 .32252 .47042 .33351 .47103 .33414 .46447 Mtetra
.56 .308 .491 r
.33414 .46447 .33351 .47103 .34459 .47161 .34522 .46498 Mtetra
.57 .309 .482 r
.34522 .46498 .34459 .47161 .35575 .47214 .35637 .46545 Mtetra
.58 .31 .472 r
.35637 .46545 .35575 .47214 .367 .47264 .3676 .46587 Mtetra
.589 .31 .462 r
.3676 .46587 .367 .47264 .37832 .47309 .3789 .46626 Mtetra
.597 .31 .452 r
.3789 .46626 .37832 .47309 .3897 .4735 .39026 .4666 Mtetra
.605 .31 .442 r
.39026 .4666 .3897 .4735 .40115 .47387 .40167 .4669 Mtetra
.613 .309 .431 r
.40167 .4669 .40115 .47387 .41265 .47419 .41314 .46716 Mtetra
.62 .308 .421 r
.41314 .46716 .41265 .47419 .4242 .47447 .42464 .46737 Mtetra
.627 .308 .411 r
.42464 .46737 .4242 .47447 .4358 .47471 .43619 .46755 Mtetra
.633 .307 .401 r
.43619 .46755 .4358 .47471 .44743 .47489 .44776 .46767 Mtetra
.64 .307 .391 r
.44776 .46767 .44743 .47489 .45909 .47503 .45935 .46775 Mtetra
.648 .308 .382 r
.45935 .46775 .45909 .47503 .47077 .47511 .47096 .46778 Mtetra
.657 .31 .373 r
.47096 .46778 .47077 .47511 .48246 .47512 .48258 .46775 Mtetra
.666 .313 .365 r
.48258 .46775 .48246 .47512 .49415 .47507 .4942 .46765 Mtetra
.646 .292 .357 r
.4942 .46765 .49415 .47507 .50585 .47507 .5058 .46765 Mtetra
.933 .756 .64 r
.90059 .44509 .90063 .45032 .9091 .44937 .9091 .44419 Mtetra
.931 .749 .634 r
.89199 .44599 .89208 .45127 .90063 .45032 .90059 .44509 Mtetra
.93 .742 .628 r
.8833 .4469 .88343 .45222 .89208 .45127 .89199 .44599 Mtetra
.928 .735 .622 r
.87453 .44781 .8747 .45318 .88343 .45222 .8833 .4469 Mtetra
.926 .728 .617 r
.86566 .44873 .86586 .45414 .8747 .45318 .87453 .44781 Mtetra
.923 .72 .611 r
.85669 .44964 .85693 .4551 .86586 .45414 .86566 .44873 Mtetra
.92 .712 .606 r
.84762 .45055 .8479 .45606 .85693 .4551 .85669 .44964 Mtetra
.917 .704 .6 r
.83845 .45146 .83876 .45702 .8479 .45606 .84762 .45055 Mtetra
.913 .696 .595 r
.82917 .45236 .82952 .45798 .83876 .45702 .83845 .45146 Mtetra
.909 .687 .59 r
.81979 .45325 .82017 .45892 .82952 .45798 .82917 .45236 Mtetra
.904 .677 .584 r
.81029 .45414 .8107 .45986 .82017 .45892 .81979 .45325 Mtetra
.899 .668 .579 r
.80069 .45502 .80113 .46079 .8107 .45986 .81029 .45414 Mtetra
.894 .658 .573 r
.79097 .45588 .79144 .46171 .80113 .46079 .80069 .45502 Mtetra
.888 .647 .568 r
.78115 .45673 .78164 .46261 .79144 .46171 .79097 .45588 Mtetra
.882 .636 .562 r
.77121 .45756 .77173 .4635 .78164 .46261 .78115 .45673 Mtetra
.875 .625 .556 r
.76116 .45837 .7617 .46437 .77173 .4635 .77121 .45756 Mtetra
.868 .613 .55 r
.75099 .45916 .75155 .46522 .7617 .46437 .76116 .45837 Mtetra
.861 .6 .543 r
.74072 .45993 .7413 .46604 .75155 .46522 .75099 .45916 Mtetra
.853 .587 .537 r
.73033 .46067 .73093 .46685 .7413 .46604 .74072 .45993 Mtetra
.844 .574 .529 r
.71984 .46138 .72045 .46762 .73093 .46685 .73033 .46067 Mtetra
.835 .56 .522 r
.70924 .46207 .70986 .46837 .72045 .46762 .71984 .46138 Mtetra
.826 .545 .514 r
.69854 .46272 .69917 .46909 .70986 .46837 .70924 .46207 Mtetra
.816 .53 .506 r
.68774 .46334 .68837 .46977 .69917 .46909 .69854 .46272 Mtetra
.805 .515 .498 r
.67684 .46392 .67748 .47042 .68837 .46977 .68774 .46334 Mtetra
.795 .499 .489 r
.66586 .46447 .66649 .47103 .67748 .47042 .67684 .46392 Mtetra
.783 .483 .48 r
.65478 .46498 .65541 .47161 .66649 .47103 .66586 .46447 Mtetra
.772 .467 .471 r
.64363 .46545 .64425 .47214 .65541 .47161 .65478 .46498 Mtetra
.761 .451 .461 r
.6324 .46587 .633 .47264 .64425 .47214 .64363 .46545 Mtetra
.749 .434 .451 r
.6211 .46626 .62168 .47309 .633 .47264 .6324 .46587 Mtetra
.737 .418 .441 r
.60974 .4666 .6103 .4735 .62168 .47309 .6211 .46626 Mtetra
.726 .402 .43 r
.59833 .4669 .59885 .47387 .6103 .4735 .60974 .4666 Mtetra
.714 .386 .42 r
.58686 .46716 .58735 .47419 .59885 .47387 .59833 .4669 Mtetra
.703 .37 .41 r
.57536 .46737 .5758 .47447 .58735 .47419 .58686 .46716 Mtetra
.691 .354 .4 r
.56381 .46755 .5642 .47471 .5758 .47447 .57536 .46737 Mtetra
.68 .339 .391 r
.55224 .46767 .55257 .47489 .5642 .47471 .56381 .46755 Mtetra
.668 .324 .382 r
.54065 .46775 .54091 .47503 .55257 .47489 .55224 .46767 Mtetra
.656 .309 .373 r
.52904 .46778 .52923 .47511 .54091 .47503 .54065 .46775 Mtetra
.642 .293 .365 r
.51742 .46775 .51754 .47512 .52923 .47511 .52904 .46778 Mtetra
.627 .277 .357 r
.5058 .46765 .50585 .47507 .51754 .47512 .51742 .46775 Mtetra
.369 .301 .649 r
.0909 .43901 .0909 .44419 .09941 .44509 .09946 .43987 Mtetra
.372 .298 .643 r
.09946 .43987 .09941 .44509 .10801 .44599 .1081 .44073 Mtetra
.375 .295 .637 r
.1081 .44073 .10801 .44599 .1167 .4469 .11682 .44159 Mtetra
.379 .293 .632 r
.11682 .44159 .1167 .4469 .12547 .44781 .12564 .44245 Mtetra
.384 .291 .626 r
.12564 .44245 .12547 .44781 .13434 .44873 .13455 .44332 Mtetra
.389 .29 .621 r
.13455 .44332 .13434 .44873 .14331 .44964 .14355 .44418 Mtetra
.394 .289 .616 r
.14355 .44418 .14331 .44964 .15238 .45055 .15266 .44505 Mtetra
.401 .289 .611 r
.15266 .44505 .15238 .45055 .16155 .45146 .16186 .4459 Mtetra
.407 .289 .606 r
.16186 .4459 .16155 .45146 .17083 .45236 .17117 .44676 Mtetra
.415 .29 .6 r
.17117 .44676 .17083 .45236 .18021 .45325 .18059 .4476 Mtetra
.422 .29 .595 r
.18059 .4476 .18021 .45325 .18971 .45414 .19011 .44844 Mtetra
.43 .292 .59 r
.19011 .44844 .18971 .45414 .19931 .45502 .19974 .44926 Mtetra
.439 .293 .585 r
.19974 .44926 .19931 .45502 .20903 .45588 .20948 .45007 Mtetra
.448 .295 .58 r
.20948 .45007 .20903 .45588 .21885 .45673 .21934 .45087 Mtetra
.457 .296 .574 r
.21934 .45087 .21885 .45673 .22879 .45756 .2293 .45164 Mtetra
.467 .299 .568 r
.2293 .45164 .22879 .45756 .23884 .45837 .23937 .4524 Mtetra
.477 .301 .562 r
.23937 .4524 .23884 .45837 .24901 .45916 .24956 .45314 Mtetra
.487 .303 .556 r
.24956 .45314 .24901 .45916 .25928 .45993 .25985 .45385 Mtetra
.498 .305 .55 r
.25985 .45385 .25928 .45993 .26967 .46067 .27025 .45453 Mtetra
.509 .308 .543 r
.27025 .45453 .26967 .46067 .28016 .46138 .28076 .45519 Mtetra
.52 .31 .536 r
.28076 .45519 .28016 .46138 .29076 .46207 .29137 .45581 Mtetra
.53 .313 .528 r
.29137 .45581 .29076 .46207 .30146 .46272 .30208 .45641 Mtetra
.541 .315 .521 r
.30208 .45641 .30146 .46272 .31226 .46334 .31288 .45696 Mtetra
.552 .317 .513 r
.31288 .45696 .31226 .46334 .32316 .46392 .32378 .45749 Mtetra
.563 .319 .504 r
.32378 .45749 .32316 .46392 .33414 .46447 .33476 .45797 Mtetra
.573 .32 .495 r
.33476 .45797 .33414 .46447 .34522 .46498 .34583 .45841 Mtetra
.583 .321 .486 r
.34583 .45841 .34522 .46498 .35637 .46545 .35697 .45882 Mtetra
.592 .322 .476 r
.35697 .45882 .35637 .46545 .3676 .46587 .36819 .45918 Mtetra
.601 .322 .466 r
.36819 .45918 .3676 .46587 .3789 .46626 .37947 .4595 Mtetra
.61 .322 .455 r
.37947 .4595 .3789 .46626 .39026 .4666 .3908 .45978 Mtetra
.618 .322 .445 r
.3908 .45978 .39026 .4666 .40167 .4669 .40218 .46002 Mtetra
.625 .321 .434 r
.40218 .46002 .40167 .4669 .41314 .46716 .41361 .46021 Mtetra
.632 .32 .424 r
.41361 .46021 .41314 .46716 .42464 .46737 .42507 .46037 Mtetra
.638 .319 .414 r
.42507 .46037 .42464 .46737 .43619 .46755 .43657 .46048 Mtetra
.644 .317 .404 r
.43657 .46048 .43619 .46755 .44776 .46767 .44808 .46055 Mtetra
.651 .317 .394 r
.44808 .46055 .44776 .46767 .45935 .46775 .45961 .46058 Mtetra
.658 .317 .385 r
.45961 .46058 .45935 .46775 .47096 .46778 .47116 .46056 Mtetra
.666 .319 .376 r
.47116 .46056 .47096 .46778 .48258 .46775 .4827 .46049 Mtetra
.675 .322 .368 r
.4827 .46049 .48258 .46775 .4942 .46765 .49424 .46036 Mtetra
.647 .295 .361 r
.49424 .46036 .4942 .46765 .5058 .46765 .50576 .46036 Mtetra
.929 .753 .643 r
.90054 .43987 .90059 .44509 .9091 .44419 .9091 .43901 Mtetra
.927 .746 .637 r
.8919 .44073 .89199 .44599 .90059 .44509 .90054 .43987 Mtetra
.926 .74 .631 r
.88318 .44159 .8833 .4469 .89199 .44599 .8919 .44073 Mtetra
.924 .733 .625 r
.87436 .44245 .87453 .44781 .8833 .4469 .88318 .44159 Mtetra
.922 .725 .62 r
.86545 .44332 .86566 .44873 .87453 .44781 .87436 .44245 Mtetra
.919 .718 .615 r
.85645 .44418 .85669 .44964 .86566 .44873 .86545 .44332 Mtetra
.916 .71 .609 r
.84734 .44505 .84762 .45055 .85669 .44964 .85645 .44418 Mtetra
.913 .702 .604 r
.83814 .4459 .83845 .45146 .84762 .45055 .84734 .44505 Mtetra
.909 .693 .599 r
.82883 .44676 .82917 .45236 .83845 .45146 .83814 .4459 Mtetra
.905 .684 .594 r
.81941 .4476 .81979 .45325 .82917 .45236 .82883 .44676 Mtetra
.9 .675 .588 r
.80989 .44844 .81029 .45414 .81979 .45325 .81941 .4476 Mtetra
.895 .665 .583 r
.80026 .44926 .80069 .45502 .81029 .45414 .80989 .44844 Mtetra
.89 .655 .577 r
.79052 .45007 .79097 .45588 .80069 .45502 .80026 .44926 Mtetra
.884 .644 .572 r
.78066 .45087 .78115 .45673 .79097 .45588 .79052 .45007 Mtetra
.877 .633 .566 r
.7707 .45164 .77121 .45756 .78115 .45673 .78066 .45087 Mtetra
.87 .622 .56 r
.76063 .4524 .76116 .45837 .77121 .45756 .7707 .45164 Mtetra
.863 .61 .554 r
.75044 .45314 .75099 .45916 .76116 .45837 .76063 .4524 Mtetra
.855 .597 .548 r
.74015 .45385 .74072 .45993 .75099 .45916 .75044 .45314 Mtetra
.847 .584 .541 r
.72975 .45453 .73033 .46067 .74072 .45993 .74015 .45385 Mtetra
.838 .57 .534 r
.71924 .45519 .71984 .46138 .73033 .46067 .72975 .45453 Mtetra
.829 .556 .526 r
.70863 .45581 .70924 .46207 .71984 .46138 .71924 .45519 Mtetra
.819 .541 .519 r
.69792 .45641 .69854 .46272 .70924 .46207 .70863 .45581 Mtetra
.809 .526 .511 r
.68712 .45696 .68774 .46334 .69854 .46272 .69792 .45641 Mtetra
.798 .511 .502 r
.67622 .45749 .67684 .46392 .68774 .46334 .68712 .45696 Mtetra
.787 .495 .493 r
.66524 .45797 .66586 .46447 .67684 .46392 .67622 .45749 Mtetra
.775 .478 .484 r
.65417 .45841 .65478 .46498 .66586 .46447 .66524 .45797 Mtetra
.764 .462 .474 r
.64303 .45882 .64363 .46545 .65478 .46498 .65417 .45841 Mtetra
.752 .445 .465 r
.63181 .45918 .6324 .46587 .64363 .46545 .64303 .45882 Mtetra
.74 .428 .454 r
.62053 .4595 .6211 .46626 .6324 .46587 .63181 .45918 Mtetra
.728 .412 .444 r
.6092 .45978 .60974 .4666 .6211 .46626 .62053 .4595 Mtetra
.716 .395 .434 r
.59782 .46002 .59833 .4669 .60974 .4666 .6092 .45978 Mtetra
.705 .379 .423 r
.58639 .46021 .58686 .46716 .59833 .4669 .59782 .46002 Mtetra
.693 .363 .413 r
.57493 .46037 .57536 .46737 .58686 .46716 .58639 .46021 Mtetra
.682 .348 .403 r
.56343 .46048 .56381 .46755 .57536 .46737 .57493 .46037 Mtetra
.671 .333 .394 r
.55192 .46055 .55224 .46767 .56381 .46755 .56343 .46048 Mtetra
.659 .319 .385 r
.54039 .46058 .54065 .46775 .55224 .46767 .55192 .46055 Mtetra
.648 .304 .376 r
.52884 .46056 .52904 .46778 .54065 .46775 .54039 .46058 Mtetra
.635 .289 .368 r
.5173 .46049 .51742 .46775 .52904 .46778 .52884 .46056 Mtetra
.62 .273 .361 r
.50576 .46036 .5058 .46765 .51742 .46775 .5173 .46049 Mtetra
.379 .309 .652 r
.0909 .43384 .0909 .43901 .09946 .43987 .0995 .43465 Mtetra
.381 .306 .646 r
.0995 .43465 .09946 .43987 .1081 .44073 .10818 .43546 Mtetra
.385 .303 .641 r
.10818 .43546 .1081 .44073 .11682 .44159 .11695 .43628 Mtetra
.388 .301 .635 r
.11695 .43628 .11682 .44159 .12564 .44245 .1258 .4371 Mtetra
.393 .299 .63 r
.1258 .4371 .12564 .44245 .13455 .44332 .13475 .43792 Mtetra
.398 .298 .624 r
.13475 .43792 .13455 .44332 .14355 .44418 .14379 .43874 Mtetra
.404 .298 .619 r
.14379 .43874 .14355 .44418 .15266 .44505 .15293 .43955 Mtetra
.41 .297 .614 r
.15293 .43955 .15266 .44505 .16186 .4459 .16217 .44037 Mtetra
.417 .298 .609 r
.16217 .44037 .16186 .4459 .17117 .44676 .17151 .44117 Mtetra
.424 .298 .604 r
.17151 .44117 .17117 .44676 .18059 .4476 .18095 .44197 Mtetra
.432 .299 .599 r
.18095 .44197 .18059 .4476 .19011 .44844 .19051 .44275 Mtetra
.44 .3 .594 r
.19051 .44275 .19011 .44844 .19974 .44926 .20017 .44353 Mtetra
.449 .302 .589 r
.20017 .44353 .19974 .44926 .20948 .45007 .20993 .44429 Mtetra
.458 .304 .583 r
.20993 .44429 .20948 .45007 .21934 .45087 .21981 .44503 Mtetra
.467 .306 .578 r
.21981 .44503 .21934 .45087 .2293 .45164 .2298 .44576 Mtetra
.477 .308 .572 r
.2298 .44576 .2293 .45164 .23937 .4524 .23989 .44646 Mtetra
.488 .311 .567 r
.23989 .44646 .23937 .4524 .24956 .45314 .2501 .44715 Mtetra
.498 .313 .56 r
.2501 .44715 .24956 .45314 .25985 .45385 .26041 .4478 Mtetra
.509 .316 .554 r
.26041 .4478 .25985 .45385 .27025 .45453 .27082 .44843 Mtetra
.52 .318 .547 r
.27082 .44843 .27025 .45453 .28076 .45519 .28134 .44903 Mtetra
.531 .321 .54 r
.28134 .44903 .28076 .45519 .29137 .45581 .29196 .4496 Mtetra
.542 .324 .533 r
.29196 .4496 .29137 .45581 .30208 .45641 .30268 .45014 Mtetra
.553 .326 .525 r
.30268 .45014 .30208 .45641 .31288 .45696 .31349 .45064 Mtetra
.564 .328 .517 r
.31349 .45064 .31288 .45696 .32378 .45749 .32439 .4511 Mtetra
.575 .33 .508 r
.32439 .4511 .32378 .45749 .33476 .45797 .33537 .45153 Mtetra
.585 .332 .499 r
.33537 .45153 .33476 .45797 .34583 .45841 .34643 .45191 Mtetra
.596 .333 .49 r
.34643 .45191 .34583 .45841 .35697 .45882 .35757 .45225 Mtetra
.605 .334 .48 r
.35757 .45225 .35697 .45882 .36819 .45918 .36877 .45256 Mtetra
.614 .334 .47 r
.36877 .45256 .36819 .45918 .37947 .4595 .38002 .45282 Mtetra
.623 .334 .459 r
.38002 .45282 .37947 .4595 .3908 .45978 .39133 .45304 Mtetra
.63 .334 .448 r
.39133 .45304 .3908 .45978 .40218 .46002 .40269 .45321 Mtetra
.637 .332 .438 r
.40269 .45321 .40218 .46002 .41361 .46021 .41408 .45335 Mtetra
.644 .331 .427 r
.41408 .45335 .41361 .46021 .42507 .46037 .4255 .45345 Mtetra
.65 .329 .416 r
.4255 .45345 .42507 .46037 .43657 .46048 .43694 .45351 Mtetra
.655 .328 .406 r
.43694 .45351 .43657 .46048 .44808 .46055 .4484 .45353 Mtetra
.661 .327 .396 r
.4484 .45353 .44808 .46055 .45961 .46058 .45987 .45351 Mtetra
.667 .326 .387 r
.45987 .45351 .45961 .46058 .47116 .46056 .47134 .45345 Mtetra
.674 .327 .379 r
.47134 .45345 .47116 .46056 .4827 .46049 .48282 .45335 Mtetra
.683 .33 .371 r
.48282 .45335 .4827 .46049 .49424 .46036 .49428 .45318 Mtetra
.648 .298 .364 r
.49428 .45318 .49424 .46036 .50576 .46036 .50572 .45318 Mtetra
.925 .75 .646 r
.9005 .43465 .90054 .43987 .9091 .43901 .9091 .43384 Mtetra
.924 .743 .64 r
.89182 .43546 .8919 .44073 .90054 .43987 .9005 .43465 Mtetra
.922 .737 .634 r
.88305 .43628 .88318 .44159 .8919 .44073 .89182 .43546 Mtetra
.92 .73 .629 r
.8742 .4371 .87436 .44245 .88318 .44159 .88305 .43628 Mtetra
.918 .723 .623 r
.86525 .43792 .86545 .44332 .87436 .44245 .8742 .4371 Mtetra
.915 .715 .618 r
.85621 .43874 .85645 .44418 .86545 .44332 .86525 .43792 Mtetra
.912 .707 .613 r
.84707 .43955 .84734 .44505 .85645 .44418 .85621 .43874 Mtetra
.909 .699 .608 r
.83783 .44037 .83814 .4459 .84734 .44505 .84707 .43955 Mtetra
.905 .691 .602 r
.82849 .44117 .82883 .44676 .83814 .4459 .83783 .44037 Mtetra
.9 .682 .597 r
.81905 .44197 .81941 .4476 .82883 .44676 .82849 .44117 Mtetra
.896 .673 .592 r
.80949 .44275 .80989 .44844 .81941 .4476 .81905 .44197 Mtetra
.891 .663 .587 r
.79983 .44353 .80026 .44926 .80989 .44844 .80949 .44275 Mtetra
.885 .653 .581 r
.79007 .44429 .79052 .45007 .80026 .44926 .79983 .44353 Mtetra
.879 .642 .576 r
.78019 .44503 .78066 .45087 .79052 .45007 .79007 .44429 Mtetra
.872 .631 .57 r
.7702 .44576 .7707 .45164 .78066 .45087 .78019 .44503 Mtetra
.865 .619 .564 r
.76011 .44646 .76063 .4524 .7707 .45164 .7702 .44576 Mtetra
.858 .607 .558 r
.7499 .44715 .75044 .45314 .76063 .4524 .76011 .44646 Mtetra
.85 .594 .552 r
.73959 .4478 .74015 .45385 .75044 .45314 .7499 .44715 Mtetra
.841 .581 .545 r
.72918 .44843 .72975 .45453 .74015 .45385 .73959 .4478 Mtetra
.832 .567 .538 r
.71866 .44903 .71924 .45519 .72975 .45453 .72918 .44843 Mtetra
.822 .552 .531 r
.70804 .4496 .70863 .45581 .71924 .45519 .71866 .44903 Mtetra
.812 .538 .523 r
.69732 .45014 .69792 .45641 .70863 .45581 .70804 .4496 Mtetra
.801 .522 .515 r
.68651 .45064 .68712 .45696 .69792 .45641 .69732 .45014 Mtetra
.79 .506 .506 r
.67561 .4511 .67622 .45749 .68712 .45696 .68651 .45064 Mtetra
.779 .49 .498 r
.66463 .45153 .66524 .45797 .67622 .45749 .67561 .4511 Mtetra
.767 .473 .488 r
.65357 .45191 .65417 .45841 .66524 .45797 .66463 .45153 Mtetra
.755 .456 .478 r
.64243 .45225 .64303 .45882 .65417 .45841 .65357 .45191 Mtetra
.743 .439 .468 r
.63123 .45256 .63181 .45918 .64303 .45882 .64243 .45225 Mtetra
.731 .422 .458 r
.61998 .45282 .62053 .4595 .63181 .45918 .63123 .45256 Mtetra
.719 .405 .448 r
.60867 .45304 .6092 .45978 .62053 .4595 .61998 .45282 Mtetra
.707 .389 .437 r
.59731 .45321 .59782 .46002 .6092 .45978 .60867 .45304 Mtetra
.695 .373 .426 r
.58592 .45335 .58639 .46021 .59782 .46002 .59731 .45321 Mtetra
.684 .357 .416 r
.5745 .45345 .57493 .46037 .58639 .46021 .58592 .45335 Mtetra
.673 .342 .406 r
.56306 .45351 .56343 .46048 .57493 .46037 .5745 .45345 Mtetra
.662 .327 .396 r
.5516 .45353 .55192 .46055 .56343 .46048 .56306 .45351 Mtetra
.651 .313 .387 r
.54013 .45351 .54039 .46058 .55192 .46055 .5516 .45353 Mtetra
.64 .299 .379 r
.52866 .45345 .52884 .46056 .54039 .46058 .54013 .45351 Mtetra
.628 .285 .371 r
.51718 .45335 .5173 .46049 .52884 .46056 .52866 .45345 Mtetra
.614 .27 .364 r
.50572 .45318 .50576 .46036 .5173 .46049 .51718 .45335 Mtetra
.388 .317 .655 r
.0909 .42866 .0909 .43384 .0995 .43465 .09954 .42943 Mtetra
.391 .314 .649 r
.09954 .42943 .0995 .43465 .10818 .43546 .10827 .4302 Mtetra
.394 .311 .644 r
.10827 .4302 .10818 .43546 .11695 .43628 .11707 .43097 Mtetra
.398 .309 .638 r
.11707 .43097 .11695 .43628 .1258 .4371 .12596 .43175 Mtetra
.402 .307 .633 r
.12596 .43175 .1258 .4371 .13475 .43792 .13494 .43253 Mtetra
.407 .306 .628 r
.13494 .43253 .13475 .43792 .14379 .43874 .14402 .4333 Mtetra
.413 .306 .623 r
.14402 .4333 .14379 .43874 .15293 .43955 .15319 .43407 Mtetra
.419 .306 .618 r
.15319 .43407 .15293 .43955 .16217 .44037 .16246 .43484 Mtetra
.426 .306 .613 r
.16246 .43484 .16217 .44037 .17151 .44117 .17184 .4356 Mtetra
.433 .307 .608 r
.17184 .4356 .17151 .44117 .18095 .44197 .18131 .43635 Mtetra
.441 .308 .603 r
.18131 .43635 .18095 .44197 .19051 .44275 .19089 .43709 Mtetra
.449 .309 .598 r
.19089 .43709 .19051 .44275 .20017 .44353 .20058 .43782 Mtetra
.458 .311 .593 r
.20058 .43782 .20017 .44353 .20993 .44429 .21037 .43853 Mtetra
.468 .313 .587 r
.21037 .43853 .20993 .44429 .21981 .44503 .22028 .43922 Mtetra
.477 .315 .582 r
.22028 .43922 .21981 .44503 .2298 .44576 .23029 .4399 Mtetra
.487 .318 .576 r
.23029 .4399 .2298 .44576 .23989 .44646 .2404 .44056 Mtetra
.498 .32 .571 r
.2404 .44056 .23989 .44646 .2501 .44715 .25062 .44119 Mtetra
.509 .323 .565 r
.25062 .44119 .2501 .44715 .26041 .4478 .26095 .44179 Mtetra
.52 .326 .558 r
.26095 .44179 .26041 .4478 .27082 .44843 .27138 .44237 Mtetra
.531 .329 .552 r
.27138 .44237 .27082 .44843 .28134 .44903 .28192 .44292 Mtetra
.542 .332 .545 r
.28192 .44292 .28134 .44903 .29196 .4496 .29255 .44344 Mtetra
.553 .335 .537 r
.29255 .44344 .29196 .4496 .30268 .45014 .30327 .44392 Mtetra
.565 .337 .529 r
.30327 .44392 .30268 .45014 .31349 .45064 .31409 .44436 Mtetra
.576 .34 .521 r
.31409 .44436 .31349 .45064 .32439 .4511 .32499 .44477 Mtetra
.587 .342 .512 r
.32499 .44477 .32439 .4511 .33537 .45153 .33597 .44514 Mtetra
.598 .344 .503 r
.33597 .44514 .33537 .45153 .34643 .45191 .34702 .44547 Mtetra
.608 .345 .494 r
.34702 .44547 .34643 .45191 .35757 .45225 .35815 .44576 Mtetra
.618 .346 .484 r
.35815 .44576 .35757 .45225 .36877 .45256 .36933 .446 Mtetra
.627 .347 .473 r
.36933 .446 .36877 .45256 .38002 .45282 .38057 .4462 Mtetra
.635 .346 .463 r
.38057 .4462 .38002 .45282 .39133 .45304 .39186 .44637 Mtetra
.643 .345 .452 r
.39186 .44637 .39133 .45304 .40269 .45321 .40318 .44649 Mtetra
.65 .344 .441 r
.40318 .44649 .40269 .45321 .41408 .45335 .41453 .44657 Mtetra
.656 .342 .43 r
.41453 .44657 .41408 .45335 .4255 .45345 .42591 .44662 Mtetra
.661 .34 .419 r
.42591 .44662 .4255 .45345 .43694 .45351 .43731 .44663 Mtetra
.666 .338 .408 r
.43731 .44663 .43694 .45351 .4484 .45353 .44871 .44661 Mtetra
.671 .336 .399 r
.44871 .44661 .4484 .45353 .45987 .45351 .46012 .44655 Mtetra
.676 .335 .389 r
.46012 .44655 .45987 .45351 .47134 .45345 .47153 .44645 Mtetra
.682 .336 .381 r
.47153 .44645 .47134 .45345 .48282 .45335 .48293 .44631 Mtetra
.69 .338 .374 r
.48293 .44631 .48282 .45335 .49428 .45318 .49432 .44612 Mtetra
.649 .3 .368 r
.49432 .44612 .49428 .45318 .50572 .45318 .50568 .44612 Mtetra
.921 .747 .649 r
.90046 .42943 .9005 .43465 .9091 .43384 .9091 .42866 Mtetra
.92 .74 .643 r
.89173 .4302 .89182 .43546 .9005 .43465 .90046 .42943 Mtetra
.918 .734 .637 r
.88293 .43097 .88305 .43628 .89182 .43546 .89173 .4302 Mtetra
.916 .727 .632 r
.87404 .43175 .8742 .4371 .88305 .43628 .88293 .43097 Mtetra
.914 .72 .627 r
.86506 .43253 .86525 .43792 .8742 .4371 .87404 .43175 Mtetra
.911 .713 .621 r
.85598 .4333 .85621 .43874 .86525 .43792 .86506 .43253 Mtetra
.908 .705 .616 r
.84681 .43407 .84707 .43955 .85621 .43874 .85598 .4333 Mtetra
.905 .697 .611 r
.83754 .43484 .83783 .44037 .84707 .43955 .84681 .43407 Mtetra
.901 .688 .606 r
.82816 .4356 .82849 .44117 .83783 .44037 .83754 .43484 Mtetra
.896 .679 .601 r
.81869 .43635 .81905 .44197 .82849 .44117 .82816 .4356 Mtetra
.891 .67 .596 r
.80911 .43709 .80949 .44275 .81905 .44197 .81869 .43635 Mtetra
.886 .66 .591 r
.79942 .43782 .79983 .44353 .80949 .44275 .80911 .43709 Mtetra
.88 .65 .585 r
.78963 .43853 .79007 .44429 .79983 .44353 .79942 .43782 Mtetra
.874 .639 .58 r
.77972 .43922 .78019 .44503 .79007 .44429 .78963 .43853 Mtetra
.867 .628 .574 r
.76971 .4399 .7702 .44576 .78019 .44503 .77972 .43922 Mtetra
.86 .616 .569 r
.7596 .44056 .76011 .44646 .7702 .44576 .76971 .4399 Mtetra
.852 .604 .562 r
.74938 .44119 .7499 .44715 .76011 .44646 .7596 .44056 Mtetra
.844 .591 .556 r
.73905 .44179 .73959 .4478 .7499 .44715 .74938 .44119 Mtetra
.835 .577 .55 r
.72862 .44237 .72918 .44843 .73959 .4478 .73905 .44179 Mtetra
.826 .563 .543 r
.71808 .44292 .71866 .44903 .72918 .44843 .72862 .44237 Mtetra
.816 .549 .535 r
.70745 .44344 .70804 .4496 .71866 .44903 .71808 .44292 Mtetra
.805 .534 .527 r
.69673 .44392 .69732 .45014 .70804 .4496 .70745 .44344 Mtetra
.794 .518 .519 r
.68591 .44436 .68651 .45064 .69732 .45014 .69673 .44392 Mtetra
.783 .502 .511 r
.67501 .44477 .67561 .4511 .68651 .45064 .68591 .44436 Mtetra
.771 .485 .502 r
.66403 .44514 .66463 .45153 .67561 .4511 .67501 .44477 Mtetra
.759 .468 .492 r
.65298 .44547 .65357 .45191 .66463 .45153 .66403 .44514 Mtetra
.746 .451 .482 r
.64185 .44576 .64243 .45225 .65357 .45191 .65298 .44547 Mtetra
.734 .434 .472 r
.63067 .446 .63123 .45256 .64243 .45225 .64185 .44576 Mtetra
.721 .416 .462 r
.61943 .4462 .61998 .45282 .63123 .45256 .63067 .446 Mtetra
.709 .399 .451 r
.60814 .44637 .60867 .45304 .61998 .45282 .61943 .4462 Mtetra
.697 .382 .44 r
.59682 .44649 .59731 .45321 .60867 .45304 .60814 .44637 Mtetra
.685 .366 .429 r
.58547 .44657 .58592 .45335 .59731 .45321 .59682 .44649 Mtetra
.674 .35 .418 r
.57409 .44662 .5745 .45345 .58592 .45335 .58547 .44657 Mtetra
.663 .335 .408 r
.56269 .44663 .56306 .45351 .5745 .45345 .57409 .44662 Mtetra
.653 .321 .398 r
.55129 .44661 .5516 .45353 .56306 .45351 .56269 .44663 Mtetra
.642 .307 .389 r
.53988 .44655 .54013 .45351 .5516 .45353 .55129 .44661 Mtetra
.632 .294 .381 r
.52847 .44645 .52866 .45345 .54013 .45351 .53988 .44655 Mtetra
.621 .281 .374 r
.51707 .44631 .51718 .45335 .52866 .45345 .52847 .44645 Mtetra
.608 .267 .367 r
.50568 .44612 .50572 .45318 .51718 .45335 .51707 .44631 Mtetra
.398 .325 .658 r
.0909 .42348 .0909 .42866 .09954 .42943 .09958 .42421 Mtetra
.4 .321 .652 r
.09958 .42421 .09954 .42943 .10827 .4302 .10835 .42494 Mtetra
.403 .319 .646 r
.10835 .42494 .10827 .4302 .11707 .43097 .11719 .42567 Mtetra
.407 .317 .641 r
.11719 .42567 .11707 .43097 .12596 .43175 .12612 .42641 Mtetra
.411 .315 .636 r
.12612 .42641 .12596 .43175 .13494 .43253 .13514 .42714 Mtetra
.416 .314 .631 r
.13514 .42714 .13494 .43253 .14402 .4333 .14425 .42788 Mtetra
.422 .314 .626 r
.14425 .42788 .14402 .4333 .15319 .43407 .15345 .42861 Mtetra
.428 .314 .621 r
.15345 .42861 .15319 .43407 .16246 .43484 .16276 .42933 Mtetra
.435 .314 .616 r
.16276 .42933 .16246 .43484 .17184 .4356 .17216 .43004 Mtetra
.442 .315 .611 r
.17216 .43004 .17184 .4356 .18131 .43635 .18166 .43075 Mtetra
.45 .316 .606 r
.18166 .43075 .18131 .43635 .19089 .43709 .19127 .43145 Mtetra
.459 .318 .601 r
.19127 .43145 .19089 .43709 .20058 .43782 .20099 .43213 Mtetra
.468 .32 .596 r
.20099 .43213 .20058 .43782 .21037 .43853 .2108 .43279 Mtetra
.477 .322 .591 r
.2108 .43279 .21037 .43853 .22028 .43922 .22073 .43344 Mtetra
.487 .324 .586 r
.22073 .43344 .22028 .43922 .23029 .4399 .23076 .43407 Mtetra
.497 .327 .581 r
.23076 .43407 .23029 .4399 .2404 .44056 .2409 .43468 Mtetra
.508 .33 .575 r
.2409 .43468 .2404 .44056 .25062 .44119 .25114 .43526 Mtetra
.519 .333 .569 r
.25114 .43526 .25062 .44119 .26095 .44179 .26148 .43582 Mtetra
.53 .336 .563 r
.26148 .43582 .26095 .44179 .27138 .44237 .27193 .43635 Mtetra
.542 .34 .556 r
.27193 .43635 .27138 .44237 .28192 .44292 .28248 .43685 Mtetra
.553 .343 .549 r
.28248 .43685 .28192 .44292 .29255 .44344 .29312 .43731 Mtetra
.565 .346 .542 r
.29312 .43731 .29255 .44344 .30327 .44392 .30385 .43774 Mtetra
.576 .349 .534 r
.30385 .43774 .30327 .44392 .31409 .44436 .31467 .43814 Mtetra
.588 .351 .525 r
.31467 .43814 .31409 .44436 .32499 .44477 .32557 .4385 Mtetra
.599 .354 .517 r
.32557 .4385 .32499 .44477 .33597 .44514 .33655 .43881 Mtetra
.61 .356 .507 r
.33655 .43881 .33597 .44514 .34702 .44547 .3476 .43909 Mtetra
.621 .357 .498 r
.3476 .43909 .34702 .44547 .35815 .44576 .35872 .43932 Mtetra
.631 .358 .487 r
.35872 .43932 .35815 .44576 .36933 .446 .36989 .43951 Mtetra
.64 .359 .477 r
.36989 .43951 .36933 .446 .38057 .4462 .38111 .43966 Mtetra
.648 .359 .466 r
.38111 .43966 .38057 .4462 .39186 .44637 .39237 .43977 Mtetra
.656 .357 .455 r
.39237 .43977 .39186 .44637 .40318 .44649 .40366 .43984 Mtetra
.662 .356 .443 r
.40366 .43984 .40318 .44649 .41453 .44657 .41498 .43988 Mtetra
.668 .353 .432 r
.41498 .43988 .41453 .44657 .42591 .44662 .42632 .43987 Mtetra
.672 .351 .421 r
.42632 .43987 .42591 .44662 .43731 .44663 .43767 .43984 Mtetra
.676 .348 .411 r
.43767 .43984 .43731 .44663 .44871 .44661 .44902 .43977 Mtetra
.68 .345 .401 r
.44902 .43977 .44871 .44661 .46012 .44655 .46037 .43967 Mtetra
.684 .343 .391 r
.46037 .43967 .46012 .44655 .47153 .44645 .47171 .43954 Mtetra
.69 .343 .383 r
.47171 .43954 .47153 .44645 .48293 .44631 .48304 .43938 Mtetra
.696 .345 .376 r
.48304 .43938 .48293 .44631 .49432 .44612 .49435 .43917 Mtetra
.65 .303 .371 r
.49435 .43917 .49432 .44612 .50568 .44612 .50565 .43917 Mtetra
.917 .744 .652 r
.90042 .42421 .90046 .42943 .9091 .42866 .9091 .42348 Mtetra
.916 .738 .646 r
.89165 .42494 .89173 .4302 .90046 .42943 .90042 .42421 Mtetra
.914 .731 .64 r
.88281 .42567 .88293 .43097 .89173 .4302 .89165 .42494 Mtetra
.912 .724 .635 r
.87388 .42641 .87404 .43175 .88293 .43097 .88281 .42567 Mtetra
.91 .717 .63 r
.86486 .42714 .86506 .43253 .87404 .43175 .87388 .42641 Mtetra
.907 .71 .625 r
.85575 .42788 .85598 .4333 .86506 .43253 .86486 .42714 Mtetra
.904 .702 .62 r
.84655 .42861 .84681 .43407 .85598 .4333 .85575 .42788 Mtetra
.901 .694 .615 r
.83724 .42933 .83754 .43484 .84681 .43407 .84655 .42861 Mtetra
.897 .686 .61 r
.82784 .43004 .82816 .4356 .83754 .43484 .83724 .42933 Mtetra
.892 .677 .605 r
.81834 .43075 .81869 .43635 .82816 .4356 .82784 .43004 Mtetra
.887 .668 .6 r
.80873 .43145 .80911 .43709 .81869 .43635 .81834 .43075 Mtetra
.882 .658 .594 r
.79901 .43213 .79942 .43782 .80911 .43709 .80873 .43145 Mtetra
.876 .648 .589 r
.7892 .43279 .78963 .43853 .79942 .43782 .79901 .43213 Mtetra
.869 .637 .584 r
.77927 .43344 .77972 .43922 .78963 .43853 .7892 .43279 Mtetra
.862 .625 .578 r
.76924 .43407 .76971 .4399 .77972 .43922 .77927 .43344 Mtetra
.855 .614 .573 r
.7591 .43468 .7596 .44056 .76971 .4399 .76924 .43407 Mtetra
.847 .601 .567 r
.74886 .43526 .74938 .44119 .7596 .44056 .7591 .43468 Mtetra
.838 .588 .56 r
.73852 .43582 .73905 .44179 .74938 .44119 .74886 .43526 Mtetra
.829 .574 .554 r
.72807 .43635 .72862 .44237 .73905 .44179 .73852 .43582 Mtetra
.819 .56 .547 r
.71752 .43685 .71808 .44292 .72862 .44237 .72807 .43635 Mtetra
.809 .545 .54 r
.70688 .43731 .70745 .44344 .71808 .44292 .71752 .43685 Mtetra
.798 .53 .532 r
.69615 .43774 .69673 .44392 .70745 .44344 .70688 .43731 Mtetra
.787 .514 .524 r
.68533 .43814 .68591 .44436 .69673 .44392 .69615 .43774 Mtetra
.775 .497 .515 r
.67443 .4385 .67501 .44477 .68591 .44436 .68533 .43814 Mtetra
.763 .48 .506 r
.66345 .43881 .66403 .44514 .67501 .44477 .67443 .4385 Mtetra
.75 .463 .496 r
.6524 .43909 .65298 .44547 .66403 .44514 .66345 .43881 Mtetra
.737 .445 .486 r
.64128 .43932 .64185 .44576 .65298 .44547 .6524 .43909 Mtetra
.724 .428 .476 r
.63011 .43951 .63067 .446 .64185 .44576 .64128 .43932 Mtetra
.711 .41 .465 r
.61889 .43966 .61943 .4462 .63067 .446 .63011 .43951 Mtetra
.699 .392 .454 r
.60763 .43977 .60814 .44637 .61943 .4462 .61889 .43966 Mtetra
.686 .375 .443 r
.59634 .43984 .59682 .44649 .60814 .44637 .60763 .43977 Mtetra
.675 .359 .432 r
.58502 .43988 .58547 .44657 .59682 .44649 .59634 .43984 Mtetra
.663 .343 .421 r
.57368 .43987 .57409 .44662 .58547 .44657 .58502 .43988 Mtetra
.653 .328 .41 r
.56233 .43984 .56269 .44663 .57409 .44662 .57368 .43987 Mtetra
.643 .315 .401 r
.55098 .43977 .55129 .44661 .56269 .44663 .56233 .43984 Mtetra
.634 .302 .391 r
.53963 .43967 .53988 .44655 .55129 .44661 .55098 .43977 Mtetra
.624 .289 .383 r
.52829 .43954 .52847 .44645 .53988 .44655 .53963 .43967 Mtetra
.614 .277 .376 r
.51696 .43938 .51707 .44631 .52847 .44645 .52829 .43954 Mtetra
.603 .265 .37 r
.50565 .43917 .50568 .44612 .51707 .44631 .51696 .43938 Mtetra
.407 .332 .66 r
.0909 .4183 .0909 .42348 .09958 .42421 .09962 .41899 Mtetra
.409 .329 .655 r
.09962 .41899 .09958 .42421 .10835 .42494 .10842 .41968 Mtetra
.412 .326 .649 r
.10842 .41968 .10835 .42494 .11719 .42567 .11731 .42038 Mtetra
.415 .324 .644 r
.11731 .42038 .11719 .42567 .12612 .42641 .12627 .42107 Mtetra
.42 .323 .639 r
.12627 .42107 .12612 .42641 .13514 .42714 .13532 .42177 Mtetra
.425 .322 .634 r
.13532 .42177 .13514 .42714 .14425 .42788 .14447 .42246 Mtetra
.43 .321 .629 r
.14447 .42246 .14425 .42788 .15345 .42861 .15371 .42315 Mtetra
.437 .321 .624 r
.15371 .42315 .15345 .42861 .16276 .42933 .16304 .42383 Mtetra
.443 .322 .619 r
.16304 .42383 .16276 .42933 .17216 .43004 .17247 .4245 Mtetra
.451 .323 .615 r
.17247 .4245 .17216 .43004 .18166 .43075 .18201 .42517 Mtetra
.459 .324 .61 r
.18201 .42517 .18166 .43075 .19127 .43145 .19164 .42582 Mtetra
.468 .326 .605 r
.19164 .42582 .19127 .43145 .20099 .43213 .20138 .42646 Mtetra
.477 .328 .6 r
.20138 .42646 .20099 .43213 .2108 .43279 .21123 .42708 Mtetra
.486 .331 .595 r
.21123 .42708 .2108 .43279 .22073 .43344 .22117 .42768 Mtetra
.496 .334 .59 r
.22117 .42768 .22073 .43344 .23076 .43407 .23123 .42827 Mtetra
.507 .337 .585 r
.23123 .42827 .23076 .43407 .2409 .43468 .24138 .42883 Mtetra
.518 .34 .579 r
.24138 .42883 .2409 .43468 .25114 .43526 .25164 .42937 Mtetra
.529 .343 .573 r
.25164 .42937 .25114 .43526 .26148 .43582 .262 .42988 Mtetra
.54 .346 .567 r
.262 .42988 .26148 .43582 .27193 .43635 .27247 .43036 Mtetra
.552 .35 .56 r
.27247 .43036 .27193 .43635 .28248 .43685 .28302 .43081 Mtetra
.564 .353 .553 r
.28302 .43081 .28248 .43685 .29312 .43731 .29367 .43123 Mtetra
.576 .357 .546 r
.29367 .43123 .29312 .43731 .30385 .43774 .30441 .43162 Mtetra
.588 .36 .538 r
.30441 .43162 .30385 .43774 .31467 .43814 .31524 .43196 Mtetra
.6 .363 .53 r
.31524 .43196 .31467 .43814 .32557 .4385 .32614 .43227 Mtetra
.611 .366 .521 r
.32614 .43227 .32557 .4385 .33655 .43881 .33712 .43254 Mtetra
.622 .368 .512 r
.33712 .43254 .33655 .43881 .3476 .43909 .34817 .43276 Mtetra
.633 .37 .502 r
.34817 .43276 .3476 .43909 .35872 .43932 .35927 .43295 Mtetra
.643 .371 .491 r
.35927 .43295 .35872 .43932 .36989 .43951 .37043 .43309 Mtetra
.652 .371 .481 r
.37043 .43309 .36989 .43951 .38111 .43966 .38163 .43319 Mtetra
.661 .371 .469 r
.38163 .43319 .38111 .43966 .39237 .43977 .39287 .43325 Mtetra
.668 .37 .458 r
.39287 .43325 .39237 .43977 .40366 .43984 .40414 .43327 Mtetra
.674 .367 .446 r
.40414 .43327 .40366 .43984 .41498 .43988 .41542 .43326 Mtetra
.679 .365 .435 r
.41542 .43326 .41498 .43988 .42632 .43987 .42672 .43321 Mtetra
.684 .361 .423 r
.42672 .43321 .42632 .43987 .43767 .43984 .43802 .43313 Mtetra
.687 .358 .413 r
.43802 .43313 .43767 .43984 .44902 .43977 .44932 .43302 Mtetra
.69 .354 .402 r
.44932 .43302 .44902 .43977 .46037 .43967 .46061 .43289 Mtetra
.693 .351 .393 r
.46061 .43289 .46037 .43967 .47171 .43954 .47189 .43274 Mtetra
.697 .35 .385 r
.47189 .43274 .47171 .43954 .48304 .43938 .48315 .43255 Mtetra
.702 .351 .378 r
.48315 .43255 .48304 .43938 .49435 .43917 .49439 .43233 Mtetra
.651 .305 .374 r
.49439 .43233 .49435 .43917 .50565 .43917 .50561 .43233 Mtetra
.913 .741 .654 r
.90038 .41899 .90042 .42421 .9091 .42348 .9091 .4183 Mtetra
.912 .735 .649 r
.89158 .41968 .89165 .42494 .90042 .42421 .90038 .41899 Mtetra
.91 .728 .643 r
.88269 .42038 .88281 .42567 .89165 .42494 .89158 .41968 Mtetra
.909 .722 .638 r
.87373 .42107 .87388 .42641 .88281 .42567 .88269 .42038 Mtetra
.906 .715 .633 r
.86468 .42177 .86486 .42714 .87388 .42641 .87373 .42107 Mtetra
.903 .708 .628 r
.85553 .42246 .85575 .42788 .86486 .42714 .86468 .42177 Mtetra
.9 .7 .623 r
.84629 .42315 .84655 .42861 .85575 .42788 .85553 .42246 Mtetra
.897 .692 .618 r
.83696 .42383 .83724 .42933 .84655 .42861 .84629 .42315 Mtetra
.892 .683 .613 r
.82753 .4245 .82784 .43004 .83724 .42933 .83696 .42383 Mtetra
.888 .675 .608 r
.81799 .42517 .81834 .43075 .82784 .43004 .82753 .4245 Mtetra
.883 .665 .603 r
.80836 .42582 .80873 .43145 .81834 .43075 .81799 .42517 Mtetra
.877 .655 .598 r
.79862 .42646 .79901 .43213 .80873 .43145 .80836 .42582 Mtetra
.871 .645 .593 r
.78877 .42708 .7892 .43279 .79901 .43213 .79862 .42646 Mtetra
.865 .634 .588 r
.77883 .42768 .77927 .43344 .7892 .43279 .78877 .42708 Mtetra
.858 .623 .582 r
.76877 .42827 .76924 .43407 .77927 .43344 .77883 .42768 Mtetra
.85 .611 .577 r
.75862 .42883 .7591 .43468 .76924 .43407 .76877 .42827 Mtetra
.842 .598 .571 r
.74836 .42937 .74886 .43526 .7591 .43468 .75862 .42883 Mtetra
.833 .585 .565 r
.738 .42988 .73852 .43582 .74886 .43526 .74836 .42937 Mtetra
.823 .571 .558 r
.72753 .43036 .72807 .43635 .73852 .43582 .738 .42988 Mtetra
.813 .557 .551 r
.71698 .43081 .71752 .43685 .72807 .43635 .72753 .43036 Mtetra
.802 .542 .544 r
.70633 .43123 .70688 .43731 .71752 .43685 .71698 .43081 Mtetra
.791 .526 .536 r
.69559 .43162 .69615 .43774 .70688 .43731 .70633 .43123 Mtetra
.779 .51 .528 r
.68476 .43196 .68533 .43814 .69615 .43774 .69559 .43162 Mtetra
.767 .493 .519 r
.67386 .43227 .67443 .4385 .68533 .43814 .68476 .43196 Mtetra
.754 .476 .51 r
.66288 .43254 .66345 .43881 .67443 .4385 .67386 .43227 Mtetra
.741 .458 .5 r
.65183 .43276 .6524 .43909 .66345 .43881 .66288 .43254 Mtetra
.728 .44 .49 r
.64073 .43295 .64128 .43932 .6524 .43909 .65183 .43276 Mtetra
.715 .422 .48 r
.62957 .43309 .63011 .43951 .64128 .43932 .64073 .43295 Mtetra
.701 .404 .469 r
.61837 .43319 .61889 .43966 .63011 .43951 .62957 .43309 Mtetra
.688 .386 .457 r
.60713 .43325 .60763 .43977 .61889 .43966 .61837 .43319 Mtetra
.676 .368 .446 r
.59586 .43327 .59634 .43984 .60763 .43977 .60713 .43325 Mtetra
.664 .352 .434 r
.58458 .43326 .58502 .43988 .59634 .43984 .59586 .43327 Mtetra
.653 .336 .423 r
.57328 .43321 .57368 .43987 .58502 .43988 .58458 .43326 Mtetra
.643 .321 .412 r
.56198 .43313 .56233 .43984 .57368 .43987 .57328 .43321 Mtetra
.633 .308 .402 r
.55068 .43302 .55098 .43977 .56233 .43984 .56198 .43313 Mtetra
.625 .296 .393 r
.53939 .43289 .53963 .43967 .55098 .43977 .55068 .43302 Mtetra
.617 .285 .385 r
.52811 .43274 .52829 .43954 .53963 .43967 .53939 .43289 Mtetra
.608 .274 .379 r
.51685 .43255 .51696 .43938 .52829 .43954 .52811 .43274 Mtetra
.598 .263 .373 r
.50561 .43233 .50565 .43917 .51696 .43938 .51685 .43255 Mtetra
.415 .339 .663 r
.0909 .41312 .0909 .4183 .09962 .41899 .09966 .41377 Mtetra
.418 .336 .657 r
.09966 .41377 .09962 .41899 .10842 .41968 .1085 .41443 Mtetra
.42 .333 .652 r
.1085 .41443 .10842 .41968 .11731 .42038 .11742 .41509 Mtetra
.424 .331 .647 r
.11742 .41509 .11731 .42038 .12627 .42107 .12642 .41574 Mtetra
.428 .33 .642 r
.12642 .41574 .12627 .42107 .13532 .42177 .13551 .4164 Mtetra
.433 .329 .637 r
.13551 .4164 .13532 .42177 .14447 .42246 .14468 .41705 Mtetra
.439 .329 .632 r
.14468 .41705 .14447 .42246 .15371 .42315 .15395 .4177 Mtetra
.445 .329 .627 r
.15395 .4177 .15371 .42315 .16304 .42383 .16332 .41834 Mtetra
.452 .33 .623 r
.16332 .41834 .16304 .42383 .17247 .4245 .17278 .41898 Mtetra
.46 .331 .618 r
.17278 .41898 .17247 .4245 .18201 .42517 .18234 .4196 Mtetra
.468 .333 .613 r
.18234 .4196 .18201 .42517 .19164 .42582 .192 .42021 Mtetra
.476 .335 .609 r
.192 .42021 .19164 .42582 .20138 .42646 .20177 .42081 Mtetra
.486 .337 .604 r
.20177 .42081 .20138 .42646 .21123 .42708 .21164 .42139 Mtetra
.495 .34 .599 r
.21164 .42139 .21123 .42708 .22117 .42768 .22161 .42195 Mtetra
.506 .343 .594 r
.22161 .42195 .22117 .42768 .23123 .42827 .23168 .42249 Mtetra
.516 .346 .589 r
.23168 .42249 .23123 .42827 .24138 .42883 .24186 .42301 Mtetra
.527 .349 .583 r
.24186 .42301 .24138 .42883 .25164 .42937 .25213 .42351 Mtetra
.539 .353 .577 r
.25213 .42351 .25164 .42937 .262 .42988 .26251 .42397 Mtetra
.55 .357 .571 r
.26251 .42397 .262 .42988 .27247 .43036 .27299 .42441 Mtetra
.562 .36 .565 r
.27299 .42441 .27247 .43036 .28302 .43081 .28356 .42482 Mtetra
.575 .364 .558 r
.28356 .42482 .28302 .43081 .29367 .43123 .29422 .42519 Mtetra
.587 .368 .55 r
.29422 .42519 .29367 .43123 .30441 .43162 .30496 .42553 Mtetra
.599 .371 .542 r
.30496 .42553 .30441 .43162 .31524 .43196 .31579 .42583 Mtetra
.611 .374 .534 r
.31579 .42583 .31524 .43196 .32614 .43227 .3267 .4261 Mtetra
.623 .377 .525 r
.3267 .4261 .32614 .43227 .33712 .43254 .33768 .42632 Mtetra
.634 .38 .516 r
.33768 .42632 .33712 .43254 .34817 .43276 .34872 .4265 Mtetra
.645 .382 .506 r
.34872 .4265 .34817 .43276 .35927 .43295 .35981 .42663 Mtetra
.656 .383 .495 r
.35981 .42663 .35927 .43295 .37043 .43309 .37096 .42673 Mtetra
.665 .383 .484 r
.37096 .42673 .37043 .43309 .38163 .43319 .38214 .42678 Mtetra
.673 .383 .473 r
.38214 .42678 .38163 .43319 .39287 .43325 .39336 .4268 Mtetra
.681 .382 .461 r
.39336 .4268 .39287 .43325 .40414 .43327 .4046 .42677 Mtetra
.687 .379 .449 r
.4046 .42677 .40414 .43327 .41542 .43326 .41585 .42671 Mtetra
.691 .376 .437 r
.41585 .42671 .41542 .43326 .42672 .43321 .42711 .42662 Mtetra
.695 .372 .425 r
.42711 .42662 .42672 .43321 .43802 .43313 .43836 .4265 Mtetra
.697 .367 .414 r
.43836 .4265 .43802 .43313 .44932 .43302 .44961 .42636 Mtetra
.699 .363 .404 r
.44961 .42636 .44932 .43302 .46061 .43289 .46084 .4262 Mtetra
.7 .359 .395 r
.46084 .4262 .46061 .43289 .47189 .43274 .47206 .42602 Mtetra
.703 .356 .387 r
.47206 .42602 .47189 .43274 .48315 .43255 .48326 .42581 Mtetra
.707 .357 .38 r
.48326 .42581 .48315 .43255 .49439 .43233 .49443 .42558 Mtetra
.651 .307 .377 r
.49443 .42558 .49439 .43233 .50561 .43233 .50557 .42558 Mtetra
.909 .737 .657 r
.90034 .41377 .90038 .41899 .9091 .4183 .9091 .41312 Mtetra
.908 .732 .651 r
.8915 .41443 .89158 .41968 .90038 .41899 .90034 .41377 Mtetra
.907 .726 .646 r
.88258 .41509 .88269 .42038 .89158 .41968 .8915 .41443 Mtetra
.905 .719 .641 r
.87358 .41574 .87373 .42107 .88269 .42038 .88258 .41509 Mtetra
.902 .712 .636 r
.86449 .4164 .86468 .42177 .87373 .42107 .87358 .41574 Mtetra
.899 .705 .631 r
.85532 .41705 .85553 .42246 .86468 .42177 .86449 .4164 Mtetra
.896 .698 .626 r
.84605 .4177 .84629 .42315 .85553 .42246 .85532 .41705 Mtetra
.893 .69 .621 r
.83668 .41834 .83696 .42383 .84629 .42315 .84605 .4177 Mtetra
.888 .681 .616 r
.82722 .41898 .82753 .4245 .83696 .42383 .83668 .41834 Mtetra
.884 .672 .612 r
.81766 .4196 .81799 .42517 .82753 .4245 .82722 .41898 Mtetra
.879 .663 .607 r
.808 .42021 .80836 .42582 .81799 .42517 .81766 .4196 Mtetra
.873 .653 .602 r
.79823 .42081 .79862 .42646 .80836 .42582 .808 .42021 Mtetra
.867 .643 .597 r
.78836 .42139 .78877 .42708 .79862 .42646 .79823 .42081 Mtetra
.86 .632 .592 r
.77839 .42195 .77883 .42768 .78877 .42708 .78836 .42139 Mtetra
.853 .62 .586 r
.76832 .42249 .76877 .42827 .77883 .42768 .77839 .42195 Mtetra
.845 .608 .581 r
.75814 .42301 .75862 .42883 .76877 .42827 .76832 .42249 Mtetra
.836 .596 .575 r
.74787 .42351 .74836 .42937 .75862 .42883 .75814 .42301 Mtetra
.827 .582 .569 r
.73749 .42397 .738 .42988 .74836 .42937 .74787 .42351 Mtetra
.817 .568 .562 r
.72701 .42441 .72753 .43036 .738 .42988 .73749 .42397 Mtetra
.807 .554 .556 r
.71644 .42482 .71698 .43081 .72753 .43036 .72701 .42441 Mtetra
.796 .538 .548 r
.70578 .42519 .70633 .43123 .71698 .43081 .71644 .42482 Mtetra
.784 .522 .541 r
.69504 .42553 .69559 .43162 .70633 .43123 .70578 .42519 Mtetra
.772 .506 .532 r
.68421 .42583 .68476 .43196 .69559 .43162 .69504 .42553 Mtetra
.759 .489 .524 r
.6733 .4261 .67386 .43227 .68476 .43196 .68421 .42583 Mtetra
.746 .471 .514 r
.66232 .42632 .66288 .43254 .67386 .43227 .6733 .4261 Mtetra
.732 .453 .505 r
.65128 .4265 .65183 .43276 .66288 .43254 .66232 .42632 Mtetra
.719 .434 .494 r
.64019 .42663 .64073 .43295 .65183 .43276 .65128 .4265 Mtetra
.705 .416 .483 r
.62904 .42673 .62957 .43309 .64073 .43295 .64019 .42663 Mtetra
.691 .397 .472 r
.61786 .42678 .61837 .43319 .62957 .43309 .62904 .42673 Mtetra
.678 .379 .461 r
.60664 .4268 .60713 .43325 .61837 .43319 .61786 .42678 Mtetra
.665 .361 .449 r
.5954 .42677 .59586 .43327 .60713 .43325 .60664 .4268 Mtetra
.653 .344 .437 r
.58415 .42671 .58458 .43326 .59586 .43327 .5954 .42677 Mtetra
.642 .328 .425 r
.57289 .42662 .57328 .43321 .58458 .43326 .58415 .42671 Mtetra
.632 .314 .414 r
.56164 .4265 .56198 .43313 .57328 .43321 .57289 .42662 Mtetra
.623 .301 .404 r
.55039 .42636 .55068 .43302 .56198 .43313 .56164 .4265 Mtetra
.616 .29 .395 r
.53916 .4262 .53939 .43289 .55068 .43302 .55039 .42636 Mtetra
.609 .28 .387 r
.52794 .42602 .52811 .43274 .53939 .43289 .53916 .4262 Mtetra
.602 .27 .38 r
.51674 .42581 .51685 .43255 .52811 .43274 .52794 .42602 Mtetra
.593 .261 .376 r
.50557 .42558 .50561 .43233 .51685 .43255 .51674 .42581 Mtetra
.424 .346 .665 r
.0909 .40795 .0909 .41312 .09966 .41377 .0997 .40856 Mtetra
.426 .343 .66 r
.0997 .40856 .09966 .41377 .1085 .41443 .10857 .40918 Mtetra
.429 .341 .654 r
.10857 .40918 .1085 .41443 .11742 .41509 .11753 .4098 Mtetra
.432 .339 .649 r
.11753 .4098 .11742 .41509 .12642 .41574 .12656 .41042 Mtetra
.436 .337 .644 r
.12656 .41042 .12642 .41574 .13551 .4164 .13568 .41104 Mtetra
.441 .337 .64 r
.13568 .41104 .13551 .4164 .14468 .41705 .14489 .41165 Mtetra
.447 .336 .635 r
.14489 .41165 .14468 .41705 .15395 .4177 .15419 .41226 Mtetra
.453 .337 .63 r
.15419 .41226 .15395 .4177 .16332 .41834 .16359 .41287 Mtetra
.46 .338 .626 r
.16359 .41287 .16332 .41834 .17278 .41898 .17308 .41346 Mtetra
.468 .339 .621 r
.17308 .41346 .17278 .41898 .18234 .4196 .18267 .41405 Mtetra
.476 .341 .617 r
.18267 .41405 .18234 .4196 .192 .42021 .19235 .41462 Mtetra
.485 .343 .612 r
.19235 .41462 .192 .42021 .20177 .42081 .20214 .41517 Mtetra
.494 .345 .608 r
.20214 .41517 .20177 .42081 .21164 .42139 .21203 .41572 Mtetra
.504 .348 .603 r
.21203 .41572 .21164 .42139 .22161 .42195 .22203 .41624 Mtetra
.515 .351 .598 r
.22203 .41624 .22161 .42195 .23168 .42249 .23212 .41674 Mtetra
.525 .355 .593 r
.23212 .41674 .23168 .42249 .24186 .42301 .24232 .41722 Mtetra
.537 .359 .587 r
.24232 .41722 .24186 .42301 .25213 .42351 .25261 .41767 Mtetra
.548 .363 .581 r
.25261 .41767 .25213 .42351 .26251 .42397 .26301 .4181 Mtetra
.56 .367 .575 r
.26301 .4181 .26251 .42397 .27299 .42441 .27349 .4185 Mtetra
.573 .371 .569 r
.27349 .4185 .27299 .42441 .28356 .42482 .28408 .41886 Mtetra
.585 .375 .562 r
.28408 .41886 .28356 .42482 .29422 .42519 .29475 .4192 Mtetra
.597 .379 .555 r
.29475 .4192 .29422 .42519 .30496 .42553 .3055 .41949 Mtetra
.61 .382 .547 r
.3055 .41949 .30496 .42553 .31579 .42583 .31634 .41975 Mtetra
.622 .386 .538 r
.31634 .41975 .31579 .42583 .3267 .4261 .32724 .41997 Mtetra
.634 .389 .529 r
.32724 .41997 .3267 .4261 .33768 .42632 .33822 .42015 Mtetra
.646 .392 .52 r
.33822 .42015 .33768 .42632 .34872 .4265 .34926 .42028 Mtetra
.657 .394 .51 r
.34926 .42028 .34872 .4265 .35981 .42663 .36034 .42038 Mtetra
.668 .395 .499 r
.36034 .42038 .35981 .42663 .37096 .42673 .37148 .42043 Mtetra
.677 .396 .488 r
.37148 .42043 .37096 .42673 .38214 .42678 .38265 .42044 Mtetra
.686 .395 .476 r
.38265 .42044 .38214 .42678 .39336 .4268 .39384 .42041 Mtetra
.693 .394 .464 r
.39384 .42041 .39336 .4268 .4046 .42677 .40505 .42034 Mtetra
.699 .391 .452 r
.40505 .42034 .4046 .42677 .41585 .42671 .41627 .42024 Mtetra
.703 .387 .439 r
.41627 .42024 .41585 .42671 .42711 .42662 .42749 .42011 Mtetra
.706 .383 .427 r
.42749 .42011 .42711 .42662 .43836 .4265 .4387 .41996 Mtetra
.707 .377 .416 r
.4387 .41996 .43836 .4265 .44961 .42636 .4499 .41978 Mtetra
.708 .371 .405 r
.4499 .41978 .44961 .42636 .46084 .4262 .46108 .41959 Mtetra
.708 .366 .396 r
.46108 .41959 .46084 .4262 .47206 .42602 .47223 .41939 Mtetra
.709 .362 .388 r
.47223 .41939 .47206 .42602 .48326 .42581 .48336 .41917 Mtetra
.712 .361 .382 r
.48336 .41917 .48326 .42581 .49443 .42558 .49446 .41893 Mtetra
.652 .309 .379 r
.49446 .41893 .49443 .42558 .50557 .42558 .50554 .41893 Mtetra
.905 .734 .659 r
.9003 .40856 .90034 .41377 .9091 .41312 .9091 .40795 Mtetra
.904 .729 .654 r
.89143 .40918 .8915 .41443 .90034 .41377 .9003 .40856 Mtetra
.903 .723 .649 r
.88247 .4098 .88258 .41509 .8915 .41443 .89143 .40918 Mtetra
.901 .716 .644 r
.87344 .41042 .87358 .41574 .88258 .41509 .88247 .4098 Mtetra
.898 .71 .639 r
.86432 .41104 .86449 .4164 .87358 .41574 .87344 .41042 Mtetra
.896 .703 .634 r
.85511 .41165 .85532 .41705 .86449 .4164 .86432 .41104 Mtetra
.892 .695 .629 r
.84581 .41226 .84605 .4177 .85532 .41705 .85511 .41165 Mtetra
.889 .687 .624 r
.83641 .41287 .83668 .41834 .84605 .4177 .84581 .41226 Mtetra
.884 .679 .62 r
.82692 .41346 .82722 .41898 .83668 .41834 .83641 .41287 Mtetra
.88 .67 .615 r
.81733 .41405 .81766 .4196 .82722 .41898 .82692 .41346 Mtetra
.874 .661 .61 r
.80765 .41462 .808 .42021 .81766 .4196 .81733 .41405 Mtetra
.868 .651 .606 r
.79786 .41517 .79823 .42081 .808 .42021 .80765 .41462 Mtetra
.862 .64 .601 r
.78797 .41572 .78836 .42139 .79823 .42081 .79786 .41517 Mtetra
.855 .629 .596 r
.77797 .41624 .77839 .42195 .78836 .42139 .78797 .41572 Mtetra
.848 .618 .59 r
.76788 .41674 .76832 .42249 .77839 .42195 .77797 .41624 Mtetra
.839 .606 .585 r
.75768 .41722 .75814 .42301 .76832 .42249 .76788 .41674 Mtetra
.831 .593 .579 r
.74739 .41767 .74787 .42351 .75814 .42301 .75768 .41722 Mtetra
.821 .579 .573 r
.73699 .4181 .73749 .42397 .74787 .42351 .74739 .41767 Mtetra
.811 .565 .567 r
.72651 .4185 .72701 .42441 .73749 .42397 .73699 .4181 Mtetra
.8 .55 .56 r
.71592 .41886 .71644 .42482 .72701 .42441 .72651 .4185 Mtetra
.789 .535 .553 r
.70525 .4192 .70578 .42519 .71644 .42482 .71592 .41886 Mtetra
.777 .519 .545 r
.6945 .41949 .69504 .42553 .70578 .42519 .70525 .4192 Mtetra
.764 .502 .537 r
.68366 .41975 .68421 .42583 .69504 .42553 .6945 .41949 Mtetra
.751 .484 .528 r
.67276 .41997 .6733 .4261 .68421 .42583 .68366 .41975 Mtetra
.738 .466 .519 r
.66178 .42015 .66232 .42632 .6733 .4261 .67276 .41997 Mtetra
.723 .448 .509 r
.65074 .42028 .65128 .4265 .66232 .42632 .66178 .42015 Mtetra
.709 .429 .498 r
.63966 .42038 .64019 .42663 .65128 .4265 .65074 .42028 Mtetra
.695 .41 .487 r
.62852 .42043 .62904 .42673 .64019 .42663 .63966 .42038 Mtetra
.681 .391 .476 r
.61735 .42044 .61786 .42678 .62904 .42673 .62852 .42043 Mtetra
.667 .372 .464 r
.60616 .42041 .60664 .4268 .61786 .42678 .61735 .42044 Mtetra
.653 .354 .452 r
.59495 .42034 .5954 .42677 .60664 .4268 .60616 .42041 Mtetra
.641 .337 .439 r
.58373 .42024 .58415 .42671 .5954 .42677 .59495 .42034 Mtetra
.63 .321 .427 r
.57251 .42011 .57289 .42662 .58415 .42671 .58373 .42024 Mtetra
.621 .306 .416 r
.5613 .41996 .56164 .4265 .57289 .42662 .57251 .42011 Mtetra
.613 .294 .405 r
.5501 .41978 .55039 .42636 .56164 .4265 .5613 .41996 Mtetra
.607 .283 .396 r
.53892 .41959 .53916 .4262 .55039 .42636 .5501 .41978 Mtetra
.601 .274 .388 r
.52777 .41939 .52794 .42602 .53916 .4262 .53892 .41959 Mtetra
.596 .267 .382 r
.51664 .41917 .51674 .42581 .52794 .42602 .52777 .41939 Mtetra
.59 .259 .378 r
.50554 .41893 .50557 .42558 .51674 .42581 .51664 .41917 Mtetra
.432 .353 .667 r
.09089 .40277 .0909 .40795 .0997 .40856 .09973 .40335 Mtetra
.434 .35 .662 r
.09973 .40335 .0997 .40856 .10857 .40918 .10865 .40393 Mtetra
.437 .347 .657 r
.10865 .40393 .10857 .40918 .11753 .4098 .11764 .40452 Mtetra
.44 .345 .652 r
.11764 .40452 .11753 .4098 .12656 .41042 .1267 .4051 Mtetra
.444 .344 .647 r
.1267 .4051 .12656 .41042 .13568 .41104 .13586 .40568 Mtetra
.449 .344 .642 r
.13586 .40568 .13568 .41104 .14489 .41165 .1451 .40626 Mtetra
.455 .344 .638 r
.1451 .40626 .14489 .41165 .15419 .41226 .15443 .40684 Mtetra
.461 .344 .633 r
.15443 .40684 .15419 .41226 .16359 .41287 .16385 .4074 Mtetra
.468 .345 .629 r
.16385 .4074 .16359 .41287 .17308 .41346 .17337 .40796 Mtetra
.476 .347 .625 r
.17337 .40796 .17308 .41346 .18267 .41405 .18298 .40851 Mtetra
.484 .349 .62 r
.18298 .40851 .18267 .41405 .19235 .41462 .1927 .40904 Mtetra
.493 .351 .616 r
.1927 .40904 .19235 .41462 .20214 .41517 .20251 .40956 Mtetra
.503 .354 .611 r
.20251 .40956 .20214 .41517 .21203 .41572 .21242 .41007 Mtetra
.513 .357 .606 r
.21242 .41007 .21203 .41572 .22203 .41624 .22244 .41055 Mtetra
.523 .36 .602 r
.22244 .41055 .22203 .41624 .23212 .41674 .23255 .41101 Mtetra
.534 .364 .596 r
.23255 .41101 .23212 .41674 .24232 .41722 .24277 .41146 Mtetra
.546 .368 .591 r
.24277 .41146 .24232 .41722 .25261 .41767 .25308 .41187 Mtetra
.558 .372 .585 r
.25308 .41187 .25261 .41767 .26301 .4181 .26349 .41226 Mtetra
.57 .376 .579 r
.26349 .41226 .26301 .4181 .27349 .4185 .27399 .41262 Mtetra
.583 .381 .573 r
.27399 .41262 .27349 .4185 .28408 .41886 .28458 .41294 Mtetra
.595 .385 .566 r
.28458 .41294 .28408 .41886 .29475 .4192 .29526 .41324 Mtetra
.608 .389 .559 r
.29526 .41324 .29475 .4192 .3055 .41949 .30602 .41349 Mtetra
.621 .394 .551 r
.30602 .41349 .3055 .41949 .31634 .41975 .31686 .41371 Mtetra
.633 .397 .543 r
.31686 .41371 .31634 .41975 .32724 .41997 .32777 .41389 Mtetra
.646 .401 .534 r
.32777 .41389 .32724 .41997 .33822 .42015 .33875 .41403 Mtetra
.658 .404 .524 r
.33875 .41403 .33822 .42015 .34926 .42028 .34978 .41413 Mtetra
.669 .406 .514 r
.34978 .41413 .34926 .42028 .36034 .42038 .36086 .41418 Mtetra
.68 .408 .503 r
.36086 .41418 .36034 .42038 .37148 .42043 .37198 .41419 Mtetra
.69 .408 .491 r
.37198 .41419 .37148 .42043 .38265 .42044 .38314 .41416 Mtetra
.699 .408 .479 r
.38314 .41416 .38265 .42044 .39384 .42041 .39431 .41409 Mtetra
.706 .406 .467 r
.39431 .41409 .39384 .42041 .40505 .42034 .4055 .41399 Mtetra
.711 .403 .454 r
.4055 .41399 .40505 .42034 .41627 .42024 .41669 .41385 Mtetra
.715 .399 .441 r
.41669 .41385 .41627 .42024 .42749 .42011 .42787 .41368 Mtetra
.717 .393 .429 r
.42787 .41368 .42749 .42011 .4387 .41996 .43904 .41349 Mtetra
.718 .387 .417 r
.43904 .41349 .4387 .41996 .4499 .41978 .45019 .41328 Mtetra
.717 .379 .406 r
.45019 .41328 .4499 .41978 .46108 .41959 .46131 .41306 Mtetra
.715 .373 .396 r
.46131 .41306 .46108 .41959 .47223 .41939 .4724 .41284 Mtetra
.714 .367 .389 r
.4724 .41284 .47223 .41939 .48336 .41917 .48346 .41261 Mtetra
.715 .365 .383 r
.48346 .41261 .48336 .41917 .49446 .41893 .4945 .41238 Mtetra
.653 .311 .381 r
.4945 .41238 .49446 .41893 .50554 .41893 .5055 .41238 Mtetra
.901 .731 .662 r
.90027 .40335 .9003 .40856 .9091 .40795 .90911 .40277 Mtetra
.9 .726 .656 r
.89135 .40393 .89143 .40918 .9003 .40856 .90027 .40335 Mtetra
.899 .72 .651 r
.88236 .40452 .88247 .4098 .89143 .40918 .89135 .40393 Mtetra
.897 .714 .646 r
.8733 .4051 .87344 .41042 .88247 .4098 .88236 .40452 Mtetra
.895 .707 .641 r
.86414 .40568 .86432 .41104 .87344 .41042 .8733 .4051 Mtetra
.892 .7 .637 r
.8549 .40626 .85511 .41165 .86432 .41104 .86414 .40568 Mtetra
.888 .693 .632 r
.84557 .40684 .84581 .41226 .85511 .41165 .8549 .40626 Mtetra
.885 .685 .628 r
.83615 .4074 .83641 .41287 .84581 .41226 .84557 .40684 Mtetra
.88 .677 .623 r
.82663 .40796 .82692 .41346 .83641 .41287 .83615 .4074 Mtetra
.875 .668 .618 r
.81702 .40851 .81733 .41405 .82692 .41346 .82663 .40796 Mtetra
.87 .658 .614 r
.8073 .40904 .80765 .41462 .81733 .41405 .81702 .40851 Mtetra
.864 .649 .609 r
.79749 .40956 .79786 .41517 .80765 .41462 .8073 .40904 Mtetra
.858 .638 .604 r
.78758 .41007 .78797 .41572 .79786 .41517 .79749 .40956 Mtetra
.85 .627 .599 r
.77756 .41055 .77797 .41624 .78797 .41572 .78758 .41007 Mtetra
.843 .616 .594 r
.76745 .41101 .76788 .41674 .77797 .41624 .77756 .41055 Mtetra
.834 .603 .589 r
.75723 .41146 .75768 .41722 .76788 .41674 .76745 .41101 Mtetra
.825 .59 .583 r
.74692 .41187 .74739 .41767 .75768 .41722 .75723 .41146 Mtetra
.816 .577 .577 r
.73651 .41226 .73699 .4181 .74739 .41767 .74692 .41187 Mtetra
.805 .562 .571 r
.72601 .41262 .72651 .4185 .73699 .4181 .73651 .41226 Mtetra
.794 .547 .564 r
.71542 .41294 .71592 .41886 .72651 .4185 .72601 .41262 Mtetra
.782 .532 .557 r
.70474 .41324 .70525 .4192 .71592 .41886 .71542 .41294 Mtetra
.77 .515 .549 r
.69398 .41349 .6945 .41949 .70525 .4192 .70474 .41324 Mtetra
.757 .498 .541 r
.68314 .41371 .68366 .41975 .6945 .41949 .69398 .41349 Mtetra
.743 .48 .532 r
.67223 .41389 .67276 .41997 .68366 .41975 .68314 .41371 Mtetra
.729 .462 .523 r
.66125 .41403 .66178 .42015 .67276 .41997 .67223 .41389 Mtetra
.714 .443 .513 r
.65022 .41413 .65074 .42028 .66178 .42015 .66125 .41403 Mtetra
.699 .423 .502 r
.63914 .41418 .63966 .42038 .65074 .42028 .65022 .41413 Mtetra
.684 .404 .491 r
.62802 .41419 .62852 .42043 .63966 .42038 .63914 .41418 Mtetra
.67 .384 .479 r
.61686 .41416 .61735 .42044 .62852 .42043 .62802 .41419 Mtetra
.655 .365 .467 r
.60569 .41409 .60616 .42041 .61735 .42044 .61686 .41416 Mtetra
.642 .346 .454 r
.5945 .41399 .59495 .42034 .60616 .42041 .60569 .41409 Mtetra
.629 .328 .441 r
.58331 .41385 .58373 .42024 .59495 .42034 .5945 .41399 Mtetra
.618 .312 .429 r
.57213 .41368 .57251 .42011 .58373 .42024 .58331 .41385 Mtetra
.609 .298 .417 r
.56096 .41349 .5613 .41996 .57251 .42011 .57213 .41368 Mtetra
.602 .286 .406 r
.54981 .41328 .5501 .41978 .5613 .41996 .56096 .41349 Mtetra
.597 .276 .397 r
.53869 .41306 .53892 .41959 .5501 .41978 .54981 .41328 Mtetra
.594 .269 .389 r
.5276 .41284 .52777 .41939 .53892 .41959 .53869 .41306 Mtetra
.59 .263 .383 r
.51654 .41261 .51664 .41917 .52777 .41939 .5276 .41284 Mtetra
.587 .258 .38 r
.5055 .41238 .50554 .41893 .51664 .41917 .51654 .41261 Mtetra
.44 .36 .669 r
.09089 .39759 .09089 .40277 .09973 .40335 .09977 .39814 Mtetra
.442 .356 .664 r
.09977 .39814 .09973 .40335 .10865 .40393 .10872 .39869 Mtetra
.445 .354 .659 r
.10872 .39869 .10865 .40393 .11764 .40452 .11774 .39924 Mtetra
.448 .352 .654 r
.11774 .39924 .11764 .40452 .1267 .4051 .12684 .39979 Mtetra
.452 .351 .65 r
.12684 .39979 .1267 .4051 .13586 .40568 .13603 .40034 Mtetra
.457 .351 .645 r
.13603 .40034 .13586 .40568 .1451 .40626 .1453 .40088 Mtetra
.463 .351 .641 r
.1453 .40088 .1451 .40626 .15443 .40684 .15465 .40142 Mtetra
.469 .351 .636 r
.15465 .40142 .15443 .40684 .16385 .4074 .16411 .40195 Mtetra
.476 .352 .632 r
.16411 .40195 .16385 .4074 .17337 .40796 .17365 .40247 Mtetra
.484 .354 .628 r
.17365 .40247 .17337 .40796 .18298 .40851 .18329 .40299 Mtetra
.492 .356 .624 r
.18329 .40299 .18298 .40851 .1927 .40904 .19303 .40349 Mtetra
.501 .359 .619 r
.19303 .40349 .1927 .40904 .20251 .40956 .20287 .40397 Mtetra
.511 .362 .615 r
.20287 .40397 .20251 .40956 .21242 .41007 .2128 .40444 Mtetra
.521 .365 .61 r
.2128 .40444 .21242 .41007 .22244 .41055 .22284 .40489 Mtetra
.532 .369 .605 r
.22284 .40489 .22244 .41055 .23255 .41101 .23297 .40531 Mtetra
.543 .373 .6 r
.23297 .40531 .23255 .41101 .24277 .41146 .2432 .40572 Mtetra
.555 .377 .595 r
.2432 .40572 .24277 .41146 .25308 .41187 .25353 .4061 Mtetra
.567 .382 .59 r
.25353 .4061 .25308 .41187 .26349 .41226 .26396 .40645 Mtetra
.58 .386 .584 r
.26396 .40645 .26349 .41226 .27399 .41262 .27447 .40677 Mtetra
.592 .391 .577 r
.27447 .40677 .27399 .41262 .28458 .41294 .28507 .40706 Mtetra
.605 .396 .571 r
.28507 .40706 .28458 .41294 .29526 .41324 .29576 .40732 Mtetra
.618 .4 .563 r
.29576 .40732 .29526 .41324 .30602 .41349 .30653 .40754 Mtetra
.631 .405 .555 r
.30653 .40754 .30602 .41349 .31686 .41371 .31738 .40772 Mtetra
.644 .409 .547 r
.31738 .40772 .31686 .41371 .32777 .41389 .32829 .40786 Mtetra
.657 .413 .538 r
.32829 .40786 .32777 .41389 .33875 .41403 .33926 .40796 Mtetra
.67 .416 .528 r
.33926 .40796 .33875 .41403 .34978 .41413 .35029 .40802 Mtetra
.681 .419 .518 r
.35029 .40802 .34978 .41413 .36086 .41418 .36137 .40804 Mtetra
.692 .42 .507 r
.36137 .40804 .36086 .41418 .37198 .41419 .37248 .40801 Mtetra
.702 .421 .495 r
.37248 .40801 .37198 .41419 .38314 .41416 .38362 .40795 Mtetra
.711 .421 .483 r
.38362 .40795 .38314 .41416 .39431 .41409 .39477 .40784 Mtetra
.718 .419 .47 r
.39477 .40784 .39431 .41409 .4055 .41399 .40594 .40769 Mtetra
.724 .416 .457 r
.40594 .40769 .4055 .41399 .41669 .41385 .4171 .40752 Mtetra
.727 .411 .443 r
.4171 .40752 .41669 .41385 .42787 .41368 .42824 .40731 Mtetra
.729 .404 .43 r
.42824 .40731 .42787 .41368 .43904 .41349 .43937 .40709 Mtetra
.728 .396 .418 r
.43937 .40709 .43904 .41349 .45019 .41328 .45047 .40686 Mtetra
.726 .388 .407 r
.45047 .40686 .45019 .41328 .46131 .41306 .46153 .40662 Mtetra
.722 .379 .397 r
.46153 .40662 .46131 .41306 .4724 .41284 .47257 .40638 Mtetra
.719 .372 .389 r
.47257 .40638 .4724 .41284 .48346 .41261 .48356 .40614 Mtetra
.718 .367 .384 r
.48356 .40614 .48346 .41261 .4945 .41238 .49453 .4059 Mtetra
.653 .312 .382 r
.49453 .4059 .4945 .41238 .5055 .41238 .50547 .4059 Mtetra
.897 .728 .664 r
.90023 .39814 .90027 .40335 .90911 .40277 .90911 .39759 Mtetra
.897 .723 .659 r
.89128 .39869 .89135 .40393 .90027 .40335 .90023 .39814 Mtetra
.895 .717 .654 r
.88226 .39924 .88236 .40452 .89135 .40393 .89128 .39869 Mtetra
.893 .711 .649 r
.87316 .39979 .8733 .4051 .88236 .40452 .88226 .39924 Mtetra
.891 .705 .644 r
.86397 .40034 .86414 .40568 .8733 .4051 .87316 .39979 Mtetra
.888 .698 .64 r
.8547 .40088 .8549 .40626 .86414 .40568 .86397 .40034 Mtetra
.885 .69 .635 r
.84535 .40142 .84557 .40684 .8549 .40626 .8547 .40088 Mtetra
.881 .683 .631 r
.83589 .40195 .83615 .4074 .84557 .40684 .84535 .40142 Mtetra
.876 .674 .626 r
.82635 .40247 .82663 .40796 .83615 .4074 .83589 .40195 Mtetra
.871 .666 .622 r
.81671 .40299 .81702 .40851 .82663 .40796 .82635 .40247 Mtetra
.866 .656 .617 r
.80697 .40349 .8073 .40904 .81702 .40851 .81671 .40299 Mtetra
.86 .646 .613 r
.79713 .40397 .79749 .40956 .8073 .40904 .80697 .40349 Mtetra
.853 .636 .608 r
.7872 .40444 .78758 .41007 .79749 .40956 .79713 .40397 Mtetra
.846 .625 .603 r
.77716 .40489 .77756 .41055 .78758 .41007 .7872 .40444 Mtetra
.838 .613 .598 r
.76703 .40531 .76745 .41101 .77756 .41055 .77716 .40489 Mtetra
.829 .601 .593 r
.7568 .40572 .75723 .41146 .76745 .41101 .76703 .40531 Mtetra
.82 .588 .587 r
.74647 .4061 .74692 .41187 .75723 .41146 .7568 .40572 Mtetra
.81 .574 .582 r
.73604 .40645 .73651 .41226 .74692 .41187 .74647 .4061 Mtetra
.799 .56 .575 r
.72553 .40677 .72601 .41262 .73651 .41226 .73604 .40645 Mtetra
.788 .544 .569 r
.71493 .40706 .71542 .41294 .72601 .41262 .72553 .40677 Mtetra
.776 .528 .562 r
.70424 .40732 .70474 .41324 .71542 .41294 .71493 .40706 Mtetra
.763 .512 .554 r
.69347 .40754 .69398 .41349 .70474 .41324 .70424 .40732 Mtetra
.749 .494 .546 r
.68262 .40772 .68314 .41371 .69398 .41349 .69347 .40754 Mtetra
.735 .476 .537 r
.67171 .40786 .67223 .41389 .68314 .41371 .68262 .40772 Mtetra
.72 .457 .527 r
.66074 .40796 .66125 .41403 .67223 .41389 .67171 .40786 Mtetra
.705 .437 .517 r
.64971 .40802 .65022 .41413 .66125 .41403 .66074 .40796 Mtetra
.69 .418 .506 r
.63863 .40804 .63914 .41418 .65022 .41413 .64971 .40802 Mtetra
.674 .397 .495 r
.62752 .40801 .62802 .41419 .63914 .41418 .63863 .40804 Mtetra
.658 .377 .483 r
.61638 .40795 .61686 .41416 .62802 .41419 .62752 .40801 Mtetra
.644 .357 .47 r
.60523 .40784 .60569 .41409 .61686 .41416 .61638 .40795 Mtetra
.629 .338 .457 r
.59406 .40769 .5945 .41399 .60569 .41409 .60523 .40784 Mtetra
.617 .32 .444 r
.5829 .40752 .58331 .41385 .5945 .41399 .59406 .40769 Mtetra
.606 .304 .43 r
.57176 .40731 .57213 .41368 .58331 .41385 .5829 .40752 Mtetra
.597 .289 .418 r
.56063 .40709 .56096 .41349 .57213 .41368 .57176 .40731 Mtetra
.591 .277 .407 r
.54953 .40686 .54981 .41328 .56096 .41349 .56063 .40709 Mtetra
.587 .269 .397 r
.53847 .40662 .53869 .41306 .54981 .41328 .54953 .40686 Mtetra
.586 .263 .389 r
.52743 .40638 .5276 .41284 .53869 .41306 .53847 .40662 Mtetra
.585 .259 .384 r
.51644 .40614 .51654 .41261 .5276 .41284 .52743 .40638 Mtetra
.584 .257 .381 r
.50547 .4059 .5055 .41238 .51654 .41261 .51644 .40614 Mtetra
.448 .366 .671 r
.09089 .39241 .09089 .39759 .09977 .39814 .0998 .39293 Mtetra
.45 .363 .666 r
.0998 .39293 .09977 .39814 .10872 .39869 .10879 .39345 Mtetra
.452 .36 .661 r
.10879 .39345 .10872 .39869 .11774 .39924 .11784 .39396 Mtetra
.455 .359 .657 r
.11784 .39396 .11774 .39924 .12684 .39979 .12697 .39448 Mtetra
.46 .358 .652 r
.12697 .39448 .12684 .39979 .13603 .40034 .13619 .395 Mtetra
.464 .357 .648 r
.13619 .395 .13603 .40034 .1453 .40088 .14549 .39551 Mtetra
.47 .358 .643 r
.14549 .39551 .1453 .40088 .15465 .40142 .15488 .39601 Mtetra
.477 .358 .639 r
.15488 .39601 .15465 .40142 .16411 .40195 .16435 .39651 Mtetra
.484 .36 .635 r
.16435 .39651 .16411 .40195 .17365 .40247 .17392 .397 Mtetra
.492 .361 .631 r
.17392 .397 .17365 .40247 .18329 .40299 .18359 .39748 Mtetra
.5 .364 .627 r
.18359 .39748 .18329 .40299 .19303 .40349 .19335 .39794 Mtetra
.509 .367 .623 r
.19335 .39794 .19303 .40349 .20287 .40397 .20321 .39839 Mtetra
.519 .37 .618 r
.20321 .39839 .20287 .40397 .2128 .40444 .21317 .39883 Mtetra
.529 .373 .614 r
.21317 .39883 .2128 .40444 .22284 .40489 .22322 .39924 Mtetra
.54 .377 .609 r
.22322 .39924 .22284 .40489 .23297 .40531 .23338 .39964 Mtetra
.552 .382 .604 r
.23338 .39964 .23297 .40531 .2432 .40572 .24363 .40001 Mtetra
.564 .386 .599 r
.24363 .40001 .2432 .40572 .25353 .4061 .25397 .40035 Mtetra
.576 .391 .594 r
.25397 .40035 .25353 .4061 .26396 .40645 .26441 .40067 Mtetra
.589 .396 .588 r
.26441 .40067 .26396 .40645 .27447 .40677 .27494 .40096 Mtetra
.602 .401 .582 r
.27494 .40096 .27447 .40677 .28507 .40706 .28555 .40121 Mtetra
.615 .406 .575 r
.28555 .40121 .28507 .40706 .29576 .40732 .29625 .40143 Mtetra
.628 .411 .568 r
.29625 .40143 .29576 .40732 .30653 .40754 .30703 .40162 Mtetra
.642 .416 .56 r
.30703 .40162 .30653 .40754 .31738 .40772 .31788 .40177 Mtetra
.655 .42 .551 r
.31788 .40177 .31738 .40772 .32829 .40786 .32879 .40188 Mtetra
.668 .424 .542 r
.32879 .40188 .32829 .40786 .33926 .40796 .33977 .40195 Mtetra
.681 .428 .533 r
.33977 .40195 .33926 .40796 .35029 .40802 .35079 .40197 Mtetra
.693 .431 .522 r
.35079 .40197 .35029 .40802 .36137 .40804 .36186 .40195 Mtetra
.705 .433 .511 r
.36186 .40195 .36137 .40804 .37248 .40801 .37296 .40189 Mtetra
.715 .434 .499 r
.37296 .40189 .37248 .40801 .38362 .40795 .38409 .40179 Mtetra
.724 .434 .486 r
.38409 .40179 .38362 .40795 .39477 .40784 .39522 .40165 Mtetra
.731 .432 .473 r
.39522 .40165 .39477 .40784 .40594 .40769 .40636 .40147 Mtetra
.737 .428 .459 r
.40636 .40147 .40594 .40769 .4171 .40752 .4175 .40126 Mtetra
.74 .423 .445 r
.4175 .40126 .4171 .40752 .42824 .40731 .42861 .40102 Mtetra
.74 .415 .432 r
.42861 .40102 .42824 .40731 .43937 .40709 .43969 .40077 Mtetra
.739 .406 .419 r
.43969 .40077 .43937 .40709 .45047 .40686 .45074 .4005 Mtetra
.735 .396 .407 r
.45074 .4005 .45047 .40686 .46153 .40662 .46176 .40024 Mtetra
.729 .385 .396 r
.46176 .40024 .46153 .40662 .47257 .40638 .47273 .39999 Mtetra
.724 .375 .389 r
.47273 .39999 .47257 .40638 .48356 .40614 .48366 .39974 Mtetra
.719 .369 .384 r
.48366 .39974 .48356 .40614 .49453 .4059 .49456 .39951 Mtetra
.653 .313 .383 r
.49456 .39951 .49453 .4059 .50547 .4059 .50544 .39951 Mtetra
.894 .725 .666 r
.9002 .39293 .90023 .39814 .90911 .39759 .90911 .39241 Mtetra
.893 .72 .661 r
.89121 .39345 .89128 .39869 .90023 .39814 .9002 .39293 Mtetra
.891 .715 .656 r
.88216 .39396 .88226 .39924 .89128 .39869 .89121 .39345 Mtetra
.889 .709 .651 r
.87303 .39448 .87316 .39979 .88226 .39924 .88216 .39396 Mtetra
.887 .702 .647 r
.86381 .395 .86397 .40034 .87316 .39979 .87303 .39448 Mtetra
.884 .695 .642 r
.85451 .39551 .8547 .40088 .86397 .40034 .86381 .395 Mtetra
.881 .688 .638 r
.84512 .39601 .84535 .40142 .8547 .40088 .85451 .39551 Mtetra
.877 .68 .634 r
.83565 .39651 .83589 .40195 .84535 .40142 .84512 .39601 Mtetra
.872 .672 .629 r
.82608 .397 .82635 .40247 .83589 .40195 .83565 .39651 Mtetra
.867 .664 .625 r
.81641 .39748 .81671 .40299 .82635 .40247 .82608 .397 Mtetra
.862 .654 .621 r
.80665 .39794 .80697 .40349 .81671 .40299 .81641 .39748 Mtetra
.855 .644 .616 r
.79679 .39839 .79713 .40397 .80697 .40349 .80665 .39794 Mtetra
.849 .634 .612 r
.78683 .39883 .7872 .40444 .79713 .40397 .79679 .39839 Mtetra
.841 .623 .607 r
.77678 .39924 .77716 .40489 .7872 .40444 .78683 .39883 Mtetra
.833 .611 .602 r
.76662 .39964 .76703 .40531 .77716 .40489 .77678 .39924 Mtetra
.824 .599 .597 r
.75637 .40001 .7568 .40572 .76703 .40531 .76662 .39964 Mtetra
.815 .586 .592 r
.74603 .40035 .74647 .4061 .7568 .40572 .75637 .40001 Mtetra
.804 .572 .586 r
.73559 .40067 .73604 .40645 .74647 .4061 .74603 .40035 Mtetra
.793 .557 .58 r
.72506 .40096 .72553 .40677 .73604 .40645 .73559 .40067 Mtetra
.781 .542 .573 r
.71445 .40121 .71493 .40706 .72553 .40677 .72506 .40096 Mtetra
.769 .525 .566 r
.70375 .40143 .70424 .40732 .71493 .40706 .71445 .40121 Mtetra
.756 .508 .558 r
.69297 .40162 .69347 .40754 .70424 .40732 .70375 .40143 Mtetra
.742 .49 .55 r
.68212 .40177 .68262 .40772 .69347 .40754 .69297 .40162 Mtetra
.727 .472 .541 r
.67121 .40188 .67171 .40786 .68262 .40772 .68212 .40177 Mtetra
.711 .452 .532 r
.66023 .40195 .66074 .40796 .67171 .40786 .67121 .40188 Mtetra
.696 .432 .521 r
.64921 .40197 .64971 .40802 .66074 .40796 .66023 .40195 Mtetra
.679 .412 .51 r
.63814 .40195 .63863 .40804 .64971 .40802 .64921 .40197 Mtetra
.663 .391 .499 r
.62704 .40189 .62752 .40801 .63863 .40804 .63814 .40195 Mtetra
.647 .37 .486 r
.61591 .40179 .61638 .40795 .62752 .40801 .62704 .40189 Mtetra
.631 .35 .473 r
.60478 .40165 .60523 .40784 .61638 .40795 .61591 .40179 Mtetra
.617 .33 .459 r
.59364 .40147 .59406 .40769 .60523 .40784 .60478 .40165 Mtetra
.604 .311 .445 r
.5825 .40126 .5829 .40752 .59406 .40769 .59364 .40147 Mtetra
.593 .294 .432 r
.57139 .40102 .57176 .40731 .5829 .40752 .5825 .40126 Mtetra
.584 .28 .419 r
.56031 .40077 .56063 .40709 .57176 .40731 .57139 .40102 Mtetra
.579 .268 .407 r
.54926 .4005 .54953 .40686 .56063 .40709 .56031 .40077 Mtetra
.577 .26 .396 r
.53824 .40024 .53847 .40662 .54953 .40686 .54926 .4005 Mtetra
.577 .256 .388 r
.52727 .39999 .52743 .40638 .53847 .40662 .53824 .40024 Mtetra
.58 .255 .383 r
.51634 .39974 .51644 .40614 .52743 .40638 .52727 .39999 Mtetra
.582 .256 .382 r
.50544 .39951 .50547 .4059 .51644 .40614 .51634 .39974 Mtetra
.455 .372 .673 r
.09089 .38723 .09089 .39241 .0998 .39293 .09984 .38772 Mtetra
.457 .369 .668 r
.09984 .38772 .0998 .39293 .10879 .39345 .10885 .38821 Mtetra
.459 .367 .663 r
.10885 .38821 .10879 .39345 .11784 .39396 .11794 .38869 Mtetra
.463 .365 .659 r
.11794 .38869 .11784 .39396 .12697 .39448 .1271 .38918 Mtetra
.467 .364 .655 r
.1271 .38918 .12697 .39448 .13619 .395 .13635 .38966 Mtetra
.472 .364 .65 r
.13635 .38966 .13619 .395 .14549 .39551 .14568 .39014 Mtetra
.477 .364 .646 r
.14568 .39014 .14549 .39551 .15488 .39601 .15509 .39062 Mtetra
.484 .365 .642 r
.15509 .39062 .15488 .39601 .16435 .39651 .16459 .39108 Mtetra
.491 .367 .638 r
.16459 .39108 .16435 .39651 .17392 .397 .17419 .39154 Mtetra
.499 .369 .634 r
.17419 .39154 .17392 .397 .18359 .39748 .18388 .39199 Mtetra
.508 .371 .63 r
.18388 .39199 .18359 .39748 .19335 .39794 .19367 .39242 Mtetra
.517 .374 .626 r
.19367 .39242 .19335 .39794 .20321 .39839 .20355 .39284 Mtetra
.527 .378 .622 r
.20355 .39284 .20321 .39839 .21317 .39883 .21352 .39324 Mtetra
.537 .381 .617 r
.21352 .39324 .21317 .39883 .22322 .39924 .2236 .39362 Mtetra
.548 .386 .613 r
.2236 .39362 .22322 .39924 .23338 .39964 .23377 .39398 Mtetra
.56 .39 .608 r
.23377 .39398 .23338 .39964 .24363 .40001 .24404 .39432 Mtetra
.572 .395 .603 r
.24404 .39432 .24363 .40001 .25397 .40035 .2544 .39463 Mtetra
.585 .4 .598 r
.2544 .39463 .25397 .40035 .26441 .40067 .26485 .39492 Mtetra
.598 .405 .592 r
.26485 .39492 .26441 .40067 .27494 .40096 .27539 .39517 Mtetra
.611 .411 .586 r
.27539 .39517 .27494 .40096 .28555 .40121 .28602 .3954 Mtetra
.625 .416 .579 r
.28602 .3954 .28555 .40121 .29625 .40143 .29672 .39559 Mtetra
.638 .421 .572 r
.29672 .39559 .29625 .40143 .30703 .40162 .30751 .39574 Mtetra
.652 .427 .564 r
.30751 .39574 .30703 .40162 .31788 .40177 .31836 .39586 Mtetra
.666 .431 .556 r
.31836 .39586 .31788 .40177 .32879 .40188 .32928 .39594 Mtetra
.679 .436 .547 r
.32928 .39594 .32879 .40188 .33977 .40195 .34025 .39598 Mtetra
.692 .44 .537 r
.34025 .39598 .33977 .40195 .35079 .40197 .35128 .39597 Mtetra
.705 .443 .526 r
.35128 .39597 .35079 .40197 .36186 .40195 .36234 .39592 Mtetra
.717 .446 .515 r
.36234 .39592 .36186 .40195 .37296 .40189 .37343 .39583 Mtetra
.727 .447 .502 r
.37343 .39583 .37296 .40189 .38409 .40179 .38454 .39569 Mtetra
.736 .447 .489 r
.38454 .39569 .38409 .40179 .39522 .40165 .39566 .39552 Mtetra
.744 .445 .476 r
.39566 .39552 .39522 .40165 .40636 .40147 .40678 .39531 Mtetra
.749 .441 .461 r
.40678 .39531 .40636 .40147 .4175 .40126 .41789 .39507 Mtetra
.752 .435 .447 r
.41789 .39507 .4175 .40126 .42861 .40102 .42897 .3948 Mtetra
.752 .427 .433 r
.42897 .3948 .42861 .40102 .43969 .40077 .44001 .39451 Mtetra
.75 .416 .419 r
.44001 .39451 .43969 .40077 .45074 .4005 .45102 .39422 Mtetra
.744 .404 .406 r
.45102 .39422 .45074 .4005 .46176 .40024 .46198 .39394 Mtetra
.736 .391 .395 r
.46198 .39394 .46176 .40024 .47273 .39999 .47289 .39367 Mtetra
.728 .378 .387 r
.47289 .39367 .47273 .39999 .48366 .39974 .48376 .39342 Mtetra
.72 .369 .383 r
.48376 .39342 .48366 .39974 .49456 .39951 .4946 .3932 Mtetra
.653 .313 .383 r
.4946 .3932 .49456 .39951 .50544 .39951 .5054 .3932 Mtetra
.89 .723 .668 r
.90016 .38772 .9002 .39293 .90911 .39241 .90911 .38723 Mtetra
.889 .718 .663 r
.89115 .38821 .89121 .39345 .9002 .39293 .90016 .38772 Mtetra
.888 .712 .658 r
.88206 .38869 .88216 .39396 .89121 .39345 .89115 .38821 Mtetra
.886 .706 .654 r
.8729 .38918 .87303 .39448 .88216 .39396 .88206 .38869 Mtetra
.883 .7 .649 r
.86365 .38966 .86381 .395 .87303 .39448 .8729 .38918 Mtetra
.88 .693 .645 r
.85432 .39014 .85451 .39551 .86381 .395 .86365 .38966 Mtetra
.877 .686 .641 r
.84491 .39062 .84512 .39601 .85451 .39551 .85432 .39014 Mtetra
.873 .678 .637 r
.83541 .39108 .83565 .39651 .84512 .39601 .84491 .39062 Mtetra
.868 .67 .632 r
.82581 .39154 .82608 .397 .83565 .39651 .83541 .39108 Mtetra
.863 .662 .628 r
.81612 .39199 .81641 .39748 .82608 .397 .82581 .39154 Mtetra
.857 .652 .624 r
.80633 .39242 .80665 .39794 .81641 .39748 .81612 .39199 Mtetra
.851 .642 .62 r
.79645 .39284 .79679 .39839 .80665 .39794 .80633 .39242 Mtetra
.844 .632 .615 r
.78648 .39324 .78683 .39883 .79679 .39839 .79645 .39284 Mtetra
.836 .621 .611 r
.7764 .39362 .77678 .39924 .78683 .39883 .78648 .39324 Mtetra
.828 .609 .606 r
.76623 .39398 .76662 .39964 .77678 .39924 .7764 .39362 Mtetra
.819 .597 .601 r
.75596 .39432 .75637 .40001 .76662 .39964 .76623 .39398 Mtetra
.809 .583 .596 r
.7456 .39463 .74603 .40035 .75637 .40001 .75596 .39432 Mtetra
.799 .569 .59 r
.73515 .39492 .73559 .40067 .74603 .40035 .7456 .39463 Mtetra
.787 .554 .584 r
.72461 .39517 .72506 .40096 .73559 .40067 .73515 .39492 Mtetra
.775 .539 .578 r
.71398 .3954 .71445 .40121 .72506 .40096 .72461 .39517 Mtetra
.762 .522 .57 r
.70328 .39559 .70375 .40143 .71445 .40121 .71398 .3954 Mtetra
.748 .505 .563 r
.69249 .39574 .69297 .40162 .70375 .40143 .70328 .39559 Mtetra
.734 .487 .555 r
.68164 .39586 .68212 .40177 .69297 .40162 .69249 .39574 Mtetra
.719 .468 .546 r
.67072 .39594 .67121 .40188 .68212 .40177 .68164 .39586 Mtetra
.703 .448 .536 r
.65975 .39598 .66023 .40195 .67121 .40188 .67072 .39594 Mtetra
.686 .428 .526 r
.64872 .39597 .64921 .40197 .66023 .40195 .65975 .39598 Mtetra
.669 .407 .514 r
.63766 .39592 .63814 .40195 .64921 .40197 .64872 .39597 Mtetra
.652 .385 .502 r
.62657 .39583 .62704 .40189 .63814 .40195 .63766 .39592 Mtetra
.635 .363 .49 r
.61546 .39569 .61591 .40179 .62704 .40189 .62657 .39583 Mtetra
.619 .342 .476 r
.60434 .39552 .60478 .40165 .61591 .40179 .61546 .39569 Mtetra
.604 .321 .462 r
.59322 .39531 .59364 .40147 .60478 .40165 .60434 .39552 Mtetra
.59 .302 .447 r
.58211 .39507 .5825 .40126 .59364 .40147 .59322 .39531 Mtetra
.579 .284 .433 r
.57103 .3948 .57139 .40102 .5825 .40126 .58211 .39507 Mtetra
.57 .27 .419 r
.55999 .39451 .56031 .40077 .57139 .40102 .57103 .3948 Mtetra
.566 .258 .406 r
.54898 .39422 .54926 .4005 .56031 .40077 .55999 .39451 Mtetra
.565 .251 .395 r
.53802 .39394 .53824 .40024 .54926 .4005 .54898 .39422 Mtetra
.569 .249 .387 r
.52711 .39367 .52727 .39999 .53824 .40024 .53802 .39394 Mtetra
.574 .25 .382 r
.51624 .39342 .51634 .39974 .52727 .39999 .52711 .39367 Mtetra
.581 .255 .382 r
.5054 .3932 .50544 .39951 .51634 .39974 .51624 .39342 Mtetra
.462 .378 .675 r
.09089 .38206 .09089 .38723 .09984 .38772 .09987 .38251 Mtetra
.464 .375 .67 r
.09987 .38251 .09984 .38772 .10885 .38821 .10891 .38297 Mtetra
.466 .373 .665 r
.10891 .38297 .10885 .38821 .11794 .38869 .11803 .38343 Mtetra
.47 .371 .661 r
.11803 .38343 .11794 .38869 .1271 .38918 .12723 .38388 Mtetra
.474 .37 .657 r
.12723 .38388 .1271 .38918 .13635 .38966 .1365 .38434 Mtetra
.479 .37 .653 r
.1365 .38434 .13635 .38966 .14568 .39014 .14586 .38479 Mtetra
.484 .371 .649 r
.14586 .38479 .14568 .39014 .15509 .39062 .1553 .38523 Mtetra
.491 .372 .645 r
.1553 .38523 .15509 .39062 .16459 .39108 .16483 .38567 Mtetra
.498 .373 .641 r
.16483 .38567 .16459 .39108 .17419 .39154 .17445 .38609 Mtetra
.506 .376 .637 r
.17445 .38609 .17419 .39154 .18388 .39199 .18416 .38651 Mtetra
.515 .378 .633 r
.18416 .38651 .18388 .39199 .19367 .39242 .19397 .38691 Mtetra
.524 .382 .629 r
.19397 .38691 .19367 .39242 .20355 .39284 .20387 .3873 Mtetra
.534 .385 .625 r
.20387 .3873 .20355 .39284 .21352 .39324 .21387 .38767 Mtetra
.545 .389 .621 r
.21387 .38767 .21352 .39324 .2236 .39362 .22396 .38802 Mtetra
.556 .394 .617 r
.22396 .38802 .2236 .39362 .23377 .39398 .23415 .38835 Mtetra
.568 .399 .612 r
.23415 .38835 .23377 .39398 .24404 .39432 .24444 .38866 Mtetra
.58 .404 .607 r
.24444 .38866 .24404 .39432 .2544 .39463 .25481 .38894 Mtetra
.593 .409 .602 r
.25481 .38894 .2544 .39463 .26485 .39492 .26528 .3892 Mtetra
.606 .415 .596 r
.26528 .3892 .26485 .39492 .27539 .39517 .27583 .38942 Mtetra
.62 .42 .59 r
.27583 .38942 .27539 .39517 .28602 .3954 .28647 .38962 Mtetra
.634 .426 .584 r
.28647 .38962 .28602 .3954 .29672 .39559 .29718 .38978 Mtetra
.648 .432 .576 r
.29718 .38978 .29672 .39559 .30751 .39574 .30797 .38991 Mtetra
.662 .437 .569 r
.30797 .38991 .30751 .39574 .31836 .39586 .31883 .38999 Mtetra
.676 .443 .56 r
.31883 .38999 .31836 .39586 .32928 .39594 .32975 .39004 Mtetra
.69 .448 .551 r
.32975 .39004 .32928 .39594 .34025 .39598 .34073 .39005 Mtetra
.703 .452 .541 r
.34073 .39005 .34025 .39598 .35128 .39597 .35175 .39002 Mtetra
.716 .456 .53 r
.35175 .39002 .35128 .39597 .36234 .39592 .3628 .38994 Mtetra
.728 .458 .519 r
.3628 .38994 .36234 .39592 .37343 .39583 .37389 .38982 Mtetra
.739 .46 .506 r
.37389 .38982 .37343 .39583 .38454 .39569 .38499 .38966 Mtetra
.749 .46 .493 r
.38499 .38966 .38454 .39569 .39566 .39552 .39609 .38945 Mtetra
.757 .458 .479 r
.39609 .38945 .39566 .39552 .40678 .39531 .40719 .38921 Mtetra
.762 .454 .464 r
.40719 .38921 .40678 .39531 .41789 .39507 .41827 .38894 Mtetra
.765 .448 .449 r
.41827 .38894 .41789 .39507 .42897 .3948 .42932 .38864 Mtetra
.765 .438 .433 r
.42932 .38864 .42897 .3948 .44001 .39451 .44033 .38833 Mtetra
.761 .426 .419 r
.44033 .38833 .44001 .39451 .45102 .39422 .45129 .38801 Mtetra
.754 .412 .405 r
.45129 .38801 .45102 .39422 .46198 .39394 .4622 .38771 Mtetra
.743 .396 .394 r
.4622 .38771 .46198 .39394 .47289 .39367 .47305 .38742 Mtetra
.731 .381 .385 r
.47305 .38742 .47289 .39367 .48376 .39342 .48386 .38718 Mtetra
.72 .368 .381 r
.48386 .38718 .48376 .39342 .4946 .3932 .49463 .38696 Mtetra
.653 .312 .382 r
.49463 .38696 .4946 .3932 .5054 .3932 .50537 .38696 Mtetra
.886 .72 .67 r
.90013 .38251 .90016 .38772 .90911 .38723 .90911 .38206 Mtetra
.885 .715 .665 r
.89109 .38297 .89115 .38821 .90016 .38772 .90013 .38251 Mtetra
.884 .71 .66 r
.88197 .38343 .88206 .38869 .89115 .38821 .89109 .38297 Mtetra
.882 .704 .656 r
.87277 .38388 .8729 .38918 .88206 .38869 .88197 .38343 Mtetra
.88 .698 .652 r
.8635 .38434 .86365 .38966 .8729 .38918 .87277 .38388 Mtetra
.877 .691 .648 r
.85414 .38479 .85432 .39014 .86365 .38966 .8635 .38434 Mtetra
.873 .684 .643 r
.8447 .38523 .84491 .39062 .85432 .39014 .85414 .38479 Mtetra
.869 .676 .639 r
.83517 .38567 .83541 .39108 .84491 .39062 .8447 .38523 Mtetra
.864 .668 .635 r
.82555 .38609 .82581 .39154 .83541 .39108 .83517 .38567 Mtetra
.859 .66 .631 r
.81584 .38651 .81612 .39199 .82581 .39154 .82555 .38609 Mtetra
.853 .65 .627 r
.80603 .38691 .80633 .39242 .81612 .39199 .81584 .38651 Mtetra
.847 .641 .623 r
.79613 .3873 .79645 .39284 .80633 .39242 .80603 .38691 Mtetra
.84 .63 .619 r
.78613 .38767 .78648 .39324 .79645 .39284 .79613 .3873 Mtetra
.832 .619 .615 r
.77604 .38802 .7764 .39362 .78648 .39324 .78613 .38767 Mtetra
.823 .607 .61 r
.76585 .38835 .76623 .39398 .7764 .39362 .77604 .38802 Mtetra
.814 .595 .605 r
.75556 .38866 .75596 .39432 .76623 .39398 .76585 .38835 Mtetra
.804 .581 .6 r
.74519 .38894 .7456 .39463 .75596 .39432 .75556 .38866 Mtetra
.793 .567 .594 r
.73472 .3892 .73515 .39492 .7456 .39463 .74519 .38894 Mtetra
.781 .552 .588 r
.72417 .38942 .72461 .39517 .73515 .39492 .73472 .3892 Mtetra
.769 .536 .582 r
.71353 .38962 .71398 .3954 .72461 .39517 .72417 .38942 Mtetra
.756 .519 .575 r
.70282 .38978 .70328 .39559 .71398 .3954 .71353 .38962 Mtetra
.741 .502 .567 r
.69203 .38991 .69249 .39574 .70328 .39559 .70282 .38978 Mtetra
.726 .483 .559 r
.68117 .38999 .68164 .39586 .69249 .39574 .69203 .38991 Mtetra
.71 .464 .55 r
.67025 .39004 .67072 .39594 .68164 .39586 .68117 .38999 Mtetra
.694 .444 .541 r
.65927 .39005 .65975 .39598 .67072 .39594 .67025 .39004 Mtetra
.677 .423 .53 r
.64825 .39002 .64872 .39597 .65975 .39598 .65927 .39005 Mtetra
.659 .401 .519 r
.6372 .38994 .63766 .39592 .64872 .39597 .64825 .39002 Mtetra
.641 .379 .506 r
.62611 .38982 .62657 .39583 .63766 .39592 .6372 .38994 Mtetra
.623 .357 .493 r
.61501 .38966 .61546 .39569 .62657 .39583 .62611 .38982 Mtetra
.606 .334 .479 r
.60391 .38945 .60434 .39552 .61546 .39569 .61501 .38966 Mtetra
.59 .313 .464 r
.59281 .38921 .59322 .39531 .60434 .39552 .60391 .38945 Mtetra
.575 .292 .449 r
.58173 .38894 .58211 .39507 .59322 .39531 .59281 .38921 Mtetra
.564 .274 .434 r
.57068 .38864 .57103 .3948 .58211 .39507 .58173 .38894 Mtetra
.555 .258 .419 r
.55967 .38833 .55999 .39451 .57103 .3948 .57068 .38864 Mtetra
.552 .247 .405 r
.54871 .38801 .54898 .39422 .55999 .39451 .55967 .38833 Mtetra
.553 .241 .393 r
.5378 .38771 .53802 .39394 .54898 .39422 .54871 .38801 Mtetra
.559 .24 .385 r
.52695 .38742 .52711 .39367 .53802 .39394 .5378 .38771 Mtetra
.569 .245 .38 r
.51614 .38718 .51624 .39342 .52711 .39367 .52695 .38742 Mtetra
.58 .254 .381 r
.50537 .38696 .5054 .3932 .51624 .39342 .51614 .38718 Mtetra
.469 .383 .676 r
.09088 .37688 .09089 .38206 .09987 .38251 .0999 .37731 Mtetra
.471 .381 .672 r
.0999 .37731 .09987 .38251 .10891 .38297 .10898 .37773 Mtetra
.473 .378 .667 r
.10898 .37773 .10891 .38297 .11803 .38343 .11813 .37816 Mtetra
.476 .377 .663 r
.11813 .37816 .11803 .38343 .12723 .38388 .12735 .37859 Mtetra
.48 .376 .659 r
.12735 .37859 .12723 .38388 .1365 .38434 .13665 .37902 Mtetra
.485 .376 .655 r
.13665 .37902 .1365 .38434 .14586 .38479 .14603 .37944 Mtetra
.491 .377 .651 r
.14603 .37944 .14586 .38479 .1553 .38523 .1555 .37985 Mtetra
.498 .378 .647 r
.1555 .37985 .1553 .38523 .16483 .38567 .16505 .38026 Mtetra
.505 .38 .644 r
.16505 .38026 .16483 .38567 .17445 .38609 .1747 .38065 Mtetra
.513 .383 .64 r
.1747 .38065 .17445 .38609 .18416 .38651 .18443 .38104 Mtetra
.522 .385 .636 r
.18443 .38104 .18416 .38651 .19397 .38691 .19426 .38141 Mtetra
.531 .389 .632 r
.19426 .38141 .19397 .38691 .20387 .3873 .20419 .38177 Mtetra
.541 .393 .629 r
.20419 .38177 .20387 .3873 .21387 .38767 .2142 .38211 Mtetra
.552 .397 .624 r
.2142 .38211 .21387 .38767 .22396 .38802 .22431 .38244 Mtetra
.564 .402 .62 r
.22431 .38244 .22396 .38802 .23415 .38835 .23452 .38274 Mtetra
.576 .407 .616 r
.23452 .38274 .23415 .38835 .24444 .38866 .24482 .38302 Mtetra
.588 .412 .611 r
.24482 .38302 .24444 .38866 .25481 .38894 .25521 .38327 Mtetra
.601 .418 .606 r
.25521 .38327 .25481 .38894 .26528 .3892 .26569 .3835 Mtetra
.615 .424 .6 r
.26569 .3835 .26528 .3892 .27583 .38942 .27625 .3837 Mtetra
.629 .43 .594 r
.27625 .3837 .27583 .38942 .28647 .38962 .2869 .38387 Mtetra
.643 .436 .588 r
.2869 .38387 .28647 .38962 .29718 .38978 .29763 .384 Mtetra
.657 .442 .581 r
.29763 .384 .29718 .38978 .30797 .38991 .30842 .3841 Mtetra
.672 .448 .573 r
.30842 .3841 .30797 .38991 .31883 .38999 .31929 .38417 Mtetra
.686 .454 .565 r
.31929 .38417 .31883 .38999 .32975 .39004 .33021 .38419 Mtetra
.7 .459 .556 r
.33021 .38419 .32975 .39004 .34073 .39005 .34118 .38417 Mtetra
.714 .464 .546 r
.34118 .38417 .34073 .39005 .35175 .39002 .3522 .38411 Mtetra
.728 .468 .535 r
.3522 .38411 .35175 .39002 .3628 .38994 .36326 .38401 Mtetra
.74 .471 .523 r
.36326 .38401 .3628 .38994 .37389 .38982 .37433 .38386 Mtetra
.752 .473 .51 r
.37433 .38386 .37389 .38982 .38499 .38966 .38542 .38367 Mtetra
.762 .473 .496 r
.38542 .38367 .38499 .38966 .39609 .38945 .39651 .38344 Mtetra
.77 .472 .482 r
.39651 .38344 .39609 .38945 .40719 .38921 .40759 .38317 Mtetra
.776 .468 .466 r
.40759 .38317 .40719 .38921 .41827 .38894 .41865 .38287 Mtetra
.778 .461 .45 r
.41865 .38287 .41827 .38894 .42932 .38864 .42967 .38255 Mtetra
.778 .451 .434 r
.42967 .38255 .42932 .38864 .44033 .38833 .44064 .3822 Mtetra
.773 .437 .418 r
.44064 .3822 .44033 .38833 .45129 .38801 .45156 .38186 Mtetra
.764 .42 .404 r
.45156 .38186 .45129 .38801 .4622 .38771 .46242 .38154 Mtetra
.751 .401 .391 r
.46242 .38154 .4622 .38771 .47305 .38742 .47322 .38124 Mtetra
.735 .382 .383 r
.47322 .38124 .47305 .38742 .48386 .38718 .48396 .38099 Mtetra
.719 .365 .378 r
.48396 .38099 .48386 .38718 .49463 .38696 .49466 .38079 Mtetra
.652 .31 .38 r
.49466 .38079 .49463 .38696 .50537 .38696 .50534 .38079 Mtetra
.883 .717 .672 r
.9001 .37731 .90013 .38251 .90911 .38206 .90912 .37688 Mtetra
.882 .712 .667 r
.89102 .37773 .89109 .38297 .90013 .38251 .9001 .37731 Mtetra
.88 .707 .663 r
.88187 .37816 .88197 .38343 .89109 .38297 .89102 .37773 Mtetra
.879 .701 .658 r
.87265 .37859 .87277 .38388 .88197 .38343 .88187 .37816 Mtetra
.876 .695 .654 r
.86335 .37902 .8635 .38434 .87277 .38388 .87265 .37859 Mtetra
.873 .689 .65 r
.85397 .37944 .85414 .38479 .8635 .38434 .86335 .37902 Mtetra
.87 .682 .646 r
.8445 .37985 .8447 .38523 .85414 .38479 .85397 .37944 Mtetra
.865 .674 .642 r
.83495 .38026 .83517 .38567 .8447 .38523 .8445 .37985 Mtetra
.861 .666 .638 r
.8253 .38065 .82555 .38609 .83517 .38567 .83495 .38026 Mtetra
.855 .658 .635 r
.81557 .38104 .81584 .38651 .82555 .38609 .8253 .38065 Mtetra
.849 .649 .631 r
.80574 .38141 .80603 .38691 .81584 .38651 .81557 .38104 Mtetra
.843 .639 .627 r
.79581 .38177 .79613 .3873 .80603 .38691 .80574 .38141 Mtetra
.835 .628 .623 r
.7858 .38211 .78613 .38767 .79613 .3873 .79581 .38177 Mtetra
.827 .617 .618 r
.77569 .38244 .77604 .38802 .78613 .38767 .7858 .38211 Mtetra
.819 .605 .614 r
.76548 .38274 .76585 .38835 .77604 .38802 .77569 .38244 Mtetra
.809 .593 .609 r
.75518 .38302 .75556 .38866 .76585 .38835 .76548 .38274 Mtetra
.799 .579 .604 r
.74479 .38327 .74519 .38894 .75556 .38866 .75518 .38302 Mtetra
.788 .565 .599 r
.73431 .3835 .73472 .3892 .74519 .38894 .74479 .38327 Mtetra
.776 .55 .593 r
.72375 .3837 .72417 .38942 .73472 .3892 .73431 .3835 Mtetra
.763 .534 .586 r
.7131 .38387 .71353 .38962 .72417 .38942 .72375 .3837 Mtetra
.749 .517 .58 r
.70237 .384 .70282 .38978 .71353 .38962 .7131 .38387 Mtetra
.734 .499 .572 r
.69158 .3841 .69203 .38991 .70282 .38978 .70237 .384 Mtetra
.719 .48 .564 r
.68071 .38417 .68117 .38999 .69203 .38991 .69158 .3841 Mtetra
.702 .46 .555 r
.66979 .38419 .67025 .39004 .68117 .38999 .68071 .38417 Mtetra
.685 .44 .545 r
.65882 .38417 .65927 .39005 .67025 .39004 .66979 .38419 Mtetra
.667 .418 .535 r
.6478 .38411 .64825 .39002 .65927 .39005 .65882 .38417 Mtetra
.649 .396 .523 r
.63674 .38401 .6372 .38994 .64825 .39002 .6478 .38411 Mtetra
.63 .373 .51 r
.62567 .38386 .62611 .38982 .6372 .38994 .63674 .38401 Mtetra
.611 .35 .497 r
.61458 .38367 .61501 .38966 .62611 .38982 .62567 .38386 Mtetra
.593 .326 .482 r
.60349 .38344 .60391 .38945 .61501 .38966 .61458 .38367 Mtetra
.575 .303 .467 r
.59241 .38317 .59281 .38921 .60391 .38945 .60349 .38344 Mtetra
.56 .282 .451 r
.58135 .38287 .58173 .38894 .59281 .38921 .59241 .38317 Mtetra
.548 .262 .434 r
.57033 .38255 .57068 .38864 .58173 .38894 .58135 .38287 Mtetra
.539 .246 .418 r
.55936 .3822 .55967 .38833 .57068 .38864 .57033 .38255 Mtetra
.536 .235 .403 r
.54844 .38186 .54871 .38801 .55967 .38833 .55936 .3822 Mtetra
.539 .229 .391 r
.53758 .38154 .5378 .38771 .54871 .38801 .54844 .38186 Mtetra
.548 .231 .382 r
.52678 .38124 .52695 .38742 .5378 .38771 .53758 .38154 Mtetra
.563 .239 .377 r
.51604 .38099 .51614 .38718 .52695 .38742 .52678 .38124 Mtetra
.58 .252 .378 r
.50534 .38079 .50537 .38696 .51614 .38718 .51604 .38099 Mtetra
.476 .389 .678 r
.09088 .3717 .09088 .37688 .0999 .37731 .09993 .3721 Mtetra
.477 .386 .674 r
.09993 .3721 .0999 .37731 .10898 .37773 .10904 .3725 Mtetra
.48 .384 .669 r
.10904 .3725 .10898 .37773 .11813 .37816 .11821 .3729 Mtetra
.483 .383 .665 r
.11821 .3729 .11813 .37816 .12735 .37859 .12746 .3733 Mtetra
.487 .382 .661 r
.12746 .3733 .12735 .37859 .13665 .37902 .13679 .3737 Mtetra
.492 .382 .657 r
.13679 .3737 .13665 .37902 .14603 .37944 .1462 .37409 Mtetra
.498 .383 .654 r
.1462 .37409 .14603 .37944 .1555 .37985 .15569 .37448 Mtetra
.504 .385 .65 r
.15569 .37448 .1555 .37985 .16505 .38026 .16527 .37486 Mtetra
.512 .387 .646 r
.16527 .37486 .16505 .38026 .1747 .38065 .17494 .37523 Mtetra
.52 .389 .643 r
.17494 .37523 .1747 .38065 .18443 .38104 .1847 .37559 Mtetra
.529 .392 .639 r
.1847 .37559 .18443 .38104 .19426 .38141 .19454 .37593 Mtetra
.538 .396 .636 r
.19454 .37593 .19426 .38141 .20419 .38177 .20449 .37626 Mtetra
.548 .4 .632 r
.20449 .37626 .20419 .38177 .2142 .38211 .21452 .37658 Mtetra
.559 .405 .628 r
.21452 .37658 .2142 .38211 .22431 .38244 .22465 .37688 Mtetra
.571 .41 .624 r
.22465 .37688 .22431 .38244 .23452 .38274 .23488 .37715 Mtetra
.583 .415 .62 r
.23488 .37715 .23452 .38274 .24482 .38302 .24519 .3774 Mtetra
.596 .421 .615 r
.24519 .3774 .24482 .38302 .25521 .38327 .2556 .37763 Mtetra
.609 .427 .61 r
.2556 .37763 .25521 .38327 .26569 .3835 .26609 .37784 Mtetra
.623 .433 .605 r
.26609 .37784 .26569 .3835 .27625 .3837 .27666 .37801 Mtetra
.637 .44 .599 r
.27666 .37801 .27625 .3837 .2869 .38387 .28732 .37815 Mtetra
.652 .446 .592 r
.28732 .37815 .2869 .38387 .29763 .384 .29805 .37826 Mtetra
.666 .452 .585 r
.29805 .37826 .29763 .384 .30842 .3841 .30886 .37834 Mtetra
.681 .459 .578 r
.30886 .37834 .30842 .3841 .31929 .38417 .31973 .37838 Mtetra
.696 .465 .569 r
.31973 .37838 .31929 .38417 .33021 .38419 .33065 .37838 Mtetra
.71 .471 .56 r
.33065 .37838 .33021 .38419 .34118 .38417 .34163 .37834 Mtetra
.725 .476 .55 r
.34163 .37834 .34118 .38417 .3522 .38411 .35264 .37825 Mtetra
.739 .48 .539 r
.35264 .37825 .3522 .38411 .36326 .38401 .36369 .37813 Mtetra
.752 .484 .527 r
.36369 .37813 .36326 .38401 .37433 .38386 .37476 .37796 Mtetra
.764 .486 .514 r
.37476 .37796 .37433 .38386 .38542 .38367 .38584 .37774 Mtetra
.774 .487 .5 r
.38584 .37774 .38542 .38367 .39651 .38344 .39692 .37749 Mtetra
.783 .485 .484 r
.39692 .37749 .39651 .38344 .40759 .38317 .40799 .3772 Mtetra
.789 .481 .468 r
.40799 .3772 .40759 .38317 .41865 .38287 .41902 .37687 Mtetra
.792 .474 .451 r
.41902 .37687 .41865 .38287 .42967 .38255 .43001 .37652 Mtetra
.791 .463 .434 r
.43001 .37652 .42967 .38255 .44064 .3822 .44095 .37615 Mtetra
.785 .448 .417 r
.44095 .37615 .44064 .3822 .45156 .38186 .45183 .37578 Mtetra
.774 .429 .402 r
.45183 .37578 .45156 .38186 .46242 .38154 .46264 .37544 Mtetra
.758 .407 .388 r
.46264 .37544 .46242 .38154 .47322 .38124 .47338 .37513 Mtetra
.738 .383 .378 r
.47338 .37513 .47322 .38124 .48396 .38099 .48406 .37488 Mtetra
.716 .361 .374 r
.48406 .37488 .48396 .38099 .49466 .38079 .49469 .37468 Mtetra
.651 .307 .376 r
.49469 .37468 .49466 .38079 .50534 .38079 .50531 .37468 Mtetra
.879 .714 .673 r
.90007 .3721 .9001 .37731 .90912 .37688 .90912 .3717 Mtetra
.878 .71 .669 r
.89096 .3725 .89102 .37773 .9001 .37731 .90007 .3721 Mtetra
.877 .705 .665 r
.88179 .3729 .88187 .37816 .89102 .37773 .89096 .3725 Mtetra
.875 .699 .66 r
.87254 .3733 .87265 .37859 .88187 .37816 .88179 .3729 Mtetra
.873 .693 .656 r
.86321 .3737 .86335 .37902 .87265 .37859 .87254 .3733 Mtetra
.87 .687 .653 r
.8538 .37409 .85397 .37944 .86335 .37902 .86321 .3737 Mtetra
.866 .68 .649 r
.84431 .37448 .8445 .37985 .85397 .37944 .8538 .37409 Mtetra
.862 .673 .645 r
.83473 .37486 .83495 .38026 .8445 .37985 .84431 .37448 Mtetra
.857 .665 .641 r
.82506 .37523 .8253 .38065 .83495 .38026 .83473 .37486 Mtetra
.852 .656 .638 r
.8153 .37559 .81557 .38104 .8253 .38065 .82506 .37523 Mtetra
.845 .647 .634 r
.80546 .37593 .80574 .38141 .81557 .38104 .8153 .37559 Mtetra
.839 .637 .63 r
.79551 .37626 .79581 .38177 .80574 .38141 .80546 .37593 Mtetra
.831 .627 .626 r
.78548 .37658 .7858 .38211 .79581 .38177 .79551 .37626 Mtetra
.823 .615 .622 r
.77535 .37688 .77569 .38244 .7858 .38211 .78548 .37658 Mtetra
.814 .604 .618 r
.76512 .37715 .76548 .38274 .77569 .38244 .77535 .37688 Mtetra
.804 .591 .613 r
.75481 .3774 .75518 .38302 .76548 .38274 .76512 .37715 Mtetra
.794 .577 .608 r
.7444 .37763 .74479 .38327 .75518 .38302 .75481 .3774 Mtetra
.782 .563 .603 r
.73391 .37784 .73431 .3835 .74479 .38327 .7444 .37763 Mtetra
.77 .548 .597 r
.72334 .37801 .72375 .3837 .73431 .3835 .73391 .37784 Mtetra
.757 .531 .591 r
.71268 .37815 .7131 .38387 .72375 .3837 .72334 .37801 Mtetra
.742 .514 .584 r
.70195 .37826 .70237 .384 .7131 .38387 .71268 .37815 Mtetra
.727 .496 .577 r
.69114 .37834 .69158 .3841 .70237 .384 .70195 .37826 Mtetra
.711 .477 .569 r
.68027 .37838 .68071 .38417 .69158 .3841 .69114 .37834 Mtetra
.694 .457 .56 r
.66935 .37838 .66979 .38419 .68071 .38417 .68027 .37838 Mtetra
.676 .436 .55 r
.65837 .37834 .65882 .38417 .66979 .38419 .66935 .37838 Mtetra
.657 .414 .539 r
.64736 .37825 .6478 .38411 .65882 .38417 .65837 .37834 Mtetra
.638 .391 .527 r
.63631 .37813 .63674 .38401 .6478 .38411 .64736 .37825 Mtetra
.618 .367 .514 r
.62524 .37796 .62567 .38386 .63674 .38401 .63631 .37813 Mtetra
.598 .343 .5 r
.61416 .37774 .61458 .38367 .62567 .38386 .62524 .37796 Mtetra
.579 .318 .485 r
.60308 .37749 .60349 .38344 .61458 .38367 .61416 .37774 Mtetra
.56 .294 .469 r
.59201 .3772 .59241 .38317 .60349 .38344 .60308 .37749 Mtetra
.544 .271 .452 r
.58098 .37687 .58135 .38287 .59241 .38317 .59201 .3772 Mtetra
.531 .25 .435 r
.56999 .37652 .57033 .38255 .58135 .38287 .58098 .37687 Mtetra
.522 .233 .417 r
.55905 .37615 .55936 .3822 .57033 .38255 .56999 .37652 Mtetra
.519 .221 .401 r
.54817 .37578 .54844 .38186 .55936 .3822 .55905 .37615 Mtetra
.524 .216 .387 r
.53736 .37544 .53758 .38154 .54844 .38186 .54817 .37578 Mtetra
.536 .219 .377 r
.52662 .37513 .52678 .38124 .53758 .38154 .53736 .37544 Mtetra
.556 .231 .373 r
.51594 .37488 .51604 .38099 .52678 .38124 .52662 .37513 Mtetra
.58 .25 .375 r
.50531 .37468 .50534 .38079 .51604 .38099 .51594 .37488 Mtetra
.482 .394 .679 r
.09088 .36652 .09088 .3717 .09993 .3721 .09996 .3669 Mtetra
.484 .391 .675 r
.09996 .3669 .09993 .3721 .10904 .3725 .10909 .36727 Mtetra
.486 .389 .671 r
.10909 .36727 .10904 .3725 .11821 .3729 .1183 .36765 Mtetra
.489 .388 .667 r
.1183 .36765 .11821 .3729 .12746 .3733 .12758 .36802 Mtetra
.493 .388 .663 r
.12758 .36802 .12746 .3733 .13679 .3737 .13693 .36839 Mtetra
.498 .388 .66 r
.13693 .36839 .13679 .3737 .1462 .37409 .14636 .36876 Mtetra
.504 .389 .656 r
.14636 .36876 .1462 .37409 .15569 .37448 .15588 .36912 Mtetra
.51 .391 .653 r
.15588 .36912 .15569 .37448 .16527 .37486 .16548 .36947 Mtetra
.518 .393 .649 r
.16548 .36947 .16527 .37486 .17494 .37523 .17517 .36981 Mtetra
.526 .396 .646 r
.17517 .36981 .17494 .37523 .1847 .37559 .18495 .37015 Mtetra
.535 .399 .642 r
.18495 .37015 .1847 .37559 .19454 .37593 .19482 .37047 Mtetra
.545 .403 .639 r
.19482 .37047 .19454 .37593 .20449 .37626 .20478 .37077 Mtetra
.555 .407 .635 r
.20478 .37077 .20449 .37626 .21452 .37658 .21483 .37106 Mtetra
.566 .412 .631 r
.21483 .37106 .21452 .37658 .22465 .37688 .22498 .37133 Mtetra
.578 .417 .628 r
.22498 .37133 .22465 .37688 .23488 .37715 .23522 .37158 Mtetra
.59 .423 .623 r
.23522 .37158 .23488 .37715 .24519 .3774 .24555 .37181 Mtetra
.603 .429 .619 r
.24555 .37181 .24519 .3774 .2556 .37763 .25597 .37202 Mtetra
.617 .436 .614 r
.25597 .37202 .2556 .37763 .26609 .37784 .26647 .3722 Mtetra
.631 .442 .609 r
.26647 .3722 .26609 .37784 .27666 .37801 .27706 .37235 Mtetra
.645 .449 .603 r
.27706 .37235 .27666 .37801 .28732 .37815 .28772 .37247 Mtetra
.66 .456 .597 r
.28772 .37247 .28732 .37815 .29805 .37826 .29847 .37255 Mtetra
.675 .463 .59 r
.29847 .37255 .29805 .37826 .30886 .37834 .30928 .37261 Mtetra
.69 .469 .582 r
.30928 .37261 .30886 .37834 .31973 .37838 .32015 .37263 Mtetra
.705 .476 .574 r
.32015 .37263 .31973 .37838 .33065 .37838 .33108 .3726 Mtetra
.72 .482 .565 r
.33108 .3726 .33065 .37838 .34163 .37834 .34206 .37254 Mtetra
.735 .488 .555 r
.34206 .37254 .34163 .37834 .35264 .37825 .35307 .37244 Mtetra
.749 .493 .543 r
.35307 .37244 .35264 .37825 .36369 .37813 .36412 .37229 Mtetra
.763 .497 .531 r
.36412 .37229 .36369 .37813 .37476 .37796 .37518 .3721 Mtetra
.776 .5 .518 r
.37518 .3721 .37476 .37796 .38584 .37774 .38625 .37187 Mtetra
.787 .501 .503 r
.38625 .37187 .38584 .37774 .39692 .37749 .39732 .37159 Mtetra
.796 .5 .487 r
.39732 .37159 .39692 .37749 .40799 .3772 .40837 .37128 Mtetra
.802 .496 .47 r
.40837 .37128 .40799 .3772 .41902 .37687 .41938 .37093 Mtetra
.806 .488 .453 r
.41938 .37093 .41902 .37687 .43001 .37652 .43035 .37055 Mtetra
.805 .477 .434 r
.43035 .37055 .43001 .37652 .44095 .37615 .44126 .37015 Mtetra
.798 .46 .416 r
.44126 .37015 .44095 .37615 .45183 .37578 .45209 .36976 Mtetra
.786 .439 .399 r
.45209 .36976 .45183 .37578 .46264 .37544 .46285 .3694 Mtetra
.767 .412 .384 r
.46285 .3694 .46264 .37544 .47338 .37513 .47354 .36907 Mtetra
.742 .383 .373 r
.47354 .36907 .47338 .37513 .48406 .37488 .48416 .36882 Mtetra
.713 .355 .368 r
.48416 .36882 .48406 .37488 .49469 .37468 .49473 .36864 Mtetra
.65 .303 .371 r
.49473 .36864 .49469 .37468 .50531 .37468 .50527 .36864 Mtetra
.876 .712 .675 r
.90004 .3669 .90007 .3721 .90912 .3717 .90912 .36652 Mtetra
.875 .707 .671 r
.89091 .36727 .89096 .3725 .90007 .3721 .90004 .3669 Mtetra
.874 .702 .666 r
.8817 .36765 .88179 .3729 .89096 .3725 .89091 .36727 Mtetra
.872 .697 .662 r
.87242 .36802 .87254 .3733 .88179 .3729 .8817 .36765 Mtetra
.869 .691 .659 r
.86307 .36839 .86321 .3737 .87254 .3733 .87242 .36802 Mtetra
.866 .685 .655 r
.85364 .36876 .8538 .37409 .86321 .3737 .86307 .36839 Mtetra
.862 .678 .651 r
.84412 .36912 .84431 .37448 .8538 .37409 .85364 .36876 Mtetra
.858 .671 .648 r
.83452 .36947 .83473 .37486 .84431 .37448 .84412 .36912 Mtetra
.853 .663 .644 r
.82483 .36981 .82506 .37523 .83473 .37486 .83452 .36947 Mtetra
.848 .654 .641 r
.81505 .37015 .8153 .37559 .82506 .37523 .82483 .36981 Mtetra
.842 .645 .637 r
.80518 .37047 .80546 .37593 .8153 .37559 .81505 .37015 Mtetra
.835 .636 .633 r
.79522 .37077 .79551 .37626 .80546 .37593 .80518 .37047 Mtetra
.827 .625 .63 r
.78517 .37106 .78548 .37658 .79551 .37626 .79522 .37077 Mtetra
.819 .614 .626 r
.77502 .37133 .77535 .37688 .78548 .37658 .78517 .37106 Mtetra
.81 .602 .621 r
.76478 .37158 .76512 .37715 .77535 .37688 .77502 .37133 Mtetra
.8 .589 .617 r
.75445 .37181 .75481 .3774 .76512 .37715 .76478 .37158 Mtetra
.789 .576 .612 r
.74403 .37202 .7444 .37763 .75481 .3774 .75445 .37181 Mtetra
.777 .561 .607 r
.73353 .3722 .73391 .37784 .7444 .37763 .74403 .37202 Mtetra
.764 .546 .601 r
.72294 .37235 .72334 .37801 .73391 .37784 .73353 .3722 Mtetra
.751 .529 .595 r
.71228 .37247 .71268 .37815 .72334 .37801 .72294 .37235 Mtetra
.736 .512 .589 r
.70153 .37255 .70195 .37826 .71268 .37815 .71228 .37247 Mtetra
.72 .494 .581 r
.69072 .37261 .69114 .37834 .70195 .37826 .70153 .37255 Mtetra
.704 .474 .573 r
.67985 .37263 .68027 .37838 .69114 .37834 .69072 .37261 Mtetra
.686 .454 .564 r
.66892 .3726 .66935 .37838 .68027 .37838 .67985 .37263 Mtetra
.667 .432 .555 r
.65794 .37254 .65837 .37834 .66935 .37838 .66892 .3726 Mtetra
.648 .409 .544 r
.64693 .37244 .64736 .37825 .65837 .37834 .65794 .37254 Mtetra
.628 .385 .532 r
.63588 .37229 .63631 .37813 .64736 .37825 .64693 .37244 Mtetra
.607 .361 .519 r
.62482 .3721 .62524 .37796 .63631 .37813 .63588 .37229 Mtetra
.586 .336 .504 r
.61375 .37187 .61416 .37774 .62524 .37796 .62482 .3721 Mtetra
.565 .31 .489 r
.60268 .37159 .60308 .37749 .61416 .37774 .61375 .37187 Mtetra
.545 .285 .472 r
.59163 .37128 .59201 .3772 .60308 .37749 .60268 .37159 Mtetra
.527 .26 .454 r
.58062 .37093 .58098 .37687 .59201 .3772 .59163 .37128 Mtetra
.512 .238 .435 r
.56965 .37055 .56999 .37652 .58098 .37687 .58062 .37093 Mtetra
.503 .219 .416 r
.55874 .37015 .55905 .37615 .56999 .37652 .56965 .37055 Mtetra
.5 .206 .398 r
.54791 .36976 .54817 .37578 .55905 .37615 .55874 .37015 Mtetra
.506 .201 .383 r
.53715 .3694 .53736 .37544 .54817 .37578 .54791 .36976 Mtetra
.522 .205 .372 r
.52646 .36907 .52662 .37513 .53736 .37544 .53715 .3694 Mtetra
.548 .221 .366 r
.51584 .36882 .51594 .37488 .52662 .37513 .52646 .36907 Mtetra
.58 .247 .369 r
.50527 .36864 .50531 .37468 .51594 .37488 .51584 .36882 Mtetra
.488 .399 .681 r
.09088 .36134 .09088 .36652 .09996 .3669 .09998 .36169 Mtetra
.489 .396 .677 r
.09998 .36169 .09996 .3669 .10909 .36727 .10915 .36204 Mtetra
.492 .395 .673 r
.10915 .36204 .10909 .36727 .1183 .36765 .11838 .36239 Mtetra
.495 .394 .669 r
.11838 .36239 .1183 .36765 .12758 .36802 .12768 .36274 Mtetra
.499 .393 .665 r
.12768 .36274 .12758 .36802 .13693 .36839 .13706 .36309 Mtetra
.504 .394 .662 r
.13706 .36309 .13693 .36839 .14636 .36876 .14652 .36343 Mtetra
.51 .395 .658 r
.14652 .36343 .14636 .36876 .15588 .36912 .15606 .36377 Mtetra
.516 .397 .655 r
.15606 .36377 .15588 .36912 .16548 .36947 .16568 .36409 Mtetra
.524 .399 .652 r
.16568 .36409 .16548 .36947 .17517 .36981 .17539 .36441 Mtetra
.532 .402 .649 r
.17539 .36441 .17517 .36981 .18495 .37015 .18519 .36472 Mtetra
.541 .406 .645 r
.18519 .36472 .18495 .37015 .19482 .37047 .19508 .36501 Mtetra
.551 .41 .642 r
.19508 .36501 .19482 .37047 .20478 .37077 .20506 .3653 Mtetra
.562 .414 .638 r
.20506 .3653 .20478 .37077 .21483 .37106 .21513 .36556 Mtetra
.573 .419 .635 r
.21513 .36556 .21483 .37106 .22498 .37133 .22529 .36581 Mtetra
.585 .425 .631 r
.22529 .36581 .22498 .37133 .23522 .37158 .23555 .36603 Mtetra
.597 .431 .627 r
.23555 .36603 .23522 .37158 .24555 .37181 .24589 .36624 Mtetra
.611 .437 .623 r
.24589 .36624 .24555 .37181 .25597 .37202 .25632 .36642 Mtetra
.624 .444 .618 r
.25632 .36642 .25597 .37202 .26647 .3722 .26684 .36658 Mtetra
.639 .451 .613 r
.26684 .36658 .26647 .3722 .27706 .37235 .27744 .36671 Mtetra
.653 .458 .607 r
.27744 .36671 .27706 .37235 .28772 .37247 .28811 .36681 Mtetra
.668 .465 .601 r
.28811 .36681 .28772 .37247 .29847 .37255 .29886 .36688 Mtetra
.684 .473 .594 r
.29886 .36688 .29847 .37255 .30928 .37261 .30968 .36691 Mtetra
.699 .48 .587 r
.30968 .36691 .30928 .37261 .32015 .37263 .32056 .36691 Mtetra
.715 .487 .579 r
.32056 .36691 .32015 .37263 .33108 .3726 .33149 .36687 Mtetra
.73 .493 .569 r
.33149 .36687 .33108 .3726 .34206 .37254 .34247 .36679 Mtetra
.745 .5 .559 r
.34247 .36679 .34206 .37254 .35307 .37244 .35348 .36667 Mtetra
.76 .505 .548 r
.35348 .36667 .35307 .37244 .36412 .37229 .36453 .36651 Mtetra
.774 .51 .536 r
.36453 .36651 .36412 .37229 .37518 .3721 .37559 .3663 Mtetra
.787 .513 .522 r
.37559 .3663 .37518 .3721 .38625 .37187 .38665 .36605 Mtetra
.799 .515 .507 r
.38665 .36605 .38625 .37187 .39732 .37159 .39771 .36575 Mtetra
.809 .514 .491 r
.39771 .36575 .39732 .37159 .40837 .37128 .40874 .36542 Mtetra
.816 .511 .473 r
.40874 .36542 .40837 .37128 .41938 .37093 .41974 .36504 Mtetra
.82 .503 .454 r
.41974 .36504 .41938 .37093 .43035 .37055 .43068 .36464 Mtetra
.819 .491 .434 r
.43068 .36464 .43035 .37055 .44126 .37015 .44156 .36422 Mtetra
.812 .473 .414 r
.44156 .36422 .44126 .37015 .45209 .36976 .45236 .36381 Mtetra
.799 .449 .395 r
.45236 .36381 .45209 .36976 .46285 .3694 .46307 .36341 Mtetra
.776 .419 .379 r
.46307 .36341 .46285 .3694 .47354 .36907 .4737 .36307 Mtetra
.746 .383 .366 r
.4737 .36307 .47354 .36907 .48416 .36882 .48426 .36281 Mtetra
.709 .347 .36 r
.48426 .36281 .48416 .36882 .49473 .36864 .49476 .36265 Mtetra
.647 .296 .363 r
.49476 .36265 .49473 .36864 .50527 .36864 .50524 .36265 Mtetra
.873 .709 .676 r
.90002 .36169 .90004 .3669 .90912 .36652 .90912 .36134 Mtetra
.872 .705 .672 r
.89085 .36204 .89091 .36727 .90004 .3669 .90002 .36169 Mtetra
.87 .7 .668 r
.88162 .36239 .8817 .36765 .89091 .36727 .89085 .36204 Mtetra
.868 .695 .664 r
.87232 .36274 .87242 .36802 .8817 .36765 .88162 .36239 Mtetra
.866 .689 .661 r
.86294 .36309 .86307 .36839 .87242 .36802 .87232 .36274 Mtetra
.863 .683 .657 r
.85348 .36343 .85364 .36876 .86307 .36839 .86294 .36309 Mtetra
.859 .676 .654 r
.84394 .36377 .84412 .36912 .85364 .36876 .85348 .36343 Mtetra
.855 .669 .65 r
.83432 .36409 .83452 .36947 .84412 .36912 .84394 .36377 Mtetra
.85 .661 .647 r
.82461 .36441 .82483 .36981 .83452 .36947 .83432 .36409 Mtetra
.844 .653 .644 r
.81481 .36472 .81505 .37015 .82483 .36981 .82461 .36441 Mtetra
.838 .644 .64 r
.80492 .36501 .80518 .37047 .81505 .37015 .81481 .36472 Mtetra
.831 .634 .637 r
.79494 .3653 .79522 .37077 .80518 .37047 .80492 .36501 Mtetra
.823 .624 .633 r
.78487 .36556 .78517 .37106 .79522 .37077 .79494 .3653 Mtetra
.815 .612 .629 r
.77471 .36581 .77502 .37133 .78517 .37106 .78487 .36556 Mtetra
.805 .601 .625 r
.76445 .36603 .76478 .37158 .77502 .37133 .77471 .36581 Mtetra
.795 .588 .621 r
.75411 .36624 .75445 .37181 .76478 .37158 .76445 .36603 Mtetra
.784 .574 .616 r
.74368 .36642 .74403 .37202 .75445 .37181 .75411 .36624 Mtetra
.772 .56 .611 r
.73316 .36658 .73353 .3722 .74403 .37202 .74368 .36642 Mtetra
.759 .544 .606 r
.72256 .36671 .72294 .37235 .73353 .3722 .73316 .36658 Mtetra
.745 .527 .6 r
.71189 .36681 .71228 .37247 .72294 .37235 .72256 .36671 Mtetra
.73 .51 .593 r
.70114 .36688 .70153 .37255 .71228 .37247 .71189 .36681 Mtetra
.714 .491 .586 r
.69032 .36691 .69072 .37261 .70153 .37255 .70114 .36688 Mtetra
.696 .471 .578 r
.67944 .36691 .67985 .37263 .69072 .37261 .69032 .36691 Mtetra
.678 .45 .569 r
.66851 .36687 .66892 .3726 .67985 .37263 .67944 .36691 Mtetra
.659 .428 .559 r
.65753 .36679 .65794 .37254 .66892 .3726 .66851 .36687 Mtetra
.638 .405 .549 r
.64652 .36667 .64693 .37244 .65794 .37254 .65753 .36679 Mtetra
.617 .381 .536 r
.63547 .36651 .63588 .37229 .64693 .37244 .64652 .36667 Mtetra
.595 .355 .523 r
.62441 .3663 .62482 .3721 .63588 .37229 .63547 .36651 Mtetra
.573 .329 .508 r
.61335 .36605 .61375 .37187 .62482 .3721 .62441 .3663 Mtetra
.55 .302 .492 r
.60229 .36575 .60268 .37159 .61375 .37187 .61335 .36605 Mtetra
.529 .275 .474 r
.59126 .36542 .59163 .37128 .60268 .37159 .60229 .36575 Mtetra
.509 .249 .455 r
.58026 .36504 .58062 .37093 .59163 .37128 .59126 .36542 Mtetra
.493 .224 .435 r
.56932 .36464 .56965 .37055 .58062 .37093 .58026 .36504 Mtetra
.482 .203 .414 r
.55844 .36422 .55874 .37015 .56965 .37055 .56932 .36464 Mtetra
.479 .189 .394 r
.54764 .36381 .54791 .36976 .55874 .37015 .55844 .36422 Mtetra
.486 .183 .377 r
.53693 .36341 .53715 .3694 .54791 .36976 .54764 .36381 Mtetra
.506 .189 .364 r
.5263 .36307 .52646 .36907 .53715 .3694 .53693 .36341 Mtetra
.538 .209 .358 r
.51574 .36281 .51584 .36882 .52646 .36907 .5263 .36307 Mtetra
.58 .242 .361 r
.50524 .36265 .50527 .36864 .51584 .36882 .51574 .36281 Mtetra
.494 .403 .682 r
.09088 .35616 .09088 .36134 .09998 .36169 .10001 .35649 Mtetra
.495 .401 .678 r
.10001 .35649 .09998 .36169 .10915 .36204 .1092 .35682 Mtetra
.497 .399 .674 r
.1092 .35682 .10915 .36204 .11838 .36239 .11846 .35715 Mtetra
.501 .399 .671 r
.11846 .35715 .11838 .36239 .12768 .36274 .12779 .35747 Mtetra
.505 .398 .667 r
.12779 .35747 .12768 .36274 .13706 .36309 .13719 .35779 Mtetra
.51 .399 .664 r
.13719 .35779 .13706 .36309 .14652 .36343 .14667 .35811 Mtetra
.515 .4 .661 r
.14667 .35811 .14652 .36343 .15606 .36377 .15623 .35842 Mtetra
.522 .402 .657 r
.15623 .35842 .15606 .36377 .16568 .36409 .16587 .35872 Mtetra
.53 .405 .654 r
.16587 .35872 .16568 .36409 .17539 .36441 .1756 .35902 Mtetra
.538 .408 .651 r
.1756 .35902 .17539 .36441 .18519 .36472 .18542 .3593 Mtetra
.547 .412 .648 r
.18542 .3593 .18519 .36472 .19508 .36501 .19533 .35957 Mtetra
.557 .416 .645 r
.19533 .35957 .19508 .36501 .20506 .3653 .20533 .35983 Mtetra
.568 .421 .642 r
.20533 .35983 .20506 .3653 .21513 .36556 .21542 .36007 Mtetra
.579 .426 .638 r
.21542 .36007 .21513 .36556 .22529 .36581 .2256 .3603 Mtetra
.591 .432 .635 r
.2256 .3603 .22529 .36581 .23555 .36603 .23586 .36051 Mtetra
.604 .439 .631 r
.23586 .36051 .23555 .36603 .24589 .36624 .24622 .36069 Mtetra
.617 .445 .627 r
.24622 .36069 .24589 .36624 .25632 .36642 .25666 .36085 Mtetra
.631 .452 .622 r
.25666 .36085 .25632 .36642 .26684 .36658 .26719 .36099 Mtetra
.646 .46 .617 r
.26719 .36099 .26684 .36658 .27744 .36671 .2778 .3611 Mtetra
.661 .467 .612 r
.2778 .3611 .27744 .36671 .28811 .36681 .28849 .36118 Mtetra
.676 .475 .606 r
.28849 .36118 .28811 .36681 .29886 .36688 .29924 .36123 Mtetra
.692 .482 .599 r
.29924 .36123 .29886 .36688 .30968 .36691 .31007 .36125 Mtetra
.707 .49 .591 r
.31007 .36125 .30968 .36691 .32056 .36691 .32095 .36123 Mtetra
.723 .497 .583 r
.32095 .36123 .32056 .36691 .33149 .36687 .33188 .36117 Mtetra
.739 .505 .574 r
.33188 .36117 .33149 .36687 .34247 .36679 .34286 .36108 Mtetra
.755 .511 .564 r
.34286 .36108 .34247 .36679 .35348 .36667 .35388 .36094 Mtetra
.77 .518 .553 r
.35388 .36094 .35348 .36667 .36453 .36651 .36492 .36077 Mtetra
.785 .523 .54 r
.36492 .36077 .36453 .36651 .37559 .3663 .37597 .36054 Mtetra
.799 .527 .526 r
.37597 .36054 .37559 .3663 .38665 .36605 .38703 .36028 Mtetra
.811 .529 .511 r
.38703 .36028 .38665 .36605 .39771 .36575 .39808 .35997 Mtetra
.822 .529 .494 r
.39808 .35997 .39771 .36575 .40874 .36542 .4091 .35961 Mtetra
.83 .526 .475 r
.4091 .35961 .40874 .36542 .41974 .36504 .42008 .35922 Mtetra
.834 .519 .455 r
.42008 .35922 .41974 .36504 .43068 .36464 .43101 .3588 Mtetra
.834 .506 .434 r
.43101 .3588 .43068 .36464 .44156 .36422 .44186 .35835 Mtetra
.827 .488 .412 r
.44186 .35835 .44156 .36422 .45236 .36381 .45263 .35791 Mtetra
.812 .461 .391 r
.45263 .35791 .45236 .36381 .46307 .36341 .4633 .35749 Mtetra
.787 .426 .372 r
.4633 .35749 .46307 .36341 .4737 .36307 .47387 .35713 Mtetra
.75 .383 .357 r
.47387 .35713 .4737 .36307 .48426 .36281 .48436 .35686 Mtetra
.705 .337 .35 r
.48436 .35686 .48426 .36281 .49476 .36265 .49479 .35671 Mtetra
.644 .288 .352 r
.49479 .35671 .49476 .36265 .50524 .36265 .50521 .35671 Mtetra
.869 .707 .678 r
.89999 .35649 .90002 .36169 .90912 .36134 .90912 .35616 Mtetra
.869 .702 .674 r
.8908 .35682 .89085 .36204 .90002 .36169 .89999 .35649 Mtetra
.867 .698 .67 r
.88154 .35715 .88162 .36239 .89085 .36204 .8908 .35682 Mtetra
.865 .693 .666 r
.87221 .35747 .87232 .36274 .88162 .36239 .88154 .35715 Mtetra
.863 .687 .663 r
.86281 .35779 .86294 .36309 .87232 .36274 .87221 .35747 Mtetra
.86 .681 .659 r
.85333 .35811 .85348 .36343 .86294 .36309 .86281 .35779 Mtetra
.856 .675 .656 r
.84377 .35842 .84394 .36377 .85348 .36343 .85333 .35811 Mtetra
.851 .667 .653 r
.83413 .35872 .83432 .36409 .84394 .36377 .84377 .35842 Mtetra
.846 .66 .65 r
.8244 .35902 .82461 .36441 .83432 .36409 .83413 .35872 Mtetra
.841 .651 .647 r
.81458 .3593 .81481 .36472 .82461 .36441 .8244 .35902 Mtetra
.834 .642 .643 r
.80467 .35957 .80492 .36501 .81481 .36472 .81458 .3593 Mtetra
.827 .633 .64 r
.79467 .35983 .79494 .3653 .80492 .36501 .80467 .35957 Mtetra
.819 .622 .636 r
.78458 .36007 .78487 .36556 .79494 .3653 .79467 .35983 Mtetra
.811 .611 .633 r
.7744 .3603 .77471 .36581 .78487 .36556 .78458 .36007 Mtetra
.801 .599 .629 r
.76414 .36051 .76445 .36603 .77471 .36581 .7744 .3603 Mtetra
.791 .586 .625 r
.75378 .36069 .75411 .36624 .76445 .36603 .76414 .36051 Mtetra
.779 .573 .62 r
.74334 .36085 .74368 .36642 .75411 .36624 .75378 .36069 Mtetra
.767 .558 .616 r
.73281 .36099 .73316 .36658 .74368 .36642 .74334 .36085 Mtetra
.753 .542 .61 r
.7222 .3611 .72256 .36671 .73316 .36658 .73281 .36099 Mtetra
.739 .526 .604 r
.71151 .36118 .71189 .36681 .72256 .36671 .7222 .3611 Mtetra
.724 .508 .598 r
.70076 .36123 .70114 .36688 .71189 .36681 .71151 .36118 Mtetra
.707 .489 .591 r
.68993 .36125 .69032 .36691 .70114 .36688 .70076 .36123 Mtetra
.689 .469 .583 r
.67905 .36123 .67944 .36691 .69032 .36691 .68993 .36125 Mtetra
.67 .448 .574 r
.66812 .36117 .66851 .36687 .67944 .36691 .67905 .36123 Mtetra
.65 .425 .564 r
.65714 .36108 .65753 .36679 .66851 .36687 .66812 .36117 Mtetra
.629 .401 .553 r
.64612 .36094 .64652 .36667 .65753 .36679 .65714 .36108 Mtetra
.607 .376 .541 r
.63508 .36077 .63547 .36651 .64652 .36667 .64612 .36094 Mtetra
.583 .35 .528 r
.62403 .36054 .62441 .3663 .63547 .36651 .63508 .36077 Mtetra
.56 .322 .513 r
.61297 .36028 .61335 .36605 .62441 .3663 .62403 .36054 Mtetra
.536 .294 .496 r
.60192 .35997 .60229 .36575 .61335 .36605 .61297 .36028 Mtetra
.512 .265 .477 r
.5909 .35961 .59126 .36542 .60229 .36575 .60192 .35997 Mtetra
.49 .237 .457 r
.57992 .35922 .58026 .36504 .59126 .36542 .5909 .35961 Mtetra
.472 .21 .435 r
.56899 .3588 .56932 .36464 .58026 .36504 .57992 .35922 Mtetra
.459 .187 .412 r
.55814 .35835 .55844 .36422 .56932 .36464 .56899 .3588 Mtetra
.455 .17 .39 r
.54737 .35791 .54764 .36381 .55844 .36422 .55814 .35835 Mtetra
.463 .163 .37 r
.5367 .35749 .53693 .36341 .54764 .36381 .54737 .35791 Mtetra
.486 .17 .355 r
.52613 .35713 .5263 .36307 .53693 .36341 .5367 .35749 Mtetra
.525 .193 .347 r
.51564 .35686 .51574 .36281 .5263 .36307 .52613 .35713 Mtetra
.578 .235 .351 r
.50521 .35671 .50524 .36265 .51574 .36281 .51564 .35686 Mtetra
.499 .408 .683 r
.09087 .35099 .09088 .35616 .10001 .35649 .10003 .35129 Mtetra
.501 .406 .679 r
.10003 .35129 .10001 .35649 .1092 .35682 .10925 .35159 Mtetra
.503 .404 .676 r
.10925 .35159 .1092 .35682 .11846 .35715 .11853 .3519 Mtetra
.506 .403 .672 r
.11853 .3519 .11846 .35715 .12779 .35747 .12789 .3522 Mtetra
.51 .403 .669 r
.12789 .3522 .12779 .35747 .13719 .35779 .13731 .3525 Mtetra
.515 .404 .666 r
.13731 .3525 .13719 .35779 .14667 .35811 .14681 .35279 Mtetra
.521 .406 .663 r
.14681 .35279 .14667 .35811 .15623 .35842 .15639 .35308 Mtetra
.528 .408 .66 r
.15639 .35308 .15623 .35842 .16587 .35872 .16606 .35336 Mtetra
.535 .411 .657 r
.16606 .35336 .16587 .35872 .1756 .35902 .17581 .35364 Mtetra
.544 .414 .654 r
.17581 .35364 .1756 .35902 .18542 .3593 .18564 .3539 Mtetra
.553 .418 .651 r
.18564 .3539 .18542 .3593 .19533 .35957 .19557 .35415 Mtetra
.563 .423 .648 r
.19557 .35415 .19533 .35957 .20533 .35983 .20558 .35438 Mtetra
.574 .428 .645 r
.20558 .35438 .20533 .35983 .21542 .36007 .21569 .3546 Mtetra
.585 .433 .642 r
.21569 .3546 .21542 .36007 .2256 .3603 .22588 .35481 Mtetra
.598 .439 .638 r
.22588 .35481 .2256 .3603 .23586 .36051 .23617 .355 Mtetra
.61 .446 .635 r
.23617 .355 .23586 .36051 .24622 .36069 .24654 .35516 Mtetra
.624 .453 .631 r
.24654 .35516 .24622 .36069 .25666 .36085 .25699 .3553 Mtetra
.638 .46 .626 r
.25699 .3553 .25666 .36085 .26719 .36099 .26753 .35542 Mtetra
.653 .468 .621 r
.26753 .35542 .26719 .36099 .2778 .3611 .27815 .35551 Mtetra
.668 .476 .616 r
.27815 .35551 .2778 .3611 .28849 .36118 .28884 .35558 Mtetra
.684 .484 .61 r
.28884 .35558 .28849 .36118 .29924 .36123 .29961 .35561 Mtetra
.7 .492 .603 r
.29961 .35561 .29924 .36123 .31007 .36125 .31044 .35561 Mtetra
.716 .5 .596 r
.31044 .35561 .31007 .36125 .32095 .36123 .32132 .35558 Mtetra
.732 .508 .588 r
.32132 .35558 .32095 .36123 .33188 .36117 .33226 .35551 Mtetra
.748 .516 .579 r
.33226 .35551 .33188 .36117 .34286 .36108 .34324 .35541 Mtetra
.764 .523 .569 r
.34324 .35541 .34286 .36108 .35388 .36094 .35426 .35526 Mtetra
.78 .53 .557 r
.35426 .35526 .35388 .36094 .36492 .36077 .3653 .35507 Mtetra
.795 .536 .545 r
.3653 .35507 .36492 .36077 .37597 .36054 .37635 .35484 Mtetra
.81 .54 .531 r
.37635 .35484 .37597 .36054 .38703 .36028 .3874 .35456 Mtetra
.823 .543 .515 r
.3874 .35456 .38703 .36028 .39808 .35997 .39844 .35423 Mtetra
.835 .544 .497 r
.39844 .35423 .39808 .35997 .4091 .35961 .40945 .35387 Mtetra
.844 .542 .478 r
.40945 .35387 .4091 .35961 .42008 .35922 .42042 .35346 Mtetra
.849 .535 .456 r
.42042 .35346 .42008 .35922 .43101 .3588 .43133 .35301 Mtetra
.85 .523 .433 r
.43133 .35301 .43101 .3588 .44186 .35835 .44215 .35254 Mtetra
.843 .503 .41 r
.44215 .35254 .44186 .35835 .45263 .35791 .45289 .35207 Mtetra
.828 .474 .386 r
.45289 .35207 .45263 .35791 .4633 .35749 .46352 .35163 Mtetra
.8 .434 .364 r
.46352 .35163 .4633 .35749 .47387 .35713 .47404 .35124 Mtetra
.866 .704 .679 r
.89997 .35129 .89999 .35649 .90912 .35616 .90913 .35099 Mtetra
.865 .7 .675 r
.89075 .35159 .8908 .35682 .89999 .35649 .89997 .35129 Mtetra
.864 .696 .672 r
.88147 .3519 .88154 .35715 .8908 .35682 .89075 .35159 Mtetra
.862 .691 .668 r
.87211 .3522 .87221 .35747 .88154 .35715 .88147 .3519 Mtetra
.86 .685 .665 r
.86269 .3525 .86281 .35779 .87221 .35747 .87211 .3522 Mtetra
.856 .68 .662 r
.85319 .35279 .85333 .35811 .86281 .35779 .86269 .3525 Mtetra
.853 .673 .659 r
.84361 .35308 .84377 .35842 .85333 .35811 .85319 .35279 Mtetra
.848 .666 .655 r
.83394 .35336 .83413 .35872 .84377 .35842 .84361 .35308 Mtetra
.843 .658 .652 r
.82419 .35364 .8244 .35902 .83413 .35872 .83394 .35336 Mtetra
.837 .65 .649 r
.81436 .3539 .81458 .3593 .8244 .35902 .82419 .35364 Mtetra
.831 .641 .646 r
.80443 .35415 .80467 .35957 .81458 .3593 .81436 .3539 Mtetra
.823 .632 .643 r
.79442 .35438 .79467 .35983 .80467 .35957 .80443 .35415 Mtetra
.815 .621 .64 r
.78431 .3546 .78458 .36007 .79467 .35983 .79442 .35438 Mtetra
.807 .61 .636 r
.77412 .35481 .7744 .3603 .78458 .36007 .78431 .3546 Mtetra
.797 .598 .633 r
.76383 .355 .76414 .36051 .7744 .3603 .77412 .35481 Mtetra
.786 .585 .629 r
.75346 .35516 .75378 .36069 .76414 .36051 .76383 .355 Mtetra
.775 .572 .625 r
.74301 .3553 .74334 .36085 .75378 .36069 .75346 .35516 Mtetra
.762 .557 .62 r
.73247 .35542 .73281 .36099 .74334 .36085 .74301 .3553 Mtetra
.748 .541 .615 r
.72185 .35551 .7222 .3611 .73281 .36099 .73247 .35542 Mtetra
.733 .524 .609 r
.71116 .35558 .71151 .36118 .7222 .3611 .72185 .35551 Mtetra
.717 .506 .603 r
.70039 .35561 .70076 .36123 .71151 .36118 .71116 .35558 Mtetra
.7 .487 .596 r
.68956 .35561 .68993 .36125 .70076 .36123 .70039 .35561 Mtetra
.682 .467 .588 r
.67868 .35558 .67905 .36123 .68993 .36125 .68956 .35561 Mtetra
.662 .445 .579 r
.66774 .35551 .66812 .36117 .67905 .36123 .67868 .35558 Mtetra
.642 .422 .569 r
.65676 .35541 .65714 .36108 .66812 .36117 .66774 .35551 Mtetra
.619 .398 .558 r
.64574 .35526 .64612 .36094 .65714 .36108 .65676 .35541 Mtetra
.596 .372 .546 r
.6347 .35507 .63508 .36077 .64612 .36094 .64574 .35526 Mtetra
.572 .345 .532 r
.62365 .35484 .62403 .36054 .63508 .36077 .6347 .35507 Mtetra
.547 .316 .517 r
.6126 .35456 .61297 .36028 .62403 .36054 .62365 .35484 Mtetra
.521 .286 .5 r
.60156 .35423 .60192 .35997 .61297 .36028 .6126 .35456 Mtetra
.495 .256 .48 r
.59055 .35387 .5909 .35961 .60192 .35997 .60156 .35423 Mtetra
.471 .225 .459 r
.57958 .35346 .57992 .35922 .5909 .35961 .59055 .35387 Mtetra
.45 .195 .435 r
.56867 .35301 .56899 .3588 .57992 .35922 .57958 .35346 Mtetra
.434 .169 .41 r
.55785 .35254 .55814 .35835 .56899 .3588 .56867 .35301 Mtetra
.428 .149 .385 r
.54711 .35207 .54737 .35791 .55814 .35835 .55785 .35254 Mtetra
.436 .139 .361 r
.53648 .35163 .5367 .35749 .54737 .35791 .54711 .35207 Mtetra
.462 .146 .343 r
.52596 .35124 .52613 .35713 .5367 .35749 .53648 .35163 Mtetra
.505 .412 .684 r
.09087 .34581 .09087 .35099 .10003 .35129 .10006 .34609 Mtetra
.506 .41 .681 r
.10006 .34609 .10003 .35129 .10925 .35159 .1093 .34637 Mtetra
.508 .409 .677 r
.1093 .34637 .10925 .35159 .11853 .3519 .11861 .34665 Mtetra
.511 .408 .674 r
.11861 .34665 .11853 .3519 .12789 .3522 .12798 .34693 Mtetra
.515 .408 .671 r
.12798 .34693 .12789 .3522 .13731 .3525 .13743 .34721 Mtetra
.52 .409 .668 r
.13743 .34721 .13731 .3525 .14681 .35279 .14695 .34748 Mtetra
.526 .411 .665 r
.14695 .34748 .14681 .35279 .15639 .35308 .15655 .34775 Mtetra
.533 .413 .662 r
.15655 .34775 .15639 .35308 .16606 .35336 .16623 .34801 Mtetra
.54 .416 .659 r
.16623 .34801 .16606 .35336 .17581 .35364 .176 .34826 Mtetra
.549 .42 .657 r
.176 .34826 .17581 .35364 .18564 .3539 .18586 .3485 Mtetra
.558 .424 .654 r
.18586 .3485 .18564 .3539 .19557 .35415 .1958 .34873 Mtetra
.568 .429 .651 r
.1958 .34873 .19557 .35415 .20558 .35438 .20583 .34895 Mtetra
.579 .434 .648 r
.20583 .34895 .20558 .35438 .21569 .3546 .21595 .34915 Mtetra
.591 .44 .645 r
.21595 .34915 .21569 .3546 .22588 .35481 .22616 .34933 Mtetra
.603 .446 .642 r
.22616 .34933 .22588 .35481 .23617 .355 .23645 .3495 Mtetra
.617 .453 .638 r
.23645 .3495 .23617 .355 .24654 .35516 .24684 .34965 Mtetra
.63 .461 .634 r
.24684 .34965 .24654 .35516 .25699 .3553 .2573 .34977 Mtetra
.645 .468 .63 r
.2573 .34977 .25699 .3553 .26753 .35542 .26785 .34988 Mtetra
.66 .476 .625 r
.26785 .34988 .26753 .35542 .27815 .35551 .27848 .34995 Mtetra
.675 .485 .62 r
.27848 .34995 .27815 .35551 .28884 .35558 .28918 .35 Mtetra
.691 .493 .615 r
.28918 .35 .28884 .35558 .29961 .35561 .29995 .35002 Mtetra
.707 .501 .608 r
.29995 .35002 .29961 .35561 .31044 .35561 .31079 .35001 Mtetra
.723 .51 .601 r
.31079 .35001 .31044 .35561 .32132 .35558 .32168 .34997 Mtetra
.74 .518 .593 r
.32168 .34997 .32132 .35558 .33226 .35551 .33262 .34989 Mtetra
.757 .527 .584 r
.33262 .34989 .33226 .35551 .34324 .35541 .3436 .34977 Mtetra
.773 .534 .574 r
.3436 .34977 .34324 .35541 .35426 .35526 .35462 .34961 Mtetra
.79 .542 .562 r
.35462 .34961 .35426 .35526 .3653 .35507 .36566 .34941 Mtetra
.806 .548 .55 r
.36566 .34941 .3653 .35507 .37635 .35484 .37671 .34917 Mtetra
.821 .554 .535 r
.37671 .34917 .37635 .35484 .3874 .35456 .38775 .34888 Mtetra
.835 .558 .519 r
.38775 .34888 .3874 .35456 .39844 .35423 .39878 .34855 Mtetra
.847 .559 .501 r
.39878 .34855 .39844 .35423 .40945 .35387 .40979 .34817 Mtetra
.857 .558 .48 r
.40979 .34817 .40945 .35387 .42042 .35346 .42074 .34775 Mtetra
.864 .552 .458 r
.42074 .34775 .42042 .35346 .43133 .35301 .43164 .34729 Mtetra
.866 .54 .433 r
.43164 .34729 .43133 .35301 .44215 .35254 .44245 .3468 Mtetra
.86 .52 .407 r
.44245 .3468 .44215 .35254 .45289 .35207 .45315 .3463 Mtetra
.845 .489 .38 r
.45315 .3463 .45289 .35207 .46352 .35163 .46374 .34582 Mtetra
.863 .702 .68 r
.89994 .34609 .89997 .35129 .90913 .35099 .90913 .34581 Mtetra
.862 .698 .677 r
.8907 .34637 .89075 .35159 .89997 .35129 .89994 .34609 Mtetra
.861 .694 .673 r
.88139 .34665 .88147 .3519 .89075 .35159 .8907 .34637 Mtetra
.859 .689 .67 r
.87202 .34693 .87211 .3522 .88147 .3519 .88139 .34665 Mtetra
.857 .684 .667 r
.86257 .34721 .86269 .3525 .87211 .3522 .87202 .34693 Mtetra
.853 .678 .664 r
.85305 .34748 .85319 .35279 .86269 .3525 .86257 .34721 Mtetra
.85 .672 .661 r
.84345 .34775 .84361 .35308 .85319 .35279 .85305 .34748 Mtetra
.845 .665 .658 r
.83377 .34801 .83394 .35336 .84361 .35308 .84345 .34775 Mtetra
.84 .657 .655 r
.824 .34826 .82419 .35364 .83394 .35336 .83377 .34801 Mtetra
.834 .649 .652 r
.81414 .3485 .81436 .3539 .82419 .35364 .824 .34826 Mtetra
.827 .64 .649 r
.8042 .34873 .80443 .35415 .81436 .3539 .81414 .3485 Mtetra
.82 .63 .646 r
.79417 .34895 .79442 .35438 .80443 .35415 .8042 .34873 Mtetra
.812 .62 .643 r
.78405 .34915 .78431 .3546 .79442 .35438 .79417 .34895 Mtetra
.803 .609 .64 r
.77384 .34933 .77412 .35481 .78431 .3546 .78405 .34915 Mtetra
.793 .597 .637 r
.76355 .3495 .76383 .355 .77412 .35481 .77384 .34933 Mtetra
.782 .584 .633 r
.75316 .34965 .75346 .35516 .76383 .355 .76355 .3495 Mtetra
.77 .57 .629 r
.7427 .34977 .74301 .3553 .75346 .35516 .75316 .34965 Mtetra
.757 .556 .624 r
.73215 .34988 .73247 .35542 .74301 .3553 .7427 .34977 Mtetra
.743 .54 .619 r
.72152 .34995 .72185 .35551 .73247 .35542 .73215 .34988 Mtetra
.728 .523 .614 r
.71082 .35 .71116 .35558 .72185 .35551 .72152 .34995 Mtetra
.712 .505 .607 r
.70005 .35002 .70039 .35561 .71116 .35558 .71082 .35 Mtetra
.694 .485 .601 r
.68921 .35001 .68956 .35561 .70039 .35561 .70005 .35002 Mtetra
.675 .465 .593 r
.67832 .34997 .67868 .35558 .68956 .35561 .68921 .35001 Mtetra
.655 .443 .584 r
.66738 .34989 .66774 .35551 .67868 .35558 .67832 .34997 Mtetra
.633 .419 .575 r
.6564 .34977 .65676 .35541 .66774 .35551 .66738 .34989 Mtetra
.61 .394 .564 r
.64538 .34961 .64574 .35526 .65676 .35541 .6564 .34977 Mtetra
.586 .368 .551 r
.63434 .34941 .6347 .35507 .64574 .35526 .64538 .34961 Mtetra
.56 .34 .538 r
.62329 .34917 .62365 .35484 .6347 .35507 .63434 .34941 Mtetra
.534 .31 .522 r
.61225 .34888 .6126 .35456 .62365 .35484 .62329 .34917 Mtetra
.506 .279 .504 r
.60122 .34855 .60156 .35423 .6126 .35456 .61225 .34888 Mtetra
.478 .246 .484 r
.59021 .34817 .59055 .35387 .60156 .35423 .60122 .34855 Mtetra
.451 .213 .461 r
.57926 .34775 .57958 .35346 .59055 .35387 .59021 .34817 Mtetra
.426 .18 .435 r
.56836 .34729 .56867 .35301 .57958 .35346 .57926 .34775 Mtetra
.407 .15 .408 r
.55755 .3468 .55785 .35254 .56867 .35301 .56836 .34729 Mtetra
.398 .125 .379 r
.54685 .3463 .54711 .35207 .55785 .35254 .55755 .3468 Mtetra
.405 .112 .352 r
.53626 .34582 .53648 .35163 .54711 .35207 .54685 .3463 Mtetra
.509 .416 .685 r
.09087 .34063 .09087 .34581 .10006 .34609 .10008 .34089 Mtetra
.511 .414 .682 r
.10008 .34089 .10006 .34609 .1093 .34637 .10935 .34115 Mtetra
.513 .413 .679 r
.10935 .34115 .1093 .34637 .11861 .34665 .11867 .34141 Mtetra
.516 .412 .675 r
.11867 .34141 .11861 .34665 .12798 .34693 .12807 .34167 Mtetra
.52 .413 .673 r
.12807 .34167 .12798 .34693 .13743 .34721 .13754 .34193 Mtetra
.525 .414 .67 r
.13754 .34193 .13743 .34721 .14695 .34748 .14708 .34218 Mtetra
.531 .416 .667 r
.14708 .34218 .14695 .34748 .15655 .34775 .1567 .34243 Mtetra
.538 .418 .664 r
.1567 .34243 .15655 .34775 .16623 .34801 .1664 .34267 Mtetra
.545 .421 .662 r
.1664 .34267 .16623 .34801 .176 .34826 .17619 .3429 Mtetra
.554 .425 .659 r
.17619 .3429 .176 .34826 .18586 .3485 .18606 .34312 Mtetra
.563 .43 .657 r
.18606 .34312 .18586 .3485 .1958 .34873 .19602 .34333 Mtetra
.574 .435 .654 r
.19602 .34333 .1958 .34873 .20583 .34895 .20606 .34353 Mtetra
.585 .44 .651 r
.20606 .34353 .20583 .34895 .21595 .34915 .2162 .34371 Mtetra
.596 .447 .648 r
.2162 .34371 .21595 .34915 .22616 .34933 .22642 .34388 Mtetra
.609 .453 .645 r
.22642 .34388 .22616 .34933 .23645 .3495 .23673 .34403 Mtetra
.622 .46 .642 r
.23673 .34403 .23645 .3495 .24684 .34965 .24712 .34416 Mtetra
.636 .468 .638 r
.24712 .34416 .24684 .34965 .2573 .34977 .2576 .34427 Mtetra
.651 .476 .634 r
.2576 .34427 .2573 .34977 .26785 .34988 .26816 .34435 Mtetra
.666 .484 .63 r
.26816 .34435 .26785 .34988 .27848 .34995 .2788 .34442 Mtetra
.682 .493 .625 r
.2788 .34442 .27848 .34995 .28918 .35 .28951 .34445 Mtetra
.698 .502 .619 r
.28951 .34445 .28918 .35 .29995 .35002 .30028 .34446 Mtetra
.714 .511 .613 r
.30028 .34446 .29995 .35002 .31079 .35001 .31112 .34444 Mtetra
.731 .52 .606 r
.31112 .34444 .31079 .35001 .32168 .34997 .32202 .34438 Mtetra
.748 .529 .598 r
.32202 .34438 .32168 .34997 .33262 .34989 .33297 .34429 Mtetra
.765 .537 .589 r
.33297 .34429 .33262 .34989 .3436 .34977 .34395 .34417 Mtetra
.782 .546 .579 r
.34395 .34417 .3436 .34977 .35462 .34961 .35497 .344 Mtetra
.799 .554 .567 r
.35497 .344 .35462 .34961 .36566 .34941 .366 .3438 Mtetra
.815 .561 .554 r
.366 .3438 .36566 .34941 .37671 .34917 .37705 .34355 Mtetra
.831 .567 .54 r
.37705 .34355 .37671 .34917 .38775 .34888 .38809 .34326 Mtetra
.846 .572 .523 r
.38809 .34326 .38775 .34888 .39878 .34855 .39912 .34292 Mtetra
.859 .575 .505 r
.39912 .34292 .39878 .34855 .40979 .34817 .41011 .34253 Mtetra
.871 .574 .484 r
.41011 .34253 .40979 .34817 .42074 .34775 .42106 .3421 Mtetra
.879 .57 .46 r
.42106 .3421 .42074 .34775 .43164 .34729 .43194 .34162 Mtetra
.882 .559 .433 r
.43194 .34162 .43164 .34729 .44245 .3468 .44273 .34111 Mtetra
.86 .7 .682 r
.89992 .34089 .89994 .34609 .90913 .34581 .90913 .34063 Mtetra
.86 .696 .678 r
.89065 .34115 .8907 .34637 .89994 .34609 .89992 .34089 Mtetra
.858 .692 .675 r
.88133 .34141 .88139 .34665 .8907 .34637 .89065 .34115 Mtetra
.856 .687 .672 r
.87193 .34167 .87202 .34693 .88139 .34665 .88133 .34141 Mtetra
.854 .682 .669 r
.86246 .34193 .86257 .34721 .87202 .34693 .87193 .34167 Mtetra
.85 .677 .666 r
.85292 .34218 .85305 .34748 .86257 .34721 .86246 .34193 Mtetra
.847 .67 .663 r
.8433 .34243 .84345 .34775 .85305 .34748 .85292 .34218 Mtetra
.842 .663 .66 r
.8336 .34267 .83377 .34801 .84345 .34775 .8433 .34243 Mtetra
.837 .656 .658 r
.82381 .3429 .824 .34826 .83377 .34801 .8336 .34267 Mtetra
.831 .648 .655 r
.81394 .34312 .81414 .3485 .824 .34826 .82381 .3429 Mtetra
.824 .639 .652 r
.80398 .34333 .8042 .34873 .81414 .3485 .81394 .34312 Mtetra
.817 .63 .65 r
.79394 .34353 .79417 .34895 .8042 .34873 .80398 .34333 Mtetra
.808 .619 .647 r
.7838 .34371 .78405 .34915 .79417 .34895 .79394 .34353 Mtetra
.799 .608 .644 r
.77358 .34388 .77384 .34933 .78405 .34915 .7838 .34371 Mtetra
.789 .596 .64 r
.76327 .34403 .76355 .3495 .77384 .34933 .77358 .34388 Mtetra
.778 .583 .637 r
.75288 .34416 .75316 .34965 .76355 .3495 .76327 .34403 Mtetra
.766 .57 .633 r
.7424 .34427 .7427 .34977 .75316 .34965 .75288 .34416 Mtetra
.753 .555 .628 r
.73184 .34435 .73215 .34988 .7427 .34977 .7424 .34427 Mtetra
.738 .539 .624 r
.7212 .34442 .72152 .34995 .73215 .34988 .73184 .34435 Mtetra
.723 .522 .618 r
.71049 .34445 .71082 .35 .72152 .34995 .7212 .34442 Mtetra
.706 .504 .612 r
.69972 .34446 .70005 .35002 .71082 .35 .71049 .34445 Mtetra
.688 .484 .606 r
.68888 .34444 .68921 .35001 .70005 .35002 .69972 .34446 Mtetra
.668 .463 .598 r
.67798 .34438 .67832 .34997 .68921 .35001 .68888 .34444 Mtetra
.648 .441 .589 r
.66703 .34429 .66738 .34989 .67832 .34997 .67798 .34438 Mtetra
.625 .417 .58 r
.65605 .34417 .6564 .34977 .66738 .34989 .66703 .34429 Mtetra
.601 .392 .569 r
.64503 .344 .64538 .34961 .6564 .34977 .65605 .34417 Mtetra
.576 .365 .557 r
.634 .3438 .63434 .34941 .64538 .34961 .64503 .344 Mtetra
.549 .336 .543 r
.62295 .34355 .62329 .34917 .63434 .34941 .634 .3438 Mtetra
.521 .305 .527 r
.61191 .34326 .61225 .34888 .62329 .34917 .62295 .34355 Mtetra
.491 .272 .509 r
.60088 .34292 .60122 .34855 .61225 .34888 .61191 .34326 Mtetra
.461 .237 .488 r
.58989 .34253 .59021 .34817 .60122 .34855 .60088 .34292 Mtetra
.43 .201 .464 r
.57894 .3421 .57926 .34775 .59021 .34817 .58989 .34253 Mtetra
.402 .165 .436 r
.56806 .34162 .56836 .34729 .57926 .34775 .57894 .3421 Mtetra
.378 .13 .406 r
.55727 .34111 .55755 .3468 .56836 .34729 .56806 .34162 Mtetra
.514 .42 .686 r
.09087 .33545 .09087 .34063 .10008 .34089 .1001 .33569 Mtetra
.515 .418 .683 r
.1001 .33569 .10008 .34089 .10935 .34115 .10939 .33593 Mtetra
.517 .417 .68 r
.10939 .33593 .10935 .34115 .11867 .34141 .11874 .33618 Mtetra
.52 .417 .677 r
.11874 .33618 .11867 .34141 .12807 .34167 .12815 .33641 Mtetra
.525 .417 .674 r
.12815 .33641 .12807 .34167 .13754 .34193 .13764 .33665 Mtetra
.53 .418 .672 r
.13764 .33665 .13754 .34193 .14708 .34218 .1472 .33688 Mtetra
.536 .42 .669 r
.1472 .33688 .14708 .34218 .1567 .34243 .15684 .33711 Mtetra
.542 .423 .667 r
.15684 .33711 .1567 .34243 .1664 .34267 .16656 .33733 Mtetra
.55 .426 .664 r
.16656 .33733 .1664 .34267 .17619 .3429 .17636 .33754 Mtetra
.559 .43 .662 r
.17636 .33754 .17619 .3429 .18606 .34312 .18625 .33774 Mtetra
.568 .435 .659 r
.18625 .33774 .18606 .34312 .19602 .34333 .19622 .33794 Mtetra
.579 .44 .657 r
.19622 .33794 .19602 .34333 .20606 .34353 .20628 .33811 Mtetra
.59 .446 .654 r
.20628 .33811 .20606 .34353 .2162 .34371 .21643 .33828 Mtetra
.602 .453 .652 r
.21643 .33828 .2162 .34371 .22642 .34388 .22667 .33843 Mtetra
.614 .46 .649 r
.22667 .33843 .22642 .34388 .23673 .34403 .23699 .33857 Mtetra
.628 .467 .646 r
.23699 .33857 .23673 .34403 .24712 .34416 .24739 .33868 Mtetra
.642 .475 .642 r
.24739 .33868 .24712 .34416 .2576 .34427 .25788 .33878 Mtetra
.657 .484 .638 r
.25788 .33878 .2576 .34427 .26816 .34435 .26845 .33885 Mtetra
.672 .492 .634 r
.26845 .33885 .26816 .34435 .2788 .34442 .2791 .3389 Mtetra
.688 .501 .629 r
.2791 .3389 .2788 .34442 .28951 .34445 .28981 .33893 Mtetra
.704 .51 .624 r
.28981 .33893 .28951 .34445 .30028 .34446 .3006 .33892 Mtetra
.721 .52 .617 r
.3006 .33892 .30028 .34446 .31112 .34444 .31144 .33889 Mtetra
.738 .529 .611 r
.31144 .33889 .31112 .34444 .32202 .34438 .32234 .33883 Mtetra
.755 .539 .603 r
.32234 .33883 .32202 .34438 .33297 .34429 .33329 .33873 Mtetra
.773 .548 .594 r
.33329 .33873 .33297 .34429 .34395 .34417 .34428 .3386 Mtetra
.79 .557 .584 r
.34428 .3386 .34395 .34417 .35497 .344 .35529 .33843 Mtetra
.807 .565 .573 r
.35529 .33843 .35497 .344 .366 .3438 .36633 .33822 Mtetra
.824 .573 .56 r
.36633 .33822 .366 .3438 .37705 .34355 .37737 .33797 Mtetra
.841 .58 .545 r
.37737 .33797 .37705 .34355 .38809 .34326 .38841 .33768 Mtetra
.857 .586 .528 r
.38841 .33768 .38809 .34326 .39912 .34292 .39943 .33734 Mtetra
.871 .59 .509 r
.39943 .33734 .39912 .34292 .41011 .34253 .41042 .33694 Mtetra
.884 .591 .487 r
.41042 .33694 .41011 .34253 .42106 .3421 .42136 .3365 Mtetra
.893 .588 .462 r
.42136 .3365 .42106 .3421 .43194 .34162 .43223 .33601 Mtetra
.898 .578 .433 r
.43223 .33601 .43194 .34162 .44273 .34111 .44301 .33548 Mtetra
.858 .698 .683 r
.8999 .33569 .89992 .34089 .90913 .34063 .90913 .33545 Mtetra
.857 .694 .679 r
.89061 .33593 .89065 .34115 .89992 .34089 .8999 .33569 Mtetra
.856 .69 .676 r
.88126 .33618 .88133 .34141 .89065 .34115 .89061 .33593 Mtetra
.854 .686 .673 r
.87185 .33641 .87193 .34167 .88133 .34141 .88126 .33618 Mtetra
.851 .681 .671 r
.86236 .33665 .86246 .34193 .87193 .34167 .87185 .33641 Mtetra
.848 .675 .668 r
.8528 .33688 .85292 .34218 .86246 .34193 .86236 .33665 Mtetra
.844 .669 .665 r
.84316 .33711 .8433 .34243 .85292 .34218 .8528 .33688 Mtetra
.839 .662 .663 r
.83344 .33733 .8336 .34267 .8433 .34243 .84316 .33711 Mtetra
.834 .655 .66 r
.82364 .33754 .82381 .3429 .8336 .34267 .83344 .33733 Mtetra
.828 .647 .658 r
.81375 .33774 .81394 .34312 .82381 .3429 .82364 .33754 Mtetra
.821 .638 .655 r
.80378 .33794 .80398 .34333 .81394 .34312 .81375 .33774 Mtetra
.813 .629 .653 r
.79372 .33811 .79394 .34353 .80398 .34333 .80378 .33794 Mtetra
.805 .619 .65 r
.78357 .33828 .7838 .34371 .79394 .34353 .79372 .33811 Mtetra
.796 .608 .647 r
.77333 .33843 .77358 .34388 .7838 .34371 .78357 .33828 Mtetra
.785 .596 .644 r
.76301 .33857 .76327 .34403 .77358 .34388 .77333 .33843 Mtetra
.774 .583 .641 r
.75261 .33868 .75288 .34416 .76327 .34403 .76301 .33857 Mtetra
.762 .569 .637 r
.74212 .33878 .7424 .34427 .75288 .34416 .75261 .33868 Mtetra
.748 .554 .633 r
.73155 .33885 .73184 .34435 .7424 .34427 .74212 .33878 Mtetra
.733 .538 .628 r
.7209 .3389 .7212 .34442 .73184 .34435 .73155 .33885 Mtetra
.718 .521 .623 r
.71019 .33893 .71049 .34445 .7212 .34442 .7209 .3389 Mtetra
.7 .503 .617 r
.6994 .33892 .69972 .34446 .71049 .34445 .71019 .33893 Mtetra
.682 .483 .611 r
.68856 .33889 .68888 .34444 .69972 .34446 .6994 .33892 Mtetra
.662 .462 .603 r
.67766 .33883 .67798 .34438 .68888 .34444 .68856 .33889 Mtetra
.641 .439 .595 r
.66671 .33873 .66703 .34429 .67798 .34438 .67766 .33883 Mtetra
.618 .415 .585 r
.65572 .3386 .65605 .34417 .66703 .34429 .66671 .33873 Mtetra
.593 .389 .575 r
.64471 .33843 .64503 .344 .65605 .34417 .65572 .3386 Mtetra
.566 .362 .562 r
.63367 .33822 .634 .3438 .64503 .344 .64471 .33843 Mtetra
.538 .332 .548 r
.62263 .33797 .62295 .34355 .634 .3438 .63367 .33822 Mtetra
.508 .3 .532 r
.61159 .33768 .61191 .34326 .62295 .34355 .62263 .33797 Mtetra
.477 .266 .514 r
.60057 .33734 .60088 .34292 .61191 .34326 .61159 .33768 Mtetra
.443 .229 .492 r
.58958 .33694 .58989 .34253 .60088 .34292 .60057 .33734 Mtetra
.409 .19 .467 r
.57864 .3365 .57894 .3421 .58989 .34253 .58958 .33694 Mtetra
.376 .149 .438 r
.56777 .33601 .56806 .34162 .57894 .3421 .57864 .3365 Mtetra
.347 .109 .404 r
.55699 .33548 .55727 .34111 .56806 .34162 .56777 .33601 Mtetra
.518 .423 .687 r
.09087 .33027 .09087 .33545 .1001 .33569 .10012 .3305 Mtetra
.52 .422 .684 r
.10012 .3305 .1001 .33569 .10939 .33593 .10943 .33072 Mtetra
.522 .421 .681 r
.10943 .33072 .10939 .33593 .11874 .33618 .1188 .33094 Mtetra
.525 .421 .678 r
.1188 .33094 .11874 .33618 .12815 .33641 .12823 .33116 Mtetra
.529 .421 .676 r
.12823 .33116 .12815 .33641 .13764 .33665 .13774 .33138 Mtetra
.534 .423 .673 r
.13774 .33138 .13764 .33665 .1472 .33688 .14732 .33159 Mtetra
.54 .425 .671 r
.14732 .33159 .1472 .33688 .15684 .33711 .15697 .3318 Mtetra
.547 .428 .669 r
.15697 .3318 .15684 .33711 .16656 .33733 .16671 .332 Mtetra
.555 .431 .667 r
.16671 .332 .16656 .33733 .17636 .33754 .17653 .33219 Mtetra
.563 .436 .664 r
.17653 .33219 .17636 .33754 .18625 .33774 .18643 .33238 Mtetra
.573 .44 .662 r
.18643 .33238 .18625 .33774 .19622 .33794 .19642 .33255 Mtetra
.583 .446 .66 r
.19642 .33255 .19622 .33794 .20628 .33811 .20649 .33272 Mtetra
.595 .452 .657 r
.20649 .33272 .20628 .33811 .21643 .33828 .21665 .33287 Mtetra
.607 .459 .655 r
.21665 .33287 .21643 .33828 .22667 .33843 .2269 .333 Mtetra
.619 .466 .652 r
.2269 .333 .22667 .33843 .23699 .33857 .23723 .33312 Mtetra
.633 .474 .649 r
.23723 .33312 .23699 .33857 .24739 .33868 .24765 .33322 Mtetra
.647 .482 .646 r
.24765 .33322 .24739 .33868 .25788 .33878 .25815 .3333 Mtetra
.662 .491 .642 r
.25815 .3333 .25788 .33878 .26845 .33885 .26873 .33337 Mtetra
.678 .5 .638 r
.26873 .33337 .26845 .33885 .2791 .3389 .27938 .33341 Mtetra
.694 .509 .633 r
.27938 .33341 .2791 .3389 .28981 .33893 .2901 .33342 Mtetra
.71 .519 .628 r
.2901 .33342 .28981 .33893 .3006 .33892 .30089 .33341 Mtetra
.727 .529 .622 r
.30089 .33341 .3006 .33892 .31144 .33889 .31175 .33337 Mtetra
.745 .539 .615 r
.31175 .33337 .31144 .33889 .32234 .33883 .32265 .3333 Mtetra
.762 .548 .608 r
.32265 .3333 .32234 .33883 .33329 .33873 .3336 .3332 Mtetra
.78 .558 .599 r
.3336 .3332 .33329 .33873 .34428 .3386 .34459 .33307 Mtetra
.798 .568 .589 r
.34459 .33307 .34428 .3386 .35529 .33843 .3556 .33289 Mtetra
.815 .577 .578 r
.3556 .33289 .35529 .33843 .36633 .33822 .36664 .33269 Mtetra
.833 .586 .565 r
.36664 .33269 .36633 .33822 .37737 .33797 .37768 .33243 Mtetra
.85 .594 .55 r
.37768 .33243 .37737 .33797 .38841 .33768 .38871 .33214 Mtetra
.867 .6 .533 r
.38871 .33214 .38841 .33768 .39943 .33734 .39973 .3318 Mtetra
.882 .605 .514 r
.39973 .3318 .39943 .33734 .41042 .33694 .41071 .33141 Mtetra
.896 .608 .491 r
.41071 .33141 .41042 .33694 .42136 .3365 .42165 .33096 Mtetra
.907 .606 .464 r
.42165 .33096 .42136 .3365 .43223 .33601 .43251 .33047 Mtetra
.855 .696 .684 r
.89988 .3305 .8999 .33569 .90913 .33545 .90913 .33027 Mtetra
.854 .692 .681 r
.89057 .33072 .89061 .33593 .8999 .33569 .89988 .3305 Mtetra
.853 .689 .678 r
.8812 .33094 .88126 .33618 .89061 .33593 .89057 .33072 Mtetra
.851 .684 .675 r
.87177 .33116 .87185 .33641 .88126 .33618 .8812 .33094 Mtetra
.848 .679 .672 r
.86226 .33138 .86236 .33665 .87185 .33641 .87177 .33116 Mtetra
.845 .674 .67 r
.85268 .33159 .8528 .33688 .86236 .33665 .86226 .33138 Mtetra
.841 .668 .668 r
.84303 .3318 .84316 .33711 .8528 .33688 .85268 .33159 Mtetra
.836 .661 .665 r
.83329 .332 .83344 .33733 .84316 .33711 .84303 .3318 Mtetra
.831 .654 .663 r
.82347 .33219 .82364 .33754 .83344 .33733 .83329 .332 Mtetra
.825 .646 .661 r
.81357 .33238 .81375 .33774 .82364 .33754 .82347 .33219 Mtetra
.818 .638 .658 r
.80358 .33255 .80378 .33794 .81375 .33774 .81357 .33238 Mtetra
.81 .628 .656 r
.79351 .33272 .79372 .33811 .80378 .33794 .80358 .33255 Mtetra
.802 .618 .653 r
.78335 .33287 .78357 .33828 .79372 .33811 .79351 .33272 Mtetra
.792 .607 .651 r
.7731 .333 .77333 .33843 .78357 .33828 .78335 .33287 Mtetra
.782 .595 .648 r
.76277 .33312 .76301 .33857 .77333 .33843 .7731 .333 Mtetra
.77 .582 .645 r
.75235 .33322 .75261 .33868 .76301 .33857 .76277 .33312 Mtetra
.758 .569 .641 r
.74185 .3333 .74212 .33878 .75261 .33868 .75235 .33322 Mtetra
.744 .554 .637 r
.73127 .33337 .73155 .33885 .74212 .33878 .74185 .3333 Mtetra
.729 .538 .633 r
.72062 .33341 .7209 .3389 .73155 .33885 .73127 .33337 Mtetra
.713 .52 .628 r
.7099 .33342 .71019 .33893 .7209 .3389 .72062 .33341 Mtetra
.695 .502 .622 r
.69911 .33341 .6994 .33892 .71019 .33893 .7099 .33342 Mtetra
.676 .482 .616 r
.68825 .33337 .68856 .33889 .6994 .33892 .69911 .33341 Mtetra
.656 .461 .608 r
.67735 .3333 .67766 .33883 .68856 .33889 .68825 .33337 Mtetra
.634 .438 .6 r
.6664 .3332 .66671 .33873 .67766 .33883 .67735 .3333 Mtetra
.61 .414 .591 r
.65541 .33307 .65572 .3386 .66671 .33873 .6664 .3332 Mtetra
.585 .387 .58 r
.6444 .33289 .64471 .33843 .65572 .3386 .65541 .33307 Mtetra
.557 .359 .568 r
.63336 .33269 .63367 .33822 .64471 .33843 .6444 .33289 Mtetra
.528 .329 .554 r
.62232 .33243 .62263 .33797 .63367 .33822 .63336 .33269 Mtetra
.496 .296 .538 r
.61129 .33214 .61159 .33768 .62263 .33797 .62232 .33243 Mtetra
.462 .261 .52 r
.60027 .3318 .60057 .33734 .61159 .33768 .61129 .33214 Mtetra
.426 .222 .498 r
.58929 .33141 .58958 .33694 .60057 .33734 .60027 .3318 Mtetra
.389 .18 .471 r
.57835 .33096 .57864 .3365 .58958 .33694 .58929 .33141 Mtetra
.35 .135 .44 r
.56749 .33047 .56777 .33601 .57864 .3365 .57835 .33096 Mtetra
.522 .427 .688 r
.09087 .32509 .09087 .33027 .10012 .3305 .10014 .3253 Mtetra
.524 .425 .685 r
.10014 .3253 .10012 .3305 .10943 .33072 .10947 .3255 Mtetra
.526 .424 .682 r
.10947 .3255 .10943 .33072 .1188 .33094 .11886 .32571 Mtetra
.529 .424 .68 r
.11886 .32571 .1188 .33094 .12823 .33116 .12831 .32591 Mtetra
.533 .425 .677 r
.12831 .32591 .12823 .33116 .13774 .33138 .13783 .32611 Mtetra
.538 .427 .675 r
.13783 .32611 .13774 .33138 .14732 .33159 .14743 .3263 Mtetra
.544 .429 .673 r
.14743 .3263 .14732 .33159 .15697 .3318 .1571 .32649 Mtetra
.551 .432 .671 r
.1571 .32649 .15697 .3318 .16671 .332 .16685 .32668 Mtetra
.559 .436 .669 r
.16685 .32668 .16671 .332 .17653 .33219 .17668 .32685 Mtetra
.567 .44 .667 r
.17668 .32685 .17653 .33219 .18643 .33238 .1866 .32702 Mtetra
.577 .446 .665 r
.1866 .32702 .18643 .33238 .19642 .33255 .1966 .32718 Mtetra
.588 .451 .663 r
.1966 .32718 .19642 .33255 .20649 .33272 .20669 .32733 Mtetra
.599 .458 .661 r
.20669 .32733 .20649 .33272 .21665 .33287 .21686 .32746 Mtetra
.611 .465 .658 r
.21686 .32746 .21665 .33287 .2269 .333 .22712 .32758 Mtetra
.624 .472 .656 r
.22712 .32758 .2269 .333 .23723 .33312 .23746 .32769 Mtetra
.638 .48 .653 r
.23746 .32769 .23723 .33312 .24765 .33322 .24789 .32778 Mtetra
.652 .489 .65 r
.24789 .32778 .24765 .33322 .25815 .3333 .2584 .32785 Mtetra
.667 .498 .646 r
.2584 .32785 .25815 .3333 .26873 .33337 .26898 .3279 Mtetra
.683 .507 .642 r
.26898 .3279 .26873 .33337 .27938 .33341 .27965 .32793 Mtetra
.699 .517 .638 r
.27965 .32793 .27938 .33341 .2901 .33342 .29038 .32794 Mtetra
.716 .527 .633 r
.29038 .32794 .2901 .33342 .30089 .33341 .30117 .32792 Mtetra
.733 .537 .627 r
.30117 .32792 .30089 .33341 .31175 .33337 .31203 .32787 Mtetra
.751 .548 .62 r
.31203 .32787 .31175 .33337 .32265 .3333 .32294 .3278 Mtetra
.769 .558 .613 r
.32294 .3278 .32265 .3333 .3336 .3332 .33389 .3277 Mtetra
.787 .568 .604 r
.33389 .3277 .3336 .3332 .34459 .33307 .34488 .32756 Mtetra
.805 .578 .595 r
.34488 .32756 .34459 .33307 .3556 .33289 .35589 .32739 Mtetra
.823 .588 .583 r
.35589 .32739 .3556 .33289 .36664 .33269 .36693 .32718 Mtetra
.841 .598 .571 r
.36693 .32718 .36664 .33269 .37768 .33243 .37797 .32693 Mtetra
.859 .606 .556 r
.37797 .32693 .37768 .33243 .38871 .33214 .389 .32664 Mtetra
.876 .614 .539 r
.389 .32664 .38871 .33214 .39973 .3318 .40001 .32631 Mtetra
.892 .621 .519 r
.40001 .32631 .39973 .3318 .41071 .33141 .41099 .32592 Mtetra
.908 .625 .496 r
.41099 .32592 .41071 .33141 .42165 .33096 .42192 .32548 Mtetra
.853 .694 .685 r
.89986 .3253 .89988 .3305 .90913 .33027 .90913 .32509 Mtetra
.852 .691 .682 r
.89053 .3255 .89057 .33072 .89988 .3305 .89986 .3253 Mtetra
.85 .687 .679 r
.88114 .32571 .8812 .33094 .89057 .33072 .89053 .3255 Mtetra
.848 .683 .677 r
.87169 .32591 .87177 .33116 .8812 .33094 .88114 .32571 Mtetra
.846 .678 .674 r
.86217 .32611 .86226 .33138 .87177 .33116 .87169 .32591 Mtetra
.843 .673 .672 r
.85257 .3263 .85268 .33159 .86226 .33138 .86217 .32611 Mtetra
.839 .667 .67 r
.8429 .32649 .84303 .3318 .85268 .33159 .85257 .3263 Mtetra
.834 .66 .667 r
.83315 .32668 .83329 .332 .84303 .3318 .8429 .32649 Mtetra
.828 .653 .665 r
.82332 .32685 .82347 .33219 .83329 .332 .83315 .32668 Mtetra
.822 .646 .663 r
.8134 .32702 .81357 .33238 .82347 .33219 .82332 .32685 Mtetra
.815 .637 .661 r
.8034 .32718 .80358 .33255 .81357 .33238 .8134 .32702 Mtetra
.807 .628 .659 r
.79331 .32733 .79351 .33272 .80358 .33255 .8034 .32718 Mtetra
.799 .618 .657 r
.78314 .32746 .78335 .33287 .79351 .33272 .79331 .32733 Mtetra
.789 .607 .654 r
.77288 .32758 .7731 .333 .78335 .33287 .78314 .32746 Mtetra
.778 .595 .651 r
.76254 .32769 .76277 .33312 .7731 .333 .77288 .32758 Mtetra
.767 .582 .648 r
.75211 .32778 .75235 .33322 .76277 .33312 .76254 .32769 Mtetra
.754 .568 .645 r
.7416 .32785 .74185 .3333 .75235 .33322 .75211 .32778 Mtetra
.74 .553 .641 r
.73102 .3279 .73127 .33337 .74185 .3333 .7416 .32785 Mtetra
.725 .537 .637 r
.72035 .32793 .72062 .33341 .73127 .33337 .73102 .3279 Mtetra
.708 .52 .632 r
.70962 .32794 .7099 .33342 .72062 .33341 .72035 .32793 Mtetra
.69 .502 .627 r
.69883 .32792 .69911 .33341 .7099 .33342 .70962 .32794 Mtetra
.671 .482 .621 r
.68797 .32787 .68825 .33337 .69911 .33341 .69883 .32792 Mtetra
.65 .46 .614 r
.67706 .3278 .67735 .3333 .68825 .33337 .68797 .32787 Mtetra
.627 .437 .606 r
.66611 .3277 .6664 .3332 .67735 .3333 .67706 .3278 Mtetra
.603 .413 .597 r
.65512 .32756 .65541 .33307 .6664 .3332 .66611 .3277 Mtetra
.577 .386 .586 r
.64411 .32739 .6444 .33289 .65541 .33307 .65512 .32756 Mtetra
.549 .358 .574 r
.63307 .32718 .63336 .33269 .6444 .33289 .64411 .32739 Mtetra
.518 .327 .561 r
.62203 .32693 .62232 .33243 .63336 .33269 .63307 .32718 Mtetra
.485 .293 .545 r
.611 .32664 .61129 .33214 .62232 .33243 .62203 .32693 Mtetra
.449 .256 .526 r
.59999 .32631 .60027 .3318 .61129 .33214 .611 .32664 Mtetra
.41 .216 .504 r
.58901 .32592 .58929 .33141 .60027 .3318 .59999 .32631 Mtetra
.368 .171 .477 r
.57808 .32548 .57835 .33096 .58929 .33141 .58901 .32592 Mtetra
.526 .43 .688 r
.09087 .31992 .09087 .32509 .10014 .3253 .10016 .3201 Mtetra
.527 .428 .686 r
.10016 .3201 .10014 .3253 .10947 .3255 .1095 .32029 Mtetra
.529 .428 .683 r
.1095 .32029 .10947 .3255 .11886 .32571 .11891 .32048 Mtetra
.533 .428 .681 r
.11891 .32048 .11886 .32571 .12831 .32591 .12838 .32066 Mtetra
.537 .429 .679 r
.12838 .32066 .12831 .32591 .13783 .32611 .13792 .32084 Mtetra
.542 .431 .677 r
.13792 .32084 .13783 .32611 .14743 .3263 .14753 .32102 Mtetra
.548 .433 .675 r
.14753 .32102 .14743 .3263 .1571 .32649 .15722 .32119 Mtetra
.555 .436 .673 r
.15722 .32119 .1571 .32649 .16685 .32668 .16698 .32136 Mtetra
.563 .44 .671 r
.16698 .32136 .16685 .32668 .17668 .32685 .17683 .32152 Mtetra
.571 .445 .669 r
.17683 .32152 .17668 .32685 .1866 .32702 .18676 .32167 Mtetra
.581 .45 .667 r
.18676 .32167 .1866 .32702 .1966 .32718 .19677 .32182 Mtetra
.592 .456 .666 r
.19677 .32182 .1966 .32718 .20669 .32733 .20687 .32195 Mtetra
.603 .463 .664 r
.20687 .32195 .20669 .32733 .21686 .32746 .21706 .32207 Mtetra
.615 .47 .661 r
.21706 .32207 .21686 .32746 .22712 .32758 .22733 .32218 Mtetra
.629 .478 .659 r
.22733 .32218 .22712 .32758 .23746 .32769 .23768 .32227 Mtetra
.642 .487 .657 r
.23768 .32227 .23746 .32769 .24789 .32778 .24812 .32235 Mtetra
.657 .495 .654 r
.24812 .32235 .24789 .32778 .2584 .32785 .25863 .32241 Mtetra
.672 .505 .65 r
.25863 .32241 .2584 .32785 .26898 .3279 .26923 .32245 Mtetra
.688 .515 .647 r
.26923 .32245 .26898 .3279 .27965 .32793 .27989 .32247 Mtetra
.705 .525 .642 r
.27989 .32247 .27965 .32793 .29038 .32794 .29063 .32247 Mtetra
.722 .535 .637 r
.29063 .32247 .29038 .32794 .30117 .32792 .30143 .32245 Mtetra
.739 .546 .632 r
.30143 .32245 .30117 .32792 .31203 .32787 .31229 .3224 Mtetra
.757 .556 .625 r
.31229 .3224 .31203 .32787 .32294 .3278 .32321 .32232 Mtetra
.775 .567 .618 r
.32321 .32232 .32294 .3278 .33389 .3277 .33416 .32222 Mtetra
.793 .578 .61 r
.33416 .32222 .33389 .3277 .34488 .32756 .34515 .32208 Mtetra
.812 .589 .6 r
.34515 .32208 .34488 .32756 .35589 .32739 .35617 .32192 Mtetra
.83 .599 .589 r
.35617 .32192 .35589 .32739 .36693 .32718 .3672 .32171 Mtetra
.848 .609 .576 r
.3672 .32171 .36693 .32718 .37797 .32693 .37824 .32147 Mtetra
.867 .619 .562 r
.37824 .32147 .37797 .32693 .389 .32664 .38926 .32119 Mtetra
.884 .628 .545 r
.38926 .32119 .389 .32664 .40001 .32631 .40027 .32086 Mtetra
.902 .636 .525 r
.40027 .32086 .40001 .32631 .41099 .32592 .41125 .32048 Mtetra
.918 .642 .501 r
.41125 .32048 .41099 .32592 .42192 .32548 .42217 .32005 Mtetra
.85 .692 .686 r
.89984 .3201 .89986 .3253 .90913 .32509 .90913 .31992 Mtetra
.85 .689 .683 r
.8905 .32029 .89053 .3255 .89986 .3253 .89984 .3201 Mtetra
.848 .686 .68 r
.88109 .32048 .88114 .32571 .89053 .3255 .8905 .32029 Mtetra
.846 .682 .678 r
.87162 .32066 .87169 .32591 .88114 .32571 .88109 .32048 Mtetra
.844 .677 .676 r
.86208 .32084 .86217 .32611 .87169 .32591 .87162 .32066 Mtetra
.84 .672 .674 r
.85247 .32102 .85257 .3263 .86217 .32611 .86208 .32084 Mtetra
.836 .666 .672 r
.84278 .32119 .8429 .32649 .85257 .3263 .85247 .32102 Mtetra
.831 .66 .67 r
.83302 .32136 .83315 .32668 .8429 .32649 .84278 .32119 Mtetra
.826 .653 .668 r
.82317 .32152 .82332 .32685 .83315 .32668 .83302 .32136 Mtetra
.82 .645 .666 r
.81324 .32167 .8134 .32702 .82332 .32685 .82317 .32152 Mtetra
.812 .637 .664 r
.80323 .32182 .8034 .32718 .8134 .32702 .81324 .32167 Mtetra
.805 .627 .662 r
.79313 .32195 .79331 .32733 .8034 .32718 .80323 .32182 Mtetra
.796 .617 .66 r
.78294 .32207 .78314 .32746 .79331 .32733 .79313 .32195 Mtetra
.786 .607 .658 r
.77267 .32218 .77288 .32758 .78314 .32746 .78294 .32207 Mtetra
.775 .595 .655 r
.76232 .32227 .76254 .32769 .77288 .32758 .77267 .32218 Mtetra
.763 .582 .652 r
.75188 .32235 .75211 .32778 .76254 .32769 .76232 .32227 Mtetra
.75 .568 .649 r
.74137 .32241 .7416 .32785 .75211 .32778 .75188 .32235 Mtetra
.736 .553 .646 r
.73077 .32245 .73102 .3279 .7416 .32785 .74137 .32241 Mtetra
.721 .537 .642 r
.72011 .32247 .72035 .32793 .73102 .3279 .73077 .32245 Mtetra
.704 .52 .637 r
.70937 .32247 .70962 .32794 .72035 .32793 .72011 .32247 Mtetra
.686 .502 .632 r
.69857 .32245 .69883 .32792 .70962 .32794 .70937 .32247 Mtetra
.666 .482 .626 r
.68771 .3224 .68797 .32787 .69883 .32792 .69857 .32245 Mtetra
.644 .46 .619 r
.67679 .32232 .67706 .3278 .68797 .32787 .68771 .3224 Mtetra
.621 .437 .611 r
.66584 .32222 .66611 .3277 .67706 .3278 .67679 .32232 Mtetra
.596 .412 .603 r
.65485 .32208 .65512 .32756 .66611 .3277 .66584 .32222 Mtetra
.569 .385 .592 r
.64383 .32192 .64411 .32739 .65512 .32756 .65485 .32208 Mtetra
.54 .356 .581 r
.6328 .32171 .63307 .32718 .64411 .32739 .64383 .32192 Mtetra
.509 .325 .567 r
.62176 .32147 .62203 .32693 .63307 .32718 .6328 .32171 Mtetra
.474 .291 .551 r
.61074 .32119 .611 .32664 .62203 .32693 .62176 .32147 Mtetra
.437 .253 .533 r
.59973 .32086 .59999 .32631 .611 .32664 .61074 .32119 Mtetra
.395 .212 .511 r
.58875 .32048 .58901 .32592 .59999 .32631 .59973 .32086 Mtetra
.349 .164 .483 r
.57783 .32005 .57808 .32548 .58901 .32592 .58875 .32048 Mtetra
.53 .433 .689 r
.09086 .31474 .09087 .31992 .10016 .3201 .10017 .31491 Mtetra
.531 .431 .687 r
.10017 .31491 .10016 .3201 .1095 .32029 .10954 .31508 Mtetra
.533 .431 .684 r
.10954 .31508 .1095 .32029 .11891 .32048 .11896 .31525 Mtetra
.536 .431 .682 r
.11896 .31525 .11891 .32048 .12838 .32066 .12845 .31541 Mtetra
.54 .432 .68 r
.12845 .31541 .12838 .32066 .13792 .32084 .138 .31558 Mtetra
.545 .434 .678 r
.138 .31558 .13792 .32084 .14753 .32102 .14763 .31574 Mtetra
.551 .437 .677 r
.14763 .31574 .14753 .32102 .15722 .32119 .15733 .3159 Mtetra
.558 .44 .675 r
.15733 .3159 .15722 .32119 .16698 .32136 .16711 .31605 Mtetra
.566 .445 .673 r
.16711 .31605 .16698 .32136 .17683 .32152 .17697 .3162 Mtetra
.575 .45 .672 r
.17697 .3162 .17683 .32152 .18676 .32167 .18691 .31633 Mtetra
.585 .455 .67 r
.18691 .31633 .18676 .32167 .19677 .32182 .19693 .31646 Mtetra
.596 .461 .668 r
.19693 .31646 .19677 .32182 .20687 .32195 .20704 .31658 Mtetra
.607 .468 .667 r
.20704 .31658 .20687 .32195 .21706 .32207 .21724 .31669 Mtetra
.619 .476 .665 r
.21724 .31669 .21706 .32207 .22733 .32218 .22752 .31678 Mtetra
.633 .484 .663 r
.22752 .31678 .22733 .32218 .23768 .32227 .23788 .31687 Mtetra
.647 .493 .66 r
.23788 .31687 .23768 .32227 .24812 .32235 .24833 .31693 Mtetra
.661 .502 .658 r
.24833 .31693 .24812 .32235 .25863 .32241 .25885 .31699 Mtetra
.677 .511 .654 r
.25885 .31699 .25863 .32241 .26923 .32245 .26945 .31702 Mtetra
.693 .522 .651 r
.26945 .31702 .26923 .32245 .27989 .32247 .28013 .31703 Mtetra
.709 .532 .647 r
.28013 .31703 .27989 .32247 .29063 .32247 .29087 .31703 Mtetra
.727 .543 .642 r
.29087 .31703 .29063 .32247 .30143 .32245 .30168 .317 Mtetra
.744 .554 .637 r
.30168 .317 .30143 .32245 .31229 .3224 .31254 .31695 Mtetra
.762 .565 .631 r
.31254 .31695 .31229 .3224 .32321 .32232 .32346 .31687 Mtetra
.781 .576 .623 r
.32346 .31687 .32321 .32232 .33416 .32222 .33441 .31677 Mtetra
.799 .587 .615 r
.33441 .31677 .33416 .32222 .34515 .32208 .34541 .31664 Mtetra
.818 .599 .606 r
.34541 .31664 .34515 .32208 .35617 .32192 .35642 .31647 Mtetra
.836 .61 .595 r
.35642 .31647 .35617 .32192 .3672 .32171 .36745 .31627 Mtetra
.855 .62 .583 r
.36745 .31627 .3672 .32171 .37824 .32147 .37848 .31604 Mtetra
.874 .631 .568 r
.37848 .31604 .37824 .32147 .38926 .32119 .38951 .31577 Mtetra
.892 .641 .552 r
.38951 .31577 .38926 .32119 .40027 .32086 .40051 .31545 Mtetra
.91 .65 .532 r
.40051 .31545 .40027 .32086 .41125 .32048 .41148 .31509 Mtetra
.848 .69 .686 r
.89983 .31491 .89984 .3201 .90913 .31992 .90914 .31474 Mtetra
.847 .688 .684 r
.89046 .31508 .8905 .32029 .89984 .3201 .89983 .31491 Mtetra
.846 .684 .682 r
.88104 .31525 .88109 .32048 .8905 .32029 .89046 .31508 Mtetra
.844 .68 .679 r
.87155 .31541 .87162 .32066 .88109 .32048 .88104 .31525 Mtetra
.841 .676 .677 r
.862 .31558 .86208 .32084 .87162 .32066 .87155 .31541 Mtetra
.838 .671 .676 r
.85237 .31574 .85247 .32102 .86208 .32084 .862 .31558 Mtetra
.834 .665 .674 r
.84267 .3159 .84278 .32119 .85247 .32102 .85237 .31574 Mtetra
.829 .659 .672 r
.83289 .31605 .83302 .32136 .84278 .32119 .84267 .3159 Mtetra
.824 .652 .67 r
.82303 .3162 .82317 .32152 .83302 .32136 .83289 .31605 Mtetra
.817 .645 .669 r
.81309 .31633 .81324 .32167 .82317 .32152 .82303 .3162 Mtetra
.81 .636 .667 r
.80307 .31646 .80323 .32182 .81324 .32167 .81309 .31633 Mtetra
.802 .627 .665 r
.79296 .31658 .79313 .32195 .80323 .32182 .80307 .31646 Mtetra
.793 .617 .663 r
.78276 .31669 .78294 .32207 .79313 .32195 .79296 .31658 Mtetra
.783 .607 .661 r
.77248 .31678 .77267 .32218 .78294 .32207 .78276 .31669 Mtetra
.772 .595 .659 r
.76212 .31687 .76232 .32227 .77267 .32218 .77248 .31678 Mtetra
.76 .582 .656 r
.75167 .31693 .75188 .32235 .76232 .32227 .76212 .31687 Mtetra
.747 .569 .653 r
.74115 .31699 .74137 .32241 .75188 .32235 .75167 .31693 Mtetra
.732 .554 .65 r
.73055 .31702 .73077 .32245 .74137 .32241 .74115 .31699 Mtetra
.717 .538 .646 r
.71987 .31703 .72011 .32247 .73077 .32245 .73055 .31702 Mtetra
.7 .52 .642 r
.70913 .31703 .70937 .32247 .72011 .32247 .71987 .31703 Mtetra
.681 .502 .637 r
.69832 .317 .69857 .32245 .70937 .32247 .70913 .31703 Mtetra
.661 .482 .631 r
.68746 .31695 .68771 .3224 .69857 .32245 .69832 .317 Mtetra
.639 .46 .625 r
.67654 .31687 .67679 .32232 .68771 .3224 .68746 .31695 Mtetra
.616 .437 .617 r
.66559 .31677 .66584 .32222 .67679 .32232 .67654 .31687 Mtetra
.59 .412 .609 r
.65459 .31664 .65485 .32208 .66584 .32222 .66559 .31677 Mtetra
.563 .385 .599 r
.64358 .31647 .64383 .32192 .65485 .32208 .65459 .31664 Mtetra
.533 .356 .587 r
.63255 .31627 .6328 .32171 .64383 .32192 .64358 .31647 Mtetra
.5 .324 .574 r
.62152 .31604 .62176 .32147 .6328 .32171 .63255 .31627 Mtetra
.465 .29 .559 r
.61049 .31577 .61074 .32119 .62176 .32147 .62152 .31604 Mtetra
.425 .252 .541 r
.59949 .31545 .59973 .32086 .61074 .32119 .61049 .31577 Mtetra
.381 .209 .519 r
.58852 .31509 .58875 .32048 .59973 .32086 .59949 .31545 Mtetra
.533 .435 .69 r
.09086 .30956 .09086 .31474 .10017 .31491 .10019 .30971 Mtetra
.534 .434 .687 r
.10019 .30971 .10017 .31491 .10954 .31508 .10957 .30987 Mtetra
.536 .434 .685 r
.10957 .30987 .10954 .31508 .11896 .31525 .11901 .31002 Mtetra
.539 .434 .683 r
.11901 .31002 .11896 .31525 .12845 .31541 .12851 .31017 Mtetra
.543 .436 .682 r
.12851 .31017 .12845 .31541 .138 .31558 .13808 .31032 Mtetra
.548 .438 .68 r
.13808 .31032 .138 .31558 .14763 .31574 .14772 .31047 Mtetra
.555 .441 .678 r
.14772 .31047 .14763 .31574 .15733 .3159 .15743 .31061 Mtetra
.562 .444 .677 r
.15743 .31061 .15733 .3159 .16711 .31605 .16722 .31075 Mtetra
.57 .449 .675 r
.16722 .31075 .16711 .31605 .17697 .3162 .17709 .31088 Mtetra
.578 .454 .674 r
.17709 .31088 .17697 .3162 .18691 .31633 .18705 .311 Mtetra
.588 .46 .673 r
.18705 .311 .18691 .31633 .19693 .31646 .19708 .31112 Mtetra
.599 .466 .671 r
.19708 .31112 .19693 .31646 .20704 .31658 .2072 .31122 Mtetra
.611 .473 .67 r
.2072 .31122 .20704 .31658 .21724 .31669 .21741 .31132 Mtetra
.623 .481 .668 r
.21741 .31132 .21724 .31669 .22752 .31678 .2277 .3114 Mtetra
.636 .489 .666 r
.2277 .3114 .22752 .31678 .23788 .31687 .23807 .31147 Mtetra
.651 .498 .664 r
.23807 .31147 .23788 .31687 .24833 .31693 .24852 .31153 Mtetra
.665 .508 .661 r
.24852 .31153 .24833 .31693 .25885 .31699 .25905 .31158 Mtetra
.681 .518 .659 r
.25905 .31158 .25885 .31699 .26945 .31702 .26966 .3116 Mtetra
.697 .528 .655 r
.26966 .3116 .26945 .31702 .28013 .31703 .28034 .31161 Mtetra
.714 .539 .651 r
.28034 .31161 .28013 .31703 .29087 .31703 .29109 .3116 Mtetra
.731 .55 .647 r
.29109 .3116 .29087 .31703 .30168 .317 .3019 .31157 Mtetra
.749 .562 .642 r
.3019 .31157 .30168 .317 .31254 .31695 .31277 .31152 Mtetra
.767 .573 .636 r
.31277 .31152 .31254 .31695 .32346 .31687 .32369 .31144 Mtetra
.786 .585 .629 r
.32369 .31144 .32346 .31687 .33441 .31677 .33465 .31134 Mtetra
.805 .597 .621 r
.33465 .31134 .33441 .31677 .34541 .31664 .34564 .31121 Mtetra
.823 .608 .612 r
.34564 .31121 .34541 .31664 .35642 .31647 .35666 .31105 Mtetra
.842 .62 .601 r
.35666 .31105 .35642 .31647 .36745 .31627 .36768 .31087 Mtetra
.861 .631 .589 r
.36768 .31087 .36745 .31627 .37848 .31604 .37871 .31064 Mtetra
.88 .642 .575 r
.37871 .31064 .37848 .31604 .38951 .31577 .38974 .31038 Mtetra
.899 .653 .559 r
.38974 .31038 .38951 .31577 .40051 .31545 .40073 .31008 Mtetra
.917 .664 .539 r
.40073 .31008 .40051 .31545 .41148 .31509 .4117 .30973 Mtetra
.846 .689 .687 r
.89981 .30971 .89983 .31491 .90914 .31474 .90914 .30956 Mtetra
.845 .686 .685 r
.89043 .30987 .89046 .31508 .89983 .31491 .89981 .30971 Mtetra
.844 .683 .683 r
.88099 .31002 .88104 .31525 .89046 .31508 .89043 .30987 Mtetra
.842 .679 .681 r
.87149 .31017 .87155 .31541 .88104 .31525 .88099 .31002 Mtetra
.839 .675 .679 r
.86192 .31032 .862 .31558 .87155 .31541 .87149 .31017 Mtetra
.836 .67 .677 r
.85228 .31047 .85237 .31574 .862 .31558 .86192 .31032 Mtetra
.832 .665 .676 r
.84257 .31061 .84267 .3159 .85237 .31574 .85228 .31047 Mtetra
.827 .659 .674 r
.83278 .31075 .83289 .31605 .84267 .3159 .84257 .31061 Mtetra
.821 .652 .673 r
.82291 .31088 .82303 .3162 .83289 .31605 .83278 .31075 Mtetra
.815 .645 .671 r
.81295 .311 .81309 .31633 .82303 .3162 .82291 .31088 Mtetra
.808 .636 .67 r
.80292 .31112 .80307 .31646 .81309 .31633 .81295 .311 Mtetra
.8 .627 .668 r
.7928 .31122 .79296 .31658 .80307 .31646 .80292 .31112 Mtetra
.79 .618 .666 r
.78259 .31132 .78276 .31669 .79296 .31658 .7928 .31122 Mtetra
.78 .607 .665 r
.7723 .3114 .77248 .31678 .78276 .31669 .78259 .31132 Mtetra
.769 .595 .663 r
.76193 .31147 .76212 .31687 .77248 .31678 .7723 .3114 Mtetra
.757 .583 .66 r
.75148 .31153 .75167 .31693 .76212 .31687 .76193 .31147 Mtetra
.744 .569 .658 r
.74095 .31158 .74115 .31699 .75167 .31693 .75148 .31153 Mtetra
.729 .554 .655 r
.73034 .3116 .73055 .31702 .74115 .31699 .74095 .31158 Mtetra
.713 .538 .651 r
.71966 .31161 .71987 .31703 .73055 .31702 .73034 .3116 Mtetra
.696 .521 .647 r
.70891 .3116 .70913 .31703 .71987 .31703 .71966 .31161 Mtetra
.677 .502 .642 r
.6981 .31157 .69832 .317 .70913 .31703 .70891 .3116 Mtetra
.656 .482 .637 r
.68723 .31152 .68746 .31695 .69832 .317 .6981 .31157 Mtetra
.634 .461 .63 r
.67631 .31144 .67654 .31687 .68746 .31695 .68723 .31152 Mtetra
.61 .437 .623 r
.66535 .31134 .66559 .31677 .67654 .31687 .67631 .31144 Mtetra
.584 .412 .615 r
.65436 .31121 .65459 .31664 .66559 .31677 .66535 .31134 Mtetra
.556 .385 .605 r
.64334 .31105 .64358 .31647 .65459 .31664 .65436 .31121 Mtetra
.526 .356 .594 r
.63232 .31087 .63255 .31627 .64358 .31647 .64334 .31105 Mtetra
.492 .325 .581 r
.62129 .31064 .62152 .31604 .63255 .31627 .63232 .31087 Mtetra
.456 .29 .566 r
.61026 .31038 .61049 .31577 .62152 .31604 .62129 .31064 Mtetra
.415 .252 .549 r
.59927 .31008 .59949 .31545 .61049 .31577 .61026 .31038 Mtetra
.369 .208 .528 r
.5883 .30973 .58852 .31509 .59949 .31545 .59927 .31008 Mtetra
.536 .438 .69 r
.09086 .30438 .09086 .30956 .10019 .30971 .1002 .30452 Mtetra
.537 .437 .688 r
.1002 .30452 .10019 .30971 .10957 .30987 .1096 .30466 Mtetra
.539 .437 .686 r
.1096 .30466 .10957 .30987 .11901 .31002 .11905 .30479 Mtetra
.542 .437 .684 r
.11905 .30479 .11901 .31002 .12851 .31017 .12856 .30493 Mtetra
.546 .439 .683 r
.12856 .30493 .12851 .31017 .13808 .31032 .13814 .30506 Mtetra
.551 .441 .681 r
.13814 .30506 .13808 .31032 .14772 .31047 .1478 .3052 Mtetra
.558 .444 .68 r
.1478 .3052 .14772 .31047 .15743 .31061 .15752 .30532 Mtetra
.565 .448 .679 r
.15752 .30532 .15743 .31061 .16722 .31075 .16733 .30545 Mtetra
.573 .452 .678 r
.16733 .30545 .16722 .31075 .17709 .31088 .17721 .30556 Mtetra
.582 .458 .676 r
.17721 .30556 .17709 .31088 .18705 .311 .18717 .30567 Mtetra
.591 .464 .675 r
.18717 .30567 .18705 .311 .19708 .31112 .19722 .30578 Mtetra
.602 .471 .674 r
.19722 .30578 .19708 .31112 .2072 .31122 .20735 .30587 Mtetra
.614 .478 .673 r
.20735 .30587 .2072 .31122 .21741 .31132 .21756 .30595 Mtetra
.627 .486 .671 r
.21756 .30595 .21741 .31132 .2277 .3114 .22786 .30603 Mtetra
.64 .495 .669 r
.22786 .30603 .2277 .3114 .23807 .31147 .23824 .30609 Mtetra
.654 .504 .667 r
.23824 .30609 .23807 .31147 .24852 .31153 .2487 .30614 Mtetra
.669 .514 .665 r
.2487 .30614 .24852 .31153 .25905 .31158 .25924 .30618 Mtetra
.685 .524 .663 r
.25924 .30618 .25905 .31158 .26966 .3116 .26985 .3062 Mtetra
.701 .535 .659 r
.26985 .3062 .26966 .3116 .28034 .31161 .28054 .3062 Mtetra
.718 .546 .656 r
.28054 .3062 .28034 .31161 .29109 .3116 .29129 .30619 Mtetra
.736 .557 .652 r
.29129 .30619 .29109 .3116 .3019 .31157 .30211 .30616 Mtetra
.754 .569 .647 r
.30211 .30616 .3019 .31157 .31277 .31152 .31298 .30611 Mtetra
.772 .581 .641 r
.31298 .30611 .31277 .31152 .32369 .31144 .3239 .30603 Mtetra
.791 .593 .634 r
.3239 .30603 .32369 .31144 .33465 .31134 .33486 .30593 Mtetra
.809 .605 .626 r
.33486 .30593 .33465 .31134 .34564 .31121 .34585 .30581 Mtetra
.828 .618 .617 r
.34585 .30581 .34564 .31121 .35666 .31105 .35687 .30566 Mtetra
.848 .63 .607 r
.35687 .30566 .35666 .31105 .36768 .31087 .3679 .30548 Mtetra
.867 .642 .595 r
.3679 .30548 .36768 .31087 .37871 .31064 .37892 .30527 Mtetra
.886 .654 .582 r
.37892 .30527 .37871 .31064 .38974 .31038 .38994 .30503 Mtetra
.905 .665 .566 r
.38994 .30503 .38974 .31038 .40073 .31008 .40093 .30475 Mtetra
.924 .677 .547 r
.40093 .30475 .40073 .31008 .4117 .30973 .41189 .30442 Mtetra
.844 .688 .688 r
.8998 .30452 .89981 .30971 .90914 .30956 .90914 .30438 Mtetra
.843 .685 .686 r
.8904 .30466 .89043 .30987 .89981 .30971 .8998 .30452 Mtetra
.842 .682 .684 r
.88095 .30479 .88099 .31002 .89043 .30987 .8904 .30466 Mtetra
.84 .679 .682 r
.87144 .30493 .87149 .31017 .88099 .31002 .88095 .30479 Mtetra
.837 .674 .681 r
.86186 .30506 .86192 .31032 .87149 .31017 .87144 .30493 Mtetra
.834 .67 .679 r
.8522 .3052 .85228 .31047 .86192 .31032 .86186 .30506 Mtetra
.83 .664 .678 r
.84248 .30532 .84257 .31061 .85228 .31047 .8522 .3052 Mtetra
.825 .658 .676 r
.83267 .30545 .83278 .31075 .84257 .31061 .84248 .30532 Mtetra
.819 .652 .675 r
.82279 .30556 .82291 .31088 .83278 .31075 .83267 .30545 Mtetra
.813 .644 .674 r
.81283 .30567 .81295 .311 .82291 .31088 .82279 .30556 Mtetra
.805 .636 .672 r
.80278 .30578 .80292 .31112 .81295 .311 .81283 .30567 Mtetra
.797 .628 .671 r
.79265 .30587 .7928 .31122 .80292 .31112 .80278 .30578 Mtetra
.788 .618 .67 r
.78244 .30595 .78259 .31132 .7928 .31122 .79265 .30587 Mtetra
.778 .607 .668 r
.77214 .30603 .7723 .3114 .78259 .31132 .78244 .30595 Mtetra
.767 .596 .666 r
.76176 .30609 .76193 .31147 .7723 .3114 .77214 .30603 Mtetra
.754 .583 .664 r
.7513 .30614 .75148 .31153 .76193 .31147 .76176 .30609 Mtetra
.741 .57 .662 r
.74076 .30618 .74095 .31158 .75148 .31153 .7513 .30614 Mtetra
.726 .555 .659 r
.73015 .3062 .73034 .3116 .74095 .31158 .74076 .30618 Mtetra
.71 .539 .656 r
.71946 .3062 .71966 .31161 .73034 .3116 .73015 .3062 Mtetra
.692 .522 .652 r
.70871 .30619 .70891 .3116 .71966 .31161 .71946 .3062 Mtetra
.673 .503 .647 r
.69789 .30616 .6981 .31157 .70891 .3116 .70871 .30619 Mtetra
.652 .483 .642 r
.68702 .30611 .68723 .31152 .6981 .31157 .69789 .30616 Mtetra
.63 .461 .636 r
.6761 .30603 .67631 .31144 .68723 .31152 .68702 .30611 Mtetra
.605 .438 .629 r
.66514 .30593 .66535 .31134 .67631 .31144 .6761 .30603 Mtetra
.579 .413 .621 r
.65415 .30581 .65436 .31121 .66535 .31134 .66514 .30593 Mtetra
.55 .386 .612 r
.64313 .30566 .64334 .31105 .65436 .31121 .65415 .30581 Mtetra
.519 .357 .601 r
.6321 .30548 .63232 .31087 .64334 .31105 .64313 .30566 Mtetra
.486 .326 .589 r
.62108 .30527 .62129 .31064 .63232 .31087 .6321 .30548 Mtetra
.448 .291 .575 r
.61006 .30503 .61026 .31038 .62129 .31064 .62108 .30527 Mtetra
.407 .253 .558 r
.59907 .30475 .59927 .31008 .61026 .31038 .61006 .30503 Mtetra
.36 .21 .538 r
.58811 .30442 .5883 .30973 .59927 .31008 .59907 .30475 Mtetra
.539 .44 .691 r
.09086 .2992 .09086 .30438 .1002 .30452 .10022 .29932 Mtetra
.54 .439 .689 r
.10022 .29932 .1002 .30452 .1096 .30466 .10962 .29945 Mtetra
.542 .439 .687 r
.10962 .29945 .1096 .30466 .11905 .30479 .11909 .29957 Mtetra
.545 .44 .686 r
.11909 .29957 .11905 .30479 .12856 .30493 .12861 .29969 Mtetra
.549 .442 .684 r
.12861 .29969 .12856 .30493 .13814 .30506 .13821 .29981 Mtetra
.554 .444 .683 r
.13821 .29981 .13814 .30506 .1478 .3052 .14787 .29993 Mtetra
.56 .447 .682 r
.14787 .29993 .1478 .3052 .15752 .30532 .15761 .30004 Mtetra
.567 .451 .681 r
.15761 .30004 .15752 .30532 .16733 .30545 .16742 .30015 Mtetra
.575 .456 .68 r
.16742 .30015 .16733 .30545 .17721 .30556 .17731 .30025 Mtetra
.584 .462 .679 r
.17731 .30025 .17721 .30556 .18717 .30567 .18729 .30035 Mtetra
.594 .468 .678 r
.18729 .30035 .18717 .30567 .19722 .30578 .19734 .30044 Mtetra
.605 .475 .677 r
.19734 .30044 .19722 .30578 .20735 .30587 .20748 .30053 Mtetra
.617 .482 .675 r
.20748 .30053 .20735 .30587 .21756 .30595 .2177 .3006 Mtetra
.63 .491 .674 r
.2177 .3006 .21756 .30595 .22786 .30603 .22801 .30067 Mtetra
.643 .5 .673 r
.22801 .30067 .22786 .30603 .23824 .30609 .23839 .30072 Mtetra
.657 .509 .671 r
.23839 .30072 .23824 .30609 .2487 .30614 .24886 .30076 Mtetra
.672 .519 .669 r
.24886 .30076 .2487 .30614 .25924 .30618 .25941 .30079 Mtetra
.688 .53 .667 r
.25941 .30079 .25924 .30618 .26985 .3062 .27003 .30081 Mtetra
.705 .541 .664 r
.27003 .30081 .26985 .3062 .28054 .3062 .28072 .30081 Mtetra
.722 .553 .66 r
.28072 .30081 .28054 .3062 .29129 .30619 .29148 .30079 Mtetra
.739 .564 .656 r
.29148 .30079 .29129 .30619 .30211 .30616 .3023 .30076 Mtetra
.758 .577 .652 r
.3023 .30076 .30211 .30616 .31298 .30611 .31317 .30071 Mtetra
.776 .589 .646 r
.31317 .30071 .31298 .30611 .3239 .30603 .3241 .30064 Mtetra
.795 .601 .64 r
.3241 .30064 .3239 .30603 .33486 .30593 .33506 .30055 Mtetra
.814 .614 .632 r
.33506 .30055 .33486 .30593 .34585 .30581 .34605 .30043 Mtetra
.833 .626 .624 r
.34605 .30043 .34585 .30581 .35687 .30566 .35706 .30029 Mtetra
.852 .639 .614 r
.35706 .30029 .35687 .30566 .3679 .30548 .36809 .30013 Mtetra
.871 .651 .602 r
.36809 .30013 .3679 .30548 .37892 .30527 .37911 .29993 Mtetra
.89 .664 .589 r
.37911 .29993 .37892 .30527 .38994 .30503 .39012 .29971 Mtetra
.909 .677 .574 r
.39012 .29971 .38994 .30503 .40093 .30475 .40111 .29944 Mtetra
.842 .686 .689 r
.89978 .29932 .8998 .30452 .90914 .30438 .90914 .2992 Mtetra
.842 .684 .687 r
.89038 .29945 .8904 .30466 .8998 .30452 .89978 .29932 Mtetra
.84 .681 .685 r
.88091 .29957 .88095 .30479 .8904 .30466 .89038 .29945 Mtetra
.838 .678 .683 r
.87139 .29969 .87144 .30493 .88095 .30479 .88091 .29957 Mtetra
.836 .674 .682 r
.86179 .29981 .86186 .30506 .87144 .30493 .87139 .29969 Mtetra
.832 .669 .681 r
.85213 .29993 .8522 .3052 .86186 .30506 .86179 .29981 Mtetra
.828 .664 .68 r
.84239 .30004 .84248 .30532 .8522 .3052 .85213 .29993 Mtetra
.823 .658 .678 r
.83258 .30015 .83267 .30545 .84248 .30532 .84239 .30004 Mtetra
.817 .652 .677 r
.82269 .30025 .82279 .30556 .83267 .30545 .83258 .30015 Mtetra
.811 .645 .676 r
.81271 .30035 .81283 .30567 .82279 .30556 .82269 .30025 Mtetra
.804 .637 .675 r
.80266 .30044 .80278 .30578 .81283 .30567 .81271 .30035 Mtetra
.795 .628 .674 r
.79252 .30053 .79265 .30587 .80278 .30578 .80266 .30044 Mtetra
.786 .618 .673 r
.7823 .3006 .78244 .30595 .79265 .30587 .79252 .30053 Mtetra
.776 .608 .671 r
.77199 .30067 .77214 .30603 .78244 .30595 .7823 .3006 Mtetra
.764 .596 .67 r
.76161 .30072 .76176 .30609 .77214 .30603 .77199 .30067 Mtetra
.752 .584 .668 r
.75114 .30076 .7513 .30614 .76176 .30609 .76161 .30072 Mtetra
.738 .571 .666 r
.74059 .30079 .74076 .30618 .7513 .30614 .75114 .30076 Mtetra
.723 .556 .663 r
.72997 .30081 .73015 .3062 .74076 .30618 .74059 .30079 Mtetra
.707 .54 .66 r
.71928 .30081 .71946 .3062 .73015 .3062 .72997 .30081 Mtetra
.689 .523 .657 r
.70852 .30079 .70871 .30619 .71946 .3062 .71928 .30081 Mtetra
.67 .504 .652 r
.6977 .30076 .69789 .30616 .70871 .30619 .70852 .30079 Mtetra
.648 .484 .647 r
.68683 .30071 .68702 .30611 .69789 .30616 .6977 .30076 Mtetra
.626 .463 .642 r
.6759 .30064 .6761 .30603 .68702 .30611 .68683 .30071 Mtetra
.601 .439 .635 r
.66494 .30055 .66514 .30593 .6761 .30603 .6759 .30064 Mtetra
.574 .414 .627 r
.65395 .30043 .65415 .30581 .66514 .30593 .66494 .30055 Mtetra
.545 .388 .618 r
.64294 .30029 .64313 .30566 .65415 .30581 .65395 .30043 Mtetra
.514 .359 .608 r
.63191 .30013 .6321 .30548 .64313 .30566 .64294 .30029 Mtetra
.48 .327 .596 r
.62089 .29993 .62108 .30527 .6321 .30548 .63191 .30013 Mtetra
.442 .293 .583 r
.60988 .29971 .61006 .30503 .62108 .30527 .62089 .29993 Mtetra
.4 .256 .568 r
.59889 .29944 .59907 .30475 .61006 .30503 .60988 .29971 Mtetra
.541 .442 .691 r
.09086 .29402 .09086 .2992 .10022 .29932 .10023 .29413 Mtetra
.542 .441 .689 r
.10023 .29413 .10022 .29932 .10962 .29945 .10965 .29424 Mtetra
.544 .441 .688 r
.10965 .29424 .10962 .29945 .11909 .29957 .11912 .29435 Mtetra
.547 .442 .687 r
.11912 .29435 .11909 .29957 .12861 .29969 .12866 .29446 Mtetra
.551 .444 .685 r
.12866 .29446 .12861 .29969 .13821 .29981 .13826 .29456 Mtetra
.557 .447 .684 r
.13826 .29456 .13821 .29981 .14787 .29993 .14794 .29466 Mtetra
.563 .45 .683 r
.14794 .29466 .14787 .29993 .15761 .30004 .15768 .29476 Mtetra
.57 .454 .683 r
.15768 .29476 .15761 .30004 .16742 .30015 .16751 .29486 Mtetra
.578 .459 .682 r
.16751 .29486 .16742 .30015 .17731 .30025 .17741 .29495 Mtetra
.587 .465 .681 r
.17741 .29495 .17731 .30025 .18729 .30035 .18739 .29504 Mtetra
.597 .472 .68 r
.18739 .29504 .18729 .30035 .19734 .30044 .19745 .29512 Mtetra
.608 .479 .679 r
.19745 .29512 .19734 .30044 .20748 .30053 .2076 .29519 Mtetra
.62 .487 .678 r
.2076 .29519 .20748 .30053 .2177 .3006 .21783 .29525 Mtetra
.632 .495 .677 r
.21783 .29525 .2177 .3006 .22801 .30067 .22814 .29531 Mtetra
.646 .505 .676 r
.22814 .29531 .22801 .30067 .23839 .30072 .23853 .29536 Mtetra
.66 .514 .675 r
.23853 .29536 .23839 .30072 .24886 .30076 .24901 .29539 Mtetra
.675 .525 .673 r
.24901 .29539 .24886 .30076 .25941 .30079 .25956 .29542 Mtetra
.691 .536 .671 r
.25956 .29542 .25941 .30079 .27003 .30081 .27019 .29543 Mtetra
.708 .547 .668 r
.27019 .29543 .27003 .30081 .28072 .30081 .28088 .29543 Mtetra
.725 .559 .665 r
.28088 .29543 .28072 .30081 .29148 .30079 .29164 .29541 Mtetra
.743 .571 .661 r
.29164 .29541 .29148 .30079 .3023 .30076 .30247 .29538 Mtetra
.761 .584 .657 r
.30247 .29538 .3023 .30076 .31317 .30071 .31335 .29533 Mtetra
.78 .596 .651 r
.31335 .29533 .31317 .30071 .3241 .30064 .32427 .29526 Mtetra
.799 .609 .645 r
.32427 .29526 .3241 .30064 .33506 .30055 .33523 .29518 Mtetra
.818 .622 .638 r
.33523 .29518 .33506 .30055 .34605 .30043 .34623 .29507 Mtetra
.837 .635 .63 r
.34623 .29507 .34605 .30043 .35706 .30029 .35724 .29494 Mtetra
.856 .648 .62 r
.35724 .29494 .35706 .30029 .36809 .30013 .36826 .29479 Mtetra
.875 .661 .609 r
.36826 .29479 .36809 .30013 .37911 .29993 .37928 .29461 Mtetra
.894 .674 .597 r
.37928 .29461 .37911 .29993 .39012 .29971 .39029 .29441 Mtetra
.913 .687 .582 r
.39029 .29441 .39012 .29971 .40111 .29944 .40126 .29417 Mtetra
.841 .685 .689 r
.89977 .29413 .89978 .29932 .90914 .2992 .90914 .29402 Mtetra
.84 .683 .688 r
.89035 .29424 .89038 .29945 .89978 .29932 .89977 .29413 Mtetra
.839 .68 .686 r
.88088 .29435 .88091 .29957 .89038 .29945 .89035 .29424 Mtetra
.837 .677 .685 r
.87134 .29446 .87139 .29969 .88091 .29957 .88088 .29435 Mtetra
.834 .673 .683 r
.86174 .29456 .86179 .29981 .87139 .29969 .87134 .29446 Mtetra
.831 .669 .682 r
.85206 .29466 .85213 .29993 .86179 .29981 .86174 .29456 Mtetra
.826 .664 .681 r
.84232 .29476 .84239 .30004 .85213 .29993 .85206 .29466 Mtetra
.821 .658 .68 r
.83249 .29486 .83258 .30015 .84239 .30004 .84232 .29476 Mtetra
.816 .652 .68 r
.82259 .29495 .82269 .30025 .83258 .30015 .83249 .29486 Mtetra
.809 .645 .679 r
.81261 .29504 .81271 .30035 .82269 .30025 .82259 .29495 Mtetra
.802 .637 .678 r
.80255 .29512 .80266 .30044 .81271 .30035 .81261 .29504 Mtetra
.793 .628 .677 r
.7924 .29519 .79252 .30053 .80266 .30044 .80255 .29512 Mtetra
.784 .619 .676 r
.78217 .29525 .7823 .3006 .79252 .30053 .7924 .29519 Mtetra
.774 .609 .675 r
.77186 .29531 .77199 .30067 .7823 .3006 .78217 .29525 Mtetra
.762 .597 .674 r
.76147 .29536 .76161 .30072 .77199 .30067 .77186 .29531 Mtetra
.75 .585 .672 r
.75099 .29539 .75114 .30076 .76161 .30072 .76147 .29536 Mtetra
.736 .572 .67 r
.74044 .29542 .74059 .30079 .75114 .30076 .75099 .29539 Mtetra
.721 .557 .668 r
.72981 .29543 .72997 .30081 .74059 .30079 .74044 .29542 Mtetra
.704 .541 .665 r
.71912 .29543 .71928 .30081 .72997 .30081 .72981 .29543 Mtetra
.686 .524 .662 r
.70836 .29541 .70852 .30079 .71928 .30081 .71912 .29543 Mtetra
.666 .506 .658 r
.69753 .29538 .6977 .30076 .70852 .30079 .70836 .29541 Mtetra
.645 .486 .653 r
.68665 .29533 .68683 .30071 .6977 .30076 .69753 .29538 Mtetra
.622 .464 .647 r
.67573 .29526 .6759 .30064 .68683 .30071 .68665 .29533 Mtetra
.597 .441 .641 r
.66477 .29518 .66494 .30055 .6759 .30064 .67573 .29526 Mtetra
.57 .416 .634 r
.65377 .29507 .65395 .30043 .66494 .30055 .66477 .29518 Mtetra
.541 .39 .625 r
.64276 .29494 .64294 .30029 .65395 .30043 .65377 .29507 Mtetra
.509 .361 .615 r
.63174 .29479 .63191 .30013 .64294 .30029 .64276 .29494 Mtetra
.475 .33 .604 r
.62072 .29461 .62089 .29993 .63191 .30013 .63174 .29479 Mtetra
.437 .297 .592 r
.60971 .29441 .60988 .29971 .62089 .29993 .62072 .29461 Mtetra
.395 .261 .578 r
.59874 .29417 .59889 .29944 .60988 .29971 .60971 .29441 Mtetra
.543 .444 .692 r
.09086 .28884 .09086 .29402 .10023 .29413 .10024 .28894 Mtetra
.544 .443 .69 r
.10024 .28894 .10023 .29413 .10965 .29424 .10967 .28903 Mtetra
.546 .443 .689 r
.10967 .28903 .10965 .29424 .11912 .29435 .11915 .28913 Mtetra
.549 .445 .688 r
.11915 .28913 .11912 .29435 .12866 .29446 .1287 .28922 Mtetra
.554 .447 .687 r
.1287 .28922 .12866 .29446 .13826 .29456 .13831 .28931 Mtetra
.559 .449 .686 r
.13831 .28931 .13826 .29456 .14794 .29466 .148 .2894 Mtetra
.565 .453 .685 r
.148 .2894 .14794 .29466 .15768 .29476 .15775 .28949 Mtetra
.572 .457 .684 r
.15775 .28949 .15768 .29476 .16751 .29486 .16758 .28957 Mtetra
.58 .463 .684 r
.16758 .28957 .16751 .29486 .17741 .29495 .17749 .28965 Mtetra
.589 .469 .683 r
.17749 .28965 .17741 .29495 .18739 .29504 .18748 .28973 Mtetra
.599 .475 .683 r
.18748 .28973 .18739 .29504 .19745 .29512 .19755 .2898 Mtetra
.61 .483 .682 r
.19755 .2898 .19745 .29512 .2076 .29519 .20771 .28986 Mtetra
.622 .491 .681 r
.20771 .28986 .2076 .29519 .21783 .29525 .21794 .28991 Mtetra
.635 .5 .68 r
.21794 .28991 .21783 .29525 .22814 .29531 .22826 .28996 Mtetra
.649 .509 .679 r
.22826 .28996 .22814 .29531 .23853 .29536 .23866 .29 Mtetra
.663 .519 .678 r
.23866 .29 .23853 .29536 .24901 .29539 .24914 .29003 Mtetra
.678 .53 .677 r
.24914 .29003 .24901 .29539 .25956 .29542 .2597 .29005 Mtetra
.694 .541 .675 r
.2597 .29005 .25956 .29542 .27019 .29543 .27033 .29006 Mtetra
.711 .553 .672 r
.27033 .29006 .27019 .29543 .28088 .29543 .28103 .29006 Mtetra
.728 .565 .67 r
.28103 .29006 .28088 .29543 .29164 .29541 .29179 .29004 Mtetra
.746 .577 .666 r
.29179 .29004 .29164 .29541 .30247 .29538 .30262 .29001 Mtetra
.764 .59 .662 r
.30262 .29001 .30247 .29538 .31335 .29533 .3135 .28996 Mtetra
.783 .603 .657 r
.3135 .28996 .31335 .29533 .32427 .29526 .32443 .2899 Mtetra
.802 .617 .651 r
.32443 .2899 .32427 .29526 .33523 .29518 .33539 .28983 Mtetra
.821 .63 .644 r
.33539 .28983 .33523 .29518 .34623 .29507 .34638 .28973 Mtetra
.84 .643 .636 r
.34638 .28973 .34623 .29507 .35724 .29494 .3574 .28961 Mtetra
.86 .656 .627 r
.3574 .28961 .35724 .29494 .36826 .29479 .36842 .28948 Mtetra
.878 .67 .616 r
.36842 .28948 .36826 .29479 .37928 .29461 .37943 .28932 Mtetra
.897 .683 .604 r
.37943 .28932 .37928 .29461 .39029 .29441 .39043 .28913 Mtetra
.916 .696 .591 r
.39043 .28913 .39029 .29441 .40126 .29417 .4014 .28892 Mtetra
.84 .684 .69 r
.89976 .28894 .89977 .29413 .90914 .29402 .90914 .28884 Mtetra
.839 .682 .688 r
.89033 .28903 .89035 .29424 .89977 .29413 .89976 .28894 Mtetra
.838 .68 .687 r
.88085 .28913 .88088 .29435 .89035 .29424 .89033 .28903 Mtetra
.835 .677 .686 r
.8713 .28922 .87134 .29446 .88088 .29435 .88085 .28913 Mtetra
.833 .673 .685 r
.86169 .28931 .86174 .29456 .87134 .29446 .8713 .28922 Mtetra
.829 .669 .684 r
.852 .2894 .85206 .29466 .86174 .29456 .86169 .28931 Mtetra
.825 .664 .683 r
.84225 .28949 .84232 .29476 .85206 .29466 .852 .2894 Mtetra
.82 .658 .682 r
.83242 .28957 .83249 .29486 .84232 .29476 .84225 .28949 Mtetra
.814 .652 .682 r
.82251 .28965 .82259 .29495 .83249 .29486 .83242 .28957 Mtetra
.808 .645 .681 r
.81252 .28973 .81261 .29504 .82259 .29495 .82251 .28965 Mtetra
.8 .638 .681 r
.80245 .2898 .80255 .29512 .81261 .29504 .81252 .28973 Mtetra
.792 .629 .68 r
.79229 .28986 .7924 .29519 .80255 .29512 .80245 .2898 Mtetra
.782 .62 .679 r
.78206 .28991 .78217 .29525 .7924 .29519 .79229 .28986 Mtetra
.772 .61 .678 r
.77174 .28996 .77186 .29531 .78217 .29525 .78206 .28991 Mtetra
.76 .599 .677 r
.76134 .29 .76147 .29536 .77186 .29531 .77174 .28996 Mtetra
.748 .586 .676 r
.75086 .29003 .75099 .29539 .76147 .29536 .76134 .29 Mtetra
.734 .573 .674 r
.7403 .29005 .74044 .29542 .75099 .29539 .75086 .29003 Mtetra
.718 .559 .672 r
.72967 .29006 .72981 .29543 .74044 .29542 .7403 .29005 Mtetra
.702 .543 .67 r
.71897 .29006 .71912 .29543 .72981 .29543 .72967 .29006 Mtetra
.683 .526 .667 r
.70821 .29004 .70836 .29541 .71912 .29543 .71897 .29006 Mtetra
.663 .508 .663 r
.69738 .29001 .69753 .29538 .70836 .29541 .70821 .29004 Mtetra
.642 .488 .658 r
.6865 .28996 .68665 .29533 .69753 .29538 .69738 .29001 Mtetra
.619 .466 .653 r
.67557 .2899 .67573 .29526 .68665 .29533 .6865 .28996 Mtetra
.593 .443 .647 r
.66461 .28983 .66477 .29518 .67573 .29526 .67557 .2899 Mtetra
.566 .419 .64 r
.65362 .28973 .65377 .29507 .66477 .29518 .66461 .28983 Mtetra
.537 .392 .632 r
.6426 .28961 .64276 .29494 .65377 .29507 .65362 .28973 Mtetra
.505 .364 .623 r
.63158 .28948 .63174 .29479 .64276 .29494 .6426 .28961 Mtetra
.47 .333 .612 r
.62057 .28932 .62072 .29461 .63174 .29479 .63158 .28948 Mtetra
.433 .301 .601 r
.60957 .28913 .60971 .29441 .62072 .29461 .62057 .28932 Mtetra
.392 .266 .588 r
.5986 .28892 .59874 .29417 .60971 .29441 .60957 .28913 Mtetra
.545 .445 .692 r
.09086 .28366 .09086 .28884 .10024 .28894 .10025 .28375 Mtetra
.546 .445 .691 r
.10025 .28375 .10024 .28894 .10967 .28903 .10969 .28383 Mtetra
.548 .445 .689 r
.10969 .28383 .10967 .28903 .11915 .28913 .11918 .28391 Mtetra
.551 .447 .688 r
.11918 .28391 .11915 .28913 .1287 .28922 .12874 .28399 Mtetra
.555 .449 .688 r
.12874 .28399 .1287 .28922 .13831 .28931 .13836 .28407 Mtetra
.561 .452 .687 r
.13836 .28407 .13831 .28931 .148 .2894 .14805 .28414 Mtetra
.567 .456 .687 r
.14805 .28414 .148 .2894 .15775 .28949 .15781 .28422 Mtetra
.574 .46 .686 r
.15781 .28422 .15775 .28949 .16758 .28957 .16765 .28429 Mtetra
.582 .466 .686 r
.16765 .28429 .16758 .28957 .17749 .28965 .17757 .28436 Mtetra
.591 .472 .685 r
.17757 .28436 .17749 .28965 .18748 .28973 .18756 .28442 Mtetra
.601 .479 .685 r
.18756 .28442 .18748 .28973 .19755 .2898 .19764 .28448 Mtetra
.612 .486 .685 r
.19764 .28448 .19755 .2898 .20771 .28986 .2078 .28453 Mtetra
.624 .495 .684 r
.2078 .28453 .20771 .28986 .21794 .28991 .21804 .28458 Mtetra
.637 .504 .684 r
.21804 .28458 .21794 .28991 .22826 .28996 .22837 .28462 Mtetra
.651 .513 .683 r
.22837 .28462 .22826 .28996 .23866 .29 .23877 .28465 Mtetra
.665 .524 .682 r
.23877 .28465 .23866 .29 .24914 .29003 .24925 .28468 Mtetra
.681 .535 .68 r
.24925 .28468 .24914 .29003 .2597 .29005 .25981 .28469 Mtetra
.697 .546 .679 r
.25981 .28469 .2597 .29005 .27033 .29006 .27045 .2847 Mtetra
.713 .558 .677 r
.27045 .2847 .27033 .29006 .28103 .29006 .28115 .2847 Mtetra
.731 .571 .674 r
.28115 .2847 .28103 .29006 .29179 .29004 .29192 .28468 Mtetra
.749 .584 .671 r
.29192 .28468 .29179 .29004 .30262 .29001 .30275 .28465 Mtetra
.767 .597 .667 r
.30275 .28465 .30262 .29001 .3135 .28996 .31363 .28461 Mtetra
.786 .61 .662 r
.31363 .28461 .3135 .28996 .32443 .2899 .32456 .28456 Mtetra
.805 .624 .657 r
.32456 .28456 .32443 .2899 .33539 .28983 .33553 .28449 Mtetra
.824 .637 .65 r
.33553 .28449 .33539 .28983 .34638 .28973 .34652 .2844 Mtetra
.843 .651 .642 r
.34652 .2844 .34638 .28973 .3574 .28961 .35753 .2843 Mtetra
.862 .665 .633 r
.35753 .2843 .3574 .28961 .36842 .28948 .36855 .28418 Mtetra
.881 .678 .623 r
.36855 .28418 .36842 .28948 .37943 .28932 .37956 .28404 Mtetra
.9 .691 .612 r
.37956 .28404 .37943 .28932 .39043 .28913 .39055 .28388 Mtetra
.918 .705 .6 r
.39055 .28388 .39043 .28913 .4014 .28892 .40151 .28369 Mtetra
.838 .683 .69 r
.89975 .28375 .89976 .28894 .90914 .28884 .90914 .28366 Mtetra
.838 .682 .689 r
.89031 .28383 .89033 .28903 .89976 .28894 .89975 .28375 Mtetra
.836 .679 .688 r
.88082 .28391 .88085 .28913 .89033 .28903 .89031 .28383 Mtetra
.834 .676 .687 r
.87126 .28399 .8713 .28922 .88085 .28913 .88082 .28391 Mtetra
.831 .673 .686 r
.86164 .28407 .86169 .28931 .8713 .28922 .87126 .28399 Mtetra
.828 .669 .686 r
.85195 .28414 .852 .2894 .86169 .28931 .86164 .28407 Mtetra
.824 .664 .685 r
.84219 .28422 .84225 .28949 .852 .2894 .85195 .28414 Mtetra
.819 .659 .684 r
.83235 .28429 .83242 .28957 .84225 .28949 .84219 .28422 Mtetra
.813 .653 .684 r
.82243 .28436 .82251 .28965 .83242 .28957 .83235 .28429 Mtetra
.806 .646 .684 r
.81244 .28442 .81252 .28973 .82251 .28965 .82243 .28436 Mtetra
.799 .638 .683 r
.80236 .28448 .80245 .2898 .81252 .28973 .81244 .28442 Mtetra
.79 .63 .683 r
.7922 .28453 .79229 .28986 .80245 .2898 .80236 .28448 Mtetra
.781 .621 .682 r
.78196 .28458 .78206 .28991 .79229 .28986 .7922 .28453 Mtetra
.77 .611 .682 r
.77163 .28462 .77174 .28996 .78206 .28991 .78196 .28458 Mtetra
.759 .6 .681 r
.76123 .28465 .76134 .29 .77174 .28996 .77163 .28462 Mtetra
.746 .588 .68 r
.75075 .28468 .75086 .29003 .76134 .29 .76123 .28465 Mtetra
.732 .575 .678 r
.74019 .28469 .7403 .29005 .75086 .29003 .75075 .28468 Mtetra
.716 .56 .676 r
.72955 .2847 .72967 .29006 .7403 .29005 .74019 .28469 Mtetra
.699 .545 .674 r
.71885 .2847 .71897 .29006 .72967 .29006 .72955 .2847 Mtetra
.681 .528 .671 r
.70808 .28468 .70821 .29004 .71897 .29006 .71885 .2847 Mtetra
.661 .51 .668 r
.69725 .28465 .69738 .29001 .70821 .29004 .70808 .28468 Mtetra
.639 .49 .664 r
.68637 .28461 .6865 .28996 .69738 .29001 .69725 .28465 Mtetra
.616 .469 .659 r
.67544 .28456 .67557 .2899 .6865 .28996 .68637 .28461 Mtetra
.59 .446 .653 r
.66447 .28449 .66461 .28983 .67557 .2899 .67544 .28456 Mtetra
.563 .421 .647 r
.65348 .2844 .65362 .28973 .66461 .28983 .66447 .28449 Mtetra
.533 .395 .639 r
.64247 .2843 .6426 .28961 .65362 .28973 .65348 .2844 Mtetra
.501 .367 .63 r
.63145 .28418 .63158 .28948 .6426 .28961 .64247 .2843 Mtetra
.467 .338 .62 r
.62044 .28404 .62057 .28932 .63158 .28948 .63145 .28418 Mtetra
.43 .306 .61 r
.60945 .28388 .60957 .28913 .62057 .28932 .62044 .28404 Mtetra
.39 .273 .598 r
.59849 .28369 .5986 .28892 .60957 .28913 .60945 .28388 Mtetra
.547 .446 .692 r
.09086 .27848 .09086 .28366 .10025 .28375 .10026 .27855 Mtetra
.548 .446 .691 r
.10026 .27855 .10025 .28375 .10969 .28383 .1097 .27862 Mtetra
.55 .447 .69 r
.1097 .27862 .10969 .28383 .11918 .28391 .1192 .27869 Mtetra
.553 .448 .689 r
.1192 .27869 .11918 .28391 .12874 .28399 .12877 .27876 Mtetra
.557 .451 .689 r
.12877 .27876 .12874 .28399 .13836 .28407 .1384 .27882 Mtetra
.562 .454 .688 r
.1384 .27882 .13836 .28407 .14805 .28414 .14809 .27889 Mtetra
.568 .458 .688 r
.14809 .27889 .14805 .28414 .15781 .28422 .15786 .27895 Mtetra
.576 .463 .688 r
.15786 .27895 .15781 .28422 .16765 .28429 .16771 .27901 Mtetra
.584 .468 .688 r
.16771 .27901 .16765 .28429 .17757 .28436 .17763 .27907 Mtetra
.593 .475 .687 r
.17763 .27907 .17757 .28436 .18756 .28442 .18763 .27912 Mtetra
.603 .482 .687 r
.18763 .27912 .18756 .28442 .19764 .28448 .19772 .27917 Mtetra
.614 .49 .687 r
.19772 .27917 .19764 .28448 .2078 .28453 .20788 .27921 Mtetra
.626 .498 .687 r
.20788 .27921 .2078 .28453 .21804 .28458 .21813 .27925 Mtetra
.639 .508 .687 r
.21813 .27925 .21804 .28458 .22837 .28462 .22845 .27928 Mtetra
.653 .518 .686 r
.22845 .27928 .22837 .28462 .23877 .28465 .23886 .27931 Mtetra
.667 .528 .685 r
.23886 .27931 .23877 .28465 .24925 .28468 .24935 .27933 Mtetra
.683 .539 .684 r
.24935 .27933 .24925 .28468 .25981 .28469 .25992 .27934 Mtetra
.699 .551 .683 r
.25992 .27934 .25981 .28469 .27045 .2847 .27055 .27935 Mtetra
.716 .563 .681 r
.27055 .27935 .27045 .2847 .28115 .2847 .28126 .27934 Mtetra
.733 .576 .679 r
.28126 .27934 .28115 .2847 .29192 .28468 .29203 .27933 Mtetra
.751 .589 .676 r
.29203 .27933 .29192 .28468 .30275 .28465 .30287 .2793 Mtetra
.77 .603 .672 r
.30287 .2793 .30275 .28465 .31363 .28461 .31375 .27927 Mtetra
.788 .617 .668 r
.31375 .27927 .31363 .28461 .32456 .28456 .32468 .27922 Mtetra
.808 .63 .662 r
.32468 .27922 .32456 .28456 .33553 .28449 .33564 .27916 Mtetra
.827 .644 .656 r
.33564 .27916 .33553 .28449 .34652 .2844 .34664 .27909 Mtetra
.846 .658 .649 r
.34664 .27909 .34652 .2844 .35753 .2843 .35765 .279 Mtetra
.865 .672 .64 r
.35765 .279 .35753 .2843 .36855 .28418 .36866 .27889 Mtetra
.883 .686 .631 r
.36866 .27889 .36855 .28418 .37956 .28404 .37967 .27877 Mtetra
.901 .699 .62 r
.37967 .27877 .37956 .28404 .39055 .28388 .39065 .27864 Mtetra
.919 .713 .609 r
.39065 .27864 .39055 .28388 .40151 .28369 .4016 .27848 Mtetra
.837 .683 .691 r
.89974 .27855 .89975 .28375 .90914 .28366 .90914 .27848 Mtetra
.837 .681 .69 r
.8903 .27862 .89031 .28383 .89975 .28375 .89974 .27855 Mtetra
.835 .679 .689 r
.8808 .27869 .88082 .28391 .89031 .28383 .8903 .27862 Mtetra
.833 .676 .688 r
.87123 .27876 .87126 .28399 .88082 .28391 .8808 .27869 Mtetra
.83 .673 .688 r
.8616 .27882 .86164 .28407 .87126 .28399 .87123 .27876 Mtetra
.827 .669 .687 r
.85191 .27889 .85195 .28414 .86164 .28407 .8616 .27882 Mtetra
.823 .664 .687 r
.84214 .27895 .84219 .28422 .85195 .28414 .85191 .27889 Mtetra
.818 .659 .686 r
.83229 .27901 .83235 .28429 .84219 .28422 .84214 .27895 Mtetra
.812 .653 .686 r
.82237 .27907 .82243 .28436 .83235 .28429 .83229 .27901 Mtetra
.805 .647 .686 r
.81237 .27912 .81244 .28442 .82243 .28436 .82237 .27907 Mtetra
.797 .639 .686 r
.80228 .27917 .80236 .28448 .81244 .28442 .81237 .27912 Mtetra
.789 .631 .686 r
.79212 .27921 .7922 .28453 .80236 .28448 .80228 .27917 Mtetra
.779 .622 .685 r
.78187 .27925 .78196 .28458 .7922 .28453 .79212 .27921 Mtetra
.769 .612 .685 r
.77155 .27928 .77163 .28462 .78196 .28458 .78187 .27925 Mtetra
.757 .601 .684 r
.76114 .27931 .76123 .28465 .77163 .28462 .77155 .27928 Mtetra
.744 .59 .684 r
.75065 .27933 .75075 .28468 .76123 .28465 .76114 .27931 Mtetra
.73 .577 .682 r
.74008 .27934 .74019 .28469 .75075 .28468 .75065 .27933 Mtetra
.714 .562 .681 r
.72945 .27935 .72955 .2847 .74019 .28469 .74008 .27934 Mtetra
.698 .547 .679 r
.71874 .27934 .71885 .2847 .72955 .2847 .72945 .27935 Mtetra
.679 .53 .676 r
.70797 .27933 .70808 .28468 .71885 .2847 .71874 .27934 Mtetra
.659 .512 .673 r
.69713 .2793 .69725 .28465 .70808 .28468 .70797 .27933 Mtetra
.637 .493 .67 r
.68625 .27927 .68637 .28461 .69725 .28465 .69713 .2793 Mtetra
.613 .472 .665 r
.67532 .27922 .67544 .28456 .68637 .28461 .68625 .27927 Mtetra
.588 .449 .66 r
.66436 .27916 .66447 .28449 .67544 .28456 .67532 .27922 Mtetra
.56 .424 .653 r
.65336 .27909 .65348 .2844 .66447 .28449 .66436 .27916 Mtetra
.53 .399 .646 r
.64235 .279 .64247 .2843 .65348 .2844 .65336 .27909 Mtetra
.499 .371 .637 r
.63134 .27889 .63145 .28418 .64247 .2843 .64235 .279 Mtetra
.465 .342 .628 r
.62033 .27877 .62044 .28404 .63145 .28418 .63134 .27889 Mtetra
.428 .312 .618 r
.60935 .27864 .60945 .28388 .62044 .28404 .62033 .27877 Mtetra
.39 .281 .608 r
.5984 .27848 .59849 .28369 .60945 .28388 .60935 .27864 Mtetra
.548 .448 .692 r
.09086 .27331 .09086 .27848 .10026 .27855 .10026 .27336 Mtetra
.549 .448 .691 r
.10026 .27336 .10026 .27855 .1097 .27862 .10972 .27342 Mtetra
.551 .448 .691 r
.10972 .27342 .1097 .27862 .1192 .27869 .11922 .27347 Mtetra
.554 .45 .69 r
.11922 .27347 .1192 .27869 .12877 .27876 .12879 .27353 Mtetra
.558 .453 .69 r
.12879 .27353 .12877 .27876 .1384 .27882 .13843 .27358 Mtetra
.564 .456 .69 r
.13843 .27358 .1384 .27882 .14809 .27889 .14813 .27363 Mtetra
.57 .46 .689 r
.14813 .27363 .14809 .27889 .15786 .27895 .15791 .27368 Mtetra
.577 .465 .689 r
.15791 .27368 .15786 .27895 .16771 .27901 .16776 .27373 Mtetra
.585 .471 .69 r
.16776 .27373 .16771 .27901 .17763 .27907 .17768 .27378 Mtetra
.594 .477 .69 r
.17768 .27378 .17763 .27907 .18763 .27912 .18769 .27382 Mtetra
.604 .485 .69 r
.18769 .27382 .18763 .27912 .19772 .27917 .19778 .27386 Mtetra
.616 .493 .69 r
.19778 .27386 .19772 .27917 .20788 .27921 .20795 .2739 Mtetra
.628 .502 .69 r
.20795 .2739 .20788 .27921 .21813 .27925 .2182 .27393 Mtetra
.64 .511 .69 r
.2182 .27393 .21813 .27925 .22845 .27928 .22853 .27395 Mtetra
.654 .521 .689 r
.22853 .27395 .22845 .27928 .23886 .27931 .23894 .27397 Mtetra
.669 .532 .689 r
.23894 .27397 .23886 .27931 .24935 .27933 .24943 .27399 Mtetra
.684 .544 .688 r
.24943 .27399 .24935 .27933 .25992 .27934 .26 .274 Mtetra
.701 .556 .687 r
.26 .274 .25992 .27934 .27055 .27935 .27064 .274 Mtetra
.717 .568 .685 r
.27064 .274 .27055 .27935 .28126 .27934 .28135 .274 Mtetra
.735 .581 .683 r
.28135 .274 .28126 .27934 .29203 .27933 .29213 .27399 Mtetra
.753 .595 .681 r
.29213 .27399 .29203 .27933 .30287 .2793 .30296 .27396 Mtetra
.772 .609 .677 r
.30296 .27396 .30287 .2793 .31375 .27927 .31385 .27393 Mtetra
.79 .623 .673 r
.31385 .27393 .31375 .27927 .32468 .27922 .32478 .27389 Mtetra
.81 .637 .668 r
.32478 .27389 .32468 .27922 .33564 .27916 .33574 .27384 Mtetra
.829 .651 .662 r
.33574 .27384 .33564 .27916 .34664 .27909 .34673 .27378 Mtetra
.848 .665 .655 r
.34673 .27378 .34664 .27909 .35765 .279 .35774 .27371 Mtetra
.867 .679 .647 r
.35774 .27371 .35765 .279 .36866 .27889 .36876 .27362 Mtetra
.885 .693 .638 r
.36876 .27362 .36866 .27889 .37967 .27877 .37976 .27353 Mtetra
.903 .707 .628 r
.37976 .27353 .37967 .27877 .39065 .27864 .39074 .27341 Mtetra
.836 .682 .691 r
.89974 .27336 .89974 .27855 .90914 .27848 .90914 .27331 Mtetra
.836 .681 .69 r
.89028 .27342 .8903 .27862 .89974 .27855 .89974 .27336 Mtetra
.834 .679 .69 r
.88078 .27347 .8808 .27869 .8903 .27862 .89028 .27342 Mtetra
.832 .676 .689 r
.87121 .27353 .87123 .27876 .8808 .27869 .88078 .27347 Mtetra
.83 .673 .689 r
.86157 .27358 .8616 .27882 .87123 .27876 .87121 .27353 Mtetra
.826 .669 .689 r
.85187 .27363 .85191 .27889 .8616 .27882 .86157 .27358 Mtetra
.822 .665 .688 r
.84209 .27368 .84214 .27895 .85191 .27889 .85187 .27363 Mtetra
.817 .66 .688 r
.83224 .27373 .83229 .27901 .84214 .27895 .84209 .27368 Mtetra
.811 .654 .688 r
.82232 .27378 .82237 .27907 .83229 .27901 .83224 .27373 Mtetra
.804 .648 .688 r
.81231 .27382 .81237 .27912 .82237 .27907 .82232 .27378 Mtetra
.796 .641 .688 r
.80222 .27386 .80228 .27917 .81237 .27912 .81231 .27382 Mtetra
.788 .633 .688 r
.79205 .2739 .79212 .27921 .80228 .27917 .80222 .27386 Mtetra
.778 .624 .688 r
.7818 .27393 .78187 .27925 .79212 .27921 .79205 .2739 Mtetra
.768 .614 .688 r
.77147 .27395 .77155 .27928 .78187 .27925 .7818 .27393 Mtetra
.756 .603 .688 r
.76106 .27397 .76114 .27931 .77155 .27928 .77147 .27395 Mtetra
.743 .591 .687 r
.75057 .27399 .75065 .27933 .76114 .27931 .76106 .27397 Mtetra
.729 .579 .687 r
.74 .274 .74008 .27934 .75065 .27933 .75057 .27399 Mtetra
.713 .565 .685 r
.72936 .274 .72945 .27935 .74008 .27934 .74 .274 Mtetra
.696 .549 .684 r
.71865 .274 .71874 .27934 .72945 .27935 .72936 .274 Mtetra
.677 .533 .681 r
.70787 .27399 .70797 .27933 .71874 .27934 .71865 .274 Mtetra
.657 .515 .679 r
.69704 .27396 .69713 .2793 .70797 .27933 .70787 .27399 Mtetra
.635 .496 .675 r
.68615 .27393 .68625 .27927 .69713 .2793 .69704 .27396 Mtetra
.611 .475 .671 r
.67522 .27389 .67532 .27922 .68625 .27927 .68615 .27393 Mtetra
.585 .452 .666 r
.66426 .27384 .66436 .27916 .67532 .27922 .67522 .27389 Mtetra
.558 .428 .66 r
.65327 .27378 .65336 .27909 .66436 .27916 .66426 .27384 Mtetra
.528 .402 .653 r
.64226 .27371 .64235 .279 .65336 .27909 .65327 .27378 Mtetra
.496 .375 .645 r
.63124 .27362 .63134 .27889 .64235 .279 .64226 .27371 Mtetra
.463 .347 .636 r
.62024 .27353 .62033 .27877 .63134 .27889 .63124 .27362 Mtetra
.427 .318 .627 r
.60926 .27341 .60935 .27864 .62033 .27877 .62024 .27353 Mtetra
.549 .448 .692 r
.09086 .26813 .09086 .27331 .10026 .27336 .10027 .26817 Mtetra
.55 .449 .692 r
.10027 .26817 .10026 .27336 .10972 .27342 .10973 .26821 Mtetra
.552 .45 .691 r
.10973 .26821 .10972 .27342 .11922 .27347 .11924 .26826 Mtetra
.555 .451 .691 r
.11924 .26826 .11922 .27347 .12879 .27353 .12881 .2683 Mtetra
.559 .454 .691 r
.12881 .2683 .12879 .27353 .13843 .27358 .13845 .26834 Mtetra
.565 .458 .691 r
.13845 .26834 .13843 .27358 .14813 .27363 .14816 .26838 Mtetra
.571 .462 .691 r
.14816 .26838 .14813 .27363 .15791 .27368 .15794 .26842 Mtetra
.578 .467 .691 r
.15794 .26842 .15791 .27368 .16776 .27373 .16779 .26846 Mtetra
.586 .473 .691 r
.16779 .26846 .16776 .27373 .17768 .27378 .17773 .26849 Mtetra
.595 .48 .692 r
.17773 .26849 .17768 .27378 .18769 .27382 .18774 .26852 Mtetra
.606 .487 .692 r
.18774 .26852 .18769 .27382 .19778 .27386 .19783 .26855 Mtetra
.617 .496 .692 r
.19783 .26855 .19778 .27386 .20795 .2739 .208 .26858 Mtetra
.629 .505 .693 r
.208 .26858 .20795 .2739 .2182 .27393 .21825 .26861 Mtetra
.642 .515 .693 r
.21825 .26861 .2182 .27393 .22853 .27395 .22859 .26863 Mtetra
.656 .525 .693 r
.22859 .26863 .22853 .27395 .23894 .27397 .23901 .26864 Mtetra
.67 .536 .692 r
.23901 .26864 .23894 .27397 .24943 .27399 .2495 .26865 Mtetra
.686 .548 .692 r
.2495 .26865 .24943 .27399 .26 .274 .26007 .26866 Mtetra
.702 .56 .691 r
.26007 .26866 .26 .274 .27064 .274 .27071 .26866 Mtetra
.719 .573 .69 r
.27071 .26866 .27064 .274 .28135 .274 .28143 .26866 Mtetra
.736 .586 .688 r
.28143 .26866 .28135 .274 .29213 .27399 .2922 .26865 Mtetra
.755 .6 .686 r
.2922 .26865 .29213 .27399 .30296 .27396 .30304 .26863 Mtetra
.773 .614 .682 r
.30304 .26863 .30296 .27396 .31385 .27393 .31392 .26861 Mtetra
.792 .629 .679 r
.31392 .26861 .31385 .27393 .32478 .27389 .32485 .26858 Mtetra
.811 .643 .674 r
.32485 .26858 .32478 .27389 .33574 .27384 .33582 .26854 Mtetra
.83 .658 .668 r
.33582 .26854 .33574 .27384 .34673 .27378 .34681 .26849 Mtetra
.849 .672 .662 r
.34681 .26849 .34673 .27378 .35774 .27371 .35782 .26843 Mtetra
.868 .686 .654 r
.35782 .26843 .35774 .27371 .36876 .27362 .36883 .26836 Mtetra
.886 .7 .645 r
.36883 .26836 .36876 .27362 .37976 .27353 .37983 .26829 Mtetra
.903 .714 .636 r
.37983 .26829 .37976 .27353 .39074 .27341 .3908 .2682 Mtetra
.836 .682 .692 r
.89973 .26817 .89974 .27336 .90914 .27331 .90914 .26813 Mtetra
.835 .68 .691 r
.89027 .26821 .89028 .27342 .89974 .27336 .89973 .26817 Mtetra
.834 .679 .69 r
.88076 .26826 .88078 .27347 .89028 .27342 .89027 .26821 Mtetra
.832 .676 .69 r
.87119 .2683 .87121 .27353 .88078 .27347 .88076 .26826 Mtetra
.829 .673 .69 r
.86155 .26834 .86157 .27358 .87121 .27353 .87119 .2683 Mtetra
.825 .67 .69 r
.85184 .26838 .85187 .27363 .86157 .27358 .86155 .26834 Mtetra
.821 .666 .69 r
.84206 .26842 .84209 .27368 .85187 .27363 .85184 .26838 Mtetra
.816 .661 .69 r
.83221 .26846 .83224 .27373 .84209 .27368 .84206 .26842 Mtetra
.81 .655 .69 r
.82227 .26849 .82232 .27378 .83224 .27373 .83221 .26846 Mtetra
.803 .649 .691 r
.81226 .26852 .81231 .27382 .82232 .27378 .82227 .26849 Mtetra
.796 .642 .691 r
.80217 .26855 .80222 .27386 .81231 .27382 .81226 .26852 Mtetra
.787 .634 .691 r
.792 .26858 .79205 .2739 .80222 .27386 .80217 .26855 Mtetra
.777 .625 .691 r
.78175 .26861 .7818 .27393 .79205 .2739 .792 .26858 Mtetra
.767 .616 .692 r
.77141 .26863 .77147 .27395 .7818 .27393 .78175 .26861 Mtetra
.755 .605 .692 r
.76099 .26864 .76106 .27397 .77147 .27395 .77141 .26863 Mtetra
.742 .594 .691 r
.7505 .26865 .75057 .27399 .76106 .27397 .76099 .26864 Mtetra
.728 .581 .691 r
.73993 .26866 .74 .274 .75057 .27399 .7505 .26865 Mtetra
.712 .567 .69 r
.72929 .26866 .72936 .274 .74 .274 .73993 .26866 Mtetra
.695 .552 .688 r
.71857 .26866 .71865 .274 .72936 .274 .72929 .26866 Mtetra
.676 .536 .686 r
.7078 .26865 .70787 .27399 .71865 .274 .71857 .26866 Mtetra
.656 .518 .684 r
.69696 .26863 .69704 .27396 .70787 .27399 .7078 .26865 Mtetra
.633 .499 .681 r
.68608 .26861 .68615 .27393 .69704 .27396 .69696 .26863 Mtetra
.61 .478 .677 r
.67515 .26858 .67522 .27389 .68615 .27393 .68608 .26861 Mtetra
.584 .456 .672 r
.66418 .26854 .66426 .27384 .67522 .27389 .67515 .26858 Mtetra
.556 .432 .666 r
.65319 .26849 .65327 .27378 .66426 .27384 .66418 .26854 Mtetra
.526 .407 .66 r
.64218 .26843 .64226 .27371 .65327 .27378 .65319 .26849 Mtetra
.495 .38 .652 r
.63117 .26836 .63124 .27362 .64226 .27371 .64218 .26843 Mtetra
.461 .352 .644 r
.62017 .26829 .62024 .27353 .63124 .27362 .63117 .26836 Mtetra
.427 .324 .635 r
.6092 .2682 .60926 .27341 .62024 .27353 .62017 .26829 Mtetra
.55 .449 .693 r
.09086 .26295 .09086 .26813 .10027 .26817 .10027 .26298 Mtetra
.551 .449 .692 r
.10027 .26298 .10027 .26817 .10973 .26821 .10973 .26301 Mtetra
.553 .451 .692 r
.10973 .26301 .10973 .26821 .11924 .26826 .11925 .26304 Mtetra
.556 .453 .692 r
.11925 .26304 .11924 .26826 .12881 .2683 .12883 .26307 Mtetra
.56 .455 .692 r
.12883 .26307 .12881 .2683 .13845 .26834 .13847 .2631 Mtetra
.565 .459 .692 r
.13847 .2631 .13845 .26834 .14816 .26838 .14818 .26313 Mtetra
.572 .464 .692 r
.14818 .26313 .14816 .26838 .15794 .26842 .15797 .26316 Mtetra
.579 .469 .693 r
.15797 .26316 .15794 .26842 .16779 .26846 .16782 .26318 Mtetra
.587 .475 .693 r
.16782 .26318 .16779 .26846 .17773 .26849 .17776 .26321 Mtetra
.596 .482 .694 r
.17776 .26321 .17773 .26849 .18774 .26852 .18777 .26323 Mtetra
.606 .49 .694 r
.18777 .26323 .18774 .26852 .19783 .26855 .19787 .26325 Mtetra
.618 .498 .695 r
.19787 .26325 .19783 .26855 .208 .26858 .20804 .26327 Mtetra
.63 .508 .695 r
.20804 .26327 .208 .26858 .21825 .26861 .2183 .26329 Mtetra
.643 .518 .696 r
.2183 .26329 .21825 .26861 .22859 .26863 .22863 .2633 Mtetra
.656 .528 .696 r
.22863 .2633 .22859 .26863 .23901 .26864 .23905 .26331 Mtetra
.671 .54 .696 r
.23905 .26331 .23901 .26864 .2495 .26865 .24955 .26332 Mtetra
.687 .552 .696 r
.24955 .26332 .2495 .26865 .26007 .26866 .26012 .26333 Mtetra
.703 .564 .695 r
.26012 .26333 .26007 .26866 .27071 .26866 .27077 .26333 Mtetra
.72 .577 .694 r
.27077 .26333 .27071 .26866 .28143 .26866 .28148 .26332 Mtetra
.738 .591 .693 r
.28148 .26332 .28143 .26866 .2922 .26865 .29226 .26332 Mtetra
.756 .605 .69 r
.29226 .26332 .2922 .26865 .30304 .26863 .30309 .2633 Mtetra
.774 .619 .688 r
.30309 .2633 .30304 .26863 .31392 .26861 .31398 .26329 Mtetra
.793 .634 .684 r
.31398 .26329 .31392 .26861 .32485 .26858 .32491 .26326 Mtetra
.813 .649 .68 r
.32491 .26326 .32485 .26858 .33582 .26854 .33588 .26324 Mtetra
.832 .664 .674 r
.33588 .26324 .33582 .26854 .34681 .26849 .34687 .2632 Mtetra
.851 .678 .668 r
.34687 .2632 .34681 .26849 .35782 .26843 .35788 .26316 Mtetra
.869 .693 .661 r
.35788 .26316 .35782 .26843 .36883 .26836 .36889 .26311 Mtetra
.887 .707 .652 r
.36889 .26311 .36883 .26836 .37983 .26829 .37988 .26306 Mtetra
.904 .72 .643 r
.37988 .26306 .37983 .26829 .3908 .2682 .39085 .26299 Mtetra
.835 .681 .692 r
.89973 .26298 .89973 .26817 .90914 .26813 .90914 .26295 Mtetra
.835 .68 .692 r
.89027 .26301 .89027 .26821 .89973 .26817 .89973 .26298 Mtetra
.833 .679 .691 r
.88075 .26304 .88076 .26826 .89027 .26821 .89027 .26301 Mtetra
.831 .677 .691 r
.87117 .26307 .87119 .2683 .88076 .26826 .88075 .26304 Mtetra
.828 .674 .691 r
.86153 .2631 .86155 .26834 .87119 .2683 .87117 .26307 Mtetra
.825 .67 .691 r
.85182 .26313 .85184 .26838 .86155 .26834 .86153 .2631 Mtetra
.82 .666 .692 r
.84203 .26316 .84206 .26842 .85184 .26838 .85182 .26313 Mtetra
.815 .662 .692 r
.83218 .26318 .83221 .26846 .84206 .26842 .84203 .26316 Mtetra
.809 .656 .692 r
.82224 .26321 .82227 .26849 .83221 .26846 .83218 .26318 Mtetra
.803 .65 .693 r
.81223 .26323 .81226 .26852 .82227 .26849 .82224 .26321 Mtetra
.795 .643 .694 r
.80213 .26325 .80217 .26855 .81226 .26852 .81223 .26323 Mtetra
.786 .636 .694 r
.79196 .26327 .792 .26858 .80217 .26855 .80213 .26325 Mtetra
.777 .627 .695 r
.7817 .26329 .78175 .26861 .792 .26858 .79196 .26327 Mtetra
.766 .618 .695 r
.77137 .2633 .77141 .26863 .78175 .26861 .7817 .26329 Mtetra
.754 .607 .695 r
.76095 .26331 .76099 .26864 .77141 .26863 .77137 .2633 Mtetra
.741 .596 .695 r
.75045 .26332 .7505 .26865 .76099 .26864 .76095 .26331 Mtetra
.727 .584 .695 r
.73988 .26333 .73993 .26866 .7505 .26865 .75045 .26332 Mtetra
.711 .57 .694 r
.72923 .26333 .72929 .26866 .73993 .26866 .73988 .26333 Mtetra
.694 .555 .693 r
.71852 .26332 .71857 .26866 .72929 .26866 .72923 .26333 Mtetra
.675 .539 .691 r
.70774 .26332 .7078 .26865 .71857 .26866 .71852 .26332 Mtetra
.654 .521 .689 r
.69691 .2633 .69696 .26863 .7078 .26865 .70774 .26332 Mtetra
.632 .502 .686 r
.68602 .26329 .68608 .26861 .69696 .26863 .69691 .2633 Mtetra
.608 .482 .683 r
.67509 .26326 .67515 .26858 .68608 .26861 .68602 .26329 Mtetra
.582 .46 .678 r
.66412 .26324 .66418 .26854 .67515 .26858 .67509 .26326 Mtetra
.555 .436 .673 r
.65313 .2632 .65319 .26849 .66418 .26854 .66412 .26324 Mtetra
.525 .411 .667 r
.64212 .26316 .64218 .26843 .65319 .26849 .65313 .2632 Mtetra
.494 .385 .66 r
.63111 .26311 .63117 .26836 .64218 .26843 .64212 .26316 Mtetra
.461 .358 .652 r
.62012 .26306 .62017 .26829 .63117 .26836 .63111 .26311 Mtetra
.427 .331 .643 r
.60915 .26299 .6092 .2682 .62017 .26829 .62012 .26306 Mtetra
.55 .449 .693 r
.09086 .25777 .09086 .26295 .10027 .26298 .10027 .25779 Mtetra
.551 .45 .692 r
.10027 .25779 .10027 .26298 .10973 .26301 .10974 .25781 Mtetra
.554 .451 .692 r
.10974 .25781 .10973 .26301 .11925 .26304 .11926 .25782 Mtetra
.557 .453 .692 r
.11926 .25782 .11925 .26304 .12883 .26307 .12884 .25784 Mtetra
.561 .457 .693 r
.12884 .25784 .12883 .26307 .13847 .2631 .13849 .25786 Mtetra
.566 .46 .693 r
.13849 .25786 .13847 .2631 .14818 .26313 .1482 .25788 Mtetra
.572 .465 .694 r
.1482 .25788 .14818 .26313 .15797 .26316 .15798 .25789 Mtetra
.579 .471 .694 r
.15798 .25789 .15797 .26316 .16782 .26318 .16784 .25791 Mtetra
.588 .477 .695 r
.16784 .25791 .16782 .26318 .17776 .26321 .17778 .25792 Mtetra
.597 .484 .696 r
.17778 .25792 .17776 .26321 .18777 .26323 .18779 .25794 Mtetra
.607 .492 .697 r
.18779 .25794 .18777 .26323 .19787 .26325 .19789 .25795 Mtetra
.618 .501 .697 r
.19789 .25795 .19787 .26325 .20804 .26327 .20807 .25796 Mtetra
.63 .51 .698 r
.20807 .25796 .20804 .26327 .2183 .26329 .21833 .25797 Mtetra
.643 .521 .699 r
.21833 .25797 .2183 .26329 .22863 .2633 .22867 .25798 Mtetra
.657 .531 .699 r
.22867 .25798 .22863 .2633 .23905 .26331 .23908 .25799 Mtetra
.672 .543 .699 r
.23908 .25799 .23905 .26331 .24955 .26332 .24958 .25799 Mtetra
.687 .555 .699 r
.24958 .25799 .24955 .26332 .26012 .26333 .26016 .25799 Mtetra
.704 .568 .699 r
.26016 .25799 .26012 .26333 .27077 .26333 .2708 .258 Mtetra
.721 .581 .698 r
.2708 .258 .27077 .26333 .28148 .26332 .28152 .25799 Mtetra
.738 .595 .697 r
.28152 .25799 .28148 .26332 .29226 .26332 .29229 .25799 Mtetra
.757 .61 .695 r
.29229 .25799 .29226 .26332 .30309 .2633 .30313 .25798 Mtetra
.775 .624 .693 r
.30313 .25798 .30309 .2633 .31398 .26329 .31402 .25797 Mtetra
.794 .639 .69 r
.31402 .25797 .31398 .26329 .32491 .26326 .32495 .25796 Mtetra
.813 .654 .686 r
.32495 .25796 .32491 .26326 .33588 .26324 .33592 .25794 Mtetra
.833 .67 .681 r
.33592 .25794 .33588 .26324 .34687 .2632 .34691 .25792 Mtetra
.851 .684 .675 r
.34691 .25792 .34687 .2632 .35788 .26316 .35792 .25789 Mtetra
.87 .699 .668 r
.35792 .25789 .35788 .26316 .36889 .26311 .36892 .25786 Mtetra
.888 .713 .66 r
.36892 .25786 .36889 .26311 .37988 .26306 .37992 .25783 Mtetra
.904 .726 .651 r
.37992 .25783 .37988 .26306 .39085 .26299 .39088 .25779 Mtetra
.835 .681 .692 r
.89973 .25779 .89973 .26298 .90914 .26295 .90914 .25777 Mtetra
.834 .68 .692 r
.89026 .25781 .89027 .26301 .89973 .26298 .89973 .25779 Mtetra
.833 .679 .692 r
.88074 .25782 .88075 .26304 .89027 .26301 .89026 .25781 Mtetra
.831 .677 .692 r
.87116 .25784 .87117 .26307 .88075 .26304 .88074 .25782 Mtetra
.828 .674 .692 r
.86151 .25786 .86153 .2631 .87117 .26307 .87116 .25784 Mtetra
.824 .671 .693 r
.8518 .25788 .85182 .26313 .86153 .2631 .86151 .25786 Mtetra
.82 .667 .693 r
.84202 .25789 .84203 .26316 .85182 .26313 .8518 .25788 Mtetra
.815 .663 .694 r
.83216 .25791 .83218 .26318 .84203 .26316 .84202 .25789 Mtetra
.809 .657 .695 r
.82222 .25792 .82224 .26321 .83218 .26318 .83216 .25791 Mtetra
.802 .652 .695 r
.81221 .25794 .81223 .26323 .82224 .26321 .82222 .25792 Mtetra
.795 .645 .696 r
.80211 .25795 .80213 .26325 .81223 .26323 .81221 .25794 Mtetra
.786 .637 .697 r
.79193 .25796 .79196 .26327 .80213 .26325 .80211 .25795 Mtetra
.776 .629 .697 r
.78167 .25797 .7817 .26329 .79196 .26327 .79193 .25796 Mtetra
.766 .62 .698 r
.77133 .25798 .77137 .2633 .7817 .26329 .78167 .25797 Mtetra
.754 .61 .699 r
.76092 .25799 .76095 .26331 .77137 .2633 .77133 .25798 Mtetra
.741 .599 .699 r
.75042 .25799 .75045 .26332 .76095 .26331 .76092 .25799 Mtetra
.726 .586 .699 r
.73984 .25799 .73988 .26333 .75045 .26332 .75042 .25799 Mtetra
.71 .573 .698 r
.7292 .258 .72923 .26333 .73988 .26333 .73984 .25799 Mtetra
.693 .558 .698 r
.71848 .25799 .71852 .26332 .72923 .26333 .7292 .258 Mtetra
.674 .542 .696 r
.70771 .25799 .70774 .26332 .71852 .26332 .71848 .25799 Mtetra
.654 .525 .695 r
.69687 .25798 .69691 .2633 .70774 .26332 .70771 .25799 Mtetra
.632 .506 .692 r
.68598 .25797 .68602 .26329 .69691 .2633 .69687 .25798 Mtetra
.607 .486 .689 r
.67505 .25796 .67509 .26326 .68602 .26329 .68598 .25797 Mtetra
.582 .464 .685 r
.66408 .25794 .66412 .26324 .67509 .26326 .67505 .25796 Mtetra
.554 .441 .68 r
.65309 .25792 .65313 .2632 .66412 .26324 .66408 .25794 Mtetra
.524 .416 .674 r
.64208 .25789 .64212 .26316 .65313 .2632 .65309 .25792 Mtetra
.493 .391 .667 r
.63108 .25786 .63111 .26311 .64212 .26316 .64208 .25789 Mtetra
.46 .364 .659 r
.62008 .25783 .62012 .26306 .63111 .26311 .63108 .25786 Mtetra
.427 .337 .651 r
.60912 .25779 .60915 .26299 .62012 .26306 .62008 .25783 Mtetra
.551 .45 .693 r
.09086 .25259 .09086 .25777 .10027 .25779 .10027 .2526 Mtetra
.552 .45 .693 r
.10027 .2526 .10027 .25779 .10974 .25781 .10974 .2526 Mtetra
.554 .452 .693 r
.10974 .2526 .10974 .25781 .11926 .25782 .11926 .25261 Mtetra
.557 .454 .693 r
.11926 .25261 .11926 .25782 .12884 .25784 .12885 .25261 Mtetra
.561 .457 .694 r
.12885 .25261 .12884 .25784 .13849 .25786 .13849 .25262 Mtetra
.566 .461 .694 r
.13849 .25262 .13849 .25786 .1482 .25788 .14821 .25263 Mtetra
.572 .466 .695 r
.14821 .25263 .1482 .25788 .15798 .25789 .15799 .25263 Mtetra
.58 .472 .696 r
.15799 .25263 .15798 .25789 .16784 .25791 .16785 .25264 Mtetra
.588 .479 .697 r
.16785 .25264 .16784 .25791 .17778 .25792 .17779 .25264 Mtetra
.597 .486 .698 r
.17779 .25264 .17778 .25792 .18779 .25794 .18781 .25265 Mtetra
.607 .494 .699 r
.18781 .25265 .18779 .25794 .19789 .25795 .1979 .25265 Mtetra
.618 .503 .7 r
.1979 .25265 .19789 .25795 .20807 .25796 .20808 .25265 Mtetra
.631 .513 .701 r
.20808 .25265 .20807 .25796 .21833 .25797 .21834 .25266 Mtetra
.644 .523 .702 r
.21834 .25266 .21833 .25797 .22867 .25798 .22868 .25266 Mtetra
.657 .534 .702 r
.22868 .25266 .22867 .25798 .23908 .25799 .2391 .25266 Mtetra
.672 .546 .703 r
.2391 .25266 .23908 .25799 .24958 .25799 .2496 .25266 Mtetra
.688 .559 .703 r
.2496 .25266 .24958 .25799 .26016 .25799 .26017 .25266 Mtetra
.704 .572 .703 r
.26017 .25266 .26016 .25799 .2708 .258 .27082 .25266 Mtetra
.721 .585 .703 r
.27082 .25266 .2708 .258 .28152 .25799 .28153 .25266 Mtetra
.739 .599 .702 r
.28153 .25266 .28152 .25799 .29229 .25799 .29231 .25266 Mtetra
.757 .614 .7 r
.29231 .25266 .29229 .25799 .30313 .25798 .30315 .25266 Mtetra
.776 .629 .698 r
.30315 .25266 .30313 .25798 .31402 .25797 .31404 .25266 Mtetra
.795 .644 .695 r
.31404 .25266 .31402 .25797 .32495 .25796 .32497 .25265 Mtetra
.814 .66 .692 r
.32497 .25265 .32495 .25796 .33592 .25794 .33594 .25265 Mtetra
.833 .675 .687 r
.33594 .25265 .33592 .25794 .34691 .25792 .34693 .25264 Mtetra
.852 .69 .681 r
.34693 .25264 .34691 .25792 .35792 .25789 .35793 .25263 Mtetra
.87 .705 .674 r
.35793 .25263 .35792 .25789 .36892 .25786 .36894 .25262 Mtetra
.888 .719 .667 r
.36894 .25262 .36892 .25786 .37992 .25783 .37993 .25261 Mtetra
.904 .732 .658 r
.37993 .25261 .37992 .25783 .39088 .25779 .3909 .2526 Mtetra
.835 .681 .693 r
.89973 .2526 .89973 .25779 .90914 .25777 .90914 .25259 Mtetra
.834 .681 .692 r
.89026 .2526 .89026 .25781 .89973 .25779 .89973 .2526 Mtetra
.833 .679 .693 r
.88074 .25261 .88074 .25782 .89026 .25781 .89026 .2526 Mtetra
.831 .677 .693 r
.87115 .25261 .87116 .25784 .88074 .25782 .88074 .25261 Mtetra
.828 .675 .693 r
.86151 .25262 .86151 .25786 .87116 .25784 .87115 .25261 Mtetra
.824 .672 .694 r
.85179 .25263 .8518 .25788 .86151 .25786 .86151 .25262 Mtetra
.82 .668 .695 r
.84201 .25263 .84202 .25789 .8518 .25788 .85179 .25263 Mtetra
.815 .664 .696 r
.83215 .25264 .83216 .25791 .84202 .25789 .84201 .25263 Mtetra
.809 .659 .696 r
.82221 .25264 .82222 .25792 .83216 .25791 .83215 .25264 Mtetra
.802 .653 .697 r
.81219 .25265 .81221 .25794 .82222 .25792 .82221 .25264 Mtetra
.794 .647 .698 r
.8021 .25265 .80211 .25795 .81221 .25794 .81219 .25265 Mtetra
.786 .639 .699 r
.79192 .25265 .79193 .25796 .80211 .25795 .8021 .25265 Mtetra
.776 .631 .7 r
.78166 .25266 .78167 .25797 .79193 .25796 .79192 .25265 Mtetra
.765 .622 .701 r
.77132 .25266 .77133 .25798 .78167 .25797 .78166 .25266 Mtetra
.753 .612 .702 r
.7609 .25266 .76092 .25799 .77133 .25798 .77132 .25266 Mtetra
.74 .601 .703 r
.7504 .25266 .75042 .25799 .76092 .25799 .7609 .25266 Mtetra
.726 .589 .703 r
.73983 .25266 .73984 .25799 .75042 .25799 .7504 .25266 Mtetra
.71 .576 .703 r
.72918 .25266 .7292 .258 .73984 .25799 .73983 .25266 Mtetra
.693 .562 .702 r
.71847 .25266 .71848 .25799 .7292 .258 .72918 .25266 Mtetra
.674 .546 .701 r
.70769 .25266 .70771 .25799 .71848 .25799 .71847 .25266 Mtetra
.653 .529 .7 r
.69685 .25266 .69687 .25798 .70771 .25799 .70769 .25266 Mtetra
.631 .511 .698 r
.68596 .25266 .68598 .25797 .69687 .25798 .69685 .25266 Mtetra
.607 .491 .695 r
.67503 .25265 .67505 .25796 .68598 .25797 .68596 .25266 Mtetra
.581 .469 .691 r
.66406 .25265 .66408 .25794 .67505 .25796 .67503 .25265 Mtetra
.553 .446 .686 r
.65307 .25264 .65309 .25792 .66408 .25794 .66406 .25265 Mtetra
.524 .422 .681 r
.64207 .25263 .64208 .25789 .65309 .25792 .65307 .25264 Mtetra
.492 .396 .674 r
.63106 .25262 .63108 .25786 .64208 .25789 .64207 .25263 Mtetra
.46 .369 .667 r
.62007 .25261 .62008 .25783 .63108 .25786 .63106 .25262 Mtetra
.427 .343 .658 r
.6091 .2526 .60912 .25779 .62008 .25783 .62007 .25261 Mtetra
0 g
0 0 m
0 .5 L
s
0 0 m
.00625 0 L
s
[(-2)] -0.0125 0 1 0 Mshowa
0 .125 m
.00625 .125 L
s
[(-1)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(2)] -0.0125 .5 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML001_G00<0emL0>mL403[G
0P0me`@0?]L00`3Ge`05e`006mL00`3Ge`0ke`030=OG03[G00@0emL0?=L00`3Ge`0oe`030=OG00GG
000He`D0?ML00`3Ge`0ie`040=OG03gG00<0emL0>mL500KG000Ce`@000GG0=OG000ge`@01=L00`3G
e`0he`040=OG03kG00<0emL0>]L0103Ge`07e`006ML00`3G0010e`030=OG03OG00@0emL0?mL00`3G
e`0je`030=L000OG000Je`80?ML0103Ge`0ie`040=OG03cG00@0emL0?ML200OG000Ke`030=OG03cG
0P0ke`80?]L203oG00<0emL01ML000CG1003e`030=OG00;G103oe`gG0006e`030=OG00OG00@0emL0
omL=e`001]L00`3Ge`08e`030=L000CGo`0200OG0006e`040=OGe`@00]L300GG100<e`030=OG00gG
00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL03ML00`3G
e`0=e`030=OG00gG00<0emL03ML00`3Ge`0=e`030=OG00gG00<0emL03ML00`3Ge`0;e`<01mL000KG
00<0emL01mL0103Ge`04e`030=OG00<0m]L200;G00<0emL01ML000CG0`09e`040=OG00CG203be`80
1=L00`3Ge`05e`001]L00`3Ge`07e`@01=L0103Ge`03e`80kmL200KG00<0emL01ML001SG00@0emL0
1ML40>WG0P08e`030=OG00GG000Fe`@000?G00001=L504[G01Z3PX>2Ph:9PXV2RH:9PXV2RH:9PXV3
RH>9P`B901j]RJf9[HV]RJf9[HV]RJf9[HV]RJf9[HV]RJf9[HT3[@0A[:f/[Jb][:f/[Jb][:f/[J`0
C=L200[G00<0emL01ML001GG00@0emL00]L00`3Ge`06e`@0>]L0H5R2F89HPUR2F89NPUj2GX=NPej3
GX=NPej3PX>2RH:9PXV2RH:9PXV2RH:9PXV2RH:9R8V8RHR9PXV2RHR9R8V8[HR]R:f8[HR]R:f8[HR]
R:f8[HR][:f/[Jb][:f/[@b/?=L200cG00<0emL01ML001GG00<0emL01008e`030=OG00@0:]L0QUR2
F89HPUR2F89HPeR3GX=NPej3GX>2Ph:3PX>2Ph:9PXV2RH:9PXV2RH:9PXV2RH>9Pjf9[HV]RJf9[HV]
RJf9[HV]RJf9[HV]RJf9[HV]RJf9[HV]RJf9[Jb][:f/[Jb][:f/[Jb][:f/[Jb][=N/ejcG[=N/ejcG
[=J/eZcF[=J/eZcF;ML200kG00<0emL01ML001GG00@0emL00]L00`3Ge`03e`<01ML301oG00QHEeQG
F5MHE`QH06MNF89HPUR2F89HPUR2F89HPUj2GX9NPej3GX>2Ph:3PX>2RH:9PXV2RH:9PXV2RH:9PXV2
RH:9PXV8[HR9PXV2RH:9PXV2RHR]R:f8[HR]R:f8[HR]R:f8[HR]R:f8[Jb][:f/[Jb]016/01;@[=2/
d:c@[=2/d:c@Zm2[d:/Qe`804=L00`3Ge`05e`005ML0103Ge`08e`030=OG00CG0P000mL0000201;G
00EGF5MHE`0:F02EPUR2F89HPUR2F89HPUR2F8=HPej3PX>2Ph:3PX>2Ph:3PXV2RH:9PXV2RH:9PXV2
RH:]PZf9[HV]RJf9[HV]RJf9[HV]RJf9[HV]RJf9[HV]RJf9[HV]RJf9[HV]RJf/[Jb][:f/[Jb][:f/
[Jb][:f/[Jb][:f/dJcA[=6/dJcG[=N/eZcF[=J/eZc@[=2/eZcF[=H02=000lo@e`0De`804]L00`3G
e`05e`005ML0103Ge`08e`030=OG00?G00@0emL00]L300SG01/]F2eH;EP]F2eH;EQAF5MHEeQGF5MH
EeQGF5L01UP0JH9HPUR2F89HPUR2F89HPUj2GX9NPUj2GX=NPh:3PX>2RH:9PXV2RH:9PXV2RH:9PXV2
RH:9PXV2RHR9R:f8RH:9PXV2RH:9PXV2RH:]R:f8[HR]R:f8[HR]R:f8[HR]R:f8[HR][:f/[@0E[00Q
d:c@[=2/d:c@Zm2[d:_@Zm2[d:_@Zm2[d:_@Zm2[d:_@00[G0P0De`030=OG00GG000Fe`<02=L400;G
00@0emL01=L05E5HDEQAF55HDEQAF55HEeQGF5MHE`08F02JO5R2F89HPUR2F89HPUR2F89HPUR3GX>2
Ph:3PX>2Ph:3PX>2Ph:9PXV2RH:9PXV2RH:9PZf2[H:]RJf9[HV]RJf9[HV]RJf9[HV]RJf9[HV]RJf9
[HV]RJf9[HV]RJf9[HV]R:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jb][:f/[JcA[=6/dJcA[=2/d:c@[=2/
d:c@[=2/d:c@[0O@01G?d<o@cm3?d<o@cm3?d<o@cm3?d0005]L00`3Ge`05e`006=L200gG00@0emL0
1=L0954]DBeA;EL]F2eH;EP]F2eHDEQAF55HEeQGF5MHEeQGF5MHE`AH01B2F89HPUR2F89HPUR2F89H
PUj2GPJ20563PX>2Ph:9PXV2RH:9PXV2RH:9PXV2RH:9PXV2RHR]R:f8[HR]R8V2RH:9PXV2RH:9PXV2
RH:9PZf2[H:]R:f8[HR]R:f8[HR]R:f8[HR][:d05j`0:M2/d:c@[=2[d:_@Zm2[d:_@Zm2[d:_@Zm2[
d:_@Zm2[d:_?Zln[cj/001KG00<0emL01ML001SG00<0emL03=L0103Ge`04e`0EDEQAF55HDEQAF55H
EeQGF5MHEeQG00IH04mlF7aHPUR2F89HPUR2F89HPUR2F89NPh:3PX>2Ph:3PX>2Ph:9PXV2RH:9PXV2
RH:]PZf2[H:]PZf8[HV]RJf9[HV]RJf9[HV]RJf9[HV]00>904j]RJf9[HV]RJf9[HV]RJf9[HV]R:f8
[HR][:f/[Jb][:f/[Jb][:f/[Jb][:f/dJcA[=6/dJcA[=2/d:c@[=2/d:c@[=2/d:c@[=2/d:`5d00C
cm3?d<o@cm3?d<o@cm3?d<o@000Fe`030=OG00GG000He`030=OG00cG00@0emL01=L08UL]EbeG;EL]
F2eH;EQAF55HDEQAF5MHEeQGF5MHEeQGF5L2F00FO5QlF89HPUR2F89HPUR2F89HPUj2GPR20563PX>2
Ph:9PXV2RH:9PXV2RH:9PXV2RH:9PZf2[HR]R:f8[HR]R8V2RH:9PXV2RH:9PXV2RH:9PXV2[H:]PZf2
[H:]PZf2[H:]R:f8[HR]R:d05j`0:M2/d:c@[=2[d:_@Zm2[d:_@Zm2[d:_@Zm2[d:_@Zm2[d:_@Zln[
cj/001KG00<0emL01ML001SG00<0emL03ML200GG01EAF55HDEQAF55HEeQGF5MHEeQGF5L015P05WaH
O5R2F89HPUR2F89HPUR2F89HPUP2PP0iPh:3PX>2Ph:3PX>2Ph:9PXV2RH:9PXV2[H:]PZf2[H:]R:f8
[HV]RJf9[HV]RJf9[HV]RJf9[HV]00>9052]RJf9[HV]RJf9[HV]RJf9[HV]R:f8[HR]R:f/[Jb][:f/
[Jb][:f/[Jb][:f/[Jb][=6/dJc@[=2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@[0?@01??d<o@cm3?d<o@
cm3?d<o@cm0001KG00<0emL01ML001SG00<0emL05=L0=UL]EbeGDEQAF55HDEQAF55HDEQGF5MHEeQG
F5MHEeQGF5MlF89HPUR2F89HPUR2F89HPUR2GPb20563PX>2RH:9PXV2RH:9PXV2RH:]PZf2[H:]PZf8
[HR]R:f8[HR]R8V2RH:9PXV2RH:9PXV2RH:9PXV2RH:9PZf2[H:]PZf2[H:]PZf2[H:]PZd06J`09m2/
d:c@Zm2[d:_@Zm2[d:_@Zm2[d:_@Zm2[d:_@Zm2[d:_?Zln[000Fe`030=OG00GG000He`030=OG01CG
02]AF55HDEQAF55HEeQGF5MHEeQGF5MlF7aHO5R2F89HPUR2F89HPUR2F89H00R203N3PX>2Ph:3PX>2
RH:9PZf2[H:]PZf2[H:]PZf8[HR]R:f8[HV]RJf9[HV]RJf9[HV]RJf9[HV]00:900>3RHT018T0H:f9
[HV]RJf9[HV]RJf8[HR]R:f8[HR][:f/[Jb][:f/[Jb][:f/[Jb][:f/dJcA[=2/d:c@[=2/d:c@[=2/
d:c@[=2/d:c@[=2/d:c@cm3?d<o@cm3?d<o@cm3?d<o@01KG00<0emL01ML001SG0P0Ee`0dEe5GDEMA
F55HDEQAF55HDEQGF5MHEeQGF5MHEeQGF5MlEgaHPUR2F89HPUR2F89HPUR2F0j205J3PX>2RH:9PXV2
RH:]PZf2[H:]PZf2[HR]R:f8[HR]R:f8[HR]R8V2RH:9PXV2RH:9PXV2RH:9PXV2RH:9PXV2[H:]PZf2
[H:]PZf2[H:]PZf2[:J/YQJ/02G@[=2/d:_@Zm2[d:_@Zm2[d:_@Zm2[d:_@Zm2[d:_@YM2UcjD001KG
00<0emL01ML001SG00<0emL05=L0:e5HDEQAF5MHEeQGF5MHEeQGF5MlF7aHO5QlF89HPUR2F89HPUR2
F89HPW`02880=h>2Ph:3PX>2RH:]PZf2[H:]PZf2[H:]PZf8[HR]R:f8[HR]R:f8[HV]RJf9[HV]RJf9
[HV]RJd00XT01h>9PhV3RH<018T0G:f9[HV]R:f8[HR]R:f8[HR]R:f8[HR][:f/[Jb][:f/[Jb][:f/
[Jb][:f/d:c@[=2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@[=2[d:_@cm3?d<o@cm3?d<o@cm005]L00`3G
e`05e`006=L00`3Ge`0De`0bEe5GDEMAF55HDEQAF55HEeQGF5MHEeQGF5MHEeQGO5MlEh9HPUR2F89H
PUR2F89HPUPBPP1LRH:]PZf2[H:]PZf2[H:]PZf2[HR]R:f8[HR]R:f8[HR]R:f8RH:9PXV2RH:9PXV2
RH:9PXV2RH:9PXV2RH:9PZf2[H:]PZf2[H:]PZb2[8:/PZb2[:J/YZbV[:H@[00Sd:c@Zm2[d:_@Zm2[
d:_@Zm2[d:_@Zm2[d:G@YM2Ud:G?Y@005]L00`3Ge`05e`006=L00`3Ge`0De`0YDEQAF5MHEeQGF5MH
EgaGO5MlEgaHO5QlF89HPUR2F89HPUR2F89lPW`02X80=h>2Ph:3PX>2[H:]PZf2[H:]PZf2[H:]PZf8
[HR]R:f8[HR]R:f8[HV]RJf9[HV]RJf9[HV]RJd00XT0Ih>9PhV3RH>9PhV3RH>]Pjf2[H:]PZf2[HR]
R:f8[HR]R:f8[Jb][:f/[Jb][:f/[Jb][:f/[Jc@[=2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@
Zm2[d:_@Zm3?d<o@cm3?d0005]L00`3Ge`05e`006=L00`3Ge`0De`0bEe5GDEQAF55HDEQAF55HEeQG
F5MHEeQGF5MlEgaGO5MlEh9HPUR2F89HPUR2F89lPW`>PP1XR8:8PZb2[H:]PZf2[H:]PZf2[H:]R:f8
[HR]R:f8[HR]R:f8[HR]R8V2RH:9PXV2RH:9PXV2RH:9PXV2RH:9PXV2RH:9PXV2[H:]PZf2[H:/PZb2
[8:/PZb2[:J/YZbV[:J/YZbV[:H;[00PZm2[d:_@Zm2[d:_@Zm2[d:_@Zm2Ud:G@YM2Ud:G@Y@0Fe`03
0=OG00GG000He`030=OG01CG02UGF5MHEgaGO5MlEgaGO5MlEgaGO5QlF7aHPUR2F89HPUR2F89HPWb2
O00:PP0VPh:3PX>2Yh:]PZf2[H:]PZf2[H:]R:f8[HR]R:f8[HR][:f/[J`9[@03RJf900>]03Z9[H>9
PhV3RH>9PhV3RH>9PhV3RH:9PZf2[H:]PZf2[H:]PZf2[HR][:f/[Jb][:f/[Jb][:f/[Jb]0j`0;]2/
d:c@[=2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@Zm2[d:_@Zm2[d:_@Zm3?d00Fe`030=OG00GG000He`03
0=OG01CG031GDEMAF55HDEQAF5MHEeQGF5MHEeQGF5MlEgaGO5MlEh9GPUR2F89HPUR2F89lPW`@PP2C
[8:/PZb2[H:]PZf2[H:]PZf8[HR]R:f8[HR]R:f8[HR]R:f8[HR]R8V2RH:9PXV2RH:9PXV2RH:9PXV2
RH:9PXV2RH:9PXV2RH:]PZf2[H:/PZb2[8:/PZb2[:J/YZbV[:J/YZbV[:J/YZbV[:J/YZbV[:G@YM2U
d:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:D001KG00<0emL01ML001SG0P0Ee`0WEgaGO5MlEgaGO5Ml
EgaGO5MlEgaHO5R2F89HPUR2F89HPWb2O89l00j202RWPZN2[H:]PZf2[H:]PZf2[HR]R:f/[Jb][:f/
[Jb][:f/[Jb][:f/2jd0>8V]PhV3RH>9PhV3RH>9PhV3RH:9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[H:]
PZfV[Jb][:f/[Jb]1J`0;]2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@Zm2[d:_@Zm2[d:_@Zm2[
d00Fe`030=OG00GG000He`030=OG01CG031HDEQAF55HDEQAF5MHEeQGF5MHEgaGO5MlEgaGO5MlEh9G
PUR2F89HPUR2O89lPW`>PP2EYX:/PZb2[8:/PZb2[H:]PZf2[HR]R:f8[HR]R:f8[HR]R:f8[HR]R:f8
RH:9PXV2RH:9PXV2RH:9PXV2RH:9PXV2RH:9PXV2RH:9PXV2[H:]PZb2[8:/PZb2[8:/PZbV[:J/YZbV
[:J/YZbV[:J/YZbV[:J/YJbU[:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@Y@005]L00`3Ge`05e`00
6=L00`3Ge`0De`0WEgaGO5MlEgaGO5MlEgaGO5MlEh9HPUR2F89HPUR2O89lPWb2O89l00b2036VPZN2
Yh:]PZf2[H:]PZf2[H:][:f/[Jb][:f/[Jb][:f/[Jb][:f/[Jbc[K>]/jfc00B]03R9[H>9PhV3RH>9
PhV3RH>9PXV2RH:9PXV2RH:9PXV2[H:]PZf2[H:]PZf2[H:]YZfV[Jb][:f/[@V/02[@[=2/d:c@[=2/
d:c@[=2/d:c@[=2/d:c@Zm2[d:_@Zm2[d:_@Zm2[d00Fe`030=OG00GG000He`030=OG01CG02aHDEQA
F55HEeQGF5MHEeQGO5MlEgaGO5MlEgaGO5N2Eh9GPUR2F89HPWb2O12209NVPZb2[8:/PZb2[8:/PZb2
[HR]R:f/[Jb]R:f8[HR]R:f8[HR]R:f8[HR]R8V2RH:9PXV2REj9GXUNPej3GX>2Ph:3PX>2Ph:3PX>2
Ph:3PXR2R8:/PZb2[8:/PZb2[8:/PZb2[:J/YZbV[:J/YZbV[:J/YZbU[:F/YJbUd:G@YM2Ud:G@YM2U
d:G@YM2Ud:G@YM2Ud:D001KG00<0emL01ML0013G1004e`030=OG01CG02EGO5MlEgaGO5MlEgaGO5Ml
Eh9HPUR2F89HPUR2O89lPWb2O89l00b203>VPZJ2[H:]PZf2[H:]PZf2[H:]YZf/[Jb][:f/[Jb][:f/
[Jb][;>//jbc[;>//jfc[K<01:d0>8V]PhV3RH>9PhV3RH>9PXV2RH:9PXV2RH:9PXV2RH:]PZf2[H:]
PZf2[H:]PZf2[JJ]YZfV[JJ]2j`0:=2/d:c@[=2/d:c@[=2/d:c@[=2/d:c@Zm2[d:_@Zm2[d:_@Zm2[
d00Fe`030=OG00GG000Be`030=OG00?G00<0emL05=L0;5QAF5MHEeQGF5MHEgaGO5MlEgaGO5MlEgaG
O5N2Eh9GPUN2Eh9lPWb2O89l3880DJJ2YX:VPZb2[8:/PZb2[8:/PZb2[Jb][:f/[Jb][:f/[Jb][:f/
[Jb]R:f8[HR]R8V2RH:9GXUNPej3GX=NPej3GX=NPej3GX>2Ph:3PX>2P`07PP13[8:/PZb2[8:/PZb2
[8:/PZbV[:J/YZbV[:J/YZbV[:J/YJbU[:F/YJbUd:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2U000Fe`03
0=OG00GG000Be`030=OG00?G0`0De`0UEgaGO5MlEgaGO5MlEgaGO5N2F89HPUR2F89HPWb2O89lPWb2
O008PP0gYX:VPZJ2YX:VPZb2[H:]PZf2[H:]YZf/[Jb][:f/[Jb][:f/[Jb][:f//jbc[;>//jbc[K>]
/`04[@0oRJf3RH>9PhV3RH>9PhV2RH:9PXV2RH:9PX>2RH:9PXV2RH:9PZf2[H:]PZf2[H:]PZfV[JJ/
YZbV[:J/YZbV00J/02K@[=2/d:c@[=2/d:c@[=2/d:c@[=2[d:_@Zm2[d:_@Zm2[d:_@01KG00<0emL0
1ML000[G1004e`030=OG00?G00<0emL05=L0;5QGF5MHEeQGF5MlEgaGO5MlEgaGO5MlEgaGO5N2Eh9G
PUN2Eh9lPWb2O89l2X805ZJ2YX:VPZb2[8:/PZb2[8:/PZbV[:H4[00e[Jb][:f/[Jb][:f/[Jb][:f8
[HR]R:f8RH:9PXUNREj3GX=NPej3GX=NPej3GX=NPej3PX<03H80@JJ2[8:/PZb2[8:/PZb2[8:/YZbV
[:J/YZbV[:J/YJbU[:F/YJbU[:F/YJbU[:G@YM2Ud:G@YM2Ud:G@YM2Ud:D001KG00<0emL01ML001;G
00<0emL00mL00`3Ge`0De`0SEgaGO5MlEgaGO5MlEgaGPUN2F89HPWb2O89lPWb2O89lPW`02X80O:J2
YX:VPZb2[8:/PZf2[H:]YZfV[JJ][:f/[Jb][:f/[Jb][:f//jbc[;>//jbc[;>//jfc[K>]/hVcRJf3
RH>9PhV3RH>9Gh=NPej3GX=NPh:3PX>2Ph:3PX>2RH:9PZf2[H:]PZf2[H:]PZfV[JJ/YZbV[:J/YZbV
[:H4[00Vd:c@[=2/d:c@[=2/d:c@[=2/d:c@Zm2[d:_@Zm2[d:_@Zm2[d00Fe`030=OG00GG000@e`<0
1ML00`3Ge`0De`0ZO5MlEgaGO5MlEgaGO5MlEgaGO5MlEgaGO5MlEh9GPUN2Nh9kPW^2O89l2X805:J2
YX:VPZJ2[8:/PZb2[8:/PZbV2Z`0=:f/[Jb][:f/[Jb][:f/[Jb]R:f8[HR9PXV2REj9GX=NPej3GX=N
Pej3GX=NPej2GX9NPUh>PP0oYX:VPZJ2[8:/PZb2[8:/PZbV[:J/YZbV[:J/YJbU[:F/YJbU[:F/YJbU
[:G@YM2Ud:G@YM2Ud:G@YM2Ud:D001KG00<0emL01ML001;G00<0emL00mL00`3Ge`0De`0SEgaGO5Ml
EgaGO5MlEgaGPUN2F89lPWb2O89lPWb2O89lPW`02880Z:J2YX:VPZJ2[8:/PZb2[8:]YZfV[JJ][:f/
[Jb][:f/[Jb][=6/dJcG[=N/ejcG[=N//jbc[K>]/jfcRK>9[H>9PhV3REn9Gh=NPej3GX=NPej3GX>2
Ph:3PX>2Ph:3PX>2RH:]PZf2[H:]PZf2[H:/YZbV[:J/YZbV[:J/YZbV[:J/Y]2/d:c@[=2/d:c@[=2/
d:c@[=2[d:_@Zm2[d:_@Zm2[d:_@01KG00<0emL01ML001SG00<0emL05=L0:WaGO5MlEgaGO5MlEgaG
O5MlEgaGO5MlEgaGPUN2Eh9GPW^2Nh9kPWb2O0Z201BVPZJ2YX:VPZb2[8:/PZb2[:J/YQ2/032][;>/
/jbc[:f/[HR]R:f8RHR9PXUNREj3GUmNGeiOGUmHGeQOF89HPUR2GX9NPUh<PP0oYX:VPZJ2YX:/PZb2
[8:/PZbV[:J/YZbV[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbUd:G@YM2Ud:G@YM2Ud:D001KG00<0emL0
1ML001SG0P0Ee`0SEgaGO5MlEgaGO5MlEh9GPUN2F89lPWb2O89lPWb2O89lPW`01X80>JJ2YX:VPZJ2
YX:/PZb2[8:/YZbV[:J/YZf/[Jb][:f/[JcA[=6/ejcG[=N/ejcG[=N/ejcG[=N]/`0>e`1SGhUNPej3
GX=NPej3GX=NPej3GX=NPh:3PX>2Ph:3PZN2[H:]PZf2[8:/PZbV[:J/YZbV[:J/YZbV[:J/YZbV[:J/
Y]2Vd:K@Y]2/d:c@[=2/d:_@Zm2[d:_@Zm2[d:_@YM0001KG00<0emL01ML001SG00<0emL05=L0:WaG
O5MlEgaGO5MlEgaGO5MlEgaGO5MlEgaGPUN2Eh9kPW^2Nh9kPW^2O0R201RVPZJ2YX:VPZb2[8:/PZbV
[:J/YZbV[:H>[008/Zbc[;>//j`Be`0FGeiOF5mHGeQOF5iHGUR2F89HPUR2GQ2203^VPZJ2YX:VPZJ2
[8:/PZbV[:J/YZbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbUd:G@YM2Ud:G@YM2U000Fe`030=OG00GG
000He`030=OG01CG02=GO5MlEgaGO5MlEh9GPUN2Nh9lPWb2O89lPWb2O89lPWb2O006PP0HYX:VPZJ2
YX:VPZb2[8:/PZbV[:J/YZbV1:`05:f/[Jb][=6/dJcG[=N/ejcG[=N/7mL0FeQOF5mHPeR3GX=NPej3
PX>2Ph:3PX>2Ph:WPZN2[8:/PZb2[8:/PZbV[:J/YZbV[:J/YZbV[:J/YZbVd:K@Y]2Vd:K@Y]2Vd:K@
Zm2[d:G@YM2Ud:G@YM2Ud0005]L00`3Ge`05e`006=L00`3Ge`0De`0ZO5MlEgaGO5MlEgaGO5MlEgaG
O5MlEh9GPUN2Nh9kPW^2Nh9kPW^2Nh9l28805:J2YX:VPZJ2[8:/PZbV[:J/YZbV2Z`02]2/d:c@[=J/
eZ`Ne`0BGUQNF5iHGUQNF5iHPUR2F89H3X80>jJ2YX:VPZJ2YX:VPZb2[:J/YZbU[:F/YJbU[:F/YJbU
[:F/YJbU[:F/YJbU[:F/YM2Ud:G@YM2Ud:D001KG00<0emL01ML001SG00<0emL05=L08EMlEgaGO5Ml
Eh9GPW^2Nh9kPW^2O89lPWb2O89lPWb2O006PP0JYX:VPZJ2YX:VPZJ2[8:/YZbV[:J/YZbV[:H6[00D
d:c@[=2/dJcG[=N/ejcG[=N/ej`Me`0@F5mHGeR3F8=HPeR3GX=NP`f203jVPZJ2[8:/PZb2[:J/YZbV
[:J/YZbV[:J/YZbV[:J/Y]2Vd:K@Y]2Vd:K@Y]2Ud:G@YM2Ud:G@YM2Ud:G@01KG00<0emL01ML001SG
00<0emL05=L0:WaGO5MlEgaGO5MlEgaGO5MlEgaGO5N2Eh9GPW^2Nh9kPW^2Nh9kPW^2N`B201RVPZJ2
YX:VPZJ2YX:/PZb2[:J/YZbV[:H8[00:d:c@[=2/d:cF[2;G00=H=5P00eP03UiHGUR2F89HPUR2F89H
38803:J2YX:VPZJ2YX:VPP:V02^/YZbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU
d:D001KG00<0emL01ML001SG00<0emL05=L08EMlEgaGPUN2Nh9kPW^2Nh9kPW^2O89lPWb2O89lPWb2
O006PP0JYX:VPZJ2YX:VPZb2[8:/YZbV[:J/YZbV[:H4[00@d:c@[=2/d:cF[=J/eZcF[2SG00YNF5iH
GUR2F89H3X80?ZJ2YX:VPZJ2[8:/PZbV[:J/YZbV[:J/YZbV[:J/YZbVd:K@Y]2Vd:K@Y]2Vd:G@YM2U
d:G@YM2Ud:G@YM005]L00`3Ge`05e`006=L201GG04IlEgaGO5MlEgaGO5MlEgaGO5MlEgaGPUN2Nh9k
PW^2Nh9kPW^2Nh9kPX62PJJ1YX:VPZJ2YX:VPZJ2[8:/YZbV[:J/YZbV1:`02m2/d:c@[=2/d:c@02SG
2EP03X9HPUR2F89HPWb2O89l1X80>JJ2YX:VPZJ2YX:VPZJ1YX6/YJbU[:F/YJbU[:F/YJbU[:F/YJbU
[:F/YJbU[:F/YJbU[:F/YJbU000Fe`030=OG00GG000He`030=OG01CG025GO5N2Nh9kPW^2Nh9kPW^2
Nh9kPWb2O89lPWb2O89lPW`00X807ZJ2YX:VPZJ2YX:VPZJ2[8:/YZbV[:J/YZbV[:J/YPB/013@[=2/
d:c@[=J/eZcFd=K@:=L4F00:GUR2F89HPUR2F0Z203jVPZJ2YX:VPZb2[8:/YZbV[:J/YZbV[:J/YZbV
[:J/YZbVd:K@Y]2Vd:K@Y]2Ud:G@YM2Ud:G@YM2Ud:G@01KG00<0emL01ML001SG00<0emL05=L0AWaG
O5MlEgaGO5MlEgaGO5MlEgaGPUN2Eh9kPW^2Nh9kPW^2Nh9kPW^2PH:1YX6VPJJ2YX:VPZJ2YX:/PZbV
[:J/YZbV[:H4[008d:c@[=2/d:`^e`IH00aNF89HPUR2F89HPW`:PP0gYX:VPZJ2YX:VPJJ1YZFVYJbU
[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU000Fe`030=OG00GG000He`030=OG01CG
045kPW^2Nh9kPW^2Nh9kPW^2Nh9kPWb2O89lPWb2O89lPWbVPZJ2YX:VPZJ2YX:VPZJ2[8:/YZbV[:J/
YZbV[:J/YP02[00@d:c@[=2/d:c@[=J/e]3Fd2gG0eP02UiHPUR2F89HPW`:PP0lYX:VPZJ2YX:VPZbV
[:J/YZbV[:J/YZbV[:J/YZbV[:K@Y]2Vd:K@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM005]L00`3Ge`05e`00
6=L00`3Ge`0De`0hO5MlEgaGO5MlEgaGO5MlEgaGO5N2Eh9kPW^2Nh9kPW^2Nh9kPW^2Nh:1PX6VPJJ1
YX6VPJJ1YX42YP0I[:J/YZbV[:J/YZbU[:_@Zm2/d:_@Zm2[d00]e`03F5MH00EH011lF7aHPUR2F89l
PWb2O89l1880=jJ1YX6VPJJ1YX6VPJJ1YX6VYJJUYZF/YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU
[:F/Y@005]L00`3Ge`05e`006=L00`3Ge`0De`11Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2O89lPWb2
O89lYX:VPZJ2YX:VPZJ2YX:VPZb2[:J/YZbV[:J/YZbV[:H00Z`03=2/d:c@[=2/d:c@[0;@00?Fd=L0
;=L5F00<PUR2F89HPWb2O89l1X80?:J2YX:VPZJ2YX:/PZbV[:J/YZbV[:J/YZbV[:J/YZbV[:K@Y]2V
d:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@01KG00<0emL01ML001SG0P0Ee`1@O5MlEgaGO5MlEgaGO5MlEgaG
O5N2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh:1YX6VPJJ1YX6VPJJ1YX6VYJbU[:F/YJbU[:F/YJb[d:_@Zm2[
d:/be`1AF5MHEeQGO5MlEh9GPUN2Nh9kPW^2Nh:1PX6VPJJ1YX6VPJJ1YX6VPJJ1YZFVYJJU[:F/YJbU
[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:D001KG00<0emL01ML001SG00<0emL05=L0CG^2Nh9kPW^2
Nh9kPW^2Nh9kPW^2Nh9kPWb2O89lPWb2O:J2YX:VPZJ2YX:VPZJ2YX:/YZbV[:J/YZbV[:J/Y]2Vd:c@
[=2/d:c@[=2/00?@<]L3F00>O5QlF89HPUR2O89lPW`4PP0<YX:VPZJ2YX:VPZJ20ZH0;ZbV[:J/YZbV
[:J/YZbV[:J/YZbVd:K@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud00Fe`030=OG00GG000He`030=OG01CG
051lEgaGO5MlEgaGO5MlEgaGO5MlEh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPX6VPJJ1YX6VPJJ1YX6VYJJU
[:F/YJbU[:F/YJbU[:_@Zm2[d:_@Zc;G055HEeQGF5MlEgaGO5N2Eh9GPW^2Nh9kPW^2NjJ1YX6VPJJ1
YX6VPJJ1YX6VYJJUYZFVYJJU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:F/Y@005]L00`3Ge`05e`00
6=L00`3Ge`0De`1=Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9lPWb2O:IlYX:VPZJ2YX:VPZJ2YX:V
PZbV[:J/YZbV[:J/YZbVd:K@[=2/d:c@[=2/d:`00m0be`=H00ilF7aHPUR2F89lPWb2O0B200bVPZJ2
YX:VPZJ2YX84YP0/[:J/YZbV[:J/YZbV[:J/YZbV[:J/YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud00Fe`03
0=OG00GG000He`030=OG01CG051lEgaGO5MlEgaGO5MlEgaGO5MlNh9kPW^2Nh9kPW^2Nh9kPW^2Nh9k
PX6VPJJ1YX6VPJJ1YX6VYJJU[:F/YJbU[:F/YJbUd:G@YM2[d:_@Zc;G055HDEQGF5MHEeQGO5N2Eh9G
PW^2Nh9kPW^2Nh:1YX6VPJJ1YX6VPJJ1YX6VPJJUYZFVYJJU[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU
[:F/Y@005]L00`3Ge`05e`006=L00`3Ge`0De`0aNh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPWb2
O:IlYX:VPZJ2YX:VPZJ2YX:VPP04YP0K[:J/YZbV[:J/Y]2Vd:c@[=2/d:c@Zm2[d<o@03;G01=GF5Ml
EgaHO5R2F89lPWb2O89l00B200ZVPZJ2YX:VPZJ21ZH0:ZbV[:J/YZbV[:J/YZbU[:F/YJbUd:G@YM2U
d:G@YM2Ud:G@YM2Ud:G@01KG00<0emL01ML001SG00<0emL05=L0D7aGO5MlEgaGO5MlEgaGO5MlEgak
PW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2PJJ1YX6VPJJ1YX6VPJJUYZF/YJbU[:F/YJbU[:G@YM2Ud:_@Zm2[
<]L0DEQAF5MHEeQGF5MlEgaGPUN2Nh9kPW^2Nh9kPW^VPJJ1YX6VPJJ1YX6VPJJ1YZFVYJJUYZFVYJJU
[:F/YJbU[:F/YJbU[:F/YJbU[:F/YJbU000Fe`030=OG00GG000He`805ML0;G^2Nh9kPW^2Nh9kPW^2
Nh9kPW^2Nh9kPW^2Nh9kPWbVO:J2YX:VPZJ2YX:VPP08YP0H[:J/YZbV[:J/Y]2Vd:c@[=2/d:_@Zm2[
>=L047aGO5MlEh9HPWb2O89lPW`4PP0:YX:VPZJ2YX:VPPJV02Z/YZbV[:J/YZbV[:J/YJbU[:F/YM2U
d:G@YM2Ud:G@YM2Ud:G@YM2Ud00Fe`030=OG00GG000He`030=OG01CG04elEgaGO5MlEgaGO5MlEgaG
O5MlNh9kPW^2Nh9kPW^2Nh9kPW^2NjIkYW^VNjJ1YX6VPJJ1YX6VYJJUYZF/YJbU[:F/YJbUd:G@YM2U
d00he`1>DEQAF5MHEgaGO5N2Eh9kPW^2Nh9kPW^2NjIkYX6VPJJ1YX6VPJJ1YX6VYJJUYZFVYJJUYZFV
YJbU[:F/YJbU[:F/YJbU[:F/YJbU[:D05]L00`3Ge`05e`006=L00`3Ge`0De`0]Nh9kPW^2Nh9kPW^2
Nh9kPW^2Nh9kPW^2Nh9kPW^2NjIkYX6VPZJ2YX:VPZJ200RV01R/YZbV[:J/Y]2Vd:G@YM2Ud:_@Zm2[
d:/he`0PF5MHEgaGO5N2Nh9kPW^2O89lPWbVPZJ2YX:VPZJ2YX88YP0V[:J/YJbU[:F/YJbU[:F/YM2U
d:G@YM2Ud:G@YM2Ud:G@YM2Ud00Fe`030=OG00GG000He`030=OG01CG04elEgaGO5MlEgaGO5MlEgaG
O5MlNh9kPW^2Nh9kPW^2Nh9kPW^2NjIkYW^VNjJ1YX6VPJJ1YX6VYJJUYZF/YJbU[:F/YJbUd:G@YM2U
d00he`1>DEQAF5MHEgaGO5MlEgakPW^2Nh9kPW^2NjIkYX6VPJJ1YX6VPJJ1YX6VYJJUYZFVYJJUYZFV
YJJU[:F/YJbU[:F/YJbU[:F/YJbU[:D05]L00`3Ge`05e`004ML200GG00<0emL05=L0;G^2Nh9kPW^2
Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^VNjJ1YX6VPJJ1YX6VPP08YP0H[:J/YJbU[:G@YM2Ud:G@YM2[
d:_@Zm2[>=L085QGF5MlEgaGPW^2Nh9kPW^2Nh9kYX:VPZJ2YX:VPZJ21JH0:JFVYJbU[:F/YJbU[:F/
YJbU[:F/YM2Ud:G@YM2Ud:G@YM2Ud:G@YM0001KG00<0emL01ML0013G00@0emL01=L00`3Ge`0De`1=
O5MlEgaGO5MlEgaGO5MlNgakO7^2Nh9kPW^2Nh9kPW^2Nh9kPW^VNjIkYW^VPJJ1YX6VPJJ1YZFVYJJU
[:F/YJbU[:F/YM2Ud:G@YM00>=L0CU5HDEQGF5MlEgaGO5MlNh9kPW^2Nh9kPW^VNjIkYW^VPJJ1YX6V
PJJ1YZFVYJJUYZFVYJJUYZFVYJbU[:F/YJbU[:F/YJbU[:F/YJbU01KG00<0emL01ML0013G00@0emL0
1=L301CG04ekPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kYW^VPJJ1YX6VPJJ1YX6VYJJUYZFV
YJJU[:F/YJbUd:G@YM2Ud:G@YM2[d:_@Z`0he`1>F5MHEgaGO5MlNgakPW^2Nh9kPW^VNjJ1YX6VPJJ1
YX6VYJJUYZFVYJJU[:F/YJbU[:F/YJbU[:F/YM2Ud:G@YM2Ud:G@YM2Ud:G@YM005]L00`3Ge`05e`00
4=L0103Ge`04e`030=OG01CG04elEgaGO5MlEgaGO5MlEgakO7]lNh9kPW^2Nh9kPW^2Nh9kPW^2NjIk
YW^VNjJ1YX6VPJJ1YX6VYJJUYZFVYJJU[:F/YJbUd:G@YLnUc`0he`1>DEMAF55HEgaGO5MlEgakO7^2
Nh9kPW^2NjIkYW^VNjJ1YX6VPJJ1YX6VYJJUYZFVYJJUYZFVYJJUYZFVYJbU[:F/YJbU[:F/YJbU[:D0
5]L00`3Ge`05e`004=L0103Ge`04e`030=OG01CG04ekPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2
Nh9kYW^VNjJ1YX6VPJJ1YX6VYJJUYZFVYJJU[:F/YJbUd:G@YM2Ud:G@YM2[d:_@Z`0he`1>F5MHEgaG
O5MlNgakPW^2Nh9kPW^VNjJ1YX6VPJJ1YX6VYJJUYZFVYJJU[:F/YJbU[:F/YJbU[:F/YM2Ud:G@YM2U
d:G@YM2Ud:G@YM005]L00`3Ge`05e`004=L0103Ge`04e`030=OG01CG04elEgaGO5MlEgaGO5MlEgak
O7]lNh9kPW^2Nh9kPW^2Nh9kPW^2NjIkYW^VNjIkYX6VPJJ1YX6VYJJUYZFVYJJU[:F/YJbUd:G?YLnU
c`0he`05DEMAEe400UL0AgaGO5MlEgakO7^2Nh9kPW^2NjIkYW^VNjJ1YX6VPJJ1YX6VYJJUYZFVYJJU
YZFVYJJUYZFVYJbU[:F/YJbU[:F/YJbU[:D001KG00<0emL01ML0017G0P05e`030=OG01CG04ekPW^2
Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kYW^VNjJ1YX6VPJJ1YX6VYJJUYZFVYJJUYZFVYJbUd:G@
YM2Ud:G@YM2Ud:_@Z`0he`1>F55HEgaGO5MlNgakPW^2Nh9kPW^VNjIkYX6VPJJ1YX6VYJJUYZFVYJJU
YZF/YJbU[:F/YJbU[:F/YM2Ud:G@YM2Ud:G@YM2Ud:G@YM005]L00`3Ge`05e`006=L00`3Ge`0De`1=
O5MlEgaGO5MlEgaGO5MlNgakO7]lNgakPW^2Nh9kPW^2Nh9kPW^VNjIkYW^VNjJ1YX6VPJJ1YZFVYJJU
YZFVYJJU[:F/YLnUcjG?YLl0>=L01E5GDEMA009G04MkEgaGO5MlNgakPW^2Nh9kPW^VNjIkYW^VNjJ1
YX6VPJJ1YZFVYJJUYZFVYJJUYZFVYJJUYZFVYJbU[:F/YJbU[:F/YJbU000Fe`030=OG00GG000He`80
5ML0CG^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^VNjIkYX6VPJJ1YX6VPJJUYZFVYJJUYZFV
YJbU[:G@YM2Ud:G@YM2Ud:G@YM2U03SG04iHDEQGO5MlEgakO7^2Nh9kPW^2NjIkYW^VPJJ1YX6VPJJU
YZFVYJJUYZFVYJbU[:F/YJbU[:F/YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud00Fe`030=OG00GG000He`03
0=OG01CG03mlEgaGO5MlEgaGO5MlEgaGO5MlNgakO7^2Nh9kPW^2Nh9kPW^2NjIkYW^VNjIkYW^VPJJ1
YX6VYJJUYZFVYJH01jD01lnUcjG?YLl0>=L03E5GDEMAEe5kDG]GNeL017/0?GakO7^2Nh9kYW^VNjIk
YW^VPJJ1YX6VPJJUYZFVYJJUYZFVYJJUYZFVYJJUYZF/YJbU[:F/YJbU[:F/Y@005]L00`3Ge`05e`00
6=L00`3Ge`0De`1@Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2NjIkYW^VNjJ1YX6VPJJ1YZFV
YJJUYZFVYJJU[:F/YM2Ud:G@YM2Ud:G@YM2Ud:G?bLlbe`05DEMAEe400UL0BWaGO5MlNgakO7^2Nh9k
PW^VNjIkYX6VPJJ1YX6VPJJUYZFVYJJUYZF/YJbU[:F/YJbU[:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM00
5]L00`3Ge`05e`006=L00`3Ge`0De`0kO5MlEgaGO5MlEgaGO5MlEgaGO7]lNgakO7^2Nh9kPW^2Nh9k
PW^VNjIkYW^VNjIkYX6VPJJ1YZFVYJH02jD02/nUcjG?YLnUcjDbe`AA00aGDEMAEe5kDG]GNeL8N`0i
PW^2NjIkYW^VNjIkYX6VPJJ1YX6VYJJUYZFVYJJUYZFVYJJUYZFVYJJU[:F/YJbU[:F/YJbU[:D001KG
00<0emL01ML001SG00<0emL05=L0D7^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^VNjIkYW^V
PJJ1YX6VPJJ1YX6VYJJUYZFVYJJUYZF/YM2Ud:G@YM2Ud:G@YLnUclW?<]L0DE5GDG]ANeMlEgaGO7]l
NgakPW^2Nh9kYW^VNjJ1YX6VPJJUYZFVYJJUYZFVYJJU[:F/YJbU[:F/YJbUd:G@YM2Ud:G@YM2Ud:G@
YM2Ud:G@000Fe`030=OG00GG000He`030=OG01CG03IlEgaGO5MlEgaGO5MlEgaGO5MlNgakO7]lNgak
PW^2Nh9kPW^2Nh9kPW^VNjIkYW^VNjIkYH4@Y@0:bJG?YLnUcjG?YC;G154035MAEe5GDG]ANeMkE`Qk
03V1Nh5kYW^VNjIkYW^VPJJ1YX6VPJJUYZFVYJJUYZFVYJJUYZFVYJJUYZF/YJbU[:F/YJbU[:F/Y@00
5]L00`3Ge`05e`006=L00`3Ge`0De`1@Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2NjIkYW^V
NjIkYW^VPJJ1YX6VPJJUYZFVYJJUYZFVYJJUd:G@YM2Ud:G?YLnUcjG?bLlbe`1ADEMANe5kDG]AO5Ml
NgakO7^2Nh9kPW^VNjIkYX6VPJJ1YZFVYJJUYZFVYJJUYZF/YJbU[:F/YJbU[:G@YM2Ud:G@YM2Ud:G@
YM2Ud:G@YM0001KG00<0emL01ML001SG0P0Ee`0hO5MlEgaGO5MlEgaGO5MlEgaGO5MlNgakO7]lNh9k
PW^2Nh9kPW^2Nh9kYW^VNjIkYW^UNjEkYH4@Y@08bJG?YLnUcjDbe`AA00aGDEMAEe5kDG]GNeL8N`0i
PG^1NjEkYG^UNjIkYX6VPJJ1YZFVYJJUYZFVYJJUYZFVYJJUYZFVYJJU[:F/YJbU[:F/YJbU[:D001KG
00<0emL01ML001SG00<0emL05=L0D7^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2NjIkYW^V
NjIkYW^VPJJ1YX6VYJJUYZFVYJJUYZFVYLZUbZG@YLnUcjG?YLnUclW?<]L02e5GDG]ANe5kDG]G00Ak
049lNh9kPW^VNjIkYW^VNjIkYX6VYJJUYZFVYJJUYZFVYJJUYZF/YJbUd:G@YM2Ud:G@YM2Ud:G@YM2U
d:G@YM2Ud00Fe`030=OG00GG000He`030=OG01CG03QlEgaGO5MlEgaGO5MlEgaGO5MlEgakO7]lNgak
O7^2Nh9kPW^2Nh9kPW^UNjEkYG^UNjEkYG^UNa2U00_9YLVUbJC9Y<nTc`0]e`04DBaAD09A00YGDG]A
Ne5kDG]G2W/04X5kYG^UNjEkYG^UNjEkYH6UP@BU02>VYJJUYZFVYJJUYZFVYJJUYZFVYJbU[:F/YJbU
[:F/YJbU000Fe`030=OG00GG000He`030=OG01CG05=kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2
Nh9kPW^VNjIkYW^VNjIkYX6VPJJ1YZFVYJJUYZFVYJJUYZFVYJJUbJG?YLnUcjG?YLnUclW?b@0]e`=A
00YGDG]ANe5kDG]G17/0@WakPW^2NjIkYW^VNjIkYW^VPJJUYZFVYJJUYZFVYJJUYZFVYJbU[:G@YM2U
d:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@01KG00<0emL01ML001SG00<0emL05=L0>7aGO5MlEgaGO5MlEgaG
O5MlEgaGO5MlNgakO7]lNgakO7^2Nh5kPG^1Nh5kYG^UNjEkYG^UNjEk4:D02/VUbJG9Y<VTbJ@^e`0@
DBaAD55@Ee1kDG]ANe5kE`Yk01:1NjEkYG^UNjEkYG^UNjF1YH48Y@0OYZFVYJJUYZFVYJJUYZFVYJbU
[:F/YJbU[:F/YJbU000Fe`030=OG00GG000He`030=OG01CG03ikPW^2Nh9kPW^2Nh9kPW^2Nh9kPW^2
Nh9kPW^2Nh9kPW^2NjIkYW^VNjIkYW^VNjIkYX6VYJJUYZFVYJJUYP>U0179YLVUbJG?YLnUcjG?YLo9
c`0^e`0;D55@Ee5kDG]ANe402W/0?X5kYW^VNjIkYW^VNjJUYZFVYJJUYZFVYJJUYZFVYJJU[:G@YM2U
d:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM005]L00`3Ge`05e`006=L201GG01]lEgaGO5MlEgaGO5MlEgaG
O5MlEgaGO5MlNg`02G/0685kPG^1Nh5kYG^UNjEkYG^UNjEkYInUW`jU00_9Y<VTbJC9Y<VTb@0Xe`0C
9U4VDE1AD55@Ee1kD7]ANe5kE`0:N`0BPG^UNjEkYG^UNjEkYG^UNjF14:D05jJUYZFVYJJU[:F/YJbU
[:F/YJbU[:D001KG00<0emL01ML001SG00<0emL05=L0?5MlEgakO7]lNgakO7^2Nh9kPW^2Nh9kPW^2
Nh9kPW^2Nh9kYW^VNjIkYW^VNjIkYW^VPJJUYZFVYJJUYPFU01C9YLVUbJG9YLVUbJG?YLnTclS?b2SG
00iAD55@DE1kDG]ANe5kD@Yk03jUNjEkYW^VNjIkYW^VYJJUYZFVYJJUYZFVYJJUYZFVYJbUd:G@YM2U
d:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@01KG00<0emL01ML001SG00<0emL05=L06GaGO5MlEgaGO5MlEgaG
O5MlEgaGO5MlEg`03G/06X5kPG^1NjEkYG^UNjEkYG^UNjEkYG^UWjFO1jD03ZBUY<VTbJC9Y<VTbJC9
:=L04BIA9U5@DE1AD7]@Ne1kDG]A00ak012UNjEkYG^UNjEkYG^UNjEk5:D05JJUYZF/YJbU[:F/YJbU
[:F/YJbU000Fe`030=OG00GG000He`030=OG01CG03QGO5MlEgaGO7]lNgakO7]lNgakO7^2Nh9kPW^2
Nh9kPW^2Nh9kPW^VNjIkYW^VNjIkYW^VNjJUYPfU01?9YLVUbJG9YLVUbJC9Y<VTbLS902;G015:DDYA
D55@DE1kD7]ANgEkM@0:N`0nYG^UNjEkYG^VNjIkYZFVYJJUYZFVYJJUYZFVYJJUYZG@YM2Ud:G@YM2U
d:G@YM2Ud:G@YM2Ud:G@YM2Ud00Fe`030=OG00GG000He`030=OG01CG01YlEgaGO5MlEgaGO5MlEgaG
O5MlEg]GNeMkE`ik01b1Nh5kPG^UNjEkYG^UNjEkYG^UNjFOYInUWjFO0jD04jBUY:FTYJBUY<VTbJC9
Y<RTb:@07]L05U0VD2I@BU1:DE1AD7E@Ne1kD7]@Ne0<N`0@YG^UNjEkYG^UNjEkYG^UNaRU016[YJbU
[:F/YJbU[:F/YM2U000Fe`030=OG00GG000He`030=OG01CG03UGO5MlEgaGO5MlEgakO7]lNgakO7]l
Nh9kPW^2Nh9kPW^2Nh9kPW^VNjIkYW^VNjIkYW^VNjJOYIl03ZD04lVUbJG9YLVUbJC9Y<VTbJC9Y<T0
7]L04dY@BU5@DE1AD7E@Ne1kDG]ANgD02W/0?ZEkYG^UNjEkYG^VWjJUYZFVYJJUYZFVYJJUYZFVYJJU
d:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM005]L00`3Ge`05e`006=L00`3Ge`0De`0JO5MlEgaG
O5MlEgaGO5MlEgaGNeMkEg]GNeLDN`0/PG^1NjEkYG^UNjEkYG^UNjFOYInUWjFNYIjUWZFNYJBUY<VT
bJC9W/RNb9hNe`04D2I@BPA@011AD55@ME1kD7]@NgAkM7]j27/04YmkYG^UNjEkYG^UNjEkYInUWaRU
016[YJ^U[:F/YJbUd:G@YM2U000Fe`030=OG00GG000He`805ML0>eMlEgaGO5MlEgaGO5MlEgakO7]l
NgakO7]lNh9kPW^2Nh9kPW^2Nh9kYW^VNjIkYW^VNjEkYG^UNjFO012U01G9Y<VTbJC9Y<VTbJC9Y<VN
b9k8W/P04]L01DY@BU1:00A@00iAD7E@ME1kD7]@NgAkM0Qk012ONimkYG^UNjEkYG^UNjFO0ZD0<:JU
YZFVYJJUYZFVYJJUYZG@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@01KG00<0emL01ML001SG
00<0emL05=L07WaGO5MlEgaGO5MlEg]GNeMkEg]GNeMkEg]GNeMkEa9k02fUNjEkYG^UNjEkYG^UNjEk
YInUWjFNYIjUWZFNYIjUWZFNYIjUWZBNY9jTWZ@019h00igGe`0<e`0:D4U@BE1:D4Y@BPI@011eD7E@
ME1kD7]@Ne1kM7]j27/04YmkYG^UNjEkYG^UNjEkYInUWaRU016[YJ^UcjG@YM2Ud:G@YM2U000Fe`03
0=OG00GG000He`030=OG01CG04=GO5MlEgaGO5MlEgaGO5MlEgakO7]lNgakO7]lNgakO7^2Nh9kPW^2
NjIkYW^VNjIkYG^UNjEkYG^UWjFOYInUWjFO00JU01O9YLVTbJC9Y<VTbJC9Y<VNbIk8W/RNb006WP04
NYidWPId00E@M4YdBP04D00@M51eD7E@ME1kD7]@NgAkM0Qk00jONimkYG^UNjEkYInUW`JU02jVYJJU
YZFVYJJUYZFVYM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM005]L00`3Ge`05e`006=L00`3G
e`0De`0PO5MlEgaGO5MlEgaGNeMkEg]GNeMkEg]GNeMkEg]GNeLDN`0YWg^UNjEkYG^UNjEkYGZUNZFN
YIjUWZFNYIjUWZFNY9jTWZBNY9jTWZ@019h06IfNNIicWW=jLgAcM4mdCgA9M4U@BU1:D4X01500:7A@
ME1eD7]@Ne1kM7]dNgAkNW]jNgZONimkWg^UNjEkYG^UNjEkYIlJY@0CZjF[YLnUcjG?YLnUd:G@YM2U
000Fe`030=OG00GG000@e`@01=L00`3Ge`0De`19EgaGO5MlEgaGO5MlEgaGO5MlEgakO7]lNgakO7]l
NgakO7^2Nh9kPW^2NjIkYG^UNjEkYG^UNjEkYG^UWjFOYInUWjFOYInUW`03Y@0DY<VTbJC9W/VNbIk9
W/VNb9jTWZ@6WP06NYidWWAj17@06E1dD7A@M51dD7A@ME1eD7]@Ne1kM7]dNg@01W/049mkWg^ONjEk
YG^UNjEkYIl8Y@0/YZFVYJJUYZG:YLZUd:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud00Fe`03
0=OG00GG000Be`030=OG00?G00<0emL05=L087aGO5MlEgaGO5MkEg]GNeMkEg]GNeMkEg]GNeMkEg]G
57/09ImkWg^UNjEkYG^UNZEjYGZUNZFNYIjUWZFNYIjUWZBNY9jTWZ@029h0AifNNIicWW=jLgAcM4md
CgA9M4UdBWA:M51dD7A@M51dD7A@Ne1kM7]dNgAkNW]jNgYkNYmjWg^ONjEkYG^UNjEkYG^UWjFO01RU
01>[YLnUcjG?YLnUcjG?YM2Ud:D001KG00<0emL01ML001;G00<0emL00mL301CG061GO5MlEgaGO5Ml
EgaGO5MlEgaGO5MlNgakO7]lNgakO7]lNgakO7]lNh5kPG^UNjEkYG^UNjEkYG^UNjEkYInUWjFOYInU
WjFOYIjUWZFNYIjUWZFNYIjUWZFNY9jTWZ@6WP06NYidWWAj17@06e1dD7A@M51dD7A@ME1eM7]dNgAk
M7]jNgYkNP02N`0BWg^ONimkYG^UNjEkYInUWjFO3ZD09/ZUbZG:YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2U
d:G@YM2Ud:G@YM005]L00`3Ge`05e`004]L00`3Ge`03e`030=OG01CG029HEeQGO5MlEg]GNeMkEg]G
NeMkEg]GNeMkEg]GNeMkEg]G57/07ImkWg^ONimkYGZUNZEjYGZUWZFNYIjUWZFNYIjT00jN04MjWWVN
LiicNW=dLgA?M4mdCgA@M51dD7A@M51dD7A@M51dD7]@NgAkM7]dNgYkNW]jWgZONYmkWg^UNjEkYG^U
NjFOYInUW`0HY@0CcjG?YLnUcjG?YLnUcjG@YM2U000Fe`030=OG00GG000Be`030=OG00?G00<0emL0
5=L0:5MlEgaGO5MlEgaGO5MlEgaGO5MlEgaGO7]lNgakO7]lNgakO7]lNg`5N`0aYG^UNjEkYG^UNjEk
YG^UNjEkYInUWjFOYInUWjFNYIjUWZFNYIjUWZFNYIjUWZBNY00:WP04M9idNPYd01E@M51dD7]dNgAk
M7]dNgAkNW]jNgX00W/04YmkWg^ONjEkYG^UNjFOYInUW`jU02K9YLVUbZG@YM2Ud:G@YM2Ud:G@YM2U
d:G@YM2Ud:G@YM2Ud:_@01KG00<0emL01ML0013G0`05e`030=OG01CG02AHDEQAF55GDEMAEe5kDG]A
Ne5kDG]ANeMkEg]GNeMkEg]GNeLDN`0IWg^ONYmjWgZONYmjWgZONYmjWgZOWYnNW`0>WP0QNYijWWZN
LiicNW=dLgA?M4mdD7A@M51dD7A@M51dD7A@009d02IjM7]dNgAkM7]dNgYkNYmjWgZONYmjYGZUNjEk
YG^UWjFOYInUWaBU01O9YLVUcjG?YLnUcjG?YLnUcjG?YM2U000Fe`030=OG00GG000Be`030=OG00?G
00<0emL05=L08UMlEgaGO5MlEgaGO5MlEgaGO5MlEgaGO5MlEgakO7]lNg`?N`0YYG^UNjEkYG^UNjEk
YG^UNjEkYInUWZFNYIjUWZFNYIjUWZFNYIjUWZD03Yh0=gBNM7YdNWAjM7YdNWAjM7YdNWAkM7]dNgAk
M7]dNgAkNYmjWgZONYmkWg^UNjEkYInUWjFOYIl03:D0:<VUbJG9YLVUcjG@YM2Ud:G@YM2Ud:G@YM2U
d:G@YM2Ud:G@Zm2[d00Fe`030=OG00GG000He`030=OG01CG02QHDEQAF55GDEMAEe5GDG]ANe5kDG]A
Ne5kDG]ANeMkEg]GNeMkEg]G4G/067YkNYmjWgZONYmjWgZONYmjWgZONYmjW`ZN00ijWWZNNYijWWZN
M9idNPAd03]?M4mdD7A@M51dD7A@M51dD7YdNWAjM7]dNgAkM7]dNgYkNYmjWgZONYmjYGZUNZEkYG^U
WjFOYInUW`0BY@0IbJG9YLnUcjG?YLnUcjG?YLnUcjG?YLnU000Fe`030=OG00GG000He`805ML085Ml
EgaGO5MlEgaGO5MlEgaGO5MlEgaGO5MlEgaGO7]l4g/09imkWg^ONimkYG^UNjEkYG^UNjFNYIjUWZFN
YIjUWZFNYIjUWYnNW`0>WP0gM9idNWAjM7YdNWAjM7YdNWAjM7]dNgAkM7]dNgYkNYmjWgZONYmjWg^O
NjEkYInUWjFOYInUW`0<Y@0XbJG9YLVUcjG?YM2Ud:G@YM2Ud:G@YM2Ud:G@YM2Ud:G@Zm2[d:_@01KG
00<0emL01ML001SG00<0emL05=L0:UQAF55GDEMAEe5GDEMAEe5GDG]ANe5kDG]ANe5kDG]ANe5kDG]G
NeMkE`mk031jNgYkNYmjWgZONYmjWgZONYmjWgZNNYijWWZNNYijWWZNNYijWWZNNYidWWBNM7X>M003
D7A@00Ad02YjM7YdNWAjM7YdNgAkNYmjWgZONYmjWgZONZEjYGZUWZFNYInUWjFOYIl@Y@0KbJG9YLVU
cjG?YLnUcjG?YLnUcjG?YLnUcjD001KG00<0emL01ML001SG00<0emL05=L07eMlEgaGO5MlEgaGO5Ml
EgaGO5MlEgaGO5MlEg]GNeL05W/09ImkWg^ONimkWg^ONimkYGZUNZFNYIjUWZFNYIjOWYnNWijOWYl0
3Yh0=GBNM7YdNWAjM7YdNWAjM7YdNWAkM7]dNgAkM7]jWgZONYmjWgZONZEjYG^UNjFOYInUWjFO00bU
02[9YLVUbJG9YLnUcjG?YLnUcjG@YM2Ud:G@YM2Ud:G@YM2Ud:_@Zm2[d00Fe`030=OG00GG000He`03
0=OG01CG02aGDEMAEe5GDEMAEe5GDEMAEe5GDEMAEe5kDG]ANe5kDG]ANe5kDG]ANe5kE`Mk03QjNgYk
NW]jNgYkNW]jWgZONYmjWgZONYmjWgZNNYijWWZNNYijWWZNNYijWWBNM9idWWBNM7YdNPmd02ajM7Yd
NWAjM7YdNWAjM7]dWgZONYmjWgZONYmjWgZUNZFNYIjUWZFNYInUWa2U01g9YLVUcjG?YLnUcjG?YLnU
cjG?YLnUcjG?YLnU000Fe`030=OG00GG000He`030=OG01CG02EGF5MHEgaGO5MlEgaGO5MlEgaGO5Ml
EgaGO5MkEg]GNeMkEg]G019k02>ONimkWg^ONimkWg^ONYmjWgZONYmjWijOWYnNWijOWYnNW`0>WP0e
M9idNWAjM7YdNWAjM7YdNWAjM7YdNgAkM9mjWgZONYmjWgZONYmjWgZUWjFOYInUWjFOYIl02ZD0;<VU
bJG9YLVUbJG?YLnUcjG?YLnUcjG@YM2Ud:G@YM2Ud:G@Zm2[d:_@cm005]L00`3Ge`05e`006=L00`3G
e`0De`0^Ee5GDEMAEe5GDEMAEe5GDEMAEe5GDEMAEe5kDG]ANe5kDG]ANe5kDG]ANe5kD@Ek03UjNgYk
NW]jNgYkNW]jNgYkNYmjWgZONYmjWgZNNYijWWZNNYijWWZNNYidWWBNM9idWWBNM7YdNW<02W@047Yd
NWAjM7YdNWAjM7YdNW@2NP0NWgZONYmjWgZONYmjWgZUNZEjYIjUWZFNYIjUWZFN3ZD07lVUbJG9YLnU
cjG?YLnUcjG?YLnUcjG?YLnUcjG?Y@005]L00`3Ge`05e`006=L00`3Ge`0De`0SDEQAF55HDEQAF55H
DGaAO55lDGaANe5kDG]GNeMkEg]GNeL067/07ImkWg^ONimkWgZONYmjWgZONYmjWgZONYnNWijO00:N
04=jWWZNNYijWWZNNYijWWBNM7YdNWAjM7YdNWAjM7YdNWAjM7]dWgBONYmjWgZONYmjWgZONYmjYIjU
WZFOYInUWjFO00JU0339YLVUbJG9YLVUbJG9YLnUcjG?YLnUcjG?YLnUd:G@YM2Ud:G@YM3?d<o@cm3?
d00Fe`030=OG00GG000He`805ML0K5MAEe5GDEMAEe5GDEMAEe5GDEMAEe5GDEMAEe5GDG]ANe5kDG]A
Ne5kDG]ANe5kM7]dNgAkM7]jNgYkNW]jNgYkNW]jNgZONYmjWgZNNYijWWZNNYijWWZNM9idWWBNM9id
WWBNM9idNW=jL`Yd039jM7YdNWAjM7YdNWAjM9idWWZNNYmjWgZONYmjWgZONZEjYIjUWZFNYIjUWZFN
YIjUY0RU02?9YLVUbJG9YLVUcjG?YLnUcjG?YLnUcjG?YLnUcjG?YLnU000Fe`030=OG00GG000He`03
0=OG01CG02MAF55HDEQAF55HDEQAF55lDGaANe5kDG]ANe5kDG]ANe5kEg]GNeL05W/0H9mkWgZONYmj
WgZONYmjWgZONYmjWgZONYmjWWZNNYijWWZNNYijWWZNNYidWWAjM7YdNWAjM7YdNWBNM9idWWBNM9mj
WgZONYmjWgZONYmjYIjUWZFNYIjUWjFOYInUW`JU0339YLVUbJG9YLVUbJG?YLnUcjG?YLnUcjG?YLnU
cjG?YM39d<o@cm3?d<o@cm3?d00Fe`030=OG00GG000He`030=OG01CG071GDEMAEe5GDEMAEe5GDEMA
Ee5GDEMAEe5GDEMAEe5kDG]ANe5kDG]ANe5kDG]@Ne1kD7]@NgAkM7]dNgAkM7]dNgAkNW]jNgYkNW]j
WWZNNYidWWBNM9idWWBNM9idWWBNM9idWW>NLgYcNW=dLgAc17@0=WYdNWAjM7YdNWAjM7YdNWAjM9ij
WWZONYmjWgZONYmjWgZUNZFNYIjUWZFNYIjUWZFNYJBUY0BU02G9YLVUbJG9YLVUcjG?YLnUcjG?YLnU
cjG?YLnUcjG?YLnUcjD001KG00<0emL01ML001SG00<0emL05=L0:e5HDEQAF55HDEQAF55HDEQAEe5G
DG]ANe5kDG]ANe5kDG]ANe5kDG]ANe404G/0GgYkNYmjWgZONYmjWgZONYmjWgZONYmjWgZONYijWWZN
NYijWWZNNYijWWZNM9idNWAjM7YdNWBNM9idWWBNM9ijWWZONYmjWgZONYmjWijOWZFNYIjUWZFNYIjU
WZFO00JU03;9YLVUbJG9YLVUbJG9YLnUcjG?YLnUcjG?YLnUcjG?bLo9clW@bM3?d<o@cm3?d<o@01KG
00<0emL01ML001SG00<0emL05=L0L5L]Ee5GDEMAEe5GDEMAEe5GDEMAEe5GDEMAEe5GDEMAEe5kDG]A
Ne5kD7]@Ne1kD7]@Ne1kD7]dNgAkM7]dNgAkM7]dNgAkM7]dNgAjM9idWWBNM9idWWBNM9idWWBNM9id
WWBNLiicNW=jLgAcM7<4M00hNWAjM7YdNWAjM7YdNWBNM9ijWWZNNYijWWZONYmjWijUWZFNYIjUWZFN
YIjUWZFNYJBUY:FTYJ@2Y@0UbJG9YLVUbJG9YLnUcjG?YLnUcjG?YLnUcjG?YLnUcjG?YLnU000Fe`03
0=OG00GG000He`030=OG01CG03=AF55HDEQAF55HDEQAF55GDEMAEe5GDG]ANe5kDG]ANe5kDG]ANe5k
DG]ANe5kDG]eNgD02G/0GgYkNW]jNgZONYmjWgZONYmjWgZONYmjWgZONYijWWZNNYijWWZNNYijWWZN
M9idNWAjM7YdWWBNM9idWWBNM9ijWWZONYmjWgZONYmjWgZOWZFNYIjUWZFNYIjUWZFO00BU02C9YLVU
bJG9YLVUbJG9YLVUcjG?YLnUcjG?YLnUcjG?bLo9clT4c`0<d<o@cm3?d<o@cm005]L00`3Ge`05e`00
6=L201GG00QG;EL]EbeG;@9A0<UGDEMAEe5GDEMAEe5GDEMAEe5GDEMAEe5GDG]ANe1kD7]@Ne1kD7]@
Ne1kD7]@NgAkM7]dNgAkM7]dNgAkM7YdNWAjM7YdNWAjM7YdNWAjM7YdWWBNM9idWWBNLiicNW=jLgAc
M7=jM7YdNWAjM7YdNWBNM9idWWBNNYijWWZNNYijWWZONYmjWijUWZFNYIjUWZFNYIjUWZFNYJBUY:FT
bJC9Y<VTbJG9YLVUbJG?YLnUcjG?YLnUcjG?YLnUcjG?YLnUcjG?Y@005]L00`3Ge`05e`006=L00`3G
e`0De`33DEQAF55HDEQAF55HDEMAEe5GDEMAEe5GDEMANe5kDG]ANe5kDG]ANe5kDG]ANe5kDG]eNgEk
MG]eNgAkM7]dNgYkNW]jNgYkNYmjWgZONYmjWgZONYmjWWZNNYijWWZNNYijWWZNNYidWWAjM9idWWBN
M9idWWBNM9ijWWZNNYmjWgZONYmjWijOWZFNYIjUWZFNYIjUWZFNYIjUY<VUbJG9YLVUbJG9YLVUbJG9
YLnUcjG?YLnUcjG?YLo9clW?bLo900K?00[@cm3?d<o@cm005]L00`3Ge`05e`006=L00`3Ge`0Be`80
0mL02beA;E4]DBeA;E4]019A0;1GDEMAEe1kD7]@Ne1kD7]@Ne1kD7]@Ne1kD7]@NgAkM7]dNgAkM7]d
NWAjM7YdNWAjM7YdNWAjM7YdNWAjM7YdWWBNLiicWW=jLgYcM7=dLgYcNWAjM7YdNWBNM9idWWBNM9ij
WWZNNYijWWZNNYmjWijOWZFNYIjUWZFNYIjUWZFNYIjUY:FTYJC9Y<VTbJC9YLVUbJG?YLnUcjG?YLnU
cjG?YLnUcjG?YLnUcjG?Y@?G0P0De`030=OG00GG000He`030=OG013G0P0=e`2fEe5GDEMAEe5GDEMA
Ee5GDEMANe5kDG]ANe5kDG]ANe5kDG]ANe5kDG]eNgAkM7]dNgAkM7]dNgAkM7]dNgYkNYmjWgZOM9md
WWBNM9idWWBNM9idWWBNM9idWWBNM9idNWAjM9idWWBNM9idWWBNNYijWWZNNYijWgZOWYnNWijUWZFN
YIjUWZFNYIjUWZFTYJC9Y<VUbJG9YLVUbJG9YLVUcjG?YLnUcjG?YLnUclW?bLo9clT6c`kG0P0Be`03
0=OG00GG000He`030=OG00kG0P0Ie`YA06m@DE1AD5M@Ee1GD7]@Ne1kD7]@Ne1kD7]@Ne1kD7]@NgAk
M7]dNWAjM7YdNWAjM7YdNWAjM7YdNWAjM7YdNWAjM7YdNW=jLiicNW=jLgAcNW=jLgYdNWBNM9idWWBN
M9idWWBNNYijWWZNNYijWWX019h0:jFNYIjUWZFNYIjUWZFNYJBUY:FTYJC9Y<VTbJC9Y<VTbJC9Y<nU
cjG?YLl06]L2013G00<0emL01ML001SG00<0emL03=L202CG06=AEe5kDG]ANe5kDG]ANe5kDG]ANe5k
DG]dNgAkM7]dNgAkM7]dNgAkM7]dNgAkM7]dNgBOM9idWWBNM9idWWBNM9idWWBNM9idWWBNM9idWWBN
M9idWWBNM9idWWZNNYijWWX00Yh0<InNWijOWZFNYIjUWZFNYIjUWZFNYIk9Y<VTbJC9Y<VUbJG9YLVU
bJG9YLnUcjG?YLl09ML200kG00<0emL01ML001SG00<0emL02]L2037G06E@DE1AD7]@Ne1kD7]@Ne1k
D7]@Ne1kD7]@Ne1jM7YdNWAjM7YdNWAjM7YdNWAjM7YdNWAjM7YdNWAjLgYcNW=jLgYcM7=jLgYcNW>N
M9idWWBNM9idWWZNNYijWWZNNYijWWZNNP04WP0HYIjUWZFNYIjUWZFNYIjUWZFTbJC9Y<VT<ML200cG
00<0emL01ML001SG0P09e`80?ML0C7]@Ne1kD7]dNgAkM7]dNgAkM7]dNgAkM7]dNgAkM7YdNWAjM7Yd
WWBNM9idWWBNM9idWWBNM9idWWBNM9idWWBNM9idWWZNNYijWWX6WP0JWijOWZFNYIjUWZFNYIjUWZFN
bIk9Y<VTbJ@ne`802]L00`3Ge`05e`006=L00`3Ge`06e`80D=L0AWY@NWAjM7YdNWAjM7YdNWAjM7Yd
NWAjM7YdNW=jLgYcNW=jLgYcNW=dLgYcNW=jLiicWWBNM9idWWBNM9ijWWZNNYijWWX4WU7G0P08e`03
0=OG00GG000He`030=OG00CG0P1]e`0EWWBNM9idWWBNM9idWWBNM9idWWBN06gG0P06e`030=OG00GG
000He`030=OG00;G0P3ce`801=L00`3Ge`05e`004=L400CG00<0emL00P3ge`800]L00`3Ge`05e`00
4=L00`3Ge`05e`<0nmL300OG000Ae`030=OG00CGo`0200OG000Be`030=OG0?oG3=L001?G00<0emL0
omL;e`004=L0103Ge`3oe`gG000Ae`80omL>e`00\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.0965551, -0.0828726, \
0.00390931, 0.00781861}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Off[ContourPlot::plnr];Off[ContourGraphics::ctpnt];
CP=ContourPlot[g[x,y],{x,-3.99999,3.99999},{y,-1.99999,1.99999},\
ContourShading->False,ContourSmoothing->2,PlotPoints->40,Contours->9,\
AspectRatio->0.5,Frame->False]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.120193 0.25 0.120193 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.62537 .49038 m
.61095 .48758 L
.58629 .48412 L
.56164 .48203 L
.53698 .48107 L
.51233 .48115 L
.48767 .48115 L
.46302 .48107 L
.43836 .48203 L
.41371 .48412 L
.38905 .48758 L
.37463 .49038 L
s
.62537 .00962 m
.61095 .01242 L
.58629 .01588 L
.56164 .01797 L
.53698 .01893 L
.51233 .01885 L
.48767 .01885 L
.46302 .01893 L
.43836 .01797 L
.41371 .01588 L
.38905 .01242 L
.37463 .00962 L
s
.69049 .49038 m
.68491 .48809 L
.66026 .47987 L
.65337 .47806 L
.6356 .47428 L
.61095 .47074 L
.58629 .46874 L
.56164 .46788 L
.53698 .4679 L
.51233 .46876 L
.48767 .46876 L
.46302 .4679 L
.43836 .46788 L
.41371 .46874 L
.38905 .47074 L
.3644 .47428 L
.34663 .47806 L
.33974 .47987 L
.31509 .48809 L
.30951 .49038 L
s
.69049 .00962 m
.68491 .01191 L
.66026 .02013 L
.65337 .02194 L
.6356 .02572 L
.61095 .02926 L
.58629 .03126 L
.56164 .03212 L
.53698 .0321 L
.51233 .03124 L
.48767 .03124 L
.46302 .0321 L
.43836 .03212 L
.41371 .03126 L
.38905 .02926 L
.3644 .02572 L
.34663 .02194 L
.33974 .02013 L
.31509 .01191 L
.30951 .00962 L
s
.74007 .49038 m
.73422 .48664 L
.71892 .47806 L
.70957 .47364 L
.68872 .46573 L
.68491 .46456 L
.66026 .45861 L
.6356 .45511 L
.61095 .45343 L
.61032 .4534 L
.58629 .45302 L
.56355 .4534 L
.56164 .45346 L
.53698 .45449 L
.51233 .45608 L
.48767 .45608 L
.46302 .45449 L
.43836 .45346 L
.43645 .4534 L
.41371 .45302 L
.38968 .4534 L
.38905 .45343 L
.3644 .45511 L
.33974 .45861 L
.31509 .46456 L
.31128 .46573 L
.29043 .47364 L
.28108 .47806 L
.26578 .48664 L
.25993 .49038 L
s
.74007 .00962 m
.73422 .01336 L
.71892 .02194 L
.70957 .02636 L
.68872 .03427 L
.68491 .03544 L
.66026 .04139 L
.6356 .04489 L
.61095 .04657 L
.61032 .0466 L
.58629 .04698 L
.56355 .0466 L
.56164 .04654 L
.53698 .04551 L
.51233 .04392 L
.48767 .04392 L
.46302 .04551 L
.43836 .04654 L
.43645 .0466 L
.41371 .04698 L
.38968 .0466 L
.38905 .04657 L
.3644 .04489 L
.33974 .04139 L
.31509 .03544 L
.31128 .03427 L
.29043 .02636 L
.28108 .02194 L
.26578 .01336 L
.25993 .00962 L
s
.78256 .49038 m
.76851 .47806 L
.75888 .47081 L
.75134 .46573 L
.73422 .45603 L
.72875 .4534 L
.70957 .44592 L
.69227 .44107 L
.68491 .43959 L
.66026 .43624 L
.6356 .43513 L
.61095 .43557 L
.58629 .43695 L
.56164 .4388 L
.53698 .44086 L
.53495 .44107 L
.51233 .44314 L
.48767 .44314 L
.46505 .44107 L
.46302 .44086 L
.43836 .4388 L
.41371 .43695 L
.38905 .43557 L
.3644 .43513 L
.33974 .43624 L
.31509 .43959 L
.30773 .44107 L
.29043 .44592 L
.27125 .4534 L
.26578 .45603 L
.24866 .46573 L
.24112 .47081 L
.23149 .47806 L
.21744 .49038 L
s
.78256 .00962 m
.76851 .02194 L
.75888 .02919 L
.75134 .03427 L
.73422 .04397 L
.72875 .0466 L
.70957 .05408 L
.69227 .05893 L
.68491 .06041 L
.66026 .06376 L
.6356 .06487 L
.61095 .06443 L
.58629 .06305 L
.56164 .0612 L
.53698 .05914 L
.53495 .05893 L
.51233 .05686 L
.48767 .05686 L
.46505 .05893 L
.46302 .05914 L
.43836 .0612 L
.41371 .06305 L
.38905 .06443 L
.3644 .06487 L
.33974 .06376 L
.31509 .06041 L
.30773 .05893 L
.29043 .05408 L
.27125 .0466 L
.26578 .04397 L
.24866 .03427 L
.24112 .02919 L
.23149 .02194 L
.21744 .00962 L
s
.82101 .49038 m
.81115 .47806 L
.80819 .47464 L
.7999 .46573 L
.78672 .4534 L
.78353 .45074 L
.77068 .44107 L
.75888 .43372 L
.74953 .42875 L
.73422 .42233 L
.7141 .41642 L
.70957 .41557 L
.68491 .41253 L
.66026 .41233 L
.6356 .41411 L
.61393 .41642 L
.61095 .41707 L
.58629 .42053 L
.56164 .42397 L
.53698 .4271 L
.52458 .42875 L
.51233 .42998 L
.48767 .42998 L
.47542 .42875 L
.46302 .4271 L
.43836 .42397 L
.41371 .42053 L
.38905 .41707 L
.38607 .41642 L
.3644 .41411 L
.33974 .41233 L
.31509 .41253 L
.29043 .41557 L
.2859 .41642 L
.26578 .42233 L
.25047 .42875 L
.24112 .43372 L
.22932 .44107 L
.21647 .45074 L
.21328 .4534 L
.2001 .46573 L
.19181 .47464 L
.18885 .47806 L
.17899 .49038 L
s
.82101 .00962 m
.81115 .02194 L
.80819 .02536 L
.7999 .03427 L
.78672 .0466 L
.78353 .04926 L
.77068 .05893 L
.75888 .06628 L
.74953 .07125 L
.73422 .07767 L
.7141 .08358 L
.70957 .08443 L
.68491 .08747 L
.66026 .08767 L
.6356 .08589 L
.61393 .08358 L
.61095 .08293 L
.58629 .07947 L
.56164 .07603 L
.53698 .0729 L
.52458 .07125 L
.51233 .07002 L
.48767 .07002 L
.47542 .07125 L
.46302 .0729 L
.43836 .07603 L
.41371 .07947 L
.38905 .08293 L
.38607 .08358 L
.3644 .08589 L
.33974 .08767 L
.31509 .08747 L
.29043 .08443 L
.2859 .08358 L
.26578 .07767 L
.25047 .07125 L
.24112 .06628 L
.22932 .05893 L
.21647 .04926 L
.21328 .0466 L
.2001 .03427 L
.19181 .02536 L
.18885 .02194 L
.17899 .00962 L
s
.85688 .49038 m
.84994 .47806 L
.84227 .46573 L
.83375 .4534 L
.83284 .45217 L
.82417 .44107 L
.8132 .42875 L
.80819 .4237 L
.80032 .41642 L
.78433 .40409 L
.78353 .40356 L
.76229 .39177 L
.75888 .39036 L
.73422 .38309 L
.70957 .38071 L
.68491 .38209 L
.66026 .38609 L
.6356 .39162 L
.63496 .39177 L
.61095 .39776 L
.58629 .40375 L
.58479 .40409 L
.56164 .40903 L
.53698 .41331 L
.51547 .41642 L
.51233 .41672 L
.48767 .41672 L
.48453 .41642 L
.46302 .41331 L
.43836 .40903 L
.41521 .40409 L
.41371 .40375 L
.38905 .39776 L
.36504 .39177 L
.3644 .39162 L
.33974 .38609 L
.31509 .38209 L
.29043 .38071 L
.26578 .38309 L
.24112 .39036 L
.23771 .39177 L
.21647 .40356 L
.21567 .40409 L
.19968 .41642 L
.19181 .4237 L
.1868 .42875 L
.17583 .44107 L
.16716 .45217 L
.16625 .4534 L
.15773 .46573 L
Mistroke
.15006 .47806 L
.14312 .49038 L
Mfstroke
.85688 .00962 m
.84994 .02194 L
.84227 .03427 L
.83375 .0466 L
.83284 .04783 L
.82417 .05893 L
.8132 .07125 L
.80819 .0763 L
.80032 .08358 L
.78433 .09591 L
.78353 .09644 L
.76229 .10823 L
.75888 .10964 L
.73422 .11691 L
.70957 .11929 L
.68491 .11791 L
.66026 .11391 L
.6356 .10838 L
.63496 .10823 L
.61095 .10224 L
.58629 .09625 L
.58479 .09591 L
.56164 .09097 L
.53698 .08669 L
.51547 .08358 L
.51233 .08328 L
.48767 .08328 L
.48453 .08358 L
.46302 .08669 L
.43836 .09097 L
.41521 .09591 L
.41371 .09625 L
.38905 .10224 L
.36504 .10823 L
.3644 .10838 L
.33974 .11391 L
.31509 .11791 L
.29043 .11929 L
.26578 .11691 L
.24112 .10964 L
.23771 .10823 L
.21647 .09644 L
.21567 .09591 L
.19968 .08358 L
.19181 .0763 L
.1868 .07125 L
.17583 .05893 L
.16716 .04783 L
.16625 .0466 L
.15773 .03427 L
Mistroke
.15006 .02194 L
.14312 .00962 L
Mfstroke
.89106 .49038 m
.88633 .47806 L
.88215 .46788 L
.88123 .46573 L
.87572 .4534 L
.86973 .44107 L
.86322 .42875 L
.8575 .41874 L
.85611 .41642 L
.84832 .40409 L
.83969 .39177 L
.83284 .3829 L
.83003 .37944 L
.81904 .36711 L
.80819 .35683 L
.80594 .35478 L
.78911 .34246 L
.78353 .33955 L
.75888 .33094 L
.73422 .33035 L
.70957 .33582 L
.68775 .34246 L
.68491 .34489 L
.66182 .35478 L
.66026 .35565 L
.6356 .36676 L
.63479 .36711 L
.61095 .3773 L
.60551 .37944 L
.58629 .38656 L
.56993 .39177 L
.56164 .39408 L
.53698 .39968 L
.51233 .40352 L
.48767 .40352 L
.46302 .39968 L
.43836 .39408 L
.43007 .39177 L
.41371 .38656 L
.39449 .37944 L
.38905 .3773 L
.36521 .36711 L
.3644 .36676 L
.33974 .35565 L
.33818 .35478 L
.31509 .34489 L
.31225 .34246 L
.29043 .33582 L
.26578 .33035 L
.24112 .33094 L
Mistroke
.21647 .33955 L
.21089 .34246 L
.19406 .35478 L
.19181 .35683 L
.18096 .36711 L
.16997 .37944 L
.16716 .3829 L
.16031 .39177 L
.15168 .40409 L
.14389 .41642 L
.1425 .41874 L
.13678 .42875 L
.13027 .44107 L
.12428 .4534 L
.11877 .46573 L
.11785 .46788 L
.11367 .47806 L
.10894 .49038 L
Mfstroke
.89106 .00962 m
.88633 .02194 L
.88215 .03212 L
.88123 .03427 L
.87572 .0466 L
.86973 .05893 L
.86322 .07125 L
.8575 .08126 L
.85611 .08358 L
.84832 .09591 L
.83969 .10823 L
.83284 .1171 L
.83003 .12056 L
.81904 .13289 L
.80819 .14317 L
.80594 .14522 L
.78911 .15754 L
.78353 .16045 L
.75888 .16906 L
.73422 .16965 L
.70957 .16418 L
.68775 .15754 L
.68491 .15511 L
.66182 .14522 L
.66026 .14435 L
.6356 .13324 L
.63479 .13289 L
.61095 .1227 L
.60551 .12056 L
.58629 .11344 L
.56993 .10823 L
.56164 .10592 L
.53698 .10032 L
.51233 .09648 L
.48767 .09648 L
.46302 .10032 L
.43836 .10592 L
.43007 .10823 L
.41371 .11344 L
.39449 .12056 L
.38905 .1227 L
.36521 .13289 L
.3644 .13324 L
.33974 .14435 L
.33818 .14522 L
.31509 .15511 L
.31225 .15754 L
.29043 .16418 L
.26578 .16965 L
.24112 .16906 L
Mistroke
.21647 .16045 L
.21089 .15754 L
.19406 .14522 L
.19181 .14317 L
.18096 .13289 L
.16997 .12056 L
.16716 .1171 L
.16031 .10823 L
.15168 .09591 L
.14389 .08358 L
.1425 .08126 L
.13678 .07125 L
.13027 .05893 L
.12428 .0466 L
.11877 .03427 L
.11785 .03212 L
.11367 .02194 L
.10894 .00962 L
Mfstroke
.46302 .11362 m
.48767 .10823 L
.51233 .10823 L
.53698 .11362 L
.56106 .12056 L
.56164 .12078 L
.58629 .13123 L
.58955 .13289 L
.61095 .14518 L
.611 .14522 L
.62859 .15754 L
.6356 .16289 L
.6437 .16987 L
.65705 .1822 L
.66026 .18538 L
.66809 .19453 L
.67755 .20685 L
.68491 .21881 L
.68507 .21918 L
.6896 .23151 L
.69205 .24384 L
.69205 .25616 L
.6896 .26849 L
.68507 .28082 L
.68491 .28119 L
.67755 .29315 L
.66809 .30547 L
.66026 .31462 L
.65705 .3178 L
.6437 .33013 L
.6356 .33711 L
.62859 .34246 L
.611 .35478 L
.61095 .35482 L
.58955 .36711 L
.58629 .36877 L
.56164 .37922 L
.56106 .37944 L
.53698 .38638 L
.51233 .39177 L
.48767 .39177 L
.46302 .38638 L
.43894 .37944 L
.43836 .37922 L
.41371 .36877 L
.41045 .36711 L
.38905 .35482 L
.389 .35478 L
.37141 .34246 L
.3644 .33711 L
Mistroke
.3563 .33013 L
.34295 .3178 L
.33974 .31462 L
.33191 .30547 L
.32245 .29315 L
.31509 .28119 L
.31493 .28082 L
.3104 .26849 L
.30795 .25616 L
.30795 .24384 L
.3104 .23151 L
.31493 .21918 L
.31509 .21881 L
.32245 .20685 L
.33191 .19453 L
.33974 .18538 L
.34295 .1822 L
.3563 .16987 L
.3644 .16289 L
.37141 .15754 L
.389 .14522 L
.38905 .14518 L
.41045 .13289 L
.41371 .13123 L
.43836 .12078 L
.43894 .12056 L
.46302 .11362 L
Mfstroke
.9241 .49038 m
.92123 .47806 L
.91817 .46573 L
.91491 .4534 L
.91144 .44107 L
.90776 .42875 L
.9068 .42567 L
.90386 .41642 L
.89974 .40409 L
.89542 .39177 L
.89091 .37944 L
.88622 .36711 L
.88215 .35666 L
.88141 .35478 L
.87656 .34246 L
.87174 .33013 L
.86704 .3178 L
.86261 .30547 L
.85865 .29315 L
.8575 .28929 L
.85544 .28082 L
.85317 .26849 L
.85197 .25616 L
.85197 .24384 L
.85317 .23151 L
.85544 .21918 L
.8575 .21071 L
.85865 .20685 L
.86261 .19453 L
.86704 .1822 L
.87174 .16987 L
.87656 .15754 L
.88141 .14522 L
.88215 .14334 L
.88622 .13289 L
.89091 .12056 L
.89542 .10823 L
.89974 .09591 L
.90386 .08358 L
.9068 .07433 L
.90776 .07125 L
.91144 .05893 L
.91491 .0466 L
.91817 .03427 L
.92123 .02194 L
.9241 .00962 L
s
.0759 .49038 m
.07877 .47806 L
.08183 .46573 L
.08509 .4534 L
.08856 .44107 L
.09224 .42875 L
.0932 .42567 L
.09614 .41642 L
.10026 .40409 L
.10458 .39177 L
.10909 .37944 L
.11378 .36711 L
.11785 .35666 L
.11859 .35478 L
.12344 .34246 L
.12826 .33013 L
.13296 .3178 L
.13739 .30547 L
.14135 .29315 L
.1425 .28929 L
.14456 .28082 L
.14683 .26849 L
.14803 .25616 L
.14803 .24384 L
.14683 .23151 L
.14456 .21918 L
.1425 .21071 L
.14135 .20685 L
.13739 .19453 L
.13296 .1822 L
.12826 .16987 L
.12344 .15754 L
.11859 .14522 L
.11785 .14334 L
.11378 .13289 L
.10909 .12056 L
.10458 .10823 L
.10026 .09591 L
.09614 .08358 L
.0932 .07433 L
.09224 .07125 L
.08856 .05893 L
.08509 .0466 L
.08183 .03427 L
.07877 .02194 L
.0759 .00962 L
s
.95644 .49038 m
.95611 .48702 L
.95522 .47806 L
.95394 .46573 L
.95259 .4534 L
.95118 .44107 L
.94969 .42875 L
.94814 .41642 L
.94652 .40409 L
.94486 .39177 L
.94317 .37944 L
.94146 .36711 L
.93975 .35478 L
.93808 .34246 L
.93649 .33013 L
.93501 .3178 L
.93368 .30547 L
.93256 .29315 L
.93167 .28082 L
.93146 .27788 L
.93105 .26849 L
.93074 .25616 L
.93074 .24384 L
.93105 .23151 L
.93146 .22212 L
.93167 .21918 L
.93256 .20685 L
.93368 .19453 L
.93501 .1822 L
.93649 .16987 L
.93808 .15754 L
.93975 .14522 L
.94146 .13289 L
.94317 .12056 L
.94486 .10823 L
.94652 .09591 L
.94814 .08358 L
.94969 .07125 L
.95118 .05893 L
.95259 .0466 L
.95394 .03427 L
.95522 .02194 L
.95611 .01298 L
.95644 .00962 L
s
.04356 .49038 m
.04389 .48702 L
.04478 .47806 L
.04606 .46573 L
.04741 .4534 L
.04882 .44107 L
.05031 .42875 L
.05186 .41642 L
.05348 .40409 L
.05514 .39177 L
.05683 .37944 L
.05854 .36711 L
.06025 .35478 L
.06192 .34246 L
.06351 .33013 L
.06499 .3178 L
.06632 .30547 L
.06744 .29315 L
.06833 .28082 L
.06854 .27788 L
.06895 .26849 L
.06926 .25616 L
.06926 .24384 L
.06895 .23151 L
.06854 .22212 L
.06833 .21918 L
.06744 .20685 L
.06632 .19453 L
.06499 .1822 L
.06351 .16987 L
.06192 .15754 L
.06025 .14522 L
.05854 .13289 L
.05683 .12056 L
.05514 .10823 L
.05348 .09591 L
.05186 .08358 L
.05031 .07125 L
.04882 .05893 L
.04741 .0466 L
.04606 .03427 L
.04478 .02194 L
.04389 .01298 L
.04356 .00962 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->18,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T0P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?oooooG8ML00?oG8ML00?oG8ML000cG00<0emL0
1mL00`3Ge`06e`030=OG00OG00<0emL01mL00`3Ge`08e`030=OG00WG00<0emL03=L00`3Ge`0?e`80
AML2017G00<0emL03=L00`3Ge`09e`030=OG00SG00<0emL01mL00`3Ge`07e`030=OG00KG00<0emL0
1mL00`3Ge`0;e`003ML00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`08e`030=OG00SG00<0emL0
2ML200gG0P0Ae`H0>ML6017G0P0=e`802mL00`3Ge`08e`030=OG00OG00<0emL01mL00`3Ge`07e`03
0=OG00KG00<0emL03=L000gG00<0emL01]L00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`09e`03
0=OG00[G00<0emL03=L401?G1`0[e`L04mL400kG00<0emL02]L00`3Ge`08e`030=OG00SG00<0emL0
1mL00`3Ge`06e`030=OG00OG00<0emL03=L000gG00<0emL01mL00`3Ge`06e`030=OG00OG00<0emL0
2=L00`3Ge`09e`030=OG00[G0P0@e`806=L[01SG0P0@e`803=L00`3Ge`09e`030=OG00OG00<0emL0
1mL00`3Ge`07e`030=OG00OG00<0emL03=L000gG00<0emL01mL00`3Ge`07e`030=OG00OG00<0emL0
2=L00`3Ge`09e`030=OG00_G0P0@e`@0DmL4013G0P0=e`030=OG00WG00<0emL02=L00`3Ge`07e`03
0=OG00OG00<0emL01mL00`3Ge`0<e`003ML00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`08e`03
0=OG00WG0P0=e`<04ML604OG1P0Ae`<03ML200_G00<0emL02=L00`3Ge`08e`030=OG00OG00<0emL0
1mL00`3Ge`0<e`003ML00`3Ge`07e`030=OG00SG00<0emL01mL00`3Ge`09e`030=OG00[G00<0emL0
3ML301CG3P0>e`l03]L>01CG0`0?e`030=OG00[G00<0emL02ML00`3Ge`07e`030=OG00SG00<0emL0
1mL00`3Ge`0<e`003ML00`3Ge`07e`030=OG00SG00<0emL02=L00`3Ge`09e`030=OG00[G0P0@e`80
8=L>00oG3P0Pe`804=L200cG00<0emL02ML00`3Ge`08e`030=OG00SG00<0emL01mL00`3Ge`0<e`00
3ML00`3Ge`07e`030=OG00SG00<0emL02ML00`3Ge`09e`030=OG00_G0P0@e`@0HmL4013G0P0=e`03
0=OG00WG00<0emL02=L00`3Ge`09e`030=OG00OG00<0emL03=L000gG00<0emL01mL00`3Ge`09e`03
0=OG00SG00<0emL02]L00`3Ge`0<e`804]L705GG1`0Be`803]L00`3Ge`09e`030=OG00WG00<0emL0
2=L00`3Ge`07e`030=OG00gG000>e`030=OG00OG00<0emL02=L00`3Ge`09e`030=OG00[G00<0emL0
3ML00`3Ge`0Fe`L07=L?01cG1`0He`030=OG00gG00<0emL02]L00`3Ge`08e`030=OG00WG00<0emL0
1mL00`3Ge`0=e`003]L00`3Ge`07e`030=OG00WG00<0emL02ML00`3Ge`0:e`030=OG00gG0`0Lea`0
3mLL01cG0`0?e`030=OG00[G00<0emL02ML00`3Ge`09e`030=OG00OG00<0emL03ML000kG00<0emL0
1mL00`3Ge`09e`030=OG00[G00<0emL02]L00`3Ge`0?e`80NmL2017G00<0emL02]L00`3Ge`0:e`03
0=OG00WG00<0emL01mL00`3Ge`0=e`003]L00`3Ge`08e`030=OG00WG00<0emL02ML00`3Ge`0;e`80
4ML407?G100Ae`803ML00`3Ge`09e`030=OG00WG00<0emL02=L00`3Ge`0=e`003]L00`3Ge`08e`03
0=OG00WG00<0emL02]L00`3Ge`0<e`804mL302SG7@0Xe`<04mL200kG00<0emL02]L00`3Ge`09e`03
0=OG00SG00<0emL03ML000kG00<0emL02=L00`3Ge`09e`030=OG00_G00<0emL03ML201CG1@0Le`L0
7ML701cG1@0De`803mL00`3Ge`0:e`030=OG00[G00<0emL02=L00`3Ge`0=e`003]L00`3Ge`08e`03
0=OG00[G00<0emL02]L00`3Ge`0?e`030=OG01KG700[ea`06=L00`3Ge`0>e`030=OG00_G00<0emL0
2ML00`3Ge`09e`030=OG00gG000>e`030=OG00WG00<0emL02ML00`3Ge`0;e`030=OG00oG0P2?e`80
4ML00`3Ge`0:e`030=OG00[G00<0emL02ML00`3Ge`0=e`003]L00`3Ge`09e`030=OG00[G00<0emL0
2mL00`3Ge`0@e`030=OG03KG7@0he`030=OG013G00<0emL02mL00`3Ge`0:e`030=OG00WG00<0emL0
3ML000kG00<0emL02]L00`3Ge`0:e`030=OG00_G0P0Ae`80;mL701gG1`0_e`804ML200gG00<0emL0
2]L00`3Ge`0:e`030=OG00gG000?e`030=OG00WG00<0emL02]L00`3Ge`0=e`030=OG013G100Te`L0
:mL702CG100Be`030=OG00gG00<0emL02]L00`3Ge`09e`030=OG00kG000?e`030=OG00WG00<0emL0
2mL00`3Ge`0=e`030=OG01?G100Ie`L05ML?01GG1`0Ie`@05ML00`3Ge`0=e`030=OG00_G00<0emL0
2ML00`3Ge`0>e`003mL00`3Ge`09e`030=OG00_G00<0emL03]L00`3Ge`0Fe`@03]L701OG1@0?e`D0
5mL700kG100He`030=OG00gG00<0emL02mL00`3Ge`0:e`030=OG00kG000?e`030=OG00[G00<0emL0
2mL00`3Ge`0>e`806]L>01[G100Ie`@06]L>01[G0P0@e`030=OG00_G00<0emL02]L00`3Ge`0>e`00
3mL00`3Ge`0:e`030=OG00_G00<0emL04=L00`3Ge`0ke`@08ML403gG00<0emL03mL00`3Ge`0;e`03
0=OG00_G00<0emL03]L000oG00<0emL02mL00`3Ge`0;e`030=OG013G00<0emL0==L600gG3`0=e`H0
=]L00`3Ge`0@e`030=OG00_G00<0emL02mL00`3Ge`0>e`003mL00`3Ge`0;e`030=OG00cG00<0emL0
4=L2033G100>e`D03mL500kG100`e`804]L00`3Ge`0<e`030=OG00_G00<0emL03]L0013G00<0emL0
2mL00`3Ge`0<e`030=OG017G0P0Ye`D03]L401WG100>e`D0:ML201?G00<0emL03=L00`3Ge`0;e`03
0=OG00oG000@e`030=OG00_G00<0emL03ML00`3Ge`0Be`808]L500kG1@0;e`/02mL500kG1@0Re`80
5=L00`3Ge`0=e`030=OG00_G00<0emL03mL0013G00<0emL02mL00`3Ge`0>e`030=OG01?G0P0Le`@0
4ML200cG100;e`@03=L2017G100Le`805ML00`3Ge`0>e`030=OG00_G00<0emL03mL0013G00<0emL0
2mL00`3Ge`0>e`030=OG01GG100Ce`D04]L300_G0`0Ce`<02mL301;G1@0Ce`@05mL00`3Ge`0=e`03
0=OG00cG00<0emL03mL0013G00<0emL03=L00`3Ge`0>e`030=OG01SG1@07e`L05ML200_G0`0Ie`<0
2mL201GG1`07e`D06]L00`3Ge`0>e`030=OG00cG00<0emL03mL0013G00<0emL03=L00`3Ge`0?e`03
0=OG01cG1`0Je`802ML401oG1009e`806]L701kG00<0emL03mL00`3Ge`0<e`030=OG00oG000@e`03
0=OG00cG00<0emL04=L00`3Ge`0ie`<02ML202OG0P09e`<0>mL00`3Ge`0?e`030=OG00gG00<0emL0
3mL0013G00<0emL03ML00`3Ge`0?e`030=OG03OG0P0:e`80:mL200[G0P0he`030=OG013G00<0emL0
3=L00`3Ge`0@e`004ML00`3Ge`0<e`030=OG013G00<0emL0==L200[G0P0_e`802]L203KG00<0emL0
3mL00`3Ge`0=e`030=OG013G000Ae`030=OG00gG00<0emL04=L00`3Ge`0`e`<02mL00`3Ge`0ae`03
0=OG00WG0`0be`030=OG013G00<0emL03ML00`3Ge`0@e`004ML00`3Ge`0=e`030=OG017G0P0^e`80
3=L203GG0P0<e`80;]L201;G00<0emL03]L00`3Ge`0@e`004ML00`3Ge`0>e`030=OG01;G00<0emL0
:ML200cG0P0ie`803=L202_G00<0emL04]L00`3Ge`0>e`030=OG013G000Ae`030=OG00kG00<0emL0
4mL00`3Ge`0Ue`<03=L203gG0P0<e`<09mL00`3Ge`0Ce`030=OG00kG00<0emL04=L0017G00<0emL0
3]L00`3Ge`0De`030=OG02;G0P0>e`030=OG03oG00<0emL03=L202CG00<0emL05=L00`3Ge`0>e`03
0=OG013G000Ae`030=OG00kG00<0emL05ML00`3Ge`0Oe`803]L204?G0P0>e`808ML00`3Ge`0De`03
0=OG00kG00<0emL04ML001;G00<0emL03]L00`3Ge`0Ee`030=OG01cG0P0?e`030=OG04GG00<0emL0
3ML201kG00<0emL05ML00`3Ge`0>e`030=OG017G000Be`030=OG00kG00<0emL05]L401OG0`0@e`03
0=OG04OG00<0emL03]L301OG100He`030=OG00kG00<0emL04ML001;G00<0emL03mL00`3Ge`0Ie`80
4=L5017G0P1;e`804ML5013G0P0Ke`030=OG00oG00<0emL04ML001;G00<0emL03mL00`3Ge`0Ke`80
2]L401GG00<0emL0CML00`3Ge`0Ce`@02]L201gG00<0emL03mL00`3Ge`0Ae`004]L00`3Ge`0@e`03
0=OG01cG2P0He`030=OG04oG00<0emL05]L:01kG00<0emL04=L00`3Ge`0Ae`004]L00`3Ge`0@e`03
0=OG03gG00<0emL0DML00`3Ge`0me`030=OG013G00<0emL04ML001;G00<0emL04=L00`3Ge`0le`03
0=OG05?G00<0emL0>mL00`3Ge`0@e`030=OG01;G000Ce`030=OG013G00<0emL0>]L00`3Ge`1Ee`03
0=OG03[G00<0emL04=L00`3Ge`0Be`004mL00`3Ge`0@e`030=OG03WG00<0emL0EmL00`3Ge`0ie`03
0=OG013G00<0emL04]L001?G00<0emL04=L00`3Ge`0he`030=OG05WG00<0emL0>=L00`3Ge`0@e`03
0=OG01;G000Ce`030=OG017G00<0emL0=]L00`3Ge`1Ke`030=OG03KG00<0emL04ML00`3Ge`0Be`00
4mL00`3Ge`0Ae`030=OG03GG00<0emL0GML00`3Ge`0ee`030=OG017G00<0emL04]L001?G00<0emL0
4ML00`3Ge`0de`030=OG05oG00<0emL0==L00`3Ge`0Ae`030=OG01;G000Ce`030=OG017G00<0emL0
<mL00`3Ge`1Pe`030=OG03?G00<0emL04]L00`3Ge`0Be`004mL00`3Ge`0Be`030=OG03;G00<0emL0
HML00`3Ge`0be`030=OG01;G00<0emL04]L001?G00<0emL04]L00`3Ge`0ae`030=OG06?G00<0emL0
<ML00`3Ge`0Be`030=OG01;G000Ce`030=OG01?G00<0emL0;mL00`3Ge`1Ue`030=OG02oG00<0emL0
4mL00`3Ge`0Be`005=L00`3Ge`0Be`030=OG02oG00<0emL0IML00`3Ge`0_e`030=OG01;G00<0emL0
4mL001CG00<0emL04]L00`3Ge`0^e`030=OG06OG00<0emL0;]L00`3Ge`0Be`030=OG01?G000De`03
0=OG01;G00<0emL0;]L00`3Ge`1We`030=OG02kG00<0emL04]L00`3Ge`0Ce`005=L00`3Ge`0Be`03
0=OG02gG00<0emL0J=L00`3Ge`0]e`030=OG01?G00<0emL04mL001CG00<0emL04mL00`3Ge`0/e`03
0=OG06WG00<0emL0;=L00`3Ge`0Ce`030=OG01?G000De`030=OG01?G00<0emL0;=L00`3Ge`1Ye`03
0=OG02cG00<0emL04mL00`3Ge`0Ce`005=L00`3Ge`0Ce`030=OG02cG00<0emL0JML00`3Ge`0/e`03
0=OG01?G00<0emL04mL001CG00<0emL04mL00`3Ge`0[e`030=OG06_G00<0emL0:mL00`3Ge`0Ce`03
0=OG01?G000De`030=OG01?G00<0emL0:mL00`3Ge`1[e`030=OG02_G00<0emL04mL00`3Ge`0Ce`00
5=L00`3Ge`0Ce`030=OG02_G00<0emL0JmL00`3Ge`0[e`030=OG01?G00<0emL04mL001CG00<0emL0
4mL00`3Ge`0[e`030=OG06_G00<0emL0:mL00`3Ge`0Ce`030=OG01?G000De`030=OG01?G00<0emL0
:mL00`3Ge`1[e`030=OG02_G00<0emL04mL00`3Ge`0Ce`005=L00`3Ge`0Ce`030=OG02_G00<0emL0
JmL00`3Ge`0[e`030=OG01?G00<0emL04mL001CG00<0emL04mL00`3Ge`0[e`030=OG06_G00<0emL0
:mL00`3Ge`0Ce`030=OG01?G000De`030=OG01?G00<0emL0;=L00`3Ge`1Ye`030=OG02cG00<0emL0
4mL00`3Ge`0Ce`005=L00`3Ge`0Ce`030=OG02cG00<0emL0JML00`3Ge`0/e`030=OG01?G00<0emL0
4mL001CG00<0emL04mL00`3Ge`0/e`030=OG06WG00<0emL0;=L00`3Ge`0Ce`030=OG01?G000De`03
0=OG01;G00<0emL0;ML00`3Ge`1Xe`030=OG02gG00<0emL04mL00`3Ge`0Ce`005=L00`3Ge`0Be`03
0=OG02kG00<0emL0ImL00`3Ge`0^e`030=OG01;G00<0emL04mL001CG00<0emL04]L00`3Ge`0^e`03
0=OG06OG00<0emL0;]L00`3Ge`0Be`030=OG01?G000De`030=OG01;G00<0emL0;mL00`3Ge`1Ue`03
0=OG02oG00<0emL04]L00`3Ge`0Ce`004mL00`3Ge`0Ce`030=OG02oG00<0emL0IML00`3Ge`0_e`03
0=OG01?G00<0emL04]L001?G00<0emL04]L00`3Ge`0ae`030=OG06?G00<0emL0<ML00`3Ge`0Be`03
0=OG01;G000Ce`030=OG01;G00<0emL0<]L00`3Ge`1Qe`030=OG03;G00<0emL04]L00`3Ge`0Be`00
4mL00`3Ge`0Ae`030=OG03?G00<0emL0H=L00`3Ge`0ce`030=OG01;G00<0emL04]L001?G00<0emL0
4ML00`3Ge`0de`030=OG05oG00<0emL0==L00`3Ge`0Ae`030=OG01;G000Ce`030=OG017G00<0emL0
=ML00`3Ge`1Me`030=OG03GG00<0emL04ML00`3Ge`0Be`004mL00`3Ge`0Ae`030=OG03KG00<0emL0
FmL00`3Ge`0fe`030=OG017G00<0emL04]L001?G00<0emL04=L00`3Ge`0he`030=OG05WG00<0emL0
>=L00`3Ge`0@e`030=OG01;G000Ce`030=OG013G00<0emL0>ML00`3Ge`1Ge`030=OG03WG00<0emL0
4=L00`3Ge`0Be`004mL00`3Ge`0@e`030=OG03[G00<0emL0EML00`3Ge`0je`030=OG013G00<0emL0
4]L001;G00<0emL04=L00`3Ge`0le`030=OG05?G00<0emL0>mL00`3Ge`0@e`030=OG01;G000Be`03
0=OG013G00<0emL0?ML00`3Ge`1Ae`030=OG03gG00<0emL04=L00`3Ge`0Ae`004]L00`3Ge`0@e`03
0=OG01cG2P0He`030=OG04oG00<0emL05]L:01kG00<0emL04=L00`3Ge`0Ae`004]L00`3Ge`0?e`03
0=OG01_G0P0:e`@05ML00`3Ge`1=e`030=OG01?G100:e`807ML00`3Ge`0?e`030=OG017G000Be`03
0=OG00oG00<0emL06ML2013G100Be`030=OG04_G00<0emL04=L4013G0P0Ke`030=OG00oG00<0emL0
4ML001;G00<0emL03]L00`3Ge`0Fe`@05]L400oG0P19e`803mL401KG100He`030=OG00kG00<0emL0
4ML001;G00<0emL03]L00`3Ge`0Ee`030=OG01cG0P0?e`030=OG04GG00<0emL03ML201kG00<0emL0
5ML00`3Ge`0>e`030=OG017G000Ae`030=OG00kG00<0emL05ML00`3Ge`0Oe`803]L204?G0P0>e`80
8ML00`3Ge`0De`030=OG00kG00<0emL04ML0017G00<0emL03]L00`3Ge`0De`030=OG02;G0P0>e`03
0=OG03oG00<0emL03=L202CG00<0emL05=L00`3Ge`0>e`030=OG013G000Ae`030=OG00kG00<0emL0
4mL00`3Ge`0Ue`<03=L203kG00<0emL02]L302OG00<0emL04mL00`3Ge`0>e`030=OG013G000Ae`03
0=OG00kG00<0emL04]L00`3Ge`0Ye`802mL203_G0P0;e`80:mL00`3Ge`0Be`030=OG00kG00<0emL0
4=L0017G00<0emL03ML00`3Ge`0Ae`80;]L200_G0P0ge`802mL202kG0P0Be`030=OG00kG00<0emL0
4=L0017G00<0emL03ML00`3Ge`0@e`030=OG033G0`0:e`80<mL200[G0`0be`030=OG013G00<0emL0
3ML00`3Ge`0@e`004ML00`3Ge`0<e`030=OG013G00<0emL0==L200[G0P0_e`802]L203KG00<0emL0
3mL00`3Ge`0=e`030=OG013G000@e`030=OG00gG00<0emL03mL00`3Ge`0ge`802]L202_G0P0:e`80
>=L00`3Ge`0@e`030=OG00cG00<0emL04=L0013G00<0emL03=L00`3Ge`0@e`030=OG03WG0P0:e`80
9mL200[G0P0ke`030=OG00oG00<0emL03ML00`3Ge`0?e`004=L00`3Ge`0<e`030=OG00oG00<0emL0
7=L701WG0`09e`@07mL400WG0`0Ie`L07]L00`3Ge`0?e`030=OG00cG00<0emL03mL0013G00<0emL0
3=L00`3Ge`0>e`030=OG01SG1@07e`L05ML200_G0`0Ie`<02mL201GG1`07e`D06]L00`3Ge`0>e`03
0=OG00cG00<0emL03mL0013G00<0emL02mL00`3Ge`0>e`030=OG01GG100Ce`D04]L300_G0`0Ce`<0
2mL301;G1@0Ce`@05mL00`3Ge`0=e`030=OG00cG00<0emL03mL0013G00<0emL02mL00`3Ge`0>e`03
0=OG01?G0P0Le`@04ML200cG100;e`@03=L2017G100Le`805ML00`3Ge`0>e`030=OG00_G00<0emL0
3mL0013G00<0emL02mL00`3Ge`0=e`030=OG01?G00<0emL08=L500kG1@0;e`/02mL500kG1@0Re`03
0=OG01?G00<0emL03ML00`3Ge`0;e`030=OG00oG000@e`030=OG00_G00<0emL03=L00`3Ge`0Be`80
:=L500kG100Ie`@03]L502SG0P0De`030=OG00cG00<0emL02mL00`3Ge`0?e`003mL00`3Ge`0;e`03
0=OG00cG00<0emL04ML202oG100>e`D03mL500kG100_e`804mL00`3Ge`0<e`030=OG00_G00<0emL0
3]L000oG00<0emL02mL00`3Ge`0;e`030=OG013G0P0ee`D03]L?00kG1@0ee`804]L00`3Ge`0;e`03
0=OG00_G00<0emL03]L000oG00<0emL02]L00`3Ge`0;e`030=OG013G00<0emL0>]L5027G1@0le`03
0=OG00oG00<0emL02mL00`3Ge`0;e`030=OG00kG000?e`030=OG00[G00<0emL02mL00`3Ge`0>e`80
6]L>01[G100Ie`@06]L>01[G0P0@e`030=OG00_G00<0emL02]L00`3Ge`0>e`003mL00`3Ge`09e`03
0=OG00_G00<0emL03]L00`3Ge`0Fe`@03]L601SG1@0?e`D06=L600kG100He`030=OG00gG00<0emL0
2mL00`3Ge`0:e`030=OG00kG000?e`030=OG00WG00<0emL02mL00`3Ge`0=e`030=OG01CG0`0He`P0
5ML?01GG200He`<05]L00`3Ge`0=e`030=OG00_G00<0emL02ML00`3Ge`0>e`003mL00`3Ge`09e`03
0=OG00[G00<0emL03ML00`3Ge`0Ae`@08mL702_G1`0Se`@04mL00`3Ge`0=e`030=OG00[G00<0emL0
2ML00`3Ge`0>e`003]L00`3Ge`0:e`030=OG00[G00<0emL03=L00`3Ge`0@e`80;]L701gG1`0^e`80
4]L00`3Ge`0<e`030=OG00[G00<0emL02]L00`3Ge`0=e`003]L00`3Ge`09e`030=OG00[G00<0emL0
2mL2017G0P0gead0=mL2017G0P0=e`030=OG00[G00<0emL02ML00`3Ge`0=e`003]L00`3Ge`09e`03
0=OG00WG00<0emL02mL00`3Ge`0?e`80SmL2017G00<0emL02]L00`3Ge`0:e`030=OG00WG00<0emL0
3ML000kG00<0emL02=L00`3Ge`0:e`030=OG00[G00<0emL03mL00`3Ge`0Fea`0:mLL01SG00<0emL0
3]L00`3Ge`0;e`030=OG00WG00<0emL02ML00`3Ge`0=e`003]L00`3Ge`08e`030=OG00WG00<0emL0
2mL00`3Ge`0=e`805ML401cG1`0Me`L07=L401GG0P0?e`030=OG00[G00<0emL02]L00`3Ge`08e`03
0=OG00gG000>e`030=OG00SG00<0emL02ML00`3Ge`0:e`030=OG00gG00<0emL04ML402OG7@0We`@0
4mL00`3Ge`0=e`030=OG00[G00<0emL02ML00`3Ge`08e`030=OG00gG000>e`030=OG00SG00<0emL0
2ML00`3Ge`09e`030=OG00cG0P0@e`@0LmL4013G0P0>e`030=OG00WG00<0emL02ML00`3Ge`08e`03
0=OG00gG000>e`030=OG00OG00<0emL02ML00`3Ge`0:e`030=OG00[G0P0@e`80NmL2013G0P0<e`03
0=OG00[G00<0emL02ML00`3Ge`07e`030=OG00gG000>e`030=OG00OG00<0emL02ML00`3Ge`09e`03
0=OG00[G00<0emL03]L201cG700?ea`07=L2013G00<0emL02]L00`3Ge`09e`030=OG00WG00<0emL0
1mL00`3Ge`0=e`003]L00`3Ge`07e`030=OG00SG00<0emL02ML00`3Ge`0:e`030=OG00gG0P0Ge`L0
7=L?01cG1`0Ge`803mL00`3Ge`0:e`030=OG00SG00<0emL02ML00`3Ge`07e`030=OG00gG000=e`03
0=OG00OG00<0emL02ML00`3Ge`08e`030=OG00[G00<0emL03=L201;G1`1Ee`L04]L200kG00<0emL0
2ML00`3Ge`09e`030=OG00SG00<0emL01mL00`3Ge`0=e`003ML00`3Ge`07e`030=OG00SG00<0emL0
2ML00`3Ge`09e`030=OG00_G0P0@e`@0HmL4013G0P0=e`030=OG00WG00<0emL02=L00`3Ge`09e`03
0=OG00OG00<0emL03=L000gG00<0emL01mL00`3Ge`08e`030=OG00SG00<0emL02ML00`3Ge`0;e`03
0=OG00kG0P0Pe`h03mL>023G0P0@e`030=OG00_G00<0emL02ML00`3Ge`08e`030=OG00SG00<0emL0
1mL00`3Ge`0<e`003ML00`3Ge`07e`030=OG00SG00<0emL01mL00`3Ge`09e`030=OG00[G0P0>e`<0
5=L>00kG3`0>e`h05=L300kG0P0<e`030=OG00WG00<0emL01mL00`3Ge`08e`030=OG00OG00<0emL0
3=L000gG00<0emL01mL00`3Ge`07e`030=OG00SG00<0emL02=L00`3Ge`09e`803ML3017G1P17e`H0
4ML300gG0P0;e`030=OG00SG00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL03=L000gG00<0emL0
1mL00`3Ge`07e`030=OG00OG00<0emL02=L00`3Ge`09e`030=OG00_G0P0Ae`<0DmL3017G0P0=e`03
0=OG00WG00<0emL02=L00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`0<e`003ML00`3Ge`07e`03
0=OG00KG00<0emL01mL00`3Ge`08e`030=OG00WG00<0emL02mL00`3Ge`0>e`<05mL[01OG0`0@e`03
0=OG00_G00<0emL02ML00`3Ge`07e`030=OG00OG00<0emL01mL00`3Ge`07e`030=OG00cG000=e`03
0=OG00KG00<0emL01mL00`3Ge`07e`030=OG00OG00<0emL02ML00`3Ge`0:e`803ML401?G1`0[e`L0
4mL400gG0P0<e`030=OG00SG00<0emL02=L00`3Ge`07e`030=OG00KG00<0emL01mL00`3Ge`0<e`00
3ML00`3Ge`06e`030=OG00KG00<0emL01mL00`3Ge`08e`030=OG00SG00<0emL02]L00`3Ge`0;e`80
4]L503WG1@0Be`803ML00`3Ge`0:e`030=OG00SG00<0emL01mL00`3Ge`07e`030=OG00OG00<0emL0
1]L00`3Ge`0<e`003=L00`3Ge`07e`030=OG00KG00<0emL01mL00`3Ge`07e`030=OG00SG00<0emL0
2ML200gG00<0emL03mL304?G0`0Ae`030=OG00_G0P0;e`030=OG00SG00<0emL01mL00`3Ge`07e`03
0=OG00KG00<0emL01mL00`3Ge`0;e`00omLQe`00omLQe`00\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-4.17456, -2.08001, 0.029091, \
0.029091}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1044, 722},
WindowMargins->{{85, Automatic}, {Automatic, 90}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 427, 8, 193, "Input"],
Cell[2135, 60, 916, 22, 432, "Input"],

Cell[CellGroupData[{
Cell[3076, 86, 30, 0, 32, "Input"],
Cell[3109, 88, 1523, 28, 192, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4669, 121, 50, 1, 32, "Input"],
Cell[4722, 124, 55, 1, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4814, 130, 93, 1, 32, "Input"],
Cell[4910, 133, 117, 2, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5064, 140, 60, 1, 32, "Input"],
Cell[5127, 143, 223, 3, 39, "Output"]
}, Open  ]],
Cell[5365, 149, 205, 11, 192, "Input"],
Cell[5573, 162, 296, 8, 152, "Input"],

Cell[CellGroupData[{
Cell[5894, 174, 234, 9, 172, "Input"],
Cell[6131, 185, 480800, 11946, 296, 442143, 11464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[486934, 12133, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[487108, 12141, 43, 0, 32, "Input"],
Cell[487154, 12143, 462420, 11719, 152, 442131, 11464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[949577, 23864, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[949751, 23872, 65, 0, 32, "Input"],
Cell[949819, 23874, 476964, 11938, 152, 442421, 11507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1426786, 35814, 137, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1426960, 35822, 244, 5, 72, "Input"],
Cell[1427207, 35829, 28541, 1037, 152, 13017, 840, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1455751, 36868, 137, 3, 31, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

