(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23891,        731]*)
(*NotebookOutlinePosition[     24522,        753]*)
(*  CellTagsIndexPosition[     24478,        749]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \( (*\ Code\ c56\ Toroidal\ wave\ guides, \ 
      see\ the\ \(Book : \ 
          Mathematical\ Methods\ of\ Physics\ and\ Engineering\ with\ \
Mathematica\n\(Ferdinand\ F . Cap, CRC - Press/Chapman\ and\ Hall, 2003, 
            ISBN\ 1584884029, 
            56\ Codes\ to\ be\ downloaded\ from\ www . crcpress . 
                com\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        RowBox[{\(Toroidal\ wave\ guides\ of\ arbitrary\ cross\ section\), 
          ",", " ", \(F . Cap\), ",", 
          "\[IndentingNewLine]", \(IEEE\ Trans . \ 
                Microwave\ Theory\ Tech\ MTT - 29\), ",", " ", 
          RowBox[{"Nr", " ", "10", " ", Cell["(1981),1053-1059"]}]}], " ", 
        "*)"}], "\n", \( (*\ 
        We\ start\ from\ Maxwell\ equations\ and\ introduce\ cylindrical\ \
coordinates\ *) \), "\n", \(<< Calculus`VectorAnalysis`\n
      $Packages\n
      SetCoordinates[Cylindrical]\)}]], "Input"],

Cell[BoxData[
    \({"Calculus`VectorAnalysis`", "Global`", "System`"}\)], "Output"],

Cell[BoxData[
    \(Cylindrical[Rr, Ttheta, Zz]\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(Clear[B, El, t1, t2]; 
    B[Rr_, Ttheta_, Zz_, t_] := {Br[Rr, Ttheta, Zz]*Exp[I*\[Omega]*t], 
        Bth[Rr, Ttheta, Zz]*Exp[I*\[Omega]*t], 
        Bz[Rr, Ttheta, Zz]*Exp[I*\[Omega]*t]}\), "\n", 
    \(\(El[Rr_, Ttheta_, Zz_, t_] := {Er[Rr, Ttheta, Zz]*Exp[I*\[Omega]*t], 
          Eth[Rr, Ttheta, Zz]*Exp[I*\[Omega]*t], 
          Ez[Rr, Ttheta, Zz]*Exp[I*\[Omega]*t]};\)\), "\n", 
    \(\(t1 = 
        Curl[El[Rr, Ttheta, Zz, t], Cylindrical[Rr, Ttheta, Zz]];\)\), "\n", 
    \(\(t2 = \(-D[B[Rr, Ttheta, Zz, t], t]\);\)\), "\[IndentingNewLine]", 
    \( (*\ The\ induction\ equation\ is\ \(now : \ t1\) = 
        t2\ *) \(Simplify[t1/Exp[I*\[Omega]*t]] == 
        Simplify[t2/Exp[I*\[Omega]*t]];\)\)}], "Input"],

Cell[BoxData[{
    \(Clear[t3, t4, t5, t6]; 
    t3 = Curl[B[Rr, Ttheta, Zz, t], Cylindrical[Rr, Ttheta, Zz]];\), "\n", 
    \(\(t4 = eps*D[El[Rr, Ttheta, Zz, t], t];\)\), "\n", 
    \( (*\ t3 = 
        t4\ is\ now\ the\ other\ Maxwell\ equation\ *) \(Simplify[
          t3/Exp[I*\[Omega]*t]] \[Equal] 
        Simplify[t4/Exp[I*\[Omega]*t]];\)\), "\n", 
    \(\(t5 = 
        Div[El[Rr, Ttheta, Zz, t]/Exp[I*\[Omega]*t], 
          Cylindrical[Rr, Ttheta, Zz]] (*\ vanishes\ *) ;\)\), "\n", 
    \(\(t6 = \ 
        Div[B[Rr, Ttheta, Zz, t]/Exp[I*\[Omega]*t], 
          Cylindrical[Rr, Ttheta, Zz]] (*\ vanishes\ *) ;\)\)}], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      Now\ we\ define\ a\ complex\ electromagnetic\ field\ *) \)\(\(Clear[
        F];\)\n
    \(F[Rr_, Ttheta_, Zz_] = 
        Simplify[\((El[Rr, Ttheta, Zz, t] - I*B[Rr, Ttheta, Zz, t])\)/
            Exp[I*\[Omega]*t]];\)\[IndentingNewLine] (*\ 
      Assuming\ azimuthal\  = \ toroidal\ symmetry, \ 
      we\ setup\ and\n
        redefine\ the\ components\ of\ F\ and\ continue\ calculations\ only\ \
using\ F\ *) \[IndentingNewLine]
    Clear[F, Fr, Fz, Fth]; 
    F[Rr_, Ttheta, Zz_] = {Fr[Rr, Zz]*Exp[I*m*Ttheta], 
        Fth[Rr, Zz]*Exp[I*m*Ttheta], 
        Fz[Rr, Zz]*Exp[I*m*Ttheta]};\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      Now\ we\ rewrite\ Maxwell' 
        s\ \(\(equations\)\(\ \)\(:\)\)\ *) \)\(\(Clear[t7, t7a, t8, 
        t8a];\)\[IndentingNewLine]
    \(t7 = 
        Curl[F[Rr, Ttheta, Zz], Cylindrical[Rr, Ttheta, Zz]] - \[Omega]*
            F[Rr, Ttheta, Zz];\)\n
    \(t7a = Simplify[t7/Exp[I*m*Ttheta]];\)\[IndentingNewLine]
    t8 = \ Div[F[Rr, Ttheta, Zz], Cylindrical[Rr, Ttheta, z]];  (*\ 
      vanishes\ *) t8a = Simplify[t8/Exp[I*m*Ttheta]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ As\ has\ been\ shown\ in\ the\ reference\ given\ above, \ 
      the\ solutions\ \(\(are\)\(\ \)\(:\)\)\ *) \)\(Clear[F1th, F1r, F1z, 
      F1]\[IndentingNewLine]
    \(F1th[Rr_, Ttheta_, Zz_] = 
        Exp[I*m*Ttheta]*
          Exp[I*k*Zz]*\((\(-m\)*k*
                BesselJ[m, Sqrt[\[Omega]^2 - k^2]*Rr]/
                  Rr - \[Omega]*\((Sqrt[\[Omega]^2 - k^2]*
                      BesselJ[m - 1, Sqrt[\[Omega]^2 - k^2]*Rr] - 
                    m*BesselJ[m, Sqrt[\[Omega]^2 - k^2]*Rr]/Rr)\))\);\)\n
    \(F1r[Rr_, Ttheta_, Zz_] = 
        Exp[I*m*Ttheta]*
          Exp[I*k*Zz]*\((m*k*BesselJ[m, Sqrt[\[Omega]^2 - k^2]*Rr]/Rr + 
              k*\((Sqrt[\[Omega]^2 - k^2]*
                      BesselJ[m - 1, Sqrt[\[Omega]^2 - k^2]*Rr] - 
                    m*BesselJ[m, Sqrt[\[Omega]^2 - k^2]*Rr]/Rr)\))\);\)\n
    \(F1z[Rr_, Ttheta_, Zz_] = 
        Exp[I*m*Ttheta]*Exp[I*k*Zz]*\((\[Omega]^2 - k^2)\)*
          BesselJ[m, Sqrt[\[Omega]^2 - k^2]*Rr];\)\n
    \(F1[Rr_, Ttheta, Zz_] = {F1r[Rr, Ttheta, Zz], F1th[Rr, Ttheta, Zz], 
          F1z[Rr, Ttheta, Zz]};\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      Now\ try\ to\ verify\ the\ solution\ \
*) \)\(\[IndentingNewLine]\)\(\(Simplify[
        Curl[F1[Rr, Ttheta, Zz], Cylindrical[Rr, Ttheta, Zz]] - \[Omega]*
            F1[Rr, Ttheta, Zz]];\)\n
    \(Simplify[%/\((Exp[I*m*Ttheta]*Exp[I*k*Zz])\)];\) (*\ 
      We\ see\ that\ the\ verification\ is\ not\ possibble\ since\ \
Mathematica\ does\ not\ understand\ the\ addition\ theorems\ for\ the\ Bessel\
\ functions . 
            From\ this\ solution\ the\ following\ magnetic\ field\ may\ be\ \
derived\ for\ \ axisymmetric\ modes\ m = 0*) \[IndentingNewLine]
    \ \ \ \ \(Clear\ [Bf, Br, Bz];\)\[IndentingNewLine]
    \(Bf[r_, 
          z_] = \[Omega]^2*\((b0*BesselJ[1, \[Omega]*r] + 
                c0*BesselY[1, \[Omega]*r])\) + \[Omega]*
            Sqrt[\[Omega]^2 - 
                k^2]*\((b1*BesselJ[1, Sqrt[\[Omega]^2 - k^2]*r] + 
                c1*BesselY[1, Sqrt[\[Omega]^2 - k^2]*r])\)*
            Cos[k*z];\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(Br[r_, z_] = 
        k*Sqrt[\[Omega]^2 - k^2]*\((b1*BesselJ[1, Sqrt[\[Omega]^2 - k^2]*r] + 
              c1*BesselY[1, Sqrt[\[Omega]^2 - k^2]*r])\)*
          Sin[k*z];\)\)], "Input"],

Cell[BoxData[
    \(\(Bz[r_, 
          z_] = \[Omega]^2*\((b0*BesselJ[1, \[Omega]*r] + 
                c0*BesselY[1, \[Omega]*r])\) + \((\[Omega]^2 - 
                k^2)\)*\((b1*BesselJ[0, Sqrt[\[Omega]^2 - k^2]*r] + 
                c1*BesselY[0, Sqrt[\[Omega]^2 - k^2]*r])\)*
            Cos[k*z];\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      Now\ the\ magnetic\ field\ lines\ can\ be\ obtained\ by\ integration\ \
of\ the\ following\ \(equations : \ 
            dr/Br\) = \(dz/Bz\ which\ gives\ Bf = \(const = 
            D . On\ the\ wall\ of\ the\ wave\ guide\)\), \ 
      the\ normal\ magnetic\ component\ must\ vanish . \ Thus, \ the\ wall, \ 
      equivalent\ to\ the\ cross\ section\ curve\ of\ the\ toroidal\ wave\ \
guide, \ is\ determined\ by\ Bf = 
        Da\ We\ may\ thus\ determine\ the\ cross\ section\ curve\ z \((r)\)\
*) \)\(\[IndentingNewLine]\)\(z[r_] = 
        ArcCos[\((Da - b0*r*\[Omega]^2*BesselJ[1, \[Omega]*r] - 
                  c0*\[Omega]^2*r*BesselY[1, \[Omega]*r])\)/\((\[Omega]*
                  Sqrt[\[Omega]^2 - 
                      k^2]*\((b1*r*BesselJ[1, Sqrt[\[Omega]^2 - k^2]*r] + 
                      c1*r*BesselY[1, Sqrt[\[Omega]^2 - k^2]*r])\))\)]/
          k;\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ For\ various\ values\ of\ the\ constants\ Da, c0, c1, b0, 
      b1, \ various\ cross\ sections\ can\ be\ produced . \ 
          For\ a\ given\ profile\ z \((r)\) 
        defined\ by\ a\ set\ of\ 5\ collocation\ points\ zi, ri, \ 
      the\ constants\ can\ be\ calculated . For\ the\ collocation\ method, \ 
      see\ the\ Book\ above . \ At\ the\ collocation\ points, \ 
      the\ function\ z \((r)\)\ vanishes . 
          One\ obtains\ a\ homogenous\ systems\ of\ linear\ equations . \ 
          Its\ determinant\ \ must\ vanish\ and\ gives\ \[Omega] . \ 
          One\ \(\(obtains\)\(:\)\)*) \)\(Clear[k, r, z];\)\)\)], "Input"],

Cell[BoxData[
    \(k = 1.5; r[1] = 8. ; z[1] = 0; r[2] = 9.8; z[2] = 0; r[3] = 8.6; 
    z[3] = 1.16; r[4] = 8.3; z[4] = 1.07; r[5] = 9. ; z[5] = 1.02; 
    Da = 3.8741; b0 = 0.7185; c0 = 0.4405; b1 = 1.3299; 
    c1 = 1.7971;  (*\ \[Omega]/2\ Pi\  = \ 8.57\ GHz*) Off[
      Plot::plnr]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl1 = 
      Plot[z[r], {r, 8. , 10.6}, DisplayFunction \[Rule] Identity]\)], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl2 = 
      Plot[\(-z[r]\), {r, 8. , 10.6}, 
        DisplayFunction \[Rule] Identity]\)], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[{pl1, pl2}, DisplayFunction \[Rule] $DisplayFunction]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.76301 0.465963 0.309017 0.250374 [
[.19767 .29652 -9 -9 ]
[.19767 .29652 9 0 ]
[.66363 .29652 -9 -9 ]
[.66363 .29652 9 0 ]
[.89661 .29652 -6 -9 ]
[.89661 .29652 6 0 ]
[.41815 .05864 -12 -4.5 ]
[.41815 .05864 0 4.5 ]
[.41815 .18383 -24 -4.5 ]
[.41815 .18383 0 4.5 ]
[.41815 .4342 -18 -4.5 ]
[.41815 .4342 0 4.5 ]
[.41815 .55939 -6 -4.5 ]
[.41815 .55939 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19767 .30902 m
.19767 .31527 L
s
[(8.5)] .19767 .29652 0 1 Mshowa
.66363 .30902 m
.66363 .31527 L
s
[(9.5)] .66363 .29652 0 1 Mshowa
.89661 .30902 m
.89661 .31527 L
s
[(10)] .89661 .29652 0 1 Mshowa
.125 Mabswid
.24426 .30902 m
.24426 .31277 L
s
.29086 .30902 m
.29086 .31277 L
s
.33746 .30902 m
.33746 .31277 L
s
.38405 .30902 m
.38405 .31277 L
s
.47725 .30902 m
.47725 .31277 L
s
.52384 .30902 m
.52384 .31277 L
s
.57044 .30902 m
.57044 .31277 L
s
.61703 .30902 m
.61703 .31277 L
s
.71023 .30902 m
.71023 .31277 L
s
.75682 .30902 m
.75682 .31277 L
s
.80342 .30902 m
.80342 .31277 L
s
.85002 .30902 m
.85002 .31277 L
s
.15107 .30902 m
.15107 .31277 L
s
.10448 .30902 m
.10448 .31277 L
s
.05788 .30902 m
.05788 .31277 L
s
.01128 .30902 m
.01128 .31277 L
s
.94321 .30902 m
.94321 .31277 L
s
.9898 .30902 m
.9898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.43065 .05864 m
.4369 .05864 L
s
[(-1)] .41815 .05864 1 0 Mshowa
.43065 .18383 m
.4369 .18383 L
s
[(-0.5)] .41815 .18383 1 0 Mshowa
.43065 .4342 m
.4369 .4342 L
s
[(0.5)] .41815 .4342 1 0 Mshowa
.43065 .55939 m
.4369 .55939 L
s
[(1)] .41815 .55939 1 0 Mshowa
.125 Mabswid
.43065 .08368 m
.4344 .08368 L
s
.43065 .10872 m
.4344 .10872 L
s
.43065 .13375 m
.4344 .13375 L
s
.43065 .15879 m
.4344 .15879 L
s
.43065 .20887 m
.4344 .20887 L
s
.43065 .2339 m
.4344 .2339 L
s
.43065 .25894 m
.4344 .25894 L
s
.43065 .28398 m
.4344 .28398 L
s
.43065 .33405 m
.4344 .33405 L
s
.43065 .35909 m
.4344 .35909 L
s
.43065 .38413 m
.4344 .38413 L
s
.43065 .40917 m
.4344 .40917 L
s
.43065 .45924 m
.4344 .45924 L
s
.43065 .48428 m
.4344 .48428 L
s
.43065 .50932 m
.4344 .50932 L
s
.43065 .53435 m
.4344 .53435 L
s
.43065 .03361 m
.4344 .03361 L
s
.43065 .00857 m
.4344 .00857 L
s
.43065 .58443 m
.4344 .58443 L
s
.43065 .60947 m
.4344 .60947 L
s
.25 Mabswid
.43065 0 m
.43065 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31286 m
.02382 .31454 L
.02538 .36841 L
.02626 .38267 L
.02708 .39349 L
.03021 .42417 L
.03305 .44432 L
.03941 .47684 L
.04302 .49071 L
.04634 .50156 L
.05384 .52131 L
.06045 .53485 L
.06743 .54642 L
.07984 .56215 L
.09143 .57296 L
.10414 .58185 L
.11777 .58891 L
.13071 .59384 L
.13754 .59589 L
.14479 .59772 L
.15111 .59905 L
.15809 .60027 L
.16396 .60111 L
.17039 .60185 L
.17664 .60242 L
.17982 .60264 L
.18323 .60285 L
.18642 .60301 L
.18932 .60312 L
.19224 .60321 L
.195 .60327 L
.19653 .60329 L
.1974 .6033 L
.19821 .60331 L
.19986 .60332 L
.20078 .60332 L
.20162 .60332 L
.20312 .60331 L
.20475 .6033 L
.2063 .60328 L
.20773 .60326 L
.21124 .60319 L
.21441 .6031 L
.22153 .60281 L
.22775 .60246 L
.23431 .60202 L
.24606 .60103 L
.27256 .598 L
.32093 .5903 L
.37242 .5799 L
Mistroke
.42198 .56837 L
.47466 .55488 L
.52542 .54088 L
.57424 .5266 L
.62618 .51053 L
.6762 .49413 L
.72429 .47735 L
.7755 .45807 L
.82478 .43755 L
.87718 .41227 L
.90334 .39734 L
.92765 .38098 L
.95113 .36068 L
.95789 .35318 L
.96427 .34471 L
.96999 .33485 L
.97156 .33141 L
.97322 .32707 L
.97464 .32228 L
.97619 .31241 L
Mfstroke
.02381 .30518 m
.02382 .30349 L
.02538 .24962 L
.02626 .23536 L
.02708 .22455 L
.03021 .19386 L
.03305 .17372 L
.03941 .14119 L
.04302 .12733 L
.04634 .11647 L
.05384 .09673 L
.06045 .08318 L
.06743 .07161 L
.07984 .05588 L
.09143 .04507 L
.10414 .03618 L
.11777 .02913 L
.13071 .02419 L
.13754 .02214 L
.14479 .02031 L
.15111 .01898 L
.15809 .01776 L
.16396 .01692 L
.17039 .01618 L
.17664 .01562 L
.17982 .01539 L
.18323 .01518 L
.18642 .01503 L
.18932 .01491 L
.19224 .01483 L
.195 .01477 L
.19653 .01474 L
.1974 .01473 L
.19821 .01473 L
.19986 .01472 L
.20078 .01472 L
.20162 .01472 L
.20312 .01472 L
.20475 .01473 L
.2063 .01475 L
.20773 .01477 L
.21124 .01485 L
.21441 .01494 L
.22153 .01523 L
.22775 .01557 L
.23431 .01602 L
.24606 .01701 L
.27256 .02003 L
.32093 .02774 L
.37242 .03813 L
Mistroke
.42198 .04966 L
.47466 .06316 L
.52542 .07715 L
.57424 .09143 L
.62618 .1075 L
.6762 .1239 L
.72429 .14068 L
.7755 .15996 L
.82478 .18048 L
.87718 .20577 L
.90334 .22069 L
.92765 .23706 L
.95113 .25735 L
.95789 .26485 L
.96427 .27332 L
.96999 .28318 L
.97156 .28663 L
.97322 .29097 L
.97464 .29575 L
.97619 .30562 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000000<`00IP00V@00
c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<
003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0<c<0IS<0VC<0c3<0oc<c03<c<c<c
IS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>IVC>Ic3>Ioc?<03?<<c?<IS?<VC?<
c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0ofHc06Hc<fHcIVHcVFHcc6HcofIV
06IV<fIVIVIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<IVK<VFK<c6K<ofKo06Ko<fKo
IVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITcc9TcoiUV09UV<iUVIYUVVIUV
c9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`0
0<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbI
I/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<coool00?l0<ol0I_l0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooooCM/_[aghUlI<FbZ>KNfVYPFjNGSol0VOl0
c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<
0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc?ooog_G00<0emL0X]L007_G00<0emL0X]L007_G
0P2Se`00NmL00`3Ge`2Re`00;mLK037G00<0emL0X]L002WG1P0Ke`L0:]L00`3Ge`2Re`009ML402SG
100Ve`030=OG0:;G000Se`80<=L5027G00<0emL0X]L002;G00<0emL0=ML601_G00<0emL0X]L0023G
0P0ne`L05=L20:?G000Ne`80AmL500oG00<0emL0X]L001cG0P1>e`@02mL00`3Ge`2Re`006]L205CG
1007e`030=OG0:;G000Ie`030=OG05SG1003e`030=OG0:;G000He`030=OG05SG10000mL000020:CG
000He`030=OG05[G00<0emL00mL40:7G000Ge`030=OG05_G00<0emL00mL30003e`000080WML001KG
00<0emL0E=L400CG00<0emL00mL00`3Ge`05e`@0VML001GG00<0emL0GML00`3Ge`03e`030=OG00WG
0`2Fe`005=L00`3Ge`1Le`<01ML00`3Ge`0<e`@0T]L001?G00<0emL0GmL00`3Ge`03e`030=OG013G
0`2?e`004]L00`3Ge`1Ve`030=OG01?G102;e`004]L00`3Ge`1Ve`030=OG01OG0`28e`004ML00`3G
e`1We`030=OG01[G1024e`004=L00`3Ge`1Xe`807mL3087G000@e`030=OG06SG00<0emL08ML407gG
000?e`030=OG06WG00<0emL09ML307[G000?e`030=OG06WG00<0emL0:=L407KG000?e`030=OG06WG
00<0emL0;=L407;G000>e`030=OG06[G00<0emL0<=L406kG000>e`030=OG06[G00<0emL0==L306_G
000>e`030=OG06[G0P0he`<0J=L000gG00<0emL0JmL00`3Ge`0je`80I]L000gG00<0emL0JmL00`3G
e`0le`<0HmL000gG00<0emL0JmL00`3Ge`0oe`<0H=L000cG00<0emL0K=L00`3Ge`12e`<0GML000cG
00<0emL0K=L00`3Ge`15e`<0F]L000cG00<0emL0K=L00`3Ge`18e`80F=L000_G00<0emL0KML204_G
0`1Ee`002mL00`3Ge`1]e`030=OG04gG0`1Be`002mL00`3Ge`1]e`030=OG053G0`1?e`002mL00`3G
e`1]e`030=OG05?G0`1<e`002mL00`3Ge`1]e`030=OG05KG0`19e`002]L00`3Ge`1^e`030=OG05WG
0`16e`002]L00`3Ge`1^e`030=OG05cG0`13e`002]L00`3Ge`1^e`80H=L3043G000:e`030=OG06kG
00<0emL0H]L203kG0009e`030=OG06oG00<0emL0I=L203cG0009e`030=OG06oG00<0emL0I]L303WG
0009e`030=OG06oG00<0emL0JML203OG0009e`030=OG05cG0P04e`030=OG00;G0`05e`030=OG06_G
0P0ee`002ML00`3Ge`1Ke`040=OG00_G00<0emL00]L00`3Ge`1]e`<0<]L000WG00<0emL0FmL0103G
e`0;e`030=OG00;G0`1`e`80<=L000WG00<0emL0EML400;G00@0emL02=L300GG00<0emL0L]L202kG
0009e`030=OG05_G00@0emL02=L00`3Ge`05e`030=OG07CG0P0/e`002ML00`3Ge`1Ke`040=OG00SG
00<0emL01ML00`3Ge`1fe`80:]L000WG00<0emL0G=L200WG1004e`030=OG07SG0P0Xe`002ML00`3G
e`1_e`030=OG07[G0P0Ve`002ML00`3Ge`1_e`030=OG07cG0P0Te`002ML00`3Ge`1_e`80OmL202;G
0008e`030=OG073G00<0emL0P=L00`3Ge`0Oe`002=L00`3Ge`1`e`030=OG087G00<0emL07]L000SG
00<0emL0L=L00`3Ge`22e`807]L000SG00<0emL0L=L00`3Ge`24e`030=OG01_G0008e`030=OG073G
00<0emL0QML201_G0008e`030=OG073G00<0emL0QmL201WG0007e`030=OG077G00<0emL0RML201OG
0007e`030=OG077G0P2<e`030=OG01CG0007e`030=OG077G00<0emL0S=L00`3Ge`0Ce`001mL00`3G
e`1ae`030=OG08gG00<0emL04]L000OG00<0emL0LML00`3Ge`2>e`804]L000OG00<0emL0LML00`3G
e`2@e`030=OG00oG0007e`030=OG077G00<0emL0TML00`3Ge`0>e`001mL00`3Ge`1ae`030=OG09;G
00<0emL03ML000OG00<0emL0LML209CG00<0emL03=L000OG00<0emL0LML00`3Ge`2De`030=OG00_G
0007e`030=OG077G00<0emL0UML00`3Ge`0:e`001mL00`3Ge`0We`801=L00`3Ge`02e`<0?=L00`3G
e`0he`<01=L00`3Ge`02e`<0=mL400?G0P0>e`030=OG00[G0007e`030=OG02KG00@0emL02mL00`3G
e`0ie`030=OG03_G00<0emL02ML00`3Ge`0fe`050=OGe`000]L00`3Ge`0<e`030=OG00WG0007e`03
0=OG02KG00@0emL02mL00`3Ge`0ie`030=OG03_G00<0emL02ML00`3Ge`0fe`050=OGe`000]L00`3G
e`0=e`030=OG00SG0007e`030=OG02OG0P09e`<0?=L00`3Ge`0ie`<02=L303WG00D0emOG0002e`03
0=OG00gG00<0emL02=L000OG00<0emL09]L0103Ge`08e`030=OG03cG0P0ie`040=OG00SG00<0emL0
>ML01@3GemL000;G00<0emL03]L00`3Ge`07e`001mL00`3Ge`0Ve`040=OG00SG00<0emL0?=L00`3G
e`0he`040=OG00SG00<0emL0=mL300?G00@0emL04=L00`3Ge`07e`001mL00`3Ge`0We`802ML403_G
00<0emL0>ML200WG100he`030=OG00;G0P0Ae`030=OG00OG0007e`030=OG077G00<0emL0VML00`3G
e`06e`001mL00`3Ge`1ae`030=OG09WG00<0emL01]L000OG00<0emL0LML00`3Ge`2Ie`030=OG00KG
0007e`030=OG077G00<0emL0VML00`3Ge`06e`00o`0P007G0003e`050=OGe`002=L00`3Ge`0;e`03
0=OG00[G00<0emL02]L00`3Ge`0;e`030=OG00[G00<0emL02]L00`3Ge`0;e`030=OG00[G00<0emL0
2]L00`3Ge`0;e`030=OG00[G00<0emL02mL00`3Ge`0:e`030=OG00[G00<0emL02mL00`3Ge`0:e`03
0=OG00[G00<0emL02mL00`3Ge`0:e`030=OG00KG00D0emOG0004e`001mL00`3Ge`0^e`030=OG043G
00<0emL0@=L00`3Ge`10e`030=OG01?G00<0emL01]L000OG00<0emL0LML00`3Ge`2Ie`030=OG00KG
0007e`030=OG077G00<0emL0VML00`3Ge`06e`001mL00`3Ge`1ae`030=OG09SG00<0emL01mL000OG
00<0emL0LML00`3Ge`2He`030=OG00OG0007e`030=OG077G0P2Ie`030=OG00OG0007e`030=OG077G
00<0emL0UmL00`3Ge`08e`001mL00`3Ge`1ae`030=OG09OG00<0emL02=L000OG00<0emL0LML00`3G
e`2Fe`030=OG00WG0007e`030=OG077G00<0emL0UML00`3Ge`0:e`001mL00`3Ge`1ae`030=OG09GG
00<0emL02]L000OG00<0emL0LML00`3Ge`2De`030=OG00_G0007e`030=OG077G0P2De`030=OG00cG
0007e`030=OG077G00<0emL0T]L00`3Ge`0=e`001mL00`3Ge`1ae`030=OG097G00<0emL03]L000OG
00<0emL0LML00`3Ge`2@e`030=OG00oG0007e`030=OG077G00<0emL0S]L201;G0007e`030=OG077G
00<0emL0SML00`3Ge`0Be`001mL00`3Ge`1ae`030=OG08cG00<0emL04mL000OG00<0emL0LML00`3G
e`2;e`030=OG01CG0007e`030=OG077G0P2:e`805mL000SG00<0emL0L=L00`3Ge`27e`806ML000SG
00<0emL0L=L00`3Ge`25e`806mL000SG00<0emL0L=L00`3Ge`24e`030=OG01_G0008e`030=OG073G
00<0emL0P]L201kG0008e`030=OG073G00<0emL0PML00`3Ge`0Ne`002=L00`3Ge`1`e`030=OG083G
00<0emL07mL000WG00<0emL0KmL207oG0P0Re`002ML00`3Ge`1_e`030=OG07cG0P0Te`002ML00`3G
e`1_e`030=OG07[G0P0Ve`002ML00`3Ge`1_e`030=OG07SG0P0Xe`002ML00`3Ge`1_e`030=OG07KG
0P0Ze`002ML00`3Ge`1Le`801=L00`3Ge`02e`<01ML00`3Ge`1de`80;=L000WG00<0emL0FmL0103G
e`0;e`030=OG00;G00<0emL0L]L202kG0009e`030=OG05_G00@0emL02mL00`3Ge`02e`<0L=L2033G
0009e`030=OG05_G00@0emL02=L300GG00<0emL0KML303;G0009e`030=OG05_G00@0emL02=L00`3G
e`05e`030=OG06_G0P0ee`002ML00`3Ge`1Ke`040=OG00SG00<0emL01ML00`3Ge`1Ye`80=mL000WG
00<0emL0G=L200WG1004e`030=OG06KG0`0ie`002ML00`3Ge`1_e`030=OG06CG0P0le`002]L00`3G
e`1^e`030=OG06;G0P0ne`002]L00`3Ge`1^e`80H=L3043G000:e`030=OG06kG00<0emL0G=L304?G
000:e`030=OG06kG00<0emL0FML304KG000;e`030=OG06gG00<0emL0E]L304WG000;e`030=OG06gG
00<0emL0DmL304cG000;e`030=OG06gG00<0emL0D=L304oG000;e`030=OG06gG00<0emL0CML305;G
000;e`030=OG06gG0P1<e`80EML000cG00<0emL0K=L00`3Ge`18e`<0EmL000cG00<0emL0K=L00`3G
e`15e`<0F]L000cG00<0emL0K=L00`3Ge`12e`<0GML000gG00<0emL0JmL00`3Ge`0oe`<0H=L000gG
00<0emL0JmL00`3Ge`0me`80HmL000gG00<0emL0JmL00`3Ge`0je`<0IML000kG00<0emL0J]L203SG
0`1Xe`003]L00`3Ge`1Ze`030=OG03CG0`1[e`003]L00`3Ge`1Ze`030=OG033G101^e`003mL00`3G
e`1Ye`030=OG02cG101be`003mL00`3Ge`1Ye`030=OG02SG101fe`003mL00`3Ge`1Ye`030=OG02GG
0`1je`004=L00`3Ge`1Xe`030=OG027G101me`004=L00`3Ge`1Xe`030=OG01kG0`21e`004ML00`3G
e`1We`806mL408CG000Be`030=OG06KG00<0emL05mL308SG000Be`030=OG06KG00<0emL04mL408_G
000Ce`030=OG06GG00<0emL04=L308oG000De`030=OG06CG00<0emL03=L409;G000Ee`030=OG05_G
1004e`030=OG00WG0`2Fe`005]L00`3Ge`1Le`030=OG00?G00<0emL01ML409WG000Ge`030=OG05_G
00<0emL00mL30003e`000080WML001SG00<0emL0F]L00`3Ge`03e`@0XML001SG00<0emL0F]L00`3G
e`040:CG000Ie`030=OG05OG1@03e`030=OG0:;G000Je`030=OG05?G10000mL0e`04e`030=OG0:;G
000Ke`80CmL400_G00<0emL0X]L001gG0P19e`@03mL00`3Ge`2Re`007mL204?G100Ce`80XmL0027G
0P0le`D05mL00`3Ge`2Re`008mL203CG1P0Le`030=OG0:;G000Ue`<0:]L702;G00<0emL0X]L002SG
1P0Me`L0:ML00`3Ge`2Re`00;]LM033G00<0emL0X]L007_G00<0emL0X]L007_G0P2Se`00NmL00`3G
e`2Re`00NmL00`3Ge`2Re`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {8.07311, -1.23423, \
0.00749622, 0.013951}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ 
      This\ graphics\ shows\ the\ cross\ section\ of\ the\ toroidal\ wave\ \
guide\ *) \)], "Input"]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{987, 795},
WindowMargins->{{134, Automatic}, {Automatic, 38}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 371, 7, 101, "Input"],

Cell[CellGroupData[{
Cell[2101, 61, 590, 12, 153, "Input"],
Cell[2694, 75, 84, 1, 31, "Output"],
Cell[2781, 78, 61, 1, 31, "Output"]
}, Open  ]],
Cell[2857, 82, 741, 13, 262, "Input"],
Cell[3601, 97, 637, 13, 193, "Input"],
Cell[4241, 112, 645, 14, 193, "Input"],
Cell[4889, 128, 492, 10, 124, "Input"],
Cell[5384, 140, 1124, 21, 331, "Input"],
Cell[6511, 163, 978, 19, 308, "Input"],
Cell[7492, 184, 207, 4, 78, "Input"],
Cell[7702, 190, 318, 6, 101, "Input"],
Cell[8023, 198, 924, 16, 262, "Input"],
Cell[8950, 216, 668, 10, 193, "Input"],
Cell[9621, 228, 301, 5, 101, "Input"],

Cell[CellGroupData[{
Cell[9947, 237, 106, 2, 32, "Input"],
Cell[10056, 241, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10223, 249, 120, 3, 32, "Input"],
Cell[10346, 254, 130, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10513, 262, 91, 1, 32, "Input"],
Cell[10607, 265, 13006, 453, 186, 5046, 350, "GraphicsData", "PostScript", \
"Graphics"],
Cell[23616, 720, 130, 3, 31, "Output"]
}, Open  ]],
Cell[23761, 726, 126, 3, 32, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

